Stripe.Params.AccountCapabilityUpdateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for account capability update.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountCapabilityUpdateParams{
  expand: [String.t()] | nil,
  requested: boolean() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • requested - To request a new capability for an account, pass true. There can be a delay before the requested capability becomes active. If the capability has any activation requirements, the response includes them in the requirements arrays.

If a capability isn't permanent, you can remove it from the account by passing false. Some capabilities are permanent after they've been requested. Attempting to remove a permanent capability returns an error.