Stripe.Params.AccountCreateParams.Capabilities.SofortPayments
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountCreateParams.Capabilities.SofortPayments{ requested: boolean() | nil }
requested- Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in therequirementsarrays.