Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountCreateParams.Groups{payments_pricing: map() | nil}
payments_pricing- The group the account is in to determine their payments pricing, and null if the account is on customized pricing. See the Platform pricing tool documentation for details.