Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountCreateParams.Settings{ bacs_debit_payments: Stripe.Params.AccountCreateParams.Settings.BacsDebitPayments.t() | nil, branding: Stripe.Params.AccountCreateParams.Settings.Branding.t() | nil, card_issuing: Stripe.Params.AccountCreateParams.Settings.CardIssuing.t() | nil, card_payments: Stripe.Params.AccountCreateParams.Settings.CardPayments.t() | nil, invoices: Stripe.Params.AccountCreateParams.Settings.Invoices.t() | nil, payments: Stripe.Params.AccountCreateParams.Settings.Payments.t() | nil, payouts: Stripe.Params.AccountCreateParams.Settings.Payouts.t() | nil, treasury: Stripe.Params.AccountCreateParams.Settings.Treasury.t() | nil }
bacs_debit_payments- Settings specific to Bacs Direct Debit.branding- Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.card_issuing- Settings specific to the account's use of the Card Issuing product.card_payments- Settings specific to card charging on the account.invoices- Settings specific to the account’s use of Invoices.payments- Settings that apply across payment methods for charging on the account.payouts- Settings specific to the account's payouts.treasury- Settings specific to the account's Treasury FinancialAccounts.