Stripe.Params.AccountCreateParams.Settings.CardPayments (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountCreateParams.Settings.CardPayments{
  decline_on:
    Stripe.Params.AccountCreateParams.Settings.CardPayments.DeclineOn.t() | nil,
  statement_descriptor_prefix: String.t() | nil,
  statement_descriptor_prefix_kana: map() | nil,
  statement_descriptor_prefix_kanji: map() | nil
}
  • decline_on - Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
  • statement_descriptor_prefix - The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic statement_descriptor specified on the charge. statement_descriptor_prefix is useful for maximizing descriptor space for the dynamic portion. Max length: 10.
  • statement_descriptor_prefix_kana - The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kana specified on the charge. statement_descriptor_prefix_kana is useful for maximizing descriptor space for the dynamic portion.
  • statement_descriptor_prefix_kanji - The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kanji specified on the charge. statement_descriptor_prefix_kanji is useful for maximizing descriptor space for the dynamic portion.