Stripe.Params.AccountCreateParams.Settings.CardPayments.DeclineOn (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountCreateParams.Settings.CardPayments.DeclineOn{
  avs_failure: boolean() | nil,
  cvc_failure: boolean() | nil
}
  • avs_failure - Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.
  • cvc_failure - Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.