Stripe.Params.AccountExternalAccountCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for account external account create.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountExternalAccountCreateParams{
  default_for_currency: boolean() | nil,
  expand: [String.t()] | nil,
  external_account: String.t(),
  metadata: %{required(String.t()) => String.t()} | nil
}
  • default_for_currency - When set to true, or if this is the first external account added in this currency, this account becomes the default external account for its currency.
  • expand - Specifies which fields in the response should be expanded.
  • external_account - A token, like the ones returned by Stripe.js or a dictionary containing a user's external account details (with the options shown below). Please refer to full documentation instead. Max length: 5000.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.