Parameters for account external account retrieve.
Summary
Types
@type t() :: %Stripe.Params.AccountExternalAccountRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for account external account retrieve.
@type t() :: %Stripe.Params.AccountExternalAccountRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.