Stripe.Params.AccountExternalAccountUpdateParams.Documents (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountExternalAccountUpdateParams.Documents{
  bank_account_ownership_verification:
    Stripe.Params.AccountExternalAccountUpdateParams.Documents.BankAccountOwnershipVerification.t()
    | nil
}
  • bank_account_ownership_verification - One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the bank account that displays the last 4 digits of the account number, either a statement or a check.