Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountPersonCreateParams.Documents{ company_authorization: Stripe.Params.AccountPersonCreateParams.Documents.CompanyAuthorization.t() | nil, passport: Stripe.Params.AccountPersonCreateParams.Documents.Passport.t() | nil, visa: Stripe.Params.AccountPersonCreateParams.Documents.Visa.t() | nil }
company_authorization- One or more documents that demonstrate proof that this person is authorized to represent the company.passport- One or more documents showing the person's passport page with photo and personal data.visa- One or more documents showing the person's visa required for living in the country where they are residing.