Stripe.Params.AccountPersonListParams.Relationship (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountPersonListParams.Relationship{
  authorizer: boolean() | nil,
  director: boolean() | nil,
  executive: boolean() | nil,
  legal_guardian: boolean() | nil,
  owner: boolean() | nil,
  representative: boolean() | nil
}
  • authorizer - A filter on the list of people returned based on whether these people are authorizers of the account's representative.
  • director - A filter on the list of people returned based on whether these people are directors of the account's company.
  • executive - A filter on the list of people returned based on whether these people are executives of the account's company.
  • legal_guardian - A filter on the list of people returned based on whether these people are legal guardians of the account's representative.
  • owner - A filter on the list of people returned based on whether these people are owners of the account's company.
  • representative - A filter on the list of people returned based on whether these people are the representative of the account's company.