Stripe.Params.AccountSessionCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for account session create.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountSessionCreateParams{
  account: String.t(),
  components: Stripe.Params.AccountSessionCreateParams.Components.t(),
  expand: [String.t()] | nil
}
  • account - The identifier of the account to create an Account Session for.
  • components - Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
  • expand - Specifies which fields in the response should be expanded.