Stripe.Params.AccountSessionCreateParams.Components.PaymentDetails.Features
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountSessionCreateParams.Components.PaymentDetails.Features{ capture_payments: boolean() | nil, destination_on_behalf_of_charge_management: boolean() | nil, dispute_management: boolean() | nil, refund_management: boolean() | nil }
capture_payments- Whether to allow capturing and cancelling payment intents. This istrueby default.destination_on_behalf_of_charge_management- Whether connected accounts can manage destination charges that are created on behalf of them. This isfalseby default.dispute_management- Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This istrueby default.refund_management- Whether sending refunds is enabled. This istrueby default.