Stripe.Params.AccountSessionCreateParams.Components.PaymentDisputes.Features (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.AccountSessionCreateParams.Components.PaymentDisputes.Features{
    destination_on_behalf_of_charge_management: boolean() | nil,
    dispute_management: boolean() | nil,
    refund_management: boolean() | nil
  }
  • destination_on_behalf_of_charge_management - Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.
  • dispute_management - Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is true by default.
  • refund_management - Whether sending refunds is enabled. This is true by default.