Stripe.Params.AccountSessionCreateParams.Components.Payouts.Features (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountSessionCreateParams.Components.Payouts.Features{
  disable_stripe_user_authentication: boolean() | nil,
  edit_payout_schedule: boolean() | nil,
  external_account_collection: boolean() | nil,
  instant_payouts: boolean() | nil,
  standard_payouts: boolean() | nil
}
  • disable_stripe_user_authentication - Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
  • edit_payout_schedule - Whether to allow payout schedule to be changed. Defaults to true when controller.losses.payments is set to stripe for the account, otherwise false.
  • external_account_collection - Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.
  • instant_payouts - Whether instant payouts are enabled for this component.
  • standard_payouts - Whether to allow creation of standard payouts. Defaults to true when controller.losses.payments is set to stripe for the account, otherwise false.