Stripe.Params.AccountUpdateParams.BusinessProfile.AnnualRevenue (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountUpdateParams.BusinessProfile.AnnualRevenue{
  amount: integer() | nil,
  currency: String.t() | nil,
  fiscal_year_end: String.t() | nil
}
  • amount - A non-negative integer representing the amount in the smallest currency unit.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • fiscal_year_end - The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023. Max length: 5000.