Stripe.Params.AccountUpdateParams.Company.RepresentativeDeclaration
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountUpdateParams.Company.RepresentativeDeclaration{ date: integer() | nil, ip: String.t() | nil, user_agent: String.t() | nil }
date- The Unix timestamp marking when the representative declaration attestation was made. Format: Unix timestamp.ip- The IP address from which the representative declaration attestation was made.user_agent- The user agent of the browser from which the representative declaration attestation was made. Max length: 5000.