Stripe.Params.AccountUpdateParams.Company.Verification.Document (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountUpdateParams.Company.Verification.Document{
  back: String.t() | nil,
  front: String.t() | nil
}
  • back - The back of a document returned by a file upload with a purpose value of additional_verification. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size. Max length: 500.
  • front - The front of a document returned by a file upload with a purpose value of additional_verification. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size. Max length: 500.