Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountUpdateParams.Documents{ bank_account_ownership_verification: Stripe.Params.AccountUpdateParams.Documents.BankAccountOwnershipVerification.t() | nil, company_license: Stripe.Params.AccountUpdateParams.Documents.CompanyLicense.t() | nil, company_memorandum_of_association: Stripe.Params.AccountUpdateParams.Documents.CompanyMemorandumOfAssociation.t() | nil, company_ministerial_decree: Stripe.Params.AccountUpdateParams.Documents.CompanyMinisterialDecree.t() | nil, company_registration_verification: Stripe.Params.AccountUpdateParams.Documents.CompanyRegistrationVerification.t() | nil, company_tax_id_verification: Stripe.Params.AccountUpdateParams.Documents.CompanyTaxIdVerification.t() | nil, proof_of_address: Stripe.Params.AccountUpdateParams.Documents.ProofOfAddress.t() | nil, proof_of_registration: Stripe.Params.AccountUpdateParams.Documents.ProofOfRegistration.t() | nil, proof_of_ultimate_beneficial_ownership: Stripe.Params.AccountUpdateParams.Documents.ProofOfUltimateBeneficialOwnership.t() | nil }
bank_account_ownership_verification- One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.company_license- One or more documents that demonstrate proof of a company's license to operate.company_memorandum_of_association- One or more documents showing the company's Memorandum of Association.company_ministerial_decree- (Certain countries only) One or more documents showing the ministerial decree legalizing the company's establishment.company_registration_verification- One or more documents that demonstrate proof of a company's registration with the appropriate local authorities.company_tax_id_verification- One or more documents that demonstrate proof of a company's tax ID.proof_of_address- One or more documents that demonstrate proof of address.proof_of_registration- One or more documents showing the company’s proof of registration with the national business registry.proof_of_ultimate_beneficial_ownership- One or more documents that demonstrate proof of ultimate beneficial ownership.