Stripe.Params.AccountUpdateParams.Documents.ProofOfUltimateBeneficialOwnership (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.AccountUpdateParams.Documents.ProofOfUltimateBeneficialOwnership{
    files: [String.t()] | nil,
    signer:
      Stripe.Params.AccountUpdateParams.Documents.ProofOfUltimateBeneficialOwnership.Signer.t()
      | nil
  }
  • files - One or more document ids returned by a file upload with a purpose value of account_requirement.
  • signer - Information regarding the person signing the document if applicable.