Stripe.Params.AccountUpdateParams.Individual.Relationship
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountUpdateParams.Individual.Relationship{ director: boolean() | nil, executive: boolean() | nil, owner: boolean() | nil, percent_ownership: map() | nil, title: String.t() | nil }
director- Whether the person is a director of the account's legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.executive- Whether the person has significant responsibility to control, manage, or direct the organization.owner- Whether the person is an owner of the account’s legal entity.percent_ownership- The percent owned by the person of the account's legal entity.title- The person's title (e.g., CEO, Support Engineer). Max length: 5000.