Stripe.Params.AccountUpdateParams.Individual.Verification.AdditionalDocument (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.AccountUpdateParams.Individual.Verification.AdditionalDocument{
    back: String.t() | nil,
    front: String.t() | nil
  }
  • back - The back of an ID returned by a file upload with a purpose value of identity_document. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size. Max length: 500.
  • front - The front of an ID returned by a file upload with a purpose value of identity_document. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size. Max length: 500.