Stripe.Params.AccountUpdateParams.Settings (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • bacs_debit_payments - Settings specific to Bacs Direct Debit payments.
  • branding - Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
  • card_issuing - Settings specific to the account's use of the Card Issuing product.
  • card_payments - Settings specific to card charging on the account.
  • invoices - Settings specific to the account's use of Invoices.
  • payments - Settings that apply across payment methods for charging on the account.
  • payouts - Settings specific to the account's payouts.
  • treasury - Settings specific to the account's Treasury FinancialAccounts.