Stripe.Params.AccountUpdateParams.Settings.Payments (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountUpdateParams.Settings.Payments{
  statement_descriptor: String.t() | nil,
  statement_descriptor_kana: String.t() | nil,
  statement_descriptor_kanji: String.t() | nil
}
  • statement_descriptor - The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don't set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the account settings documentation. Max length: 22.
  • statement_descriptor_kana - The Kana variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements. Max length: 22.
  • statement_descriptor_kanji - The Kanji variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements. Max length: 22.