Stripe.Params.AccountUpdateParams.Settings.Payouts (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountUpdateParams.Settings.Payouts{
  debit_negative_balances: boolean() | nil,
  schedule:
    Stripe.Params.AccountUpdateParams.Settings.Payouts.Schedule.t() | nil,
  statement_descriptor: String.t() | nil
}
  • debit_negative_balances - A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see Understanding Connect Account Balances.
  • schedule - Details on when funds from charges are available, and when they are paid out to an external account. For details, see our Setting Bank and Debit Card Payouts documentation.
  • statement_descriptor - The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard. Max length: 22.