Stripe.Params.AccountUpdateParams.TosAcceptance (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.AccountUpdateParams.TosAcceptance{
  date: integer() | nil,
  ip: String.t() | nil,
  service_agreement: String.t() | nil,
  user_agent: String.t() | nil
}
  • date - The Unix timestamp marking when the account representative accepted their service agreement. Format: Unix timestamp.
  • ip - The IP address from which the account representative accepted their service agreement.
  • service_agreement - The user's service agreement type. Max length: 5000.
  • user_agent - The user agent of the browser from which the account representative accepted their service agreement. Max length: 5000.