Stripe.Params.Apps.SecretFindParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for secret find.

Summary

Types

t()

@type t() :: %Stripe.Params.Apps.SecretFindParams{
  expand: [String.t()] | nil,
  name: String.t(),
  scope: Stripe.Params.Apps.SecretFindParams.Scope.t()
}
  • expand - Specifies which fields in the response should be expanded.
  • name - A name for the secret that's unique within the scope. Max length: 5000.
  • scope - Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.