Stripe.Params.BalanceSettingsUpdateParams.Payments.Payouts
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.BalanceSettingsUpdateParams.Payments.Payouts{ minimum_balance_by_currency: map() | nil, schedule: Stripe.Params.BalanceSettingsUpdateParams.Payments.Payouts.Schedule.t() | nil, statement_descriptor: String.t() | nil }
minimum_balance_by_currency- The minimum balance amount to retain per currency after automatic payouts. Only funds that exceed these amounts are paid out. Learn more about the minimum balances for automatic payouts.schedule- Details on when funds from charges are available, and when they are paid out to an external account. For details, see our Setting Bank and Debit Card Payouts documentation.statement_descriptor- The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard. Max length: 22.