Stripe.Params.BalanceSettingsUpdateParams.Payments.Payouts.Schedule (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.BalanceSettingsUpdateParams.Payments.Payouts.Schedule{
  interval: String.t() | nil,
  monthly_payout_days: [integer()] | nil,
  weekly_payout_days: [String.t()] | nil
}
  • interval - How frequently available funds are paid out. One of: daily, manual, weekly, or monthly. Default is daily. Possible values: daily, manual, monthly, weekly.
  • monthly_payout_days - The days of the month when available funds are paid out, specified as an array of numbers between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if interval is monthly.
  • weekly_payout_days - The days of the week when available funds are paid out, specified as an array, e.g., [monday, tuesday]. Required and applicable only if interval is weekly.