Stripe.Params.BalanceSettingsUpdateParams.Payments.SettlementTiming (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.BalanceSettingsUpdateParams.Payments.SettlementTiming{
  delay_days_override: map() | nil
}
  • delay_days_override - Change delay_days for this account, which determines the number of days charge funds are held before becoming available. The maximum value is 31. Passing an empty string to delay_days_override will return delay_days to the default, which is the lowest available value for the account. Learn more about controlling delay days.