Parameters for alert archive.
Summary
Types
@type t() :: %Stripe.Params.Billing.AlertArchiveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for alert archive.
@type t() :: %Stripe.Params.Billing.AlertArchiveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.