Stripe.Params.Billing.AlertCreateParams.UsageThreshold.Filters (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Billing.AlertCreateParams.UsageThreshold.Filters{
  customer: String.t() | nil,
  type: String.t() | nil
}
  • customer - Limit the scope to this usage alert only to this customer. Max length: 5000.
  • type - What type of filter is being applied to this usage alert. Possible values: customer.