Parameters for alert deactivate.
Summary
Types
@type t() :: %Stripe.Params.Billing.AlertDeactivateParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for alert deactivate.
@type t() :: %Stripe.Params.Billing.AlertDeactivateParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.