Parameters for alert retrieve.
Summary
Types
@type t() :: %Stripe.Params.Billing.AlertRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for alert retrieve.
@type t() :: %Stripe.Params.Billing.AlertRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.