Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams.Filter.ApplicabilityScope (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams.Filter.ApplicabilityScope{
    price_type: String.t() | nil,
    prices:
      [
        Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams.Filter.ApplicabilityScope.Prices.t()
      ]
      | nil
  }
  • price_type - The price type that credit grants can apply to. We currently only support the metered price type. Cannot be used in combination with prices. Possible values: metered.
  • prices - A list of prices that the credit grant can apply to. We currently only support the metered prices. Cannot be used in combination with price_type.