Stripe.Params.Billing.CreditGrantCreateParams.Amount.Monetary (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Billing.CreditGrantCreateParams.Amount.Monetary{
  currency: String.t() | nil,
  value: integer() | nil
}
  • currency - Three-letter ISO code for the currency of the value parameter. Format: ISO 4217 currency code.
  • value - A positive integer representing the amount of the credit grant.