Parameters for credit grant void grant.
Summary
Types
@type t() :: %Stripe.Params.Billing.CreditGrantVoidGrantParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for credit grant void grant.
@type t() :: %Stripe.Params.Billing.CreditGrantVoidGrantParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.