Stripe.Params.Billing.MeterCreateParams.CustomerMapping (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Billing.MeterCreateParams.CustomerMapping{
  event_payload_key: String.t() | nil,
  type: String.t() | nil
}
  • event_payload_key - The key in the meter event payload to use for mapping the event to a customer. Max length: 100.
  • type - The method for mapping a meter event to a customer. Must be by_id. Possible values: by_id.