Stripe.Params.Billing.MeterCreateParams.ValueSettings (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Billing.MeterCreateParams.ValueSettings{
  event_payload_key: String.t() | nil
}
  • event_payload_key - The key in the usage event payload to use as the value for this meter. For example, if the event payload contains usage on a bytes_used field, then set the event_payload_key to "bytes_used". Max length: 100.