Stripe.Params.Billing.MeterEventAdjustmentCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for meter event adjustment create.

Summary

Types

t()

@type t() :: %Stripe.Params.Billing.MeterEventAdjustmentCreateParams{
  cancel:
    Stripe.Params.Billing.MeterEventAdjustmentCreateParams.Cancel.t() | nil,
  event_name: String.t(),
  expand: [String.t()] | nil,
  type: String.t()
}
  • cancel - Specifies which event to cancel.
  • event_name - The name of the meter event. Corresponds with the event_name field on a meter. Max length: 100.
  • expand - Specifies which fields in the response should be expanded.
  • type - Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet. Possible values: cancel.