Stripe.Params.BillingPortal.ConfigurationCreateParams.Features
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.BillingPortal.ConfigurationCreateParams.Features{ customer_update: Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.CustomerUpdate.t() | nil, invoice_history: Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.InvoiceHistory.t() | nil, payment_method_update: Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.PaymentMethodUpdate.t() | nil, subscription_cancel: Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.SubscriptionCancel.t() | nil, subscription_update: Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.SubscriptionUpdate.t() | nil }
customer_update- Information about updating the customer details in the portal.invoice_history- Information about showing the billing history in the portal.payment_method_update- Information about updating payment methods in the portal.subscription_cancel- Information about canceling subscriptions in the portal.subscription_update- Information about updating subscriptions in the portal.