Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.SubscriptionUpdate (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.SubscriptionUpdate{
    billing_cycle_anchor: String.t() | nil,
    default_allowed_updates: map() | nil,
    enabled: boolean() | nil,
    products: map() | nil,
    proration_behavior: String.t() | nil,
    schedule_at_period_end:
      Stripe.Params.BillingPortal.ConfigurationCreateParams.Features.SubscriptionUpdate.ScheduleAtPeriodEnd.t()
      | nil,
    trial_update_behavior: String.t() | nil
  }
  • billing_cycle_anchor - Determines the value to use for the billing cycle anchor on subscription updates. Valid values are now or unchanged, and the default value is unchanged. Setting the value to now resets the subscription's billing cycle anchor to the current time (in UTC). For more information, see the billing cycle documentation. Possible values: now, unchanged.
  • default_allowed_updates - The types of subscription updates that are supported. When empty, subscriptions are not updateable.
  • enabled - Whether the feature is enabled.
  • products - The list of up to 10 products that support subscription updates.
  • proration_behavior - Determines how to handle prorations resulting from subscription updates. Valid values are none, create_prorations, and always_invoice. Possible values: always_invoice, create_prorations, none.
  • schedule_at_period_end - Setting to control when an update should be scheduled at the end of the period instead of applying immediately.
  • trial_update_behavior - The behavior when updating a subscription that is trialing. Possible values: continue_trial, end_trial.