Stripe.Params.BillingPortal.ConfigurationUpdateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for configuration update.

Summary

Types

t()

@type t() :: %Stripe.Params.BillingPortal.ConfigurationUpdateParams{
  active: boolean() | nil,
  business_profile:
    Stripe.Params.BillingPortal.ConfigurationUpdateParams.BusinessProfile.t()
    | nil,
  default_return_url: map() | nil,
  expand: [String.t()] | nil,
  features:
    Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.t() | nil,
  login_page:
    Stripe.Params.BillingPortal.ConfigurationUpdateParams.LoginPage.t() | nil,
  metadata: map() | nil,
  name: map() | nil
}
  • active - Whether the configuration is active and can be used to create portal sessions.
  • business_profile - The business information shown to customers in the portal.
  • default_return_url - The default URL to redirect customers to when they click on the portal's link to return to your website. This can be overriden when creating the session.
  • expand - Specifies which fields in the response should be expanded.
  • features - Information about the features available in the portal.
  • login_page - The hosted login page for this configuration. Learn more about the portal login page in our integration docs.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • name - The name of the configuration.