Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • customer_update - Information about updating the customer details in the portal.
  • invoice_history - Information about showing the billing history in the portal.
  • payment_method_update - Information about updating payment methods in the portal.
  • subscription_cancel - Information about canceling subscriptions in the portal.
  • subscription_update - Information about updating subscriptions in the portal.