Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.SubscriptionCancel (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.SubscriptionCancel{
    cancellation_reason:
      Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.SubscriptionCancel.CancellationReason.t()
      | nil,
    enabled: boolean() | nil,
    mode: String.t() | nil,
    proration_behavior: String.t() | nil
  }
  • cancellation_reason - Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer
  • enabled - Whether the feature is enabled.
  • mode - Whether to cancel subscriptions immediately or at the end of the billing period. Possible values: at_period_end, immediately.
  • proration_behavior - Whether to create prorations when canceling subscriptions. Possible values are none and create_prorations, which is only compatible with mode=immediately. Passing always_invoice will result in an error. No prorations are generated when canceling a subscription at the end of its natural billing period. Possible values: always_invoice, create_prorations, none.