Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.SubscriptionUpdate.ScheduleAtPeriodEnd (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.SubscriptionUpdate.ScheduleAtPeriodEnd{
    conditions: map() | nil
  }
  • conditions - List of conditions. When any condition is true, the update will be scheduled at the end of the current period.