Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm{
    discounts:
      [
        Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm.Discounts.t()
      ]
      | nil,
    items:
      [
        Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm.Items.t()
      ]
      | nil,
    subscription: String.t() | nil
  }
  • discounts - The coupon or promotion code to apply to this subscription update.
  • items - The subscription item to be updated through this flow. Currently, only up to one may be specified and subscriptions with multiple items are not updatable.
  • subscription - The ID of the subscription to be updated. Max length: 5000.