Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm.Discounts (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm.Discounts{
    coupon: String.t() | nil,
    promotion_code: String.t() | nil
  }
  • coupon - The ID of the coupon to apply to this subscription update. Max length: 5000.
  • promotion_code - The ID of a promotion code to apply to this subscription update. Max length: 5000.