Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm.Items (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.BillingPortal.SessionCreateParams.FlowData.SubscriptionUpdateConfirm.Items{
    id: String.t() | nil,
    price: String.t() | nil,
    quantity: integer() | nil
  }
  • id - The ID of the subscription item to be updated. Max length: 5000.
  • price - The price the customer should subscribe to through this flow. The price must also be included in the configuration's features.subscription_update.products. Max length: 5000.
  • quantity - Quantity for this item that the customer should subscribe to through this flow.