Stripe.Params.ChargeCaptureParams.TransferData (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.ChargeCaptureParams.TransferData{amount: integer() | nil}
  • amount - The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.