Stripe.Params.ChargeCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for charge create.

Summary

Types

t()

@type t() :: %Stripe.Params.ChargeCreateParams{
  amount: integer() | nil,
  application_fee: integer() | nil,
  application_fee_amount: integer() | nil,
  capture: boolean() | nil,
  currency: String.t() | nil,
  customer: String.t() | nil,
  description: String.t() | nil,
  destination: Stripe.Params.ChargeCreateParams.Destination.t() | nil,
  expand: [String.t()] | nil,
  metadata: map() | nil,
  on_behalf_of: String.t() | nil,
  radar_options: Stripe.Params.ChargeCreateParams.RadarOptions.t() | nil,
  receipt_email: String.t() | nil,
  shipping: Stripe.Params.ChargeCreateParams.Shipping.t() | nil,
  source: String.t() | nil,
  statement_descriptor: String.t() | nil,
  statement_descriptor_suffix: String.t() | nil,
  transfer_data: Stripe.Params.ChargeCreateParams.TransferData.t() | nil,
  transfer_group: String.t() | nil
}
  • amount - Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
  • application_fee
  • application_fee_amount - A fee in cents (or local equivalent) that will be applied to the charge and transferred to the application owner's Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees documentation.
  • capture - Whether to immediately capture the charge. Defaults to true. When false, the charge issues an authorization (or pre-authorization), and will need to be captured later. Uncaptured charges expire after a set number of days (7 by default). For more information, see the authorizing charges and settling later documentation.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • customer - The ID of an existing customer that will be charged in this request. Max length: 500.
  • description - An arbitrary string which you can attach to a Charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the description of the charge(s) that they are describing. Max length: 40000.
  • destination
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • on_behalf_of - The Stripe account ID for which these funds are intended. You can specify the business of record as the connected account using the on_behalf_of attribute on the charge. For details, see Creating Separate Charges and Transfers. Max length: 5000.
  • radar_options - Options to configure Radar. See Radar Session for more information.
  • receipt_email - The email address to which this charge's receipt will be sent. The receipt will not be sent until the charge is paid, and no receipts will be sent for test mode charges. If this charge is for a Customer, the email address specified here will override the customer's email address. If receipt_email is specified for a charge in live mode, a receipt will be sent regardless of your email settings.
  • shipping - Shipping information for the charge. Helps prevent fraud on charges for physical goods.
  • source - A payment source to be charged. This can be the ID of a card (i.e., credit or debit card), a bank account, a source, a token, or a connected account. For certain sources---namely, cards, bank accounts, and attached sources---you must also pass the ID of the associated customer. Max length: 5000.
  • statement_descriptor - For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

For a card charge, this value is ignored unless you don't specify a statement_descriptor_suffix, in which case this value is used as the suffix. Max length: 22.

  • statement_descriptor_suffix - Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the account's statement descriptor. Max length: 22.
  • transfer_data - An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.
  • transfer_group - A string that identifies this transaction as part of a group. For details, see Grouping transactions.