Stripe.Params.ChargeCreateParams.Destination (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.ChargeCreateParams.Destination{
  account: String.t() | nil,
  amount: integer() | nil
}
  • account - ID of an existing, connected Stripe account. Max length: 5000.
  • amount - The amount to transfer to the destination account without creating an Application Fee object. Cannot be combined with the application_fee parameter. Must be less than or equal to the charge amount.