Parameters for charge update.
Summary
Types
@type t() :: %Stripe.Params.ChargeUpdateParams{ customer: String.t() | nil, description: String.t() | nil, expand: [String.t()] | nil, fraud_details: Stripe.Params.ChargeUpdateParams.FraudDetails.t() | nil, metadata: map() | nil, receipt_email: String.t() | nil, shipping: Stripe.Params.ChargeUpdateParams.Shipping.t() | nil, transfer_group: String.t() | nil }
customer- The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge. Max length: 5000.description- An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include thedescriptionof the charge(s) that they are describing. Max length: 40000.expand- Specifies which fields in the response should be expanded.fraud_details- A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include auser_reportkey with a value offraudulent. If you believe a charge is safe, include auser_reportkey with a value ofsafe. Stripe will use the information you send to improve our fraud detection algorithms.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.receipt_email- This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address. Max length: 5000.shipping- Shipping information for the charge. Helps prevent fraud on charges for physical goods.transfer_group- A string that identifies this transaction as part of a group.transfer_groupmay only be provided if it has not been set. See the Connect documentation for details.