Stripe.Params.Checkout.SessionCreateParams.AfterExpiration.Recovery (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Checkout.SessionCreateParams.AfterExpiration.Recovery{
  allow_promotion_codes: boolean() | nil,
  enabled: boolean() | nil
}
  • allow_promotion_codes - Enables user redeemable promotion codes on the recovered Checkout Sessions. Defaults to false
  • enabled - If true, a recovery URL will be generated to recover this Checkout Session if it expires before a successful transaction is completed. It will be attached to the Checkout Session object upon expiration.