Stripe.Params.Checkout.SessionCreateParams.ConsentCollection (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Checkout.SessionCreateParams.ConsentCollection{
  payment_method_reuse_agreement:
    Stripe.Params.Checkout.SessionCreateParams.ConsentCollection.PaymentMethodReuseAgreement.t()
    | nil,
  promotions: String.t() | nil,
  terms_of_service: String.t() | nil
}
  • payment_method_reuse_agreement - Determines the display of payment method reuse agreement text in the UI. If set to hidden, it will hide legal text related to the reuse of a payment method.
  • promotions - If set to auto, enables the collection of customer consent for promotional communications. The Checkout Session will determine whether to display an option to opt into promotional communication from the merchant depending on the customer's locale. Only available to US merchants. Possible values: auto, none.
  • terms_of_service - If set to required, it requires customers to check a terms of service checkbox before being able to pay. There must be a valid terms of service URL set in your Dashboard settings. Possible values: none, required.