Stripe.Params.Checkout.SessionCreateParams.CustomFields.Dropdown.Options
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.CustomFields.Dropdown.Options{ label: String.t() | nil, value: String.t() | nil }
label- The label for the option, displayed to the customer. Up to 100 characters. Max length: 100.value- The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters. Max length: 100.