Stripe.Params.Checkout.SessionCreateParams.InvoiceCreation.InvoiceData (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Checkout.SessionCreateParams.InvoiceCreation.InvoiceData{
  account_tax_ids: map() | nil,
  custom_fields: map() | nil,
  description: String.t() | nil,
  footer: String.t() | nil,
  issuer:
    Stripe.Params.Checkout.SessionCreateParams.InvoiceCreation.InvoiceData.Issuer.t()
    | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  rendering_options: map() | nil
}
  • account_tax_ids - The account tax IDs associated with the invoice.
  • custom_fields - Default custom fields to be displayed on invoices for this customer.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 1500.
  • footer - Default footer to be displayed on invoices for this customer. Max length: 5000.
  • issuer - The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • rendering_options - Default options for invoice PDF rendering for this customer.