Stripe.Params.Checkout.SessionCreateParams.LineItems.AdjustableQuantity
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.LineItems.AdjustableQuantity{ enabled: boolean() | nil, maximum: integer() | nil, minimum: integer() | nil }
enabled- Set to true if the quantity can be adjusted to any non-negative integer.maximum- The maximum quantity the customer can purchase for the Checkout Session. By default this value is 99. You can specify a value up to 999999.minimum- The minimum quantity the customer must purchase for the Checkout Session. By default this value is 0.