Stripe.Params.Checkout.SessionCreateParams.PaymentIntentData.Shipping (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Checkout.SessionCreateParams.PaymentIntentData.Shipping{
  address:
    Stripe.Params.Checkout.SessionCreateParams.PaymentIntentData.Shipping.Address.t()
    | nil,
  carrier: String.t() | nil,
  name: String.t() | nil,
  phone: String.t() | nil,
  tracking_number: String.t() | nil
}
  • address - Shipping address.
  • carrier - The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. Max length: 5000.
  • name - Recipient name. Max length: 5000.
  • phone - Recipient phone (including extension). Max length: 5000.
  • tracking_number - The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas. Max length: 5000.