Stripe.Params.Checkout.SessionCreateParams.PaymentIntentData.TransferData
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.PaymentIntentData.TransferData{ amount: integer() | nil, destination: String.t() | nil }
amount- The amount that will be transferred automatically when a charge succeeds.destination- If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge'stransferfield.