Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions{
  acss_debit:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.AcssDebit.t()
    | nil,
  affirm:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Affirm.t()
    | nil,
  afterpay_clearpay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.AfterpayClearpay.t()
    | nil,
  alipay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Alipay.t()
    | nil,
  alma:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Alma.t()
    | nil,
  amazon_pay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.AmazonPay.t()
    | nil,
  au_becs_debit:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.AuBecsDebit.t()
    | nil,
  bacs_debit:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.BacsDebit.t()
    | nil,
  bancontact:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Bancontact.t()
    | nil,
  billie:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Billie.t()
    | nil,
  boleto:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Boleto.t()
    | nil,
  card:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Card.t()
    | nil,
  cashapp:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Cashapp.t()
    | nil,
  customer_balance:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.CustomerBalance.t()
    | nil,
  demo_pay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.DemoPay.t()
    | nil,
  eps:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Eps.t()
    | nil,
  fpx:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Fpx.t()
    | nil,
  giropay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Giropay.t()
    | nil,
  grabpay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Grabpay.t()
    | nil,
  ideal:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Ideal.t()
    | nil,
  kakao_pay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.KakaoPay.t()
    | nil,
  klarna:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Klarna.t()
    | nil,
  konbini:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Konbini.t()
    | nil,
  kr_card:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.KrCard.t()
    | nil,
  link:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Link.t()
    | nil,
  mobilepay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Mobilepay.t()
    | nil,
  multibanco:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Multibanco.t()
    | nil,
  naver_pay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.NaverPay.t()
    | nil,
  oxxo:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Oxxo.t()
    | nil,
  p24:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.P24.t()
    | nil,
  pay_by_bank: map() | nil,
  payco:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Payco.t()
    | nil,
  paynow:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Paynow.t()
    | nil,
  paypal:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Paypal.t()
    | nil,
  payto:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Payto.t()
    | nil,
  pix:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Pix.t()
    | nil,
  revolut_pay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.RevolutPay.t()
    | nil,
  samsung_pay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.SamsungPay.t()
    | nil,
  satispay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Satispay.t()
    | nil,
  sepa_debit:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.SepaDebit.t()
    | nil,
  sofort:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Sofort.t()
    | nil,
  swish:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Swish.t()
    | nil,
  twint:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Twint.t()
    | nil,
  us_bank_account:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.UsBankAccount.t()
    | nil,
  wechat_pay:
    Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.WechatPay.t()
    | nil
}
  • acss_debit - contains details about the ACSS Debit payment method options. You can't set this parameter if ui_mode is custom.
  • affirm - contains details about the Affirm payment method options.
  • afterpay_clearpay - contains details about the Afterpay Clearpay payment method options.
  • alipay - contains details about the Alipay payment method options.
  • alma - contains details about the Alma payment method options.
  • amazon_pay - contains details about the AmazonPay payment method options.
  • au_becs_debit - contains details about the AU Becs Debit payment method options.
  • bacs_debit - contains details about the Bacs Debit payment method options.
  • bancontact - contains details about the Bancontact payment method options.
  • billie - contains details about the Billie payment method options.
  • boleto - contains details about the Boleto payment method options.
  • card - contains details about the Card payment method options.
  • cashapp - contains details about the Cashapp Pay payment method options.
  • customer_balance - contains details about the Customer Balance payment method options.
  • demo_pay - contains details about the DemoPay payment method options.
  • eps - contains details about the EPS payment method options.
  • fpx - contains details about the FPX payment method options.
  • giropay - contains details about the Giropay payment method options.
  • grabpay - contains details about the Grabpay payment method options.
  • ideal - contains details about the Ideal payment method options.
  • kakao_pay - contains details about the Kakao Pay payment method options.
  • klarna - contains details about the Klarna payment method options.
  • konbini - contains details about the Konbini payment method options.
  • kr_card - contains details about the Korean card payment method options.
  • link - contains details about the Link payment method options.
  • mobilepay - contains details about the Mobilepay payment method options.
  • multibanco - contains details about the Multibanco payment method options.
  • naver_pay - contains details about the Naver Pay payment method options.
  • oxxo - contains details about the OXXO payment method options.
  • p24 - contains details about the P24 payment method options.
  • pay_by_bank - contains details about the Pay By Bank payment method options.
  • payco - contains details about the PAYCO payment method options.
  • paynow - contains details about the PayNow payment method options.
  • paypal - contains details about the PayPal payment method options.
  • payto - contains details about the PayTo payment method options.
  • pix - contains details about the Pix payment method options.
  • revolut_pay - contains details about the RevolutPay payment method options.
  • samsung_pay - contains details about the Samsung Pay payment method options.
  • satispay - contains details about the Satispay payment method options.
  • sepa_debit - contains details about the Sepa Debit payment method options.
  • sofort - contains details about the Sofort payment method options.
  • swish - contains details about the Swish payment method options.
  • twint - contains details about the TWINT payment method options.
  • us_bank_account - contains details about the Us Bank Account payment method options.
  • wechat_pay - contains details about the WeChat Pay payment method options.