Stripe.Params.Checkout.SessionCreateParams.ShippingOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Checkout.SessionCreateParams.ShippingOptions{
  shipping_rate: String.t() | nil,
  shipping_rate_data:
    Stripe.Params.Checkout.SessionCreateParams.ShippingOptions.ShippingRateData.t()
    | nil
}
  • shipping_rate - The ID of the Shipping Rate to use for this shipping option. Max length: 5000.
  • shipping_rate_data - Parameters to be passed to Shipping Rate creation for this shipping option.