Stripe.Params.Checkout.SessionCreateParams.SubscriptionData.TrialSettings.EndBehavior (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.Checkout.SessionCreateParams.SubscriptionData.TrialSettings.EndBehavior{
    missing_payment_method: String.t() | nil
  }
  • missing_payment_method - Indicates how the subscription should change when the trial ends if the user did not provide a payment method. Possible values: cancel, create_invoice, pause.