Stripe.Params.Checkout.SessionCreateParams.WalletOptions.Link (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Checkout.SessionCreateParams.WalletOptions.Link{
  display: String.t() | nil
}
  • display - Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the auto behavior, and it is the default choice. Possible values: auto, never.