Parameters for session expire.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionExpireParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for session expire.
@type t() :: %Stripe.Params.Checkout.SessionExpireParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.