Parameters for order cancel.
Summary
Types
@type t() :: %Stripe.Params.Climate.OrderCancelParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for order cancel.
@type t() :: %Stripe.Params.Climate.OrderCancelParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.