Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.CouponCreateParams.CurrencyOptions{ amount_off: integer() | nil }
amount_off- A positive integer representing the amount to subtract from an invoice total.
Nested parameters.
@type t() :: %Stripe.Params.CouponCreateParams.CurrencyOptions{ amount_off: integer() | nil }
amount_off - A positive integer representing the amount to subtract from an invoice total.