Stripe.Params.CreditNoteCreateParams.Lines (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.CreditNoteCreateParams.Lines{
  amount: integer() | nil,
  description: String.t() | nil,
  invoice_line_item: String.t() | nil,
  quantity: integer() | nil,
  tax_amounts: map() | nil,
  tax_rates: map() | nil,
  type: String.t() | nil,
  unit_amount: integer() | nil,
  unit_amount_decimal: String.t() | nil
}
  • amount - The line item amount to credit. Only valid when type is invoice_line_item. If invoice is set up with automatic_tax[enabled]=true, this amount is tax exclusive
  • description - The description of the credit note line item. Only valid when the type is custom_line_item. Max length: 5000.
  • invoice_line_item - The invoice line item to credit. Only valid when the type is invoice_line_item. Max length: 5000.
  • quantity - The line item quantity to credit.
  • tax_amounts - A list of up to 10 tax amounts for the credit note line item. Cannot be mixed with tax_rates.
  • tax_rates - The tax rates which apply to the credit note line item. Only valid when the type is custom_line_item and cannot be mixed with tax_amounts.
  • type - Type of the credit note line item, one of invoice_line_item or custom_line_item Possible values: custom_line_item, invoice_line_item.
  • unit_amount - The integer unit amount in cents (or local equivalent) of the credit note line item. This unit_amount will be multiplied by the quantity to get the full amount to credit for this line item. Only valid when type is custom_line_item.
  • unit_amount_decimal - Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set. Format: decimal string.