Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.CreditNoteCreateParams.ShippingCost{ shipping_rate: String.t() | nil }
shipping_rate- The ID of the shipping rate to use for this order. Max length: 5000.
Nested parameters.
@type t() :: %Stripe.Params.CreditNoteCreateParams.ShippingCost{ shipping_rate: String.t() | nil }
shipping_rate - The ID of the shipping rate to use for this order. Max length: 5000.