Stripe.Params.CreditNotePreviewLinesPreviewLinesParams.Refunds.PaymentRecordRefund (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.CreditNotePreviewLinesPreviewLinesParams.Refunds.PaymentRecordRefund{
    payment_record: String.t() | nil,
    refund_group: String.t() | nil
  }
  • payment_record - The ID of the PaymentRecord with the refund to link to this credit note. Max length: 5000.
  • refund_group - The PaymentRecord refund group to link to this credit note. For refunds processed off-Stripe, this will correspond to the processor_details.custom.refund_reference field provided when reporting the refund on the PaymentRecord. Max length: 5000.