Stripe.Params.CreditNotePreviewParams.Refunds.PaymentRecordRefund
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.CreditNotePreviewParams.Refunds.PaymentRecordRefund{ payment_record: String.t() | nil, refund_group: String.t() | nil }
payment_record- The ID of the PaymentRecord with the refund to link to this credit note. Max length: 5000.refund_group- The PaymentRecord refund group to link to this credit note. For refunds processed off-Stripe, this will correspond to theprocessor_details.custom.refund_referencefield provided when reporting the refund on the PaymentRecord. Max length: 5000.