Parameters for credit note void credit note.
Summary
Types
@type t() :: %Stripe.Params.CreditNoteVoidCreditNoteParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for credit note void credit note.
@type t() :: %Stripe.Params.CreditNoteVoidCreditNoteParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.