Stripe.Params.CustomerBalanceTransactionCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for customer balance transaction create.

Summary

Types

t()

@type t() :: %Stripe.Params.CustomerBalanceTransactionCreateParams{
  amount: integer(),
  currency: String.t(),
  description: String.t() | nil,
  expand: [String.t()] | nil,
  metadata: map() | nil
}
  • amount - The integer amount in cents (or local equivalent) to apply to the customer's credit balance.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Specifies the invoice_credit_balance that this transaction will apply to. If the customer's currency is not set, it will be updated to this value. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 350.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.