Stripe.Params.CustomerPaymentSourceVerifyParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for customer payment source verify.

Summary

Types

t()

@type t() :: %Stripe.Params.CustomerPaymentSourceVerifyParams{
  amounts: [integer()] | nil,
  expand: [String.t()] | nil
}
  • amounts - Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
  • expand - Specifies which fields in the response should be expanded.