Parameters for customer retrieve.
Summary
Types
@type t() :: %Stripe.Params.CustomerRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for customer retrieve.
@type t() :: %Stripe.Params.CustomerRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.