Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.CustomerUpdateParams.InvoiceSettings{ custom_fields: map() | nil, default_payment_method: String.t() | nil, footer: String.t() | nil, rendering_options: map() | nil }
custom_fields- The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.default_payment_method- ID of a payment method that's attached to the customer, to be used as the customer's default payment method for subscriptions and invoices. Max length: 5000.footer- Default footer to be displayed on invoices for this customer. Max length: 5000.rendering_options- Default options for invoice PDF rendering for this customer.