Parameters for ephemeral key create.
Summary
Types
@type t() :: %Stripe.Params.EphemeralKeyCreateParams{ customer: String.t() | nil, expand: [String.t()] | nil, issuing_card: String.t() | nil, nonce: String.t() | nil, verification_session: String.t() | nil }
customer- The ID of the Customer you'd like to modify using the resulting ephemeral key. Max length: 5000.expand- Specifies which fields in the response should be expanded.issuing_card- The ID of the Issuing Card you'd like to access using the resulting ephemeral key. Max length: 5000.nonce- A single-use token, created by Stripe.js, used for creating ephemeral keys for Issuing Cards without exchanging sensitive information. Max length: 5000.verification_session- The ID of the Identity VerificationSession you'd like to access using the resulting ephemeral key Max length: 5000.