Parameters for file link create.
Summary
Types
@type t() :: %Stripe.Params.FileLinkCreateParams{ expand: [String.t()] | nil, expires_at: integer() | nil, file: String.t(), metadata: map() | nil }
expand- Specifies which fields in the response should be expanded.expires_at- The link isn't usable after this future timestamp. Format: Unix timestamp.file- The ID of the file. The file'spurposemust be one of the following:business_icon,business_logo,customer_signature,dispute_evidence,finance_report_run,financial_account_statement,identity_document_downloadable,issuing_regulatory_reporting,pci_document,selfie,sigma_scheduled_query,tax_document_user_upload,terminal_android_apk, orterminal_reader_splashscreen. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.