Stripe.Params.FinancialConnections.AccountListParams.AccountHolder (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.FinancialConnections.AccountListParams.AccountHolder{
  account: String.t() | nil,
  customer: String.t() | nil,
  customer_account: String.t() | nil
}
  • account - The ID of the Stripe account whose accounts you will retrieve. Max length: 5000.
  • customer - The ID of the Stripe customer whose accounts you will retrieve. Max length: 5000.
  • customer_account - The ID of the Account representing a customer whose accounts you will retrieve. Max length: 5000.