Stripe.Params.FinancialConnections.AccountUnsubscribeParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for account unsubscribe.

Summary

Types

t()

@type t() :: %Stripe.Params.FinancialConnections.AccountUnsubscribeParams{
  expand: [String.t()] | nil,
  features: [String.t()]
}
  • expand - Specifies which fields in the response should be expanded.
  • features - The list of account features from which you would like to unsubscribe.