Stripe.Params.Forwarding.RequestListParams.Created (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Forwarding.RequestListParams.Created{
  gt: integer() | nil,
  gte: integer() | nil,
  lt: integer() | nil,
  lte: integer() | nil
}
  • gt - Return results where the created field is greater than this value.
  • gte - Return results where the created field is greater than or equal to this value.
  • lt - Return results where the created field is less than this value.
  • lte - Return results where the created field is less than or equal to this value.