Stripe.Params.Identity.VerificationSessionCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for verification session create.

Summary

Types

t()

@type t() :: %Stripe.Params.Identity.VerificationSessionCreateParams{
  client_reference_id: String.t() | nil,
  expand: [String.t()] | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  options:
    Stripe.Params.Identity.VerificationSessionCreateParams.Options.t() | nil,
  provided_details:
    Stripe.Params.Identity.VerificationSessionCreateParams.ProvidedDetails.t()
    | nil,
  related_customer: String.t() | nil,
  related_customer_account: String.t() | nil,
  related_person:
    Stripe.Params.Identity.VerificationSessionCreateParams.RelatedPerson.t()
    | nil,
  return_url: String.t() | nil,
  type: String.t() | nil,
  verification_flow: String.t() | nil
}
  • client_reference_id - A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • options - A set of options for the session’s verification checks.
  • provided_details - Details provided about the user being verified. These details may be shown to the user.
  • related_customer - Customer ID Max length: 5000.
  • related_customer_account - The ID of the Account representing a customer. Max length: 5000.
  • related_person - Tokens referencing a Person resource and it's associated account.
  • return_url - The URL that the user will be redirected to upon completing the verification flow.
  • type - The type of verification check to be performed. You must provide a type if not passing verification_flow. Possible values: document, id_number.
  • verification_flow - The ID of a verification flow from the Dashboard. See https://docs.stripe.com/identity/verification-flows. Max length: 5000.