Stripe.Params.Identity.VerificationSessionCreateParams.RelatedPerson (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Identity.VerificationSessionCreateParams.RelatedPerson{
  account: String.t() | nil,
  person: String.t() | nil
}
  • account - A token representing a connected account. If provided, the person parameter is also required and must be associated with the account. Max length: 5000.
  • person - A token referencing a Person resource that this verification is being used to verify. Max length: 5000.