Stripe.Params.InvoiceAddLinesParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for invoice add lines.

Summary

Types

t()

@type t() :: %Stripe.Params.InvoiceAddLinesParams{
  expand: [String.t()] | nil,
  invoice_metadata: map() | nil,
  lines: [Stripe.Params.InvoiceAddLinesParams.Lines.t()]
}
  • expand - Specifies which fields in the response should be expanded.
  • invoice_metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • lines - The line items to add.