Stripe.Params.InvoiceCreateParams.FromInvoice (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.InvoiceCreateParams.FromInvoice{
  action: String.t() | nil,
  invoice: String.t() | nil
}
  • action - The relation between the new invoice and the original invoice. Currently, only 'revision' is permitted Possible values: revision. Max length: 5000.
  • invoice - The id of the invoice that will be cloned. Max length: 5000.