Stripe.Params.InvoiceCreateParams.Rendering (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.InvoiceCreateParams.Rendering{
  amount_tax_display: String.t() | nil,
  pdf: Stripe.Params.InvoiceCreateParams.Rendering.Pdf.t() | nil,
  template: String.t() | nil,
  template_version: map() | nil
}
  • amount_tax_display - How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of exclude_tax or include_inclusive_tax. include_inclusive_tax will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. exclude_tax will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts. Possible values: exclude_tax, include_inclusive_tax.
  • pdf - Invoice pdf rendering options
  • template - ID of the invoice rendering template to use for this invoice. Max length: 5000.
  • template_version - The specific version of invoice rendering template to use for this invoice.