Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.AddInvoiceItems (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.AddInvoiceItems{
    discounts:
      [
        Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.AddInvoiceItems.Discounts.t()
      ]
      | nil,
    metadata: %{required(String.t()) => String.t()} | nil,
    period:
      Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.AddInvoiceItems.Period.t()
      | nil,
    price: String.t() | nil,
    price_data:
      Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.AddInvoiceItems.PriceData.t()
      | nil,
    quantity: integer() | nil,
    tax_rates: map() | nil
  }
  • discounts - The coupons to redeem into discounts for the item.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • period - The period associated with this invoice item. If not set, period.start.type defaults to max_item_period_start and period.end.type defaults to min_item_period_end.
  • price - The ID of the price object. One of price or price_data is required. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required.
  • quantity - Quantity for this item. Defaults to 1.
  • tax_rates - The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item.