Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.AddInvoiceItems.Discounts (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.AddInvoiceItems.Discounts{
    coupon: String.t() | nil,
    discount: String.t() | nil,
    promotion_code: String.t() | nil
  }
  • coupon - ID of the coupon to create a new discount for. Max length: 5000.
  • discount - ID of an existing discount on the object (or one of its ancestors) to reuse. Max length: 5000.
  • promotion_code - ID of the promotion code to create a new discount for. Max length: 5000.