Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.Items
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.Items{ billing_thresholds: map() | nil, discounts: map() | nil, metadata: %{required(String.t()) => String.t()} | nil, plan: String.t() | nil, price: String.t() | nil, price_data: Stripe.Params.InvoiceCreatePreviewParams.ScheduleDetails.Phases.Items.PriceData.t() | nil, quantity: integer() | nil, tax_rates: map() | nil }
billing_thresholds- Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.discounts- The coupons to redeem into discounts for the subscription item.metadata- Set of key-value pairs that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item'smetadatawhen the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item'smetadatacan be unset by posting an empty value to them in the configuration item'smetadata. To unset all keys in the subscription item'smetadata, update the subscription item directly or unset every key individually from the configuration item'smetadata.plan- The plan ID to subscribe to. You may specify the same ID inplanandprice. Max length: 5000.price- The ID of the price object. Max length: 5000.price_data- Data used to generate a new Price object inline.quantity- Quantity for the given price. Can be set only if the price'susage_typeislicensedand notmetered.tax_rates- A list of Tax Rate ids. These Tax Rates will override thedefault_tax_rateson the Subscription. When updating, pass an empty string to remove previously-defined tax rates.