Stripe.Params.InvoiceCreatePreviewParams.SubscriptionDetails.BillingMode (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.InvoiceCreatePreviewParams.SubscriptionDetails.BillingMode{
    flexible:
      Stripe.Params.InvoiceCreatePreviewParams.SubscriptionDetails.BillingMode.Flexible.t()
      | nil,
    type: String.t() | nil
  }
  • flexible - Configure behavior for flexible billing mode.
  • type - Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is flexible. Possible values: classic, flexible.