Stripe.Params.InvoiceFinalizeInvoiceParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for invoice finalize invoice.

Summary

Types

t()

@type t() :: %Stripe.Params.InvoiceFinalizeInvoiceParams{
  auto_advance: boolean() | nil,
  expand: [String.t()] | nil
}
  • auto_advance - Controls whether Stripe performs automatic collection of the invoice. If false, the invoice's state doesn't automatically advance without an explicit action.
  • expand - Specifies which fields in the response should be expanded.