Parameters for invoice item create.
Summary
Types
@type t() :: %Stripe.Params.InvoiceItemCreateParams{ amount: integer() | nil, currency: String.t() | nil, customer: String.t() | nil, customer_account: String.t() | nil, description: String.t() | nil, discountable: boolean() | nil, discounts: map() | nil, expand: [String.t()] | nil, invoice: String.t() | nil, metadata: map() | nil, period: Stripe.Params.InvoiceItemCreateParams.Period.t() | nil, price_data: Stripe.Params.InvoiceItemCreateParams.PriceData.t() | nil, pricing: Stripe.Params.InvoiceItemCreateParams.Pricing.t() | nil, quantity: integer() | nil, subscription: String.t() | nil, tax_behavior: String.t() | nil, tax_code: map() | nil, tax_rates: [String.t()] | nil, unit_amount_decimal: String.t() | nil }
amount- The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. Passing in a negativeamountwill reduce theamount_dueon the invoice.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.customer- The ID of the customer to bill for this invoice item. Max length: 5000.customer_account- The ID of the account representing the customer to bill for this invoice item. Max length: 5000.description- An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking. Max length: 5000.discountable- Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items.discounts- The coupons and promotion codes to redeem into discounts for the invoice item or invoice line item.expand- Specifies which fields in the response should be expanded.invoice- The ID of an existing invoice to add this invoice item to. For subscription invoices, when left blank, the invoice item will be added to the next upcoming scheduled invoice. For standalone invoices, the invoice item won't be automatically added unless you passpending_invoice_item_behavior: 'include'when creating the invoice. This is useful when adding invoice items in response to an invoice.created webhook. You can only add invoice items to draft invoices and there is a maximum of 250 items per invoice. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.period- The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have Stripe Revenue Recognition enabled, the period will be used to recognize and defer revenue. See the Revenue Recognition documentation for details.price_data- Data used to generate a new Price object inline.pricing- The pricing information for the invoice item.quantity- Non-negative integer. The quantity of units for the invoice item.subscription- The ID of a subscription to add this invoice item to. When left blank, the invoice item is added to the next upcoming scheduled invoice. When set, scheduled invoices for subscriptions other than the specified subscription will ignore the invoice item. Use this when you want to express that an invoice item has been accrued within the context of a particular subscription. Max length: 5000.tax_behavior- Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Once specified as eitherinclusiveorexclusive, it cannot be changed. Possible values:exclusive,inclusive,unspecified.tax_code- A tax code ID.tax_rates- The tax rates which apply to the invoice item. When set, thedefault_tax_rateson the invoice do not apply to this invoice item.unit_amount_decimal- The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. Thisunit_amount_decimalwill be multiplied by the quantity to get the full amount. Passing in a negativeunit_amount_decimalwill reduce theamount_dueon the invoice. Accepts at most 12 decimal places. Format: decimal string.