Stripe.Params.InvoiceItemCreateParams.PriceData (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.InvoiceItemCreateParams.PriceData{
  currency: String.t() | nil,
  product: String.t() | nil,
  tax_behavior: String.t() | nil,
  unit_amount: integer() | nil,
  unit_amount_decimal: String.t() | nil
}
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • product - The ID of the Product that this Price will belong to. Max length: 5000.
  • tax_behavior - Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed. Possible values: exclusive, inclusive, unspecified.
  • unit_amount - A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.
  • unit_amount_decimal - Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set. Format: decimal string.