Parameters for invoice item update.
Summary
Types
@type t() :: %Stripe.Params.InvoiceItemUpdateParams{ amount: integer() | nil, description: String.t() | nil, discountable: boolean() | nil, discounts: map() | nil, expand: [String.t()] | nil, metadata: map() | nil, period: Stripe.Params.InvoiceItemUpdateParams.Period.t() | nil, price_data: Stripe.Params.InvoiceItemUpdateParams.PriceData.t() | nil, pricing: Stripe.Params.InvoiceItemUpdateParams.Pricing.t() | nil, quantity: integer() | nil, tax_behavior: String.t() | nil, tax_code: map() | nil, tax_rates: map() | nil, unit_amount_decimal: String.t() | nil }
amount- The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer's account, pass a negative amount.description- An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking. Max length: 5000.discountable- Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.discounts- The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.period- The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have Stripe Revenue Recognition enabled, the period will be used to recognize and defer revenue. See the Revenue Recognition documentation for details.price_data- Data used to generate a new Price object inline.pricing- The pricing information for the invoice item.quantity- Non-negative integer. The quantity of units for the invoice item.tax_behavior- Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Once specified as eitherinclusiveorexclusive, it cannot be changed. Possible values:exclusive,inclusive,unspecified.tax_code- A tax code ID.tax_rates- The tax rates which apply to the invoice item. When set, thedefault_tax_rateson the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.unit_amount_decimal- The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. Thisunit_amount_decimalwill be multiplied by the quantity to get the full amount. Passing in a negativeunit_amount_decimalwill reduce theamount_dueon the invoice. Accepts at most 12 decimal places. Format: decimal string.