Parameters for invoice list.
Summary
Types
@type t() :: %Stripe.Params.InvoiceListParams{ collection_method: String.t() | nil, created: map() | nil, customer: String.t() | nil, customer_account: String.t() | nil, due_date: map() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, starting_after: String.t() | nil, status: String.t() | nil, subscription: String.t() | nil }
collection_method- The collection method of the invoice to retrieve. Eithercharge_automaticallyorsend_invoice. Possible values:charge_automatically,send_invoice.created- Only return invoices that were created during the given date interval.customer- Only return invoices for the customer specified by this customer ID. Max length: 5000.customer_account- Only return invoices for the account representing the customer specified by this account ID. Max length: 5000.due_dateending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.status- The status of the invoice, one ofdraft,open,paid,uncollectible, orvoid. Learn more Possible values:draft,open,paid,uncollectible,void.subscription- Only return invoices for the subscription specified by this subscription ID. Max length: 5000.