Parameters for invoice payment list.
Summary
Types
@type t() :: %Stripe.Params.InvoicePaymentListParams{ created: map() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, invoice: String.t() | nil, limit: integer() | nil, payment: Stripe.Params.InvoicePaymentListParams.Payment.t() | nil, starting_after: String.t() | nil, status: String.t() | nil }
created- Only return invoice payments that were created during the given date interval.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.invoice- The identifier of the invoice whose payments to return. Max length: 5000.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.payment- The payment details of the invoice payments to return.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.status- The status of the invoice payments to return. Possible values:canceled,open,paid.