Stripe.Params.InvoiceRemoveLinesParams.Lines (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.InvoiceRemoveLinesParams.Lines{
  behavior: String.t() | nil,
  id: String.t() | nil
}
  • behavior - Either delete or unassign. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice. Possible values: delete, unassign.
  • id - ID of an existing line item to remove from this invoice. Max length: 5000.