Parameters for invoice retrieve.
Summary
Types
@type t() :: %Stripe.Params.InvoiceRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for invoice retrieve.
@type t() :: %Stripe.Params.InvoiceRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.