Parameters for invoice update lines.
Summary
Types
@type t() :: %Stripe.Params.InvoiceUpdateLinesParams{ expand: [String.t()] | nil, invoice_metadata: map() | nil, lines: [Stripe.Params.InvoiceUpdateLinesParams.Lines.t()] }
expand- Specifies which fields in the response should be expanded.invoice_metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata. For type=subscription line items, the incoming metadata specified on the request is directly used to set this value, in contrast to type=invoiceitem line items, where any existing metadata on the invoice line is merged with the incoming data.lines- The line items to update.