Stripe.Params.InvoiceUpdateParams.PaymentSettings.PaymentMethodOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.InvoiceUpdateParams.PaymentSettings.PaymentMethodOptions{
  acss_debit: map() | nil,
  bancontact: map() | nil,
  card: map() | nil,
  customer_balance: map() | nil,
  konbini: map() | nil,
  payto: map() | nil,
  sepa_debit: map() | nil,
  us_bank_account: map() | nil
}
  • acss_debit - If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
  • bancontact - If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
  • card - If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
  • customer_balance - If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
  • konbini - If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
  • payto - If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
  • sepa_debit - If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
  • us_bank_account - If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.