Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.InvoiceUpdateParams.Rendering{ amount_tax_display: String.t() | nil, pdf: Stripe.Params.InvoiceUpdateParams.Rendering.Pdf.t() | nil, template: String.t() | nil, template_version: map() | nil }
amount_tax_display- How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One ofexclude_taxorinclude_inclusive_tax.include_inclusive_taxwill include inclusive tax (and exclude exclusive tax) in invoice PDF amounts.exclude_taxwill exclude all tax (inclusive and exclusive alike) from invoice PDF amounts. Possible values:exclude_tax,include_inclusive_tax.pdf- Invoice pdf rendering optionstemplate- ID of the invoice rendering template to use for this invoice. Max length: 5000.template_version- The specific version of invoice rendering template to use for this invoice.