Parameters for authorization retrieve.
Summary
Types
@type t() :: %Stripe.Params.Issuing.AuthorizationRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for authorization retrieve.
@type t() :: %Stripe.Params.Issuing.AuthorizationRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.