Parameters for card retrieve.
Summary
Types
@type t() :: %Stripe.Params.Issuing.CardRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for card retrieve.
@type t() :: %Stripe.Params.Issuing.CardRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.