Stripe.Params.Issuing.CardholderCreateParams.Individual.Verification.Document (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.Issuing.CardholderCreateParams.Individual.Verification.Document{
    back: String.t() | nil,
    front: String.t() | nil
  }
  • back - The back of an ID returned by a file upload with a purpose value of identity_document. Max length: 5000.
  • front - The front of an ID returned by a file upload with a purpose value of identity_document. Max length: 5000.