Stripe.Params.Issuing.CardholderUpdateParams.SpendingControls.SpendingLimits (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.Issuing.CardholderUpdateParams.SpendingControls.SpendingLimits{
    amount: integer() | nil,
    categories: [String.t()] | nil,
    interval: String.t() | nil
  }
  • amount - Maximum amount allowed to spend per interval.
  • categories - Array of strings containing categories this limit applies to. Omitting this field will apply the limit to all categories.
  • interval - Interval (or event) to which the amount applies. Possible values: all_time, daily, monthly, per_authorization, weekly, yearly.