Stripe.Params.Issuing.DisputeCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for dispute create.

Summary

Types

t()

@type t() :: %Stripe.Params.Issuing.DisputeCreateParams{
  amount: integer() | nil,
  evidence: Stripe.Params.Issuing.DisputeCreateParams.Evidence.t() | nil,
  expand: [String.t()] | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  transaction: String.t() | nil,
  treasury: Stripe.Params.Issuing.DisputeCreateParams.Treasury.t() | nil
}
  • amount - The dispute amount in the card's currency and in the smallest currency unit. If not set, defaults to the full transaction amount.
  • evidence - Evidence provided for the dispute.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • transaction - The ID of the issuing transaction to create a dispute for. For transaction on Treasury FinancialAccounts, use treasury.received_debit. Max length: 5000.
  • treasury - Params for disputes related to Treasury FinancialAccounts