Parameters for physical bundle retrieve.
Summary
Types
@type t() :: %Stripe.Params.Issuing.PhysicalBundleRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for physical bundle retrieve.
@type t() :: %Stripe.Params.Issuing.PhysicalBundleRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.