Stripe.Params.Issuing.TokenUpdateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for token update.

Summary

Types

t()

@type t() :: %Stripe.Params.Issuing.TokenUpdateParams{
  expand: [String.t()] | nil,
  status: String.t()
}
  • expand - Specifies which fields in the response should be expanded.
  • status - Specifies which status the token should be updated to. Possible values: active, deleted, suspended.