Stripe.Params.PaymentIntentAmountDetailsLineItemListParams
(tiger_stripe v0.1.10)
Parameters for payment intent amount details line item list.
Summary
Types
@type t() :: %Stripe.Params.PaymentIntentAmountDetailsLineItemListParams{ ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, starting_after: String.t() | nil }
ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.