Stripe.Params.PaymentIntentCaptureParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for payment intent capture.

Summary

Types

t()

@type t() :: %Stripe.Params.PaymentIntentCaptureParams{
  amount_details:
    Stripe.Params.PaymentIntentCaptureParams.AmountDetails.t() | nil,
  amount_to_capture: integer() | nil,
  application_fee_amount: integer() | nil,
  expand: [String.t()] | nil,
  final_capture: boolean() | nil,
  hooks: Stripe.Params.PaymentIntentCaptureParams.Hooks.t() | nil,
  metadata: map() | nil,
  payment_details: map() | nil,
  statement_descriptor: String.t() | nil,
  statement_descriptor_suffix: String.t() | nil,
  transfer_data: Stripe.Params.PaymentIntentCaptureParams.TransferData.t() | nil
}
  • amount_details - Provides industry-specific information about the amount.
  • amount_to_capture - The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full amount_capturable if it's not provided.
  • application_fee_amount - The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.
  • expand - Specifies which fields in the response should be expanded.
  • final_capture - Defaults to true. When capturing a PaymentIntent, setting final_capture to false notifies Stripe to not release the remaining uncaptured funds to make sure that they're captured in future requests. You can only use this setting when multicapture is available for PaymentIntents.
  • hooks - Automations to be run during the PaymentIntent lifecycle
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • payment_details - Provides industry-specific information about the charge.
  • statement_descriptor - Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead. Max length: 22.

  • statement_descriptor_suffix - Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement. Max length: 22.
  • transfer_data - The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the use case for connected accounts.