Stripe.Params.PaymentIntentConfirmParams.PaymentMethodOptions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PaymentIntentConfirmParams.PaymentMethodOptions{ acss_debit: map() | nil, affirm: map() | nil, afterpay_clearpay: map() | nil, alipay: map() | nil, alma: map() | nil, amazon_pay: map() | nil, au_becs_debit: map() | nil, bacs_debit: map() | nil, bancontact: map() | nil, billie: map() | nil, blik: map() | nil, boleto: map() | nil, card: map() | nil, card_present: map() | nil, cashapp: map() | nil, crypto: map() | nil, customer_balance: map() | nil, eps: map() | nil, fpx: map() | nil, giropay: map() | nil, grabpay: map() | nil, ideal: map() | nil, interac_present: map() | nil, kakao_pay: map() | nil, klarna: map() | nil, konbini: map() | nil, kr_card: map() | nil, link: map() | nil, mb_way: map() | nil, mobilepay: map() | nil, multibanco: map() | nil, naver_pay: map() | nil, nz_bank_account: map() | nil, oxxo: map() | nil, p24: map() | nil, pay_by_bank: map() | nil, payco: map() | nil, paynow: map() | nil, paypal: map() | nil, payto: map() | nil, pix: map() | nil, promptpay: map() | nil, revolut_pay: map() | nil, samsung_pay: map() | nil, satispay: map() | nil, sepa_debit: map() | nil, sofort: map() | nil, swish: map() | nil, twint: map() | nil, us_bank_account: map() | nil, wechat_pay: map() | nil, zip: map() | nil }
acss_debit- If this is aacss_debitPaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.affirm- If this is anaffirmPaymentMethod, this sub-hash contains details about the Affirm payment method options.afterpay_clearpay- If this is aafterpay_clearpayPaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.alipay- If this is aalipayPaymentMethod, this sub-hash contains details about the Alipay payment method options.alma- If this is aalmaPaymentMethod, this sub-hash contains details about the Alma payment method options.amazon_pay- If this is aamazon_payPaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.au_becs_debit- If this is aau_becs_debitPaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.bacs_debit- If this is abacs_debitPaymentMethod, this sub-hash contains details about the BACS Debit payment method options.bancontact- If this is abancontactPaymentMethod, this sub-hash contains details about the Bancontact payment method options.billie- If this is abilliePaymentMethod, this sub-hash contains details about the Billie payment method options.blik- If this is ablikPaymentMethod, this sub-hash contains details about the BLIK payment method options.boleto- If this is aboletoPaymentMethod, this sub-hash contains details about the Boleto payment method options.card- Configuration for any card payments attempted on this PaymentIntent.card_present- If this is acard_presentPaymentMethod, this sub-hash contains details about the Card Present payment method options.cashapp- If this is acashappPaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.crypto- If this is acryptoPaymentMethod, this sub-hash contains details about the Crypto payment method options.customer_balance- If this is acustomer balancePaymentMethod, this sub-hash contains details about the customer balance payment method options.eps- If this is aepsPaymentMethod, this sub-hash contains details about the EPS payment method options.fpx- If this is afpxPaymentMethod, this sub-hash contains details about the FPX payment method options.giropay- If this is agiropayPaymentMethod, this sub-hash contains details about the Giropay payment method options.grabpay- If this is agrabpayPaymentMethod, this sub-hash contains details about the Grabpay payment method options.ideal- If this is aidealPaymentMethod, this sub-hash contains details about the Ideal payment method options.interac_present- If this is ainterac_presentPaymentMethod, this sub-hash contains details about the Card Present payment method options.kakao_pay- If this is akakao_payPaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.klarna- If this is aklarnaPaymentMethod, this sub-hash contains details about the Klarna payment method options.konbini- If this is akonbiniPaymentMethod, this sub-hash contains details about the Konbini payment method options.kr_card- If this is akr_cardPaymentMethod, this sub-hash contains details about the KR Card payment method options.link- If this is alinkPaymentMethod, this sub-hash contains details about the Link payment method options.mb_way- If this is amb_wayPaymentMethod, this sub-hash contains details about the MB WAY payment method options.mobilepay- If this is aMobilePayPaymentMethod, this sub-hash contains details about the MobilePay payment method options.multibanco- If this is amultibancoPaymentMethod, this sub-hash contains details about the Multibanco payment method options.naver_pay- If this is anaver_payPaymentMethod, this sub-hash contains details about the Naver Pay payment method options.nz_bank_account- If this is anz_bank_accountPaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.oxxo- If this is aoxxoPaymentMethod, this sub-hash contains details about the OXXO payment method options.p24- If this is ap24PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.pay_by_bank- If this is apay_by_bankPaymentMethod, this sub-hash contains details about the PayByBank payment method options.payco- If this is apaycoPaymentMethod, this sub-hash contains details about the PAYCO payment method options.paynow- If this is apaynowPaymentMethod, this sub-hash contains details about the PayNow payment method options.paypal- If this is apaypalPaymentMethod, this sub-hash contains details about the PayPal payment method options.payto- If this is apaytoPaymentMethod, this sub-hash contains details about the PayTo payment method options.pix- If this is apixPaymentMethod, this sub-hash contains details about the Pix payment method options.promptpay- If this is apromptpayPaymentMethod, this sub-hash contains details about the PromptPay payment method options.revolut_pay- If this is arevolut_payPaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.samsung_pay- If this is asamsung_payPaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.satispay- If this is asatispayPaymentMethod, this sub-hash contains details about the Satispay payment method options.sepa_debit- If this is asepa_debitPaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.sofort- If this is asofortPaymentMethod, this sub-hash contains details about the SOFORT payment method options.swish- If this is aSwishPaymentMethod, this sub-hash contains details about the Swish payment method options.twint- If this is atwintPaymentMethod, this sub-hash contains details about the TWINT payment method options.us_bank_account- If this is aus_bank_accountPaymentMethod, this sub-hash contains details about the US bank account payment method options.wechat_pay- If this is awechat_payPaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.zip- If this is azipPaymentMethod, this sub-hash contains details about the Zip payment method options.