Stripe.Params.PaymentLinkCreateParams.AfterCompletion.Redirect (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.PaymentLinkCreateParams.AfterCompletion.Redirect{
  url: String.t() | nil
}
  • url - The URL the customer will be redirected to after the purchase is complete. You can embed {CHECKOUT_SESSION_ID} into the URL to have the id of the completed checkout session included.