Stripe.Params.PaymentLinkCreateParams.ConsentCollection.PaymentMethodReuseAgreement
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PaymentLinkCreateParams.ConsentCollection.PaymentMethodReuseAgreement{ position: String.t() | nil }
position- Determines the position and visibility of the payment method reuse agreement in the UI. When set toauto, Stripe's defaults will be used. When set tohidden, the payment method reuse agreement text will always be hidden in the UI. Possible values:auto,hidden.