Stripe.Params.PaymentLinkCreateParams.LineItems (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.PaymentLinkCreateParams.LineItems{
  adjustable_quantity:
    Stripe.Params.PaymentLinkCreateParams.LineItems.AdjustableQuantity.t() | nil,
  price: String.t() | nil,
  price_data:
    Stripe.Params.PaymentLinkCreateParams.LineItems.PriceData.t() | nil,
  quantity: integer() | nil
}
  • adjustable_quantity - When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
  • price - The ID of the Price or Plan object. One of price or price_data is required. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required.
  • quantity - The quantity of the line item being purchased.