Stripe.Params.PaymentLinkCreateParams.OptionalItems (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.PaymentLinkCreateParams.OptionalItems{
  adjustable_quantity:
    Stripe.Params.PaymentLinkCreateParams.OptionalItems.AdjustableQuantity.t()
    | nil,
  price: String.t() | nil,
  quantity: integer() | nil
}
  • adjustable_quantity - When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.
  • price - The ID of the Price or Plan object. Max length: 5000.
  • quantity - The initial quantity of the line item created when a customer chooses to add this optional item to their order.