Stripe.Params.PaymentLinkUpdateParams.AfterCompletion.Redirect
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PaymentLinkUpdateParams.AfterCompletion.Redirect{ url: String.t() | nil }
url- The URL the customer will be redirected to after the purchase is complete. You can embed{CHECKOUT_SESSION_ID}into the URL to have theidof the completed checkout session included.