Stripe.Params.PaymentLinkUpdateParams.AutomaticTax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.PaymentLinkUpdateParams.AutomaticTax{
  enabled: boolean() | nil,
  liability:
    Stripe.Params.PaymentLinkUpdateParams.AutomaticTax.Liability.t() | nil
}

Enabling this parameter causes the payment link to collect any billing address information necessary for tax calculation.

  • liability - The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.