Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PaymentLinkUpdateParams.LineItems{ adjustable_quantity: Stripe.Params.PaymentLinkUpdateParams.LineItems.AdjustableQuantity.t() | nil, id: String.t() | nil, quantity: integer() | nil }
adjustable_quantity- When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.id- The ID of an existing line item on the payment link. Max length: 5000.quantity- The quantity of the line item being purchased.