Stripe.Params.PaymentLinkUpdateParams.SubscriptionData
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PaymentLinkUpdateParams.SubscriptionData{ invoice_settings: Stripe.Params.PaymentLinkUpdateParams.SubscriptionData.InvoiceSettings.t() | nil, metadata: map() | nil, trial_period_days: map() | nil, trial_settings: map() | nil }
invoice_settings- All invoices will be billed using the specified settings.metadata- Set of key-value pairs that will declaratively set metadata on Subscriptions generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.trial_period_days- Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.trial_settings- Settings related to subscription trials.