Stripe.Params.PaymentMethodAttachParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for payment method attach.

Summary

Types

t()

@type t() :: %Stripe.Params.PaymentMethodAttachParams{
  customer: String.t() | nil,
  customer_account: String.t() | nil,
  expand: [String.t()] | nil
}
  • customer - The ID of the customer to which to attach the PaymentMethod. Max length: 5000.
  • customer_account - The ID of the Account representing the customer to which to attach the PaymentMethod. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.