Stripe.Params.PaymentRecordReportPaymentAttemptParams.PaymentMethodDetails.BillingDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.PaymentRecordReportPaymentAttemptParams.PaymentMethodDetails.BillingDetails{
    address:
      Stripe.Params.PaymentRecordReportPaymentAttemptParams.PaymentMethodDetails.BillingDetails.Address.t()
      | nil,
    email: String.t() | nil,
    name: String.t() | nil,
    phone: String.t() | nil
  }
  • address - The billing address associated with the method of payment.
  • email - The billing email associated with the method of payment.
  • name - The billing name associated with the method of payment. Max length: 5000.
  • phone - The billing phone number associated with the method of payment.