Stripe.Params.PaymentRecordReportPaymentParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for payment record report payment.

Summary

Types

t()

@type t() :: %Stripe.Params.PaymentRecordReportPaymentParams{
  amount_requested:
    Stripe.Params.PaymentRecordReportPaymentParams.AmountRequested.t(),
  customer_details:
    Stripe.Params.PaymentRecordReportPaymentParams.CustomerDetails.t() | nil,
  customer_presence: String.t() | nil,
  description: String.t() | nil,
  expand: [String.t()] | nil,
  failed: Stripe.Params.PaymentRecordReportPaymentParams.Failed.t() | nil,
  guaranteed:
    Stripe.Params.PaymentRecordReportPaymentParams.Guaranteed.t() | nil,
  initiated_at: integer(),
  metadata: map() | nil,
  outcome: String.t() | nil,
  payment_method_details:
    Stripe.Params.PaymentRecordReportPaymentParams.PaymentMethodDetails.t(),
  processor_details:
    Stripe.Params.PaymentRecordReportPaymentParams.ProcessorDetails.t() | nil,
  shipping_details:
    Stripe.Params.PaymentRecordReportPaymentParams.ShippingDetails.t() | nil
}
  • amount_requested - The amount you initially requested for this payment.
  • customer_details - Customer information for this payment.
  • customer_presence - Indicates whether the customer was present in your checkout flow during this payment. Possible values: off_session, on_session.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • failed - Information about the payment attempt failure.
  • guaranteed - Information about the payment attempt guarantee.
  • initiated_at - When the reported payment was initiated. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • outcome - The outcome of the reported payment. Possible values: failed, guaranteed.
  • payment_method_details - Information about the Payment Method debited for this payment.
  • processor_details - Processor information for this payment.
  • shipping_details - Shipping information for this payment.