Parameters for payout cancel.
Summary
Types
@type t() :: %Stripe.Params.PayoutCancelParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for payout cancel.
@type t() :: %Stripe.Params.PayoutCancelParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.