Stripe.Params.PayoutCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for payout create.

Summary

Types

t()

@type t() :: %Stripe.Params.PayoutCreateParams{
  amount: integer(),
  currency: String.t(),
  description: String.t() | nil,
  destination: String.t() | nil,
  expand: [String.t()] | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  method: String.t() | nil,
  payout_method: String.t() | nil,
  source_type: String.t() | nil,
  statement_descriptor: String.t() | nil
}
  • amount - A positive integer in cents representing how much to payout.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.
  • destination - The ID of a bank account or a card to send the payout to. If you don't provide a destination, we use the default external account for the specified currency.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • method - The method used to send this payout, which is standard or instant. We support instant for payouts to debit cards and bank accounts in certain countries. Learn more about bank support for Instant Payouts. Possible values: instant, standard. Max length: 5000.
  • payout_method - The ID of a v2 FinancialAccount to send funds to.
  • source_type - The balance type of your Stripe balance to draw this payout from. Balances for different payment sources are kept separately. You can find the amounts with the Balances API. One of bank_account, card, or fpx. Possible values: bank_account, card, fpx. Max length: 5000.
  • statement_descriptor - A string that displays on the recipient's bank or card statement (up to 22 characters). A statement_descriptor that's longer than 22 characters return an error. Most banks truncate this information and display it inconsistently. Some banks might not display it at all. Max length: 22.