Parameters for plan create.
Summary
Types
@type t() :: %Stripe.Params.PlanCreateParams{ active: boolean() | nil, amount: integer() | nil, amount_decimal: String.t() | nil, billing_scheme: String.t() | nil, currency: String.t(), expand: [String.t()] | nil, id: String.t() | nil, interval: String.t(), interval_count: integer() | nil, metadata: map() | nil, meter: String.t() | nil, nickname: String.t() | nil, product: map() | nil, tiers: [Stripe.Params.PlanCreateParams.Tiers.t()] | nil, tiers_mode: String.t() | nil, transform_usage: Stripe.Params.PlanCreateParams.TransformUsage.t() | nil, trial_period_days: integer() | nil, usage_type: String.t() | nil }
active- Whether the plan is currently available for new subscriptions. Defaults totrue.amount- A positive integer in cents (or local equivalent) (or 0 for a free plan) representing how much to charge on a recurring basis.amount_decimal- Same asamount, but accepts a decimal value with at most 12 decimal places. Only one ofamountandamount_decimalcan be set. Format: decimal string.billing_scheme- Describes how to compute the price per period. Eitherper_unitortiered.per_unitindicates that the fixed amount (specified inamount) will be charged per unit inquantity(for plans withusage_type=licensed), or per unit of total usage (for plans withusage_type=metered).tieredindicates that the unit pricing will be computed using a tiering strategy as defined using thetiersandtiers_modeattributes. Possible values:per_unit,tiered.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.expand- Specifies which fields in the response should be expanded.id- An identifier randomly generated by Stripe. Used to identify this plan when subscribing a customer. You can optionally override this ID, but the ID must be unique across all plans in your Stripe account. You can, however, use the same plan ID in both live and test modes. Max length: 5000.interval- Specifies billing frequency. Eitherday,week,monthoryear. Possible values:day,month,week,year.interval_count- The number of intervals between subscription billings. For example,interval=monthandinterval_count=3bills every 3 months. Maximum of three years interval allowed (3 years, 36 months, or 156 weeks).metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.meter- The meter tracking the usage of a metered price Max length: 5000.nickname- A brief description of the plan, hidden from customers. Max length: 5000.producttiers- Each element represents a pricing tier. This parameter requiresbilling_schemeto be set totiered. See also the documentation forbilling_scheme.tiers_mode- Defines if the tiering price should begraduatedorvolumebased. Involume-based tiering, the maximum quantity within a period determines the per unit price, ingraduatedtiering pricing can successively change as the quantity grows. Possible values:graduated,volume.transform_usage- Apply a transformation to the reported usage or set quantity before computing the billed price. Cannot be combined withtiers.trial_period_days- Default number of trial days when subscribing a customer to this plan usingtrial_from_plan=true.usage_type- Configures how the quantity per period should be determined. Can be eithermeteredorlicensed.licensedautomatically bills thequantityset when adding it to a subscription.meteredaggregates the total usage based on usage records. Defaults tolicensed. Possible values:licensed,metered.