Stripe.Params.PlanCreateParams.Tiers (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.PlanCreateParams.Tiers{
  flat_amount: integer() | nil,
  flat_amount_decimal: String.t() | nil,
  unit_amount: integer() | nil,
  unit_amount_decimal: String.t() | nil,
  up_to: map() | nil
}
  • flat_amount - The flat billing amount for an entire tier, regardless of the number of units in the tier.
  • flat_amount_decimal - Same as flat_amount, but accepts a decimal value representing an integer in the minor units of the currency. Only one of flat_amount and flat_amount_decimal can be set. Format: decimal string.
  • unit_amount - The per unit billing amount for each individual unit for which this tier applies.
  • unit_amount_decimal - Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set. Format: decimal string.
  • up_to - Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Use inf to define a fallback tier.