Stripe.Params.PlanListParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for plan list.

Summary

Types

t()

@type t() :: %Stripe.Params.PlanListParams{
  active: boolean() | nil,
  created: map() | nil,
  ending_before: String.t() | nil,
  expand: [String.t()] | nil,
  limit: integer() | nil,
  product: String.t() | nil,
  starting_after: String.t() | nil
}
  • active - Only return plans that are active or inactive (e.g., pass false to list all inactive plans).
  • created - A filter on the list, based on the object created field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
  • ending_before - A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • limit - A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
  • product - Only return plans for the given product. Max length: 5000.
  • starting_after - A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list. Max length: 5000.