Parameters for plan retrieve.
Summary
Types
@type t() :: %Stripe.Params.PlanRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for plan retrieve.
@type t() :: %Stripe.Params.PlanRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.