Parameters for price create.
Summary
Types
@type t() :: %Stripe.Params.PriceCreateParams{ active: boolean() | nil, billing_scheme: String.t() | nil, currency: String.t(), currency_options: %{ required(String.t()) => Stripe.Params.PriceCreateParams.CurrencyOptions.t() } | nil, custom_unit_amount: Stripe.Params.PriceCreateParams.CustomUnitAmount.t() | nil, expand: [String.t()] | nil, lookup_key: String.t() | nil, metadata: %{required(String.t()) => String.t()} | nil, nickname: String.t() | nil, product: String.t() | nil, product_data: Stripe.Params.PriceCreateParams.ProductData.t() | nil, recurring: Stripe.Params.PriceCreateParams.Recurring.t() | nil, tax_behavior: String.t() | nil, tiers: [Stripe.Params.PriceCreateParams.Tiers.t()] | nil, tiers_mode: String.t() | nil, transfer_lookup_key: boolean() | nil, transform_quantity: Stripe.Params.PriceCreateParams.TransformQuantity.t() | nil, unit_amount: integer() | nil, unit_amount_decimal: String.t() | nil }
active- Whether the price can be used for new purchases. Defaults totrue.billing_scheme- Describes how to compute the price per period. Eitherper_unitortiered.per_unitindicates that the fixed amount (specified inunit_amountorunit_amount_decimal) will be charged per unit inquantity(for prices withusage_type=licensed), or per unit of total usage (for prices withusage_type=metered).tieredindicates that the unit pricing will be computed using a tiering strategy as defined using thetiersandtiers_modeattributes. Possible values:per_unit,tiered.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.currency_options- Prices defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.custom_unit_amount- When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.expand- Specifies which fields in the response should be expanded.lookup_key- A lookup key used to retrieve prices dynamically from a static string. This may be up to 200 characters. Max length: 200.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.nickname- A brief description of the price, hidden from customers. Max length: 5000.product- The ID of the Product that this Price will belong to. Max length: 5000.product_data- These fields can be used to create a new product that this price will belong to.recurring- The recurring components of a price such asintervalandusage_type.tax_behavior- Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Once specified as eitherinclusiveorexclusive, it cannot be changed. Possible values:exclusive,inclusive,unspecified.tiers- Each element represents a pricing tier. This parameter requiresbilling_schemeto be set totiered. See also the documentation forbilling_scheme.tiers_mode- Defines if the tiering price should begraduatedorvolumebased. Involume-based tiering, the maximum quantity within a period determines the per unit price, ingraduatedtiering pricing can successively change as the quantity grows. Possible values:graduated,volume.transfer_lookup_key- If set to true, will atomically remove the lookup key from the existing price, and assign it to this price.transform_quantity- Apply a transformation to the reported usage or set quantity before computing the billed price. Cannot be combined withtiers.unit_amount- A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge. One ofunit_amount,unit_amount_decimal, orcustom_unit_amountis required, unlessbilling_scheme=tiered.unit_amount_decimal- Same asunit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one ofunit_amountandunit_amount_decimalcan be set. Format: decimal string.