Stripe.Params.PriceCreateParams.Recurring (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.PriceCreateParams.Recurring{
  interval: String.t() | nil,
  interval_count: integer() | nil,
  meter: String.t() | nil,
  trial_period_days: integer() | nil,
  usage_type: String.t() | nil
}
  • interval - Specifies billing frequency. Either day, week, month or year. Possible values: day, month, week, year.
  • interval_count - The number of intervals between subscription billings. For example, interval=month and interval_count=3 bills every 3 months. Maximum of three years interval allowed (3 years, 36 months, or 156 weeks).
  • meter - The meter tracking the usage of a metered price Max length: 5000.
  • trial_period_days - Default number of trial days when subscribing a customer to this price using trial_from_plan=true.
  • usage_type - Configures how the quantity per period should be determined. Can be either metered or licensed. licensed automatically bills the quantity set when adding it to a subscription. metered aggregates the total usage based on usage records. Defaults to licensed. Possible values: licensed, metered.