Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions{ custom_unit_amount: Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions.CustomUnitAmount.t() | nil, tax_behavior: String.t() | nil, tiers: [ Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions.Tiers.t() ] | nil, unit_amount: integer() | nil, unit_amount_decimal: String.t() | nil }
custom_unit_amount- When set, provides configuration for the amount to be adjusted by the customer during Checkout Sessions and Payment Links.tax_behavior- Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Once specified as eitherinclusiveorexclusive, it cannot be changed. Possible values:exclusive,inclusive,unspecified.tiers- Each element represents a pricing tier. This parameter requiresbilling_schemeto be set totiered. See also the documentation forbilling_scheme.unit_amount- A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.unit_amount_decimal- Same asunit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one ofunit_amountandunit_amount_decimalcan be set. Format: decimal string.