Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions.CustomUnitAmount (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions.CustomUnitAmount{
    enabled: boolean() | nil,
    maximum: integer() | nil,
    minimum: integer() | nil,
    preset: integer() | nil
  }
  • enabled - Pass in true to enable custom_unit_amount, otherwise omit custom_unit_amount.
  • maximum - The maximum unit amount the customer can specify for this item.
  • minimum - The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount.
  • preset - The starting unit amount which can be updated by the customer.