Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions.Tiers
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.ProductCreateParams.DefaultPriceData.CurrencyOptions.Tiers{ flat_amount: integer() | nil, flat_amount_decimal: String.t() | nil, unit_amount: integer() | nil, unit_amount_decimal: String.t() | nil, up_to: map() | nil }
flat_amount- The flat billing amount for an entire tier, regardless of the number of units in the tier.flat_amount_decimal- Same asflat_amount, but accepts a decimal value representing an integer in the minor units of the currency. Only one offlat_amountandflat_amount_decimalcan be set. Format: decimal string.unit_amount- The per unit billing amount for each individual unit for which this tier applies.unit_amount_decimal- Same asunit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one ofunit_amountandunit_amount_decimalcan be set. Format: decimal string.up_to- Specifies the upper bound of this tier. The lower bound of a tier is the upper bound of the previous tier adding one. Useinfto define a fallback tier.