Stripe.Params.ProductFeatureCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for product feature create.

Summary

Types

t()

@type t() :: %Stripe.Params.ProductFeatureCreateParams{
  entitlement_feature: String.t(),
  expand: [String.t()] | nil
}
  • entitlement_feature - The ID of the Feature object attached to this product. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.