Parameters for product feature retrieve.
Summary
Types
@type t() :: %Stripe.Params.ProductFeatureRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for product feature retrieve.
@type t() :: %Stripe.Params.ProductFeatureRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.