Stripe.Params.PromotionCodeCreateParams.Restrictions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.PromotionCodeCreateParams.Restrictions{
  currency_options:
    %{
      required(String.t()) =>
        Stripe.Params.PromotionCodeCreateParams.Restrictions.CurrencyOptions.t()
    }
    | nil,
  first_time_transaction: boolean() | nil,
  minimum_amount: integer() | nil,
  minimum_amount_currency: String.t() | nil
}
  • currency_options - Promotion codes defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
  • first_time_transaction - A Boolean indicating if the Promotion Code should only be redeemed for Customers without any successful payments or invoices
  • minimum_amount - Minimum amount required to redeem this Promotion Code into a Coupon (e.g., a purchase must be $100 or more to work).
  • minimum_amount_currency - Three-letter ISO code for minimum_amount Format: ISO 4217 currency code.