Stripe.Params.QuoteCreateParams.AutomaticTax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.QuoteCreateParams.AutomaticTax{
  enabled: boolean() | nil,
  liability: Stripe.Params.QuoteCreateParams.AutomaticTax.Liability.t() | nil
}
  • enabled - Controls whether Stripe will automatically compute tax on the resulting invoices or subscriptions as well as the quote itself.
  • liability - The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.