Stripe.Params.QuoteCreateParams.FromQuote (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.QuoteCreateParams.FromQuote{
  is_revision: boolean() | nil,
  quote: String.t() | nil
}
  • is_revision - Whether this quote is a revision of the previous quote.
  • quote - The id of the quote that will be cloned. Max length: 5000.