Stripe.Params.QuoteCreateParams.LineItems (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.QuoteCreateParams.LineItems{
  discounts: map() | nil,
  price: String.t() | nil,
  price_data: Stripe.Params.QuoteCreateParams.LineItems.PriceData.t() | nil,
  quantity: integer() | nil,
  tax_rates: map() | nil
}
  • discounts - The discounts applied to this line item.
  • price - The ID of the price object. One of price or price_data is required. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required.
  • quantity - The quantity of the line item.
  • tax_rates - The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.