Stripe.Params.QuoteFinalizeQuoteParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for quote finalize quote.

Summary

Types

t()

@type t() :: %Stripe.Params.QuoteFinalizeQuoteParams{
  expand: [String.t()] | nil,
  expires_at: integer() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • expires_at - A future timestamp on which the quote will be canceled if in open or draft status. Measured in seconds since the Unix epoch. Format: Unix timestamp.