Parameters for quote retrieve.
Summary
Types
@type t() :: %Stripe.Params.QuoteRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for quote retrieve.
@type t() :: %Stripe.Params.QuoteRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.