Stripe.Params.QuoteUpdateParams.InvoiceSettings (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.QuoteUpdateParams.InvoiceSettings{
  days_until_due: integer() | nil,
  issuer: Stripe.Params.QuoteUpdateParams.InvoiceSettings.Issuer.t() | nil
}
  • days_until_due - Number of days within which a customer must pay the invoice generated by this quote. This value will be null for quotes where collection_method=charge_automatically.
  • issuer - The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.