Stripe.Params.Radar.PaymentEvaluationCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for payment evaluation create.

Summary

Types

t()

@type t() :: %Stripe.Params.Radar.PaymentEvaluationCreateParams{
  client_device_metadata_details:
    Stripe.Params.Radar.PaymentEvaluationCreateParams.ClientDeviceMetadataDetails.t()
    | nil,
  customer_details:
    Stripe.Params.Radar.PaymentEvaluationCreateParams.CustomerDetails.t(),
  expand: [String.t()] | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  payment_details:
    Stripe.Params.Radar.PaymentEvaluationCreateParams.PaymentDetails.t()
}
  • client_device_metadata_details - Details about the Client Device Metadata to associate with the payment evaluation.
  • customer_details - Details about the customer associated with the payment evaluation.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • payment_details - Details about the payment.