Stripe.Params.Radar.PaymentEvaluationCreateParams.ClientDeviceMetadataDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.Radar.PaymentEvaluationCreateParams.ClientDeviceMetadataDetails{
    radar_session: String.t() | nil
  }
  • radar_session - ID for the Radar Session to associate with the payment evaluation. A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments. Max length: 5000.