Parameters for value list item retrieve.
Summary
Types
@type t() :: %Stripe.Params.Radar.ValueListItemRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for value list item retrieve.
@type t() :: %Stripe.Params.Radar.ValueListItemRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.