Parameters for refund cancel.
Summary
Types
@type t() :: %Stripe.Params.RefundCancelParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for refund cancel.
@type t() :: %Stripe.Params.RefundCancelParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.