Stripe.Params.SetupIntentConfirmParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for setup intent confirm.

Summary

Types

t()

@type t() :: %Stripe.Params.SetupIntentConfirmParams{
  confirmation_token: String.t() | nil,
  expand: [String.t()] | nil,
  mandate_data: map() | nil,
  payment_method: String.t() | nil,
  payment_method_data:
    Stripe.Params.SetupIntentConfirmParams.PaymentMethodData.t() | nil,
  payment_method_options:
    Stripe.Params.SetupIntentConfirmParams.PaymentMethodOptions.t() | nil,
  return_url: String.t() | nil,
  use_stripe_sdk: boolean() | nil
}
  • confirmation_token - ID of the ConfirmationToken used to confirm this SetupIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as payment_method, then the values in this request will take precedence. Max length: 5000.

  • expand - Specifies which fields in the response should be expanded.
  • mandate_data
  • payment_method - ID of the payment method (a PaymentMethod, Card, or saved Source object) to attach to this SetupIntent. Max length: 5000.
  • payment_method_data - When included, this hash creates a PaymentMethod that is set as the payment_method value in the SetupIntent.
  • payment_method_options - Payment method-specific configuration for this SetupIntent.
  • return_url - The URL to redirect your customer back to after they authenticate on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
  • use_stripe_sdk - Set to true when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.