Stripe.Params.SetupIntentCreateParams.PaymentMethodData.RadarOptions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SetupIntentCreateParams.PaymentMethodData.RadarOptions{ session: String.t() | nil }
session- A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments. Max length: 5000.