Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • acss_debit - If this is a acss_debit SetupIntent, this sub-hash contains details about the ACSS Debit payment method options.
  • amazon_pay - If this is a amazon_pay SetupIntent, this sub-hash contains details about the AmazonPay payment method options.
  • bacs_debit - If this is a bacs_debit SetupIntent, this sub-hash contains details about the Bacs Debit payment method options.
  • card - Configuration for any card setup attempted on this SetupIntent.
  • card_present - If this is a card_present PaymentMethod, this sub-hash contains details about the card-present payment method options.
  • klarna - If this is a klarna PaymentMethod, this hash contains details about the Klarna payment method options.
  • link - If this is a link PaymentMethod, this sub-hash contains details about the Link payment method options.
  • paypal - If this is a paypal PaymentMethod, this sub-hash contains details about the PayPal payment method options.
  • payto - If this is a payto SetupIntent, this sub-hash contains details about the PayTo payment method options.
  • sepa_debit - If this is a sepa_debit SetupIntent, this sub-hash contains details about the SEPA Debit payment method options.
  • us_bank_account - If this is a us_bank_account SetupIntent, this sub-hash contains details about the US bank account payment method options.