Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.AcssDebit.MandateOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.AcssDebit.MandateOptions{
    custom_mandate_url: map() | nil,
    default_for: [String.t()] | nil,
    interval_description: String.t() | nil,
    payment_schedule: String.t() | nil,
    transaction_type: String.t() | nil
  }
  • custom_mandate_url - A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters payment_intent and payment_intent_client_secret when confirming a Payment Intent, or setup_intent and setup_intent_client_secret when confirming a Setup Intent.
  • default_for - List of Stripe products where this mandate can be selected automatically.
  • interval_description - Description of the mandate interval. Only required if 'payment_schedule' parameter is 'interval' or 'combined'. Max length: 500.
  • payment_schedule - Payment schedule for the mandate. Possible values: combined, interval, sporadic.
  • transaction_type - Transaction type of the mandate. Possible values: business, personal.