Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Klarna (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Klarna{
  currency: String.t() | nil,
  on_demand:
    Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Klarna.OnDemand.t()
    | nil,
  preferred_locale: String.t() | nil,
  subscriptions: map() | nil
}
  • currency - The currency of the SetupIntent. Three letter ISO currency code. Format: ISO 4217 currency code.
  • on_demand - On-demand details if setting up a payment method for on-demand payments.
  • preferred_locale - Preferred language of the Klarna authorization page that the customer is redirected to Possible values: cs-CZ, da-DK, de-AT, de-CH, de-DE, el-GR, en-AT, en-AU, en-BE, en-CA, en-CH, en-CZ, en-DE, en-DK, en-ES, en-FI, en-FR, en-GB, en-GR, en-IE, en-IT, en-NL, en-NO, en-NZ, en-PL, en-PT, en-RO, en-SE, en-US, es-ES, es-US, fi-FI, fr-BE, fr-CA, fr-CH, fr-FR, it-CH, it-IT, nb-NO, nl-BE, nl-NL, pl-PL, pt-PT, ro-RO, sv-FI, sv-SE.
  • subscriptions - Subscription details if setting up or charging a subscription