Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Payto.MandateOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Payto.MandateOptions{
    amount: map() | nil,
    amount_type: String.t() | nil,
    end_date: map() | nil,
    payment_schedule: String.t() | nil,
    payments_per_period: map() | nil,
    purpose: String.t() | nil,
    start_date: map() | nil
  }
  • amount - Amount that will be collected. It is required when amount_type is fixed.
  • amount_type - The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum. Possible values: fixed, maximum.
  • end_date - Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
  • payment_schedule - The periodicity at which payments will be collected. Defaults to adhoc. Possible values: adhoc, annual, daily, fortnightly, monthly, quarterly, semi_annual, weekly.
  • payments_per_period - The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
  • purpose - The purpose for which payments are made. Has a default value based on your merchant category code. Possible values: dependant_support, government, loan, mortgage, other, pension, personal, retail, salary, tax, utility.
  • start_date - Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.