Stripe.Params.SetupIntentUpdateParams.PaymentMethodData.RadarOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SetupIntentUpdateParams.PaymentMethodData.RadarOptions{
  session: String.t() | nil
}
  • session - A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments. Max length: 5000.