Stripe.Params.SetupIntentUpdateParams.PaymentMethodOptions.Card.MandateOptions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SetupIntentUpdateParams.PaymentMethodOptions.Card.MandateOptions{ amount: integer() | nil, amount_type: String.t() | nil, currency: String.t() | nil, description: String.t() | nil, end_date: integer() | nil, interval: String.t() | nil, interval_count: integer() | nil, reference: String.t() | nil, start_date: integer() | nil, supported_types: [String.t()] | nil }
amount- Amount to be charged for future payments.amount_type- One offixedormaximum. Iffixed, theamountparam refers to the exact amount to be charged in future payments. Ifmaximum, the amount charged can be up to the value passed for theamountparam. Possible values:fixed,maximum.currency- Currency in which future payments will be charged. Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- A description of the mandate or subscription that is meant to be displayed to the customer. Max length: 200.end_date- End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date. Format: Unix timestamp.interval- Specifies payment frequency. One ofday,week,month,year, orsporadic. Possible values:day,month,sporadic,week,year.interval_count- The number of intervals between payments. For example,interval=monthandinterval_count=3indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional wheninterval=sporadic.reference- Unique identifier for the mandate or subscription. Max length: 80.start_date- Start date of the mandate or subscription. Start date should not be lesser than yesterday. Format: Unix timestamp.supported_types- Specifies the type of mandates supported. Possible values areindia.