Stripe.Params.SetupIntentUpdateParams.PaymentMethodOptions.Card.ThreeDSecure (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.SetupIntentUpdateParams.PaymentMethodOptions.Card.ThreeDSecure{
    ares_trans_status: String.t() | nil,
    cryptogram: String.t() | nil,
    electronic_commerce_indicator: String.t() | nil,
    network_options:
      Stripe.Params.SetupIntentUpdateParams.PaymentMethodOptions.Card.ThreeDSecure.NetworkOptions.t()
      | nil,
    requestor_challenge_indicator: String.t() | nil,
    transaction_id: String.t() | nil,
    version: String.t() | nil
  }
  • ares_trans_status - The transStatus returned from the card Issuer’s ACS in the ARes. Possible values: A, C, I, N, R, U, Y.
  • cryptogram - The cryptogram, also known as the "authentication value" (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.) Max length: 5000.
  • electronic_commerce_indicator - The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed. Possible values: 01, 02, 05, 06, 07.
  • network_options - Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter payment_method_options.card.network must be populated accordingly
  • requestor_challenge_indicator - The challenge indicator (threeDSRequestorChallengeInd) which was requested in the AReq sent to the card Issuer's ACS. A string containing 2 digits from 01-99. Max length: 2.
  • transaction_id - For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID). Max length: 5000.
  • version - The version of 3D Secure that was performed. Possible values: 1.0.2, 2.1.0, 2.2.0, 2.3.0, 2.3.1.