Stripe.Params.SetupIntentUpdateParams.PaymentMethodOptions.Card.ThreeDSecure.NetworkOptions.CartesBancaires (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.SetupIntentUpdateParams.PaymentMethodOptions.Card.ThreeDSecure.NetworkOptions.CartesBancaires{
    cb_avalgo: String.t() | nil,
    cb_exemption: String.t() | nil,
    cb_score: integer() | nil
  }
  • cb_avalgo - The cryptogram calculation algorithm used by the card Issuer's ACS to calculate the Authentication cryptogram. Also known as cavvAlgorithm. messageExtension: CB-AVALGO Possible values: 0, 1, 2, 3, 4, A.
  • cb_exemption - The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded Max length: 4.
  • cb_score - The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99