Parameters for shipping rate create.
Summary
Types
@type t() :: %Stripe.Params.ShippingRateCreateParams{ delivery_estimate: Stripe.Params.ShippingRateCreateParams.DeliveryEstimate.t() | nil, display_name: String.t(), expand: [String.t()] | nil, fixed_amount: Stripe.Params.ShippingRateCreateParams.FixedAmount.t() | nil, metadata: %{required(String.t()) => String.t()} | nil, tax_behavior: String.t() | nil, tax_code: String.t() | nil, type: String.t() | nil }
delivery_estimate- The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.display_name- The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions. Max length: 100.expand- Specifies which fields in the response should be expanded.fixed_amount- Describes a fixed amount to charge for shipping. Must be present if type isfixed_amount.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.tax_behavior- Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Possible values:exclusive,inclusive,unspecified.tax_code- A tax code ID. The Shipping tax code istxcd_92010001.type- The type of calculation to use on the shipping rate. Possible values:fixed_amount.