Parameters for shipping rate retrieve.
Summary
Types
@type t() :: %Stripe.Params.ShippingRateRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for shipping rate retrieve.
@type t() :: %Stripe.Params.ShippingRateRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.