Stripe.Params.SourceCreateParams.Redirect (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SourceCreateParams.Redirect{return_url: String.t() | nil}
  • return_url - The URL you provide to redirect the customer back to you after they authenticated their payment. It can use your application URI scheme in the context of a mobile application.