Stripe.Params.SourceRetrieveParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for source retrieve.

Summary

Types

t()

@type t() :: %Stripe.Params.SourceRetrieveParams{
  client_secret: String.t() | nil,
  expand: [String.t()] | nil
}
  • client_secret - The client secret of the source. Required if a publishable key is used to retrieve the source. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.