Stripe.Params.SourceUpdateParams.Mandate.Acceptance (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SourceUpdateParams.Mandate.Acceptance{
  date: integer() | nil,
  ip: String.t() | nil,
  offline:
    Stripe.Params.SourceUpdateParams.Mandate.Acceptance.Offline.t() | nil,
  online: Stripe.Params.SourceUpdateParams.Mandate.Acceptance.Online.t() | nil,
  status: String.t() | nil,
  type: String.t() | nil,
  user_agent: String.t() | nil
}
  • date - The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer. Format: Unix timestamp.
  • ip - The IP address from which the mandate was accepted or refused by the customer.
  • offline - The parameters required to store a mandate accepted offline. Should only be set if mandate[type] is offline
  • online - The parameters required to store a mandate accepted online. Should only be set if mandate[type] is online
  • status - The status of the mandate acceptance. Either accepted (the mandate was accepted) or refused (the mandate was refused). Possible values: accepted, pending, refused, revoked. Max length: 5000.
  • type - The type of acceptance information included with the mandate. Either online or offline Possible values: offline, online. Max length: 5000.
  • user_agent - The user agent of the browser from which the mandate was accepted or refused by the customer. Max length: 5000.