Stripe.Params.SourceUpdateParams.Mandate.Acceptance.Online (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SourceUpdateParams.Mandate.Acceptance.Online{
  date: integer() | nil,
  ip: String.t() | nil,
  user_agent: String.t() | nil
}
  • date - The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer. Format: Unix timestamp.
  • ip - The IP address from which the mandate was accepted or refused by the customer.
  • user_agent - The user agent of the browser from which the mandate was accepted or refused by the customer. Max length: 5000.