Stripe.Params.SourceUpdateParams.SourceOrder.Shipping
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SourceUpdateParams.SourceOrder.Shipping{ address: Stripe.Params.SourceUpdateParams.SourceOrder.Shipping.Address.t() | nil, carrier: String.t() | nil, name: String.t() | nil, phone: String.t() | nil, tracking_number: String.t() | nil }
address- Shipping address.carrier- The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. Max length: 5000.name- Recipient name. Max length: 5000.phone- Recipient phone (including extension). Max length: 5000.tracking_number- The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas. Max length: 5000.