Stripe.Params.SubscriptionCreateParams.AddInvoiceItems.Period.End
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionCreateParams.AddInvoiceItems.Period.End{ timestamp: integer() | nil, type: String.t() | nil }
timestamp- A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal toperiod.start. Format: Unix timestamp.type- Select how to calculate the end of the invoice item period. Possible values:min_item_period_end,timestamp.