Stripe.Params.SubscriptionCreateParams.AddInvoiceItems.Period.Start (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SubscriptionCreateParams.AddInvoiceItems.Period.Start{
  timestamp: integer() | nil,
  type: String.t() | nil
}
  • timestamp - A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to period.end. Format: Unix timestamp.
  • type - Select how to calculate the start of the invoice item period. Possible values: max_item_period_start, now, timestamp.