Stripe.Params.SubscriptionItemCreateParams.PriceData
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionItemCreateParams.PriceData{ currency: String.t() | nil, product: String.t() | nil, recurring: Stripe.Params.SubscriptionItemCreateParams.PriceData.Recurring.t() | nil, tax_behavior: String.t() | nil, unit_amount: integer() | nil, unit_amount_decimal: String.t() | nil }
currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.product- The ID of the Product that this Price will belong to. Max length: 5000.recurring- The recurring components of a price such asintervalandinterval_count.tax_behavior- Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Once specified as eitherinclusiveorexclusive, it cannot be changed. Possible values:exclusive,inclusive,unspecified.unit_amount- A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.unit_amount_decimal- Same asunit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one ofunit_amountandunit_amount_decimalcan be set. Format: decimal string.