Stripe.Params.SubscriptionListParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for subscription list.

Summary

Types

t()

@type t() :: %Stripe.Params.SubscriptionListParams{
  automatic_tax: Stripe.Params.SubscriptionListParams.AutomaticTax.t() | nil,
  collection_method: String.t() | nil,
  created: map() | nil,
  current_period_end: map() | nil,
  current_period_start: map() | nil,
  customer: String.t() | nil,
  customer_account: String.t() | nil,
  ending_before: String.t() | nil,
  expand: [String.t()] | nil,
  limit: integer() | nil,
  plan: String.t() | nil,
  price: String.t() | nil,
  starting_after: String.t() | nil,
  status: String.t() | nil,
  test_clock: String.t() | nil
}
  • automatic_tax - Filter subscriptions by their automatic tax settings.
  • collection_method - The collection method of the subscriptions to retrieve. Either charge_automatically or send_invoice. Possible values: charge_automatically, send_invoice.
  • created - Only return subscriptions that were created during the given date interval.
  • current_period_end - Only return subscriptions whose minimum item current_period_end falls within the given date interval.
  • current_period_start - Only return subscriptions whose maximum item current_period_start falls within the given date interval.
  • customer - The ID of the customer whose subscriptions you're retrieving. Max length: 5000.
  • customer_account - The ID of the account representing the customer whose subscriptions you're retrieving. Max length: 5000.
  • ending_before - A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • limit - A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
  • plan - The ID of the plan whose subscriptions will be retrieved. Max length: 5000.
  • price - Filter for subscriptions that contain this recurring price ID. Max length: 5000.
  • starting_after - A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list. Max length: 5000.
  • status - The status of the subscriptions to retrieve. Passing in a value of canceled will return all canceled subscriptions, including those belonging to deleted customers. Pass ended to find subscriptions that are canceled and subscriptions that are expired due to incomplete payment. Passing in a value of all will return subscriptions of all statuses. If no value is supplied, all subscriptions that have not been canceled are returned. Possible values: active, all, canceled, ended, incomplete, incomplete_expired, past_due, paused, trialing, unpaid.
  • test_clock - Filter for subscriptions that are associated with the specified test clock. The response will not include subscriptions with test clocks if this and the customer parameter is not set. Max length: 5000.