Stripe.Params.SubscriptionListParams.AutomaticTax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SubscriptionListParams.AutomaticTax{
  enabled: boolean() | nil
}
  • enabled - Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.