Parameters for subscription migrate.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionMigrateParams{ billing_mode: Stripe.Params.SubscriptionMigrateParams.BillingMode.t(), expand: [String.t()] | nil }
billing_mode- Controls how prorations and invoices for subscriptions are calculated and orchestrated.expand- Specifies which fields in the response should be expanded.