Parameters for subscription resume.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionResumeParams{ billing_cycle_anchor: String.t() | nil, expand: [String.t()] | nil, proration_behavior: String.t() | nil, proration_date: integer() | nil }
billing_cycle_anchor- The billing cycle anchor that applies when the subscription is resumed. Eithernoworunchanged. The default isnow. For more information, see the billing cycle documentation. Possible values:now,unchanged.expand- Specifies which fields in the response should be expanded.proration_behavior- Determines how to handle prorations resulting from thebilling_cycle_anchorbeingunchanged. When thebilling_cycle_anchoris set tonow(default value), no prorations are generated. If no value is passed, the default iscreate_prorations. Possible values:always_invoice,create_prorations,none.proration_date- If set, prorations will be calculated as though the subscription was resumed at the given time. This can be used to apply exactly the same prorations that were previewed with the create preview endpoint. Format: Unix timestamp.