Stripe.Params.SubscriptionScheduleCancelParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for subscription schedule cancel.

Summary

Types

t()

@type t() :: %Stripe.Params.SubscriptionScheduleCancelParams{
  expand: [String.t()] | nil,
  invoice_now: boolean() | nil,
  prorate: boolean() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • invoice_now - If the subscription schedule is active, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults to true.
  • prorate - If the subscription schedule is active, indicates if the cancellation should be prorated. Defaults to true.