Stripe.Params.SubscriptionScheduleCreateParams.DefaultSettings
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionScheduleCreateParams.DefaultSettings{ application_fee_percent: float() | nil, automatic_tax: Stripe.Params.SubscriptionScheduleCreateParams.DefaultSettings.AutomaticTax.t() | nil, billing_cycle_anchor: String.t() | nil, billing_thresholds: map() | nil, collection_method: String.t() | nil, default_payment_method: String.t() | nil, description: map() | nil, invoice_settings: Stripe.Params.SubscriptionScheduleCreateParams.DefaultSettings.InvoiceSettings.t() | nil, on_behalf_of: map() | nil, transfer_data: map() | nil }
application_fee_percent- A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner's Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees documentation.automatic_tax- Default settings for automatic tax computation.billing_cycle_anchor- Can be set tophase_startto set the anchor to the start of the phase orautomaticto automatically change it if needed. Cannot be set tophase_startif this phase specifies a trial. For more information, see the billing cycle documentation. Possible values:automatic,phase_start.billing_thresholds- Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.collection_method- Eithercharge_automatically, orsend_invoice. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription asactive. Defaults tocharge_automaticallyon creation. Possible values:charge_automatically,send_invoice.default_payment_method- ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer's invoice settings. Max length: 5000.description- Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.invoice_settings- All invoices will be billed using the specified settings.on_behalf_of- The account on behalf of which to charge, for each of the associated subscription's invoices.transfer_data- The data with which to automatically create a Transfer for each of the associated subscription's invoices.