Stripe.Params.SubscriptionScheduleCreateParams.DefaultSettings.InvoiceSettings
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionScheduleCreateParams.DefaultSettings.InvoiceSettings{ account_tax_ids: map() | nil, days_until_due: integer() | nil, issuer: Stripe.Params.SubscriptionScheduleCreateParams.DefaultSettings.InvoiceSettings.Issuer.t() | nil }
account_tax_ids- The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.days_until_due- Number of days within which a customer must pay invoices generated by this subscription schedule. This value will benullfor subscription schedules wherecollection_method=charge_automatically.issuer- The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.