Stripe.Params.SubscriptionScheduleReleaseParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for subscription schedule release.

Summary

Types

t()

@type t() :: %Stripe.Params.SubscriptionScheduleReleaseParams{
  expand: [String.t()] | nil,
  preserve_cancel_date: boolean() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • preserve_cancel_date - Keep any cancellation on the subscription that the schedule has set