Stripe.Params.SubscriptionScheduleUpdateParams.DefaultSettings.InvoiceSettings (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.SubscriptionScheduleUpdateParams.DefaultSettings.InvoiceSettings{
    account_tax_ids: map() | nil,
    days_until_due: integer() | nil,
    issuer:
      Stripe.Params.SubscriptionScheduleUpdateParams.DefaultSettings.InvoiceSettings.Issuer.t()
      | nil
  }
  • account_tax_ids - The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule.
  • days_until_due - Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where collection_method=charge_automatically.
  • issuer - The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.