Stripe.Params.SubscriptionScheduleUpdateParams.Phases.AddInvoiceItems
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionScheduleUpdateParams.Phases.AddInvoiceItems{ discounts: [ Stripe.Params.SubscriptionScheduleUpdateParams.Phases.AddInvoiceItems.Discounts.t() ] | nil, metadata: %{required(String.t()) => String.t()} | nil, period: Stripe.Params.SubscriptionScheduleUpdateParams.Phases.AddInvoiceItems.Period.t() | nil, price: String.t() | nil, price_data: Stripe.Params.SubscriptionScheduleUpdateParams.Phases.AddInvoiceItems.PriceData.t() | nil, quantity: integer() | nil, tax_rates: map() | nil }
discounts- The coupons to redeem into discounts for the item.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.period- The period associated with this invoice item. If not set,period.start.typedefaults tomax_item_period_startandperiod.end.typedefaults tomin_item_period_end.price- The ID of the price object. One ofpriceorprice_datais required. Max length: 5000.price_data- Data used to generate a new Price object inline. One ofpriceorprice_datais required.quantity- Quantity for this item. Defaults to 1.tax_rates- The tax rates which apply to the item. When set, thedefault_tax_ratesdo not apply to this item.