Stripe.Params.SubscriptionUpdateParams.Items (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.SubscriptionUpdateParams.Items{
  billing_thresholds: map() | nil,
  clear_usage: boolean() | nil,
  deleted: boolean() | nil,
  discounts: map() | nil,
  id: String.t() | nil,
  metadata: map() | nil,
  plan: String.t() | nil,
  price: String.t() | nil,
  price_data: Stripe.Params.SubscriptionUpdateParams.Items.PriceData.t() | nil,
  quantity: integer() | nil,
  tax_rates: map() | nil
}
  • billing_thresholds - Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
  • clear_usage - Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. clear_usage has no effect if the plan has a billing meter attached.
  • deleted - A flag that, if set to true, will delete the specified item.
  • discounts - The coupons to redeem into discounts for the subscription item.
  • id - Subscription item to update. Max length: 5000.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • plan - Plan ID for this item, as a string. Max length: 5000.
  • price - The ID of the price object. One of price or price_data is required. When changing a subscription item's price, quantity is set to 1 unless a quantity parameter is provided. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required.
  • quantity - Quantity for this item.
  • tax_rates - A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.