Stripe.Params.SubscriptionUpdateParams.PaymentSettings
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionUpdateParams.PaymentSettings{ payment_method_options: Stripe.Params.SubscriptionUpdateParams.PaymentSettings.PaymentMethodOptions.t() | nil, payment_method_types: map() | nil, save_default_payment_method: String.t() | nil }
payment_method_options- Payment-method-specific configuration to provide to invoices created by the subscription.payment_method_types- The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your invoice template settings. Should not be specified with payment_method_configurationsave_default_payment_method- Configure whether Stripe updatessubscription.default_payment_methodwhen payment succeeds. Defaults tooffif unspecified. Possible values:off,on_subscription.