Stripe.Params.SubscriptionUpdateParams.PaymentSettings.PaymentMethodOptions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionUpdateParams.PaymentSettings.PaymentMethodOptions{ acss_debit: map() | nil, bancontact: map() | nil, card: map() | nil, customer_balance: map() | nil, konbini: map() | nil, payto: map() | nil, sepa_debit: map() | nil, us_bank_account: map() | nil }
acss_debit- This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.bancontact- This sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.card- This sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.customer_balance- This sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.konbini- This sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.payto- This sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.sepa_debit- This sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.us_bank_account- This sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.