Parameters for calculation create.
Summary
Types
@type t() :: %Stripe.Params.Tax.CalculationCreateParams{ currency: String.t(), customer: String.t() | nil, customer_details: Stripe.Params.Tax.CalculationCreateParams.CustomerDetails.t() | nil, expand: [String.t()] | nil, line_items: [Stripe.Params.Tax.CalculationCreateParams.LineItems.t()], ship_from_details: Stripe.Params.Tax.CalculationCreateParams.ShipFromDetails.t() | nil, shipping_cost: Stripe.Params.Tax.CalculationCreateParams.ShippingCost.t() | nil, tax_date: integer() | nil }
currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.customer- The ID of an existing customer to use for this calculation. If provided, the customer's address and tax IDs are copied tocustomer_details. Max length: 5000.customer_details- Details about the customer, including address and tax IDs.expand- Specifies which fields in the response should be expanded.line_items- A list of items the customer is purchasing.ship_from_details- Details about the address from which the goods are being shipped.shipping_cost- Shipping cost details to be used for the calculation.tax_date- Timestamp of date at which the tax rules and rates in effect applies for the calculation. Measured in seconds since the Unix epoch. Can be up to 48 hours in the past, and up to 48 hours in the future.