Stripe.Params.Tax.CalculationCreateParams.ShippingCost
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Tax.CalculationCreateParams.ShippingCost{ amount: integer() | nil, shipping_rate: String.t() | nil, tax_behavior: String.t() | nil, tax_code: String.t() | nil }
amount- A positive integer in the smallest currency unit representing the shipping charge. Iftax_behavior=inclusive, then this amount includes taxes. Otherwise, taxes are calculated on top of this amount.shipping_rate- If provided, the shipping rate'samount,tax_codeandtax_behaviorare used. If you provide a shipping rate, then you cannot pass theamount,tax_code, ortax_behaviorparameters. Max length: 5000.tax_behavior- Specifies whether theamountincludes taxes. Iftax_behavior=inclusive, then the amount includes taxes. Defaults toexclusive. Possible values:exclusive,inclusive.tax_code- The tax code used to calculate tax on shipping. If not provided, the default shipping tax code from your Tax Settings is used.