Stripe.Params.Tax.RegistrationCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for registration create.

Summary

Types

t()

@type t() :: %Stripe.Params.Tax.RegistrationCreateParams{
  active_from: map(),
  country: String.t(),
  country_options:
    Stripe.Params.Tax.RegistrationCreateParams.CountryOptions.t(),
  expand: [String.t()] | nil,
  expires_at: integer() | nil
}
  • active_from - Time at which the Tax Registration becomes active. It can be either now to indicate the current time, or a future timestamp measured in seconds since the Unix epoch.
  • country - Two-letter country code (ISO 3166-1 alpha-2). Max length: 5000.
  • country_options - Specific options for a registration in the specified country.
  • expand - Specifies which fields in the response should be expanded.
  • expires_at - If set, the Tax Registration stops being active at this time. If not set, the Tax Registration will be active indefinitely. Timestamp measured in seconds since the Unix epoch. Format: Unix timestamp.