Parameters for settings update.
Summary
Types
@type t() :: %Stripe.Params.Tax.SettingsUpdateParams{ defaults: Stripe.Params.Tax.SettingsUpdateParams.Defaults.t() | nil, expand: [String.t()] | nil, head_office: Stripe.Params.Tax.SettingsUpdateParams.HeadOffice.t() | nil }
defaults- Default configuration to be used on Stripe Tax calculations.expand- Specifies which fields in the response should be expanded.head_office- The place where your business is located.