Stripe.Params.Tax.SettingsUpdateParams.Defaults (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Tax.SettingsUpdateParams.Defaults{
  tax_behavior: String.t() | nil,
  tax_code: String.t() | nil
}
  • tax_behavior - Specifies the default tax behavior to be used when the item's price has unspecified tax behavior. One of inclusive, exclusive, or inferred_by_currency. Once specified, it cannot be changed back to null. Possible values: exclusive, inclusive, inferred_by_currency.
  • tax_code - A tax code ID.