Stripe.Params.Tax.TransactionCreateFromCalculationParams
(tiger_stripe v0.1.10)
Parameters for transaction create from calculation.
Summary
Types
@type t() :: %Stripe.Params.Tax.TransactionCreateFromCalculationParams{ calculation: String.t(), expand: [String.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil, posted_at: integer() | nil, reference: String.t() }
calculation- Tax Calculation ID to be used as input when creating the transaction. Max length: 5000.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.posted_at- The Unix timestamp representing when the tax liability is assumed or reduced, which determines the liability posting period and handling in tax liability reports. The timestamp must fall within thetax_dateand the current time, unless thetax_dateis scheduled in advance. Defaults to the current time. Format: Unix timestamp.reference- A custom order or sale identifier, such as 'myOrder_123'. Must be unique across all transactions, including reversals. Max length: 500.