Stripe.Params.Tax.TransactionCreateReversalParams.ShippingCost
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Tax.TransactionCreateReversalParams.ShippingCost{ amount: integer() | nil, amount_tax: integer() | nil }
amount- The amount to reverse, in the smallest currency unit in negative.amount_tax- The amount of tax to reverse, in the smallest currency unit in negative.