Stripe.Params.TaxIdCreateParams.Owner (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.TaxIdCreateParams.Owner{
  account: String.t() | nil,
  customer: String.t() | nil,
  customer_account: String.t() | nil,
  type: String.t() | nil
}
  • account - Connected Account the tax ID belongs to. Required when type=account
  • customer - Customer the tax ID belongs to. Required when type=customer Max length: 5000.
  • customer_account - ID of the Account representing the customer that the tax ID belongs to. Can be used in place of customer when type=customer Max length: 5000.
  • type - Type of owner referenced. Possible values: account, application, customer, self.