Parameters for tax rate retrieve.
Summary
Types
@type t() :: %Stripe.Params.TaxRateRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for tax rate retrieve.
@type t() :: %Stripe.Params.TaxRateRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.