Stripe.Params.Terminal.ConfigurationCreateParams.RebootWindow (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Terminal.ConfigurationCreateParams.RebootWindow{
  end_hour: integer() | nil,
  start_hour: integer() | nil
}
  • end_hour - Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.
  • start_hour - Integer between 0 to 23 that represents the start hour of the reboot time window.