Parameters for configuration retrieve.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ConfigurationRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for configuration retrieve.
@type t() :: %Stripe.Params.Terminal.ConfigurationRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.