Stripe.Params.Terminal.LocationCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for location create.

Summary

Types

t()

@type t() :: %Stripe.Params.Terminal.LocationCreateParams{
  address: Stripe.Params.Terminal.LocationCreateParams.Address.t() | nil,
  address_kana:
    Stripe.Params.Terminal.LocationCreateParams.AddressKana.t() | nil,
  address_kanji:
    Stripe.Params.Terminal.LocationCreateParams.AddressKanji.t() | nil,
  configuration_overrides: String.t() | nil,
  display_name: String.t() | nil,
  display_name_kana: String.t() | nil,
  display_name_kanji: String.t() | nil,
  expand: [String.t()] | nil,
  metadata: map() | nil,
  phone: String.t() | nil
}
  • address - The full address of the location.
  • address_kana - The Kana variation of the full address of the location (Japan only).
  • address_kanji - The Kanji variation of the full address of the location (Japan only).
  • configuration_overrides - The ID of a configuration that will be used to customize all readers in this location. Max length: 500.
  • display_name - A name for the location. Maximum length is 1000 characters. Max length: 1000.
  • display_name_kana - The Kana variation of the name for the location (Japan only). Maximum length is 1000 characters. Max length: 1000.
  • display_name_kanji - The Kanji variation of the name for the location (Japan only). Maximum length is 1000 characters. Max length: 1000.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • phone - The phone number for the location.