Parameters for location update.
Summary
Types
@type t() :: %Stripe.Params.Terminal.LocationUpdateParams{ address: Stripe.Params.Terminal.LocationUpdateParams.Address.t() | nil, address_kana: Stripe.Params.Terminal.LocationUpdateParams.AddressKana.t() | nil, address_kanji: Stripe.Params.Terminal.LocationUpdateParams.AddressKanji.t() | nil, configuration_overrides: map() | nil, display_name: map() | nil, display_name_kana: map() | nil, display_name_kanji: map() | nil, expand: [String.t()] | nil, metadata: map() | nil, phone: map() | nil }
address- The full address of the location. You can't change the location'scountry. If you need to modify thecountryfield, create a newLocationobject and re-register any existing readers to that location.address_kana- The Kana variation of the full address of the location (Japan only).address_kanji- The Kanji variation of the full address of the location (Japan only).configuration_overrides- The ID of a configuration that will be used to customize all readers in this location.display_name- A name for the location.display_name_kana- The Kana variation of the name for the location (Japan only).display_name_kanji- The Kanji variation of the name for the location (Japan only).expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.phone- The phone number for the location.