Parameters for reader cancel action.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderCancelActionParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for reader cancel action.
@type t() :: %Stripe.Params.Terminal.ReaderCancelActionParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.