Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs{
  custom_text:
    Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.CustomText.t() | nil,
  required: boolean() | nil,
  selection:
    Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Selection.t() | nil,
  toggles:
    [Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Toggles.t()] | nil,
  type: String.t() | nil
}
  • custom_text - Customize the text which will be displayed while collecting this input
  • required - Indicate that this input is required, disabling the skip button
  • selection - Options for the selection input
  • toggles - List of toggles to be displayed and customization for the toggles
  • type - The type of input to collect Possible values: email, numeric, phone, selection, signature, text.