Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Selection.Choices (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Selection.Choices{
    id: String.t() | nil,
    style: String.t() | nil,
    text: String.t() | nil
  }
  • id - The unique identifier for this choice Max length: 50.
  • style - The style of the button which will be shown for this choice. Can be primary or secondary. Possible values: primary, secondary.
  • text - The text which will be shown on the button for this choice Max length: 30.