Stripe.Params.Terminal.ReaderCollectPaymentMethodParams
(tiger_stripe v0.1.10)
Parameters for reader collect payment method.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderCollectPaymentMethodParams{ collect_config: Stripe.Params.Terminal.ReaderCollectPaymentMethodParams.CollectConfig.t() | nil, expand: [String.t()] | nil, payment_intent: String.t() }
collect_config- Configuration overrides for this collection, such as tipping, surcharging, and customer cancellation settings.expand- Specifies which fields in the response should be expanded.payment_intent- The ID of the PaymentIntent to collect a payment method for. Max length: 5000.