Stripe.Params.Terminal.ReaderCollectPaymentMethodParams.CollectConfig (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Terminal.ReaderCollectPaymentMethodParams.CollectConfig{
  allow_redisplay: String.t() | nil,
  enable_customer_cancellation: boolean() | nil,
  skip_tipping: boolean() | nil,
  tipping:
    Stripe.Params.Terminal.ReaderCollectPaymentMethodParams.CollectConfig.Tipping.t()
    | nil
}
  • allow_redisplay - This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. Possible values: always, limited, unspecified.
  • enable_customer_cancellation - Enables cancel button on transaction screens.
  • skip_tipping - Override showing a tipping selection screen on this transaction.
  • tipping - Tipping configuration for this transaction.