Stripe.Params.Terminal.ReaderConfirmPaymentIntentParams
(tiger_stripe v0.1.10)
Parameters for reader confirm payment intent.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderConfirmPaymentIntentParams{ confirm_config: Stripe.Params.Terminal.ReaderConfirmPaymentIntentParams.ConfirmConfig.t() | nil, expand: [String.t()] | nil, payment_intent: String.t() }
confirm_config- Configuration overrides for this confirmation, such as surcharge settings and return URL.expand- Specifies which fields in the response should be expanded.payment_intent- The ID of the PaymentIntent to confirm. Max length: 5000.