Stripe.Params.Terminal.ReaderConfirmPaymentIntentParams.ConfirmConfig (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Terminal.ReaderConfirmPaymentIntentParams.ConfirmConfig{
  return_url: String.t() | nil
}
  • return_url - The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.