Stripe.Params.Terminal.ReaderProcessPaymentIntentParams.ProcessConfig (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Terminal.ReaderProcessPaymentIntentParams.ProcessConfig{
  allow_redisplay: String.t() | nil,
  enable_customer_cancellation: boolean() | nil,
  return_url: String.t() | nil,
  skip_tipping: boolean() | nil,
  tipping:
    Stripe.Params.Terminal.ReaderProcessPaymentIntentParams.ProcessConfig.Tipping.t()
    | nil
}
  • allow_redisplay - This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. Possible values: always, limited, unspecified.
  • enable_customer_cancellation - Enables cancel button on transaction screens.
  • return_url - The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. If you'd prefer to redirect to a mobile application, you can alternatively supply an application URI scheme.
  • skip_tipping - Override showing a tipping selection screen on this transaction.
  • tipping - Tipping configuration for this transaction.