Stripe.Params.Terminal.ReaderProcessPaymentIntentParams.ProcessConfig.Tipping (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.Terminal.ReaderProcessPaymentIntentParams.ProcessConfig.Tipping{
    amount_eligible: integer() | nil
  }
  • amount_eligible - Amount used to calculate tip suggestions on tipping selection screen for this transaction. Must be a positive integer in the smallest currency unit (e.g., 100 cents to represent $1.00 or 100 to represent ¥100, a zero-decimal currency).