Parameters for reader retrieve.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderRetrieveParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for reader retrieve.
@type t() :: %Stripe.Params.Terminal.ReaderRetrieveParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.