Stripe.Params.Terminal.ReaderSetReaderDisplayParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for reader set reader display.

Summary

Types

t()

@type t() :: %Stripe.Params.Terminal.ReaderSetReaderDisplayParams{
  cart: Stripe.Params.Terminal.ReaderSetReaderDisplayParams.Cart.t() | nil,
  expand: [String.t()] | nil,
  type: String.t()
}
  • cart - Cart details to display on the reader screen, including line items, amounts, and currency.
  • expand - Specifies which fields in the response should be expanded.
  • type - Type of information to display. Only cart is currently supported. Possible values: cart.