Parameters for reader update.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderUpdateParams{ expand: [String.t()] | nil, label: map() | nil, metadata: map() | nil }
expand- Specifies which fields in the response should be expanded.label- The new label of the reader.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.