Stripe.Params.TestHelpers.ConfirmationTokenCreateParams
(tiger_stripe v0.1.10)
Parameters for confirmation token create.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.ConfirmationTokenCreateParams{ expand: [String.t()] | nil, payment_method: String.t() | nil, payment_method_data: Stripe.Params.TestHelpers.ConfirmationTokenCreateParams.PaymentMethodData.t() | nil, payment_method_options: Stripe.Params.TestHelpers.ConfirmationTokenCreateParams.PaymentMethodOptions.t() | nil, return_url: String.t() | nil, setup_future_usage: String.t() | nil, shipping: Stripe.Params.TestHelpers.ConfirmationTokenCreateParams.Shipping.t() | nil }
expand- Specifies which fields in the response should be expanded.payment_method- ID of an existing PaymentMethod. Max length: 5000.payment_method_data- If provided, this hash will be used to create a PaymentMethod.payment_method_options- Payment-method-specific configuration for this ConfirmationToken.return_url- Return URL used to confirm the Intent.setup_future_usage- Indicates that you intend to make future payments with this ConfirmationToken's payment method.
The presence of this property will attach the payment method to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete. Possible values: off_session, on_session.
shipping- Shipping information for this ConfirmationToken.