Stripe.Params.TestHelpers.ConfirmationTokenCreateParams.PaymentMethodOptions.Card.Installments.Plan
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.ConfirmationTokenCreateParams.PaymentMethodOptions.Card.Installments.Plan{ count: integer() | nil, interval: String.t() | nil, type: String.t() | nil }
count- Forfixed_countinstallment plans, this is required. It represents the number of installment payments your customer will make to their credit card.interval- Forfixed_countinstallment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One ofmonth. Possible values:month.type- Type of installment plan, one offixed_count,bonus, orrevolving. Possible values:bonus,fixed_count,revolving.