Stripe.Params.TestHelpers.CustomerFundCashBalanceParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for customer fund cash balance.

Summary

Types

t()

@type t() :: %Stripe.Params.TestHelpers.CustomerFundCashBalanceParams{
  amount: integer(),
  currency: String.t(),
  expand: [String.t()] | nil,
  reference: String.t() | nil
}
  • amount - Amount to be used for this test cash balance transaction. A positive integer representing how much to fund in the smallest currency unit (e.g., 100 cents to fund $1.00 or 100 to fund ¥100, a zero-decimal currency).
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • expand - Specifies which fields in the response should be expanded.
  • reference - A description of the test funding. This simulates free-text references supplied by customers when making bank transfers to their cash balance. You can use this to test how Stripe's reconciliation algorithm applies to different user inputs. Max length: 5000.