Stripe.Params.TestHelpers.Issuing.AuthorizationCaptureParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for authorization capture.

Summary

Types

t()

@type t() :: %Stripe.Params.TestHelpers.Issuing.AuthorizationCaptureParams{
  capture_amount: integer() | nil,
  close_authorization: boolean() | nil,
  expand: [String.t()] | nil,
  purchase_details:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCaptureParams.PurchaseDetails.t()
    | nil
}
  • capture_amount - The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the smallest currency unit.
  • close_authorization - Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.
  • expand - Specifies which fields in the response should be expanded.
  • purchase_details - Additional purchase information that is optionally provided by the merchant.