Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for authorization create.

Summary

Types

t()

@type t() :: %Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams{
  amount: integer() | nil,
  amount_details:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.AmountDetails.t()
    | nil,
  authorization_method: String.t() | nil,
  card: String.t(),
  currency: String.t() | nil,
  expand: [String.t()] | nil,
  fleet:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.Fleet.t() | nil,
  fraud_disputability_likelihood: String.t() | nil,
  fuel:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.Fuel.t() | nil,
  is_amount_controllable: boolean() | nil,
  merchant_amount: integer() | nil,
  merchant_currency: String.t() | nil,
  merchant_data:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.MerchantData.t()
    | nil,
  network_data:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.NetworkData.t()
    | nil,
  risk_assessment:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.RiskAssessment.t()
    | nil,
  verification_data:
    Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.VerificationData.t()
    | nil,
  wallet: String.t() | nil
}
  • amount - The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card's currency, and in the smallest currency unit.
  • amount_details - Detailed breakdown of amount components. These amounts are denominated in currency and in the smallest currency unit.
  • authorization_method - How the card details were provided. Defaults to online. Possible values: chip, contactless, keyed_in, online, swipe.
  • card - Card associated with this authorization. Max length: 5000.
  • currency - The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • expand - Specifies which fields in the response should be expanded.
  • fleet - Fleet-specific information for authorizations using Fleet cards.
  • fraud_disputability_likelihood - Probability that this transaction can be disputed in the event of fraud. Assessed by comparing the characteristics of the authorization to card network rules. Possible values: neutral, unknown, very_likely, very_unlikely.
  • fuel - Information about fuel that was purchased with this transaction.
  • is_amount_controllable - If set true, you may provide amount to control how much to hold for the authorization.
  • merchant_amount - The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the smallest currency unit.
  • merchant_currency - The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • merchant_data - Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
  • network_data - Details about the authorization, such as identifiers, set by the card network.
  • risk_assessment - Stripe’s assessment of the fraud risk for this authorization.
  • verification_data - Verifications that Stripe performed on information that the cardholder provided to the merchant.
  • wallet - The digital wallet used for this transaction. One of apple_pay, google_pay, or samsung_pay. Will populate as null when no digital wallet was utilized. Possible values: apple_pay, google_pay, samsung_pay.