Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.RiskAssessment.CardTestingRisk (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.RiskAssessment.CardTestingRisk{
    invalid_account_number_decline_rate_past_hour: integer() | nil,
    invalid_credentials_decline_rate_past_hour: integer() | nil,
    risk_level: String.t() | nil
  }
  • invalid_account_number_decline_rate_past_hour - The % of declines due to a card number not existing in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of card testing activity, meaning bad actors may be attempting different card number combinations to guess a correct one. Takes on values between 0 and 100.
  • invalid_credentials_decline_rate_past_hour - The % of declines due to incorrect verification data (like CVV or expiry) in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of bad actors attempting to utilize valid card credentials at merchants with verification requirements. Takes on values between 0 and 100.
  • risk_level - The likelihood that this authorization is associated with card testing activity. This is assessed by evaluating decline activity over the last hour. Possible values: elevated, highest, low, normal, not_assessed, unknown.