Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.RiskAssessment.FraudRisk (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.RiskAssessment.FraudRisk{
    level: String.t() | nil,
    score: float() | nil
  }
  • level - Stripe’s assessment of the likelihood of fraud on an authorization. Possible values: elevated, highest, low, normal, not_assessed, unknown.
  • score - Stripe’s numerical model score assessing the likelihood of fraudulent activity. A higher score means a higher likelihood of fraudulent activity, and anything above 25 is considered high risk.