Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.RiskAssessment.MerchantDisputeRisk (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.TestHelpers.Issuing.AuthorizationCreateParams.RiskAssessment.MerchantDisputeRisk{
    dispute_rate: integer() | nil,
    risk_level: String.t() | nil
  }
  • dispute_rate - The dispute rate observed across all Stripe Issuing authorizations for this merchant. For example, a value of 50 means 50% of authorizations from this merchant on Stripe Issuing have resulted in a dispute. Higher values mean a higher likelihood the authorization is disputed. Takes on values between 0 and 100.
  • risk_level - The likelihood that authorizations from this merchant will result in a dispute based on their history on Stripe Issuing. Possible values: elevated, highest, low, normal, not_assessed, unknown.