Stripe.Params.TestHelpers.Issuing.AuthorizationIncrementParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for authorization increment.

Summary

Types

t()

@type t() :: %Stripe.Params.TestHelpers.Issuing.AuthorizationIncrementParams{
  expand: [String.t()] | nil,
  increment_amount: integer(),
  is_amount_controllable: boolean() | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • increment_amount - The amount to increment the authorization by. This amount is in the authorization currency and in the smallest currency unit.
  • is_amount_controllable - If set true, you may provide amount to control how much to hold for the authorization.