Stripe.Params.TestHelpers.Issuing.AuthorizationRespondParams
(tiger_stripe v0.1.10)
Parameters for authorization respond.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.Issuing.AuthorizationRespondParams{ confirmed: boolean(), expand: [String.t()] | nil }
confirmed- Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).expand- Specifies which fields in the response should be expanded.