Stripe.Params.TestHelpers.Issuing.TransactionCreateForceCaptureParams.PurchaseDetails.Fleet.ReportedBreakdown.Tax
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.Issuing.TransactionCreateForceCaptureParams.PurchaseDetails.Fleet.ReportedBreakdown.Tax{ local_amount_decimal: String.t() | nil, national_amount_decimal: String.t() | nil }
local_amount_decimal- Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax. Format: decimal string.national_amount_decimal- Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax. Format: decimal string.