Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • fleet - Fleet-specific information for transactions using Fleet cards.
  • flight - Information about the flight that was purchased with this transaction.
  • fuel - Information about fuel that was purchased with this transaction.
  • lodging - Information about lodging that was purchased with this transaction.
  • receipt - The line items in the purchase.
  • reference - A merchant-specific order number. Max length: 5000.