Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Fleet
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Fleet{ cardholder_prompt_data: Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Fleet.CardholderPromptData.t() | nil, purchase_type: String.t() | nil, reported_breakdown: Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Fleet.ReportedBreakdown.t() | nil, service_type: String.t() | nil }
cardholder_prompt_data- Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.purchase_type- The type of purchase. One offuel_purchase,non_fuel_purchase, orfuel_and_non_fuel_purchase. Possible values:fuel_and_non_fuel_purchase,fuel_purchase,non_fuel_purchase. Max length: 5000.reported_breakdown- More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.service_type- The type of fuel service. One ofnon_fuel_transaction,full_service, orself_service. Possible values:full_service,non_fuel_transaction,self_service. Max length: 5000.