Parameters for test clock retrieve.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.TestClockRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for test clock retrieve.
@type t() :: %Stripe.Params.TestHelpers.TestClockRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.