Stripe.Params.TestHelpers.Treasury.ReceivedCreditCreateParams
(tiger_stripe v0.1.10)
Parameters for received credit create.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.Treasury.ReceivedCreditCreateParams{ amount: integer(), currency: String.t(), description: String.t() | nil, expand: [String.t()] | nil, financial_account: String.t(), initiating_payment_method_details: Stripe.Params.TestHelpers.Treasury.ReceivedCreditCreateParams.InitiatingPaymentMethodDetails.t() | nil, network: String.t() }
amount- Amount (in cents) to be transferred.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.expand- Specifies which fields in the response should be expanded.financial_account- The FinancialAccount to send funds to.initiating_payment_method_details- Initiating payment method details for the object.network- Specifies the network rails to be used. If not set, will default to the PaymentMethod's preferred network. See the docs to learn more about money movement timelines for each network type. Possible values:ach,us_domestic_wire.