Stripe.Params.TokenCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for token create.

Summary

Types

t()

@type t() :: %Stripe.Params.TokenCreateParams{
  account: Stripe.Params.TokenCreateParams.Account.t() | nil,
  bank_account: Stripe.Params.TokenCreateParams.BankAccount.t() | nil,
  card: map() | nil,
  customer: String.t() | nil,
  cvc_update: Stripe.Params.TokenCreateParams.CvcUpdate.t() | nil,
  expand: [String.t()] | nil,
  person: Stripe.Params.TokenCreateParams.Person.t() | nil,
  pii: Stripe.Params.TokenCreateParams.Pii.t() | nil
}
  • account - Information for the account this token represents.
  • bank_account - The bank account this token will represent.
  • card - The card this token will represent. If you also pass in a customer, the card must be the ID of a card belonging to the customer. Otherwise, if you do not pass in a customer, this is a dictionary containing a user's credit card details, with the options described below.
  • customer - Create a token for the customer, which is owned by the application's account. You can only use this with an OAuth access token or Stripe-Account header. Learn more about cloning saved payment methods. Max length: 5000.
  • cvc_update - The updated CVC value this token represents.
  • expand - Specifies which fields in the response should be expanded.
  • person - Information for the person this token represents.
  • pii - The PII this token represents.