Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.TokenCreateParams.Account{ business_type: String.t() | nil, company: Stripe.Params.TokenCreateParams.Account.Company.t() | nil, individual: Stripe.Params.TokenCreateParams.Account.Individual.t() | nil, tos_shown_and_accepted: boolean() | nil }
business_type- The business type. Possible values:company,government_entity,individual,non_profit.company- Information about the company or business.individual- Information about the person represented by the account.tos_shown_and_accepted- Whether the user described by the data in the token has been shown the Stripe Connected Account Agreement. When creating an account token to create a new Connect account, this value must betrue.