Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.TokenCreateParams.Account.Company{ address: Stripe.Params.TokenCreateParams.Account.Company.Address.t() | nil, address_kana: Stripe.Params.TokenCreateParams.Account.Company.AddressKana.t() | nil, address_kanji: Stripe.Params.TokenCreateParams.Account.Company.AddressKanji.t() | nil, directors_provided: boolean() | nil, directorship_declaration: Stripe.Params.TokenCreateParams.Account.Company.DirectorshipDeclaration.t() | nil, executives_provided: boolean() | nil, export_license_id: String.t() | nil, export_purpose_code: String.t() | nil, name: String.t() | nil, name_kana: String.t() | nil, name_kanji: String.t() | nil, owners_provided: boolean() | nil, ownership_declaration: Stripe.Params.TokenCreateParams.Account.Company.OwnershipDeclaration.t() | nil, ownership_declaration_shown_and_signed: boolean() | nil, ownership_exemption_reason: String.t() | nil, phone: String.t() | nil, registration_date: map() | nil, registration_number: String.t() | nil, representative_declaration: Stripe.Params.TokenCreateParams.Account.Company.RepresentativeDeclaration.t() | nil, structure: String.t() | nil, tax_id: String.t() | nil, tax_id_registrar: String.t() | nil, vat_id: String.t() | nil, verification: Stripe.Params.TokenCreateParams.Account.Company.Verification.t() | nil }
address- The company's primary address.address_kana- The Kana variation of the company's primary address (Japan only).address_kanji- The Kanji variation of the company's primary address (Japan only).directors_provided- Whether the company's directors have been provided. Set this Boolean totrueafter creating all the company's directors with the Persons API for accounts with arelationship.directorrequirement. This value is not automatically set totrueafter creating directors, so it needs to be updated to indicate all directors have been provided.directorship_declaration- This hash is used to attest that the directors information provided to Stripe is both current and correct.executives_provided- Whether the company's executives have been provided. Set this Boolean totrueafter creating all the company's executives with the Persons API for accounts with arelationship.executiverequirement.export_license_id- The export license ID number of the company, also referred as Import Export Code (India only). Max length: 5000.export_purpose_code- The purpose code to use for export transactions (India only). Max length: 5000.name- The company's legal name. Max length: 100.name_kana- The Kana variation of the company's legal name (Japan only). Max length: 100.name_kanji- The Kanji variation of the company's legal name (Japan only). Max length: 100.owners_provided- Whether the company's owners have been provided. Set this Boolean totrueafter creating all the company's owners with the Persons API for accounts with arelationship.ownerrequirement.ownership_declaration- This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.ownership_declaration_shown_and_signed- Whether the user described by the data in the token has been shown the Ownership Declaration and indicated that it is correct.ownership_exemption_reason- This value is used to determine if a business is exempt from providing ultimate beneficial owners. See this support article and changelog for more details. Possible values:qualified_entity_exceeds_ownership_threshold,qualifies_as_financial_institution.phone- The company's phone number (used for verification). Max length: 5000.registration_date- When the business was incorporated or registered.registration_number- The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong). Max length: 5000.representative_declaration- This hash is used to attest that the representative is authorized to act as the representative of their legal entity.structure- The category identifying the legal structure of the company or legal entity. See Business structure for more details. Pass an empty string to unset this value. Possible values:free_zone_establishment,free_zone_llc,government_instrumentality,governmental_unit,incorporated_non_profit,incorporated_partnership,limited_liability_partnership,llc,multi_member_llc,private_company,private_corporation,private_partnership,public_company,public_corporation,public_partnership,registered_charity,single_member_llc,sole_establishment,sole_proprietorship,tax_exempt_government_instrumentality,unincorporated_association,unincorporated_non_profit,unincorporated_partnership.tax_id- The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.) Max length: 5000.tax_id_registrar- The jurisdiction in which thetax_idis registered (Germany-based companies only). Max length: 5000.vat_id- The VAT number of the company. Max length: 5000.verification- Information on the verification state of the company.