Stripe.Params.TokenCreateParams.Account.Company.OwnershipDeclaration (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.TokenCreateParams.Account.Company.OwnershipDeclaration{
  date: integer() | nil,
  ip: String.t() | nil,
  user_agent: String.t() | nil
}
  • date - The Unix timestamp marking when the beneficial owner attestation was made. Format: Unix timestamp.
  • ip - The IP address from which the beneficial owner attestation was made.
  • user_agent - The user agent of the browser from which the beneficial owner attestation was made. Max length: 5000.