Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.TokenCreateParams.Account.Individual{ address: Stripe.Params.TokenCreateParams.Account.Individual.Address.t() | nil, address_kana: Stripe.Params.TokenCreateParams.Account.Individual.AddressKana.t() | nil, address_kanji: Stripe.Params.TokenCreateParams.Account.Individual.AddressKanji.t() | nil, dob: map() | nil, email: String.t() | nil, first_name: String.t() | nil, first_name_kana: String.t() | nil, first_name_kanji: String.t() | nil, full_name_aliases: map() | nil, gender: String.t() | nil, id_number: String.t() | nil, id_number_secondary: String.t() | nil, last_name: String.t() | nil, last_name_kana: String.t() | nil, last_name_kanji: String.t() | nil, maiden_name: String.t() | nil, metadata: map() | nil, phone: String.t() | nil, political_exposure: String.t() | nil, registered_address: Stripe.Params.TokenCreateParams.Account.Individual.RegisteredAddress.t() | nil, relationship: Stripe.Params.TokenCreateParams.Account.Individual.Relationship.t() | nil, ssn_last_4: String.t() | nil, verification: Stripe.Params.TokenCreateParams.Account.Individual.Verification.t() | nil }
address- The individual's primary address.address_kana- The Kana variation of the individual's primary address (Japan only).address_kanji- The Kanji variation of the individual's primary address (Japan only).dob- The individual's date of birth.email- The individual's email address.first_name- The individual's first name. Max length: 100.first_name_kana- The Kana variation of the individual's first name (Japan only). Max length: 5000.first_name_kanji- The Kanji variation of the individual's first name (Japan only). Max length: 5000.full_name_aliases- A list of alternate names or aliases that the individual is known by.gender- The individual's genderid_number- The government-issued ID number of the individual, as appropriate for the representative's country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a PII token created with Stripe.js. Max length: 5000.id_number_secondary- The government-issued secondary ID number of the individual, as appropriate for the representative's country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a PII token created with Stripe.js. Max length: 5000.last_name- The individual's last name. Max length: 100.last_name_kana- The Kana variation of the individual's last name (Japan only). Max length: 5000.last_name_kanji- The Kanji variation of the individual's last name (Japan only). Max length: 5000.maiden_name- The individual's maiden name. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.phone- The individual's phone number.political_exposure- Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction. Possible values:existing,none.registered_address- The individual's registered address.relationship- Describes the person’s relationship to the account.ssn_last_4- The last four digits of the individual's Social Security Number (U.S. only). Max length: 5000.verification- The individual's verification document information.