Stripe.Params.TokenCreateParams.Person.AdditionalTosAcceptances.Account (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.TokenCreateParams.Person.AdditionalTosAcceptances.Account{
  date: integer() | nil,
  ip: String.t() | nil,
  user_agent: map() | nil
}
  • date - The Unix timestamp marking when the account representative accepted the service agreement. Format: Unix timestamp.
  • ip - The IP address from which the account representative accepted the service agreement.
  • user_agent - The user agent of the browser from which the account representative accepted the service agreement.