Stripe.Params.TokenCreateParams.Person.Documents (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.TokenCreateParams.Person.Documents{
  company_authorization:
    Stripe.Params.TokenCreateParams.Person.Documents.CompanyAuthorization.t()
    | nil,
  passport: Stripe.Params.TokenCreateParams.Person.Documents.Passport.t() | nil,
  visa: Stripe.Params.TokenCreateParams.Person.Documents.Visa.t() | nil
}
  • company_authorization - One or more documents that demonstrate proof that this person is authorized to represent the company.
  • passport - One or more documents showing the person's passport page with photo and personal data.
  • visa - One or more documents showing the person's visa required for living in the country where they are residing.