Parameters for topup list.
Summary
Types
@type t() :: %Stripe.Params.TopupListParams{ amount: map() | nil, created: map() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, starting_after: String.t() | nil, status: String.t() | nil }
amount- A positive integer representing how much to transfer.created- A filter on the list, based on the objectcreatedfield. The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.status- Only return top-ups that have the given status. One ofcanceled,failed,pendingorsucceeded. Possible values:canceled,failed,pending,succeeded. Max length: 5000.