Stripe.Params.TransferUpdateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for transfer update.

Summary

Types

t()

@type t() :: %Stripe.Params.TransferUpdateParams{
  description: String.t() | nil,
  expand: [String.t()] | nil,
  metadata: map() | nil
}
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.