Stripe.Params.Treasury.DebitReversalListParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for debit reversal list.

Summary

Types

t()

@type t() :: %Stripe.Params.Treasury.DebitReversalListParams{
  ending_before: String.t() | nil,
  expand: [String.t()] | nil,
  financial_account: String.t(),
  limit: integer() | nil,
  received_debit: String.t() | nil,
  resolution: String.t() | nil,
  starting_after: String.t() | nil,
  status: String.t() | nil
}
  • ending_before - A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • financial_account - Returns objects associated with this FinancialAccount.
  • limit - A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
  • received_debit - Only return DebitReversals for the ReceivedDebit ID. Max length: 5000.
  • resolution - Only return DebitReversals for a given resolution. Possible values: lost, won.
  • starting_after - A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list. Max length: 5000.
  • status - Only return DebitReversals for a given status. Possible values: canceled, completed, processing.