Stripe.Params.Treasury.FinancialAccountCloseParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for financial account close.

Summary

Types

t()

@type t() :: %Stripe.Params.Treasury.FinancialAccountCloseParams{
  expand: [String.t()] | nil,
  forwarding_settings:
    Stripe.Params.Treasury.FinancialAccountCloseParams.ForwardingSettings.t()
    | nil
}
  • expand - Specifies which fields in the response should be expanded.
  • forwarding_settings - A different bank account where funds can be deposited/debited in order to get the closing FA's balance to $0