Stripe.Params.Treasury.FinancialAccountCreateParams.Features (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • card_issuing - Encodes the FinancialAccount's ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.
  • deposit_insurance - Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.
  • financial_addresses - Contains Features that add FinancialAddresses to the FinancialAccount.
  • inbound_transfers - Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.
  • intra_stripe_flows - Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).
  • outbound_payments - Includes Features related to initiating money movement out of the FinancialAccount to someone else's bucket of money.
  • outbound_transfers - Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.