Parameters for outbound payment cancel.
Summary
Types
@type t() :: %Stripe.Params.Treasury.OutboundPaymentCancelParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for outbound payment cancel.
@type t() :: %Stripe.Params.Treasury.OutboundPaymentCancelParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.