Stripe.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodData
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodData{ billing_details: Stripe.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodData.BillingDetails.t() | nil, financial_account: String.t() | nil, metadata: %{required(String.t()) => String.t()} | nil, type: String.t() | nil, us_bank_account: Stripe.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodData.UsBankAccount.t() | nil }
billing_details- Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.financial_account- Required if type is set tofinancial_account. The FinancialAccount ID to send funds to.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.type- The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type. Possible values:financial_account,us_bank_account.us_bank_account- Required hash if type is set tous_bank_account.