Stripe.Params.Treasury.OutboundPaymentCreateParams.EndUserDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.Treasury.OutboundPaymentCreateParams.EndUserDetails{
  ip_address: String.t() | nil,
  present: boolean() | nil
}
  • ip_address - IP address of the user initiating the OutboundPayment. Must be supplied if present is set to true.
  • present - True if the OutboundPayment creation request is being made on behalf of an end user by a platform. Otherwise, false.