Stripe.Params.V2.Core.AccountCreateParams.Configuration.Customer.AutomaticIndirectTax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.V2.Core.AccountCreateParams.Configuration.Customer.AutomaticIndirectTax{
    exempt: String.t() | nil,
    ip_address: String.t() | nil
  }
  • exempt - Describes the customer's tax exemption status, which is none, exempt, or reverse. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”. Possible values: exempt, none, reverse.
  • ip_address - A recent IP address of the customer used for tax reporting and tax location inference.