Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • directorship_declaration - This hash is used to attest that the directors information provided to Stripe is both current and correct.
  • ownership_declaration - This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
  • persons_provided - Attestation that all Persons with a specific Relationship value have been provided.
  • representative_declaration - This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
  • terms_of_service - Attestations of accepted terms of service agreements.