Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.OwnershipDeclaration (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.OwnershipDeclaration{
    date: String.t() | nil,
    ip: String.t() | nil,
    user_agent: String.t() | nil
  }
  • date - The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z. Format: date-time.
  • ip - The IP address from which the beneficial owner attestation was made.
  • user_agent - The user agent of the browser from which the beneficial owner attestation was made.