Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.RepresentativeDeclaration
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.RepresentativeDeclaration{ date: String.t() | nil, ip: String.t() | nil, user_agent: String.t() | nil }
date- The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z. Format: date-time.ip- The IP address from which the representative attestation was made.user_agent- The user agent of the browser from which the representative attestation was made.