Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails{ address: Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.Address.t() | nil, annual_revenue: Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.AnnualRevenue.t() | nil, documents: Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.Documents.t() | nil, estimated_worker_count: integer() | nil, id_numbers: [ Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.IdNumbers.t() ] | nil, monthly_estimated_revenue: Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.MonthlyEstimatedRevenue.t() | nil, phone: String.t() | nil, registered_name: String.t() | nil, registration_date: Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.RegistrationDate.t() | nil, script_addresses: Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.ScriptAddresses.t() | nil, script_names: Stripe.Params.V2.Core.AccountCreateParams.Identity.BusinessDetails.ScriptNames.t() | nil, structure: String.t() | nil }
address- The business registration address of the business entity.annual_revenue- The business gross annual revenue for its preceding fiscal year.documents- A document verifying the business.estimated_worker_count- Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).id_numbers- The ID numbers of a business entity.monthly_estimated_revenue- An estimate of the monthly revenue of the business.phone- The phone number of the Business Entity.registered_name- The business legal name.registration_date- When the business was incorporated or registered.script_addresses- The business registration address of the business entity in non latin script.script_names- The business legal name in non latin script.structure- The category identifying the legal structure of the business. Possible values:cooperative,free_zone_establishment,free_zone_llc,governmental_unit,government_instrumentality,incorporated_association,incorporated_non_profit,incorporated_partnership,limited_liability_partnership,llc,multi_member_llc,private_company,private_corporation,private_partnership,public_company,public_corporation,public_listed_corporation,public_partnership,registered_charity,single_member_llc,sole_establishment,sole_proprietorship,tax_exempt_government_instrumentality,trust,unincorporated_association,unincorporated_non_profit,unincorporated_partnership.