Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual{
  additional_addresses:
    [
      Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.AdditionalAddresses.t()
    ]
    | nil,
  additional_names:
    [
      Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.AdditionalNames.t()
    ]
    | nil,
  address:
    Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.Address.t()
    | nil,
  date_of_birth:
    Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.DateOfBirth.t()
    | nil,
  documents:
    Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.Documents.t()
    | nil,
  email: String.t() | nil,
  given_name: String.t() | nil,
  id_numbers:
    [
      Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.IdNumbers.t()
    ]
    | nil,
  legal_gender: String.t() | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  nationalities: [String.t()] | nil,
  phone: String.t() | nil,
  political_exposure: String.t() | nil,
  relationship:
    Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.Relationship.t()
    | nil,
  script_addresses:
    Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.ScriptAddresses.t()
    | nil,
  script_names:
    Stripe.Params.V2.Core.AccountCreateParams.Identity.Individual.ScriptNames.t()
    | nil,
  surname: String.t() | nil
}
  • additional_addresses - Additional addresses associated with the individual.
  • additional_names - Additional names (e.g. aliases) associated with the individual.
  • address - The individual's residential address.
  • date_of_birth - The individual's date of birth.
  • documents - Documents that may be submitted to satisfy various informational requests.
  • email - The individual's email address.
  • given_name - The individual's first name.
  • id_numbers - The identification numbers (e.g., SSN) associated with the individual.
  • legal_gender - The individual's gender (International regulations require either "male" or "female"). Possible values: female, male.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • nationalities - The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).
  • phone - The individual's phone number.
  • political_exposure - The individual's political exposure. Possible values: existing, none.
  • relationship - The relationship that this individual has with the account's identity.
  • script_addresses - The script addresses (e.g., non-Latin characters) associated with the individual.
  • script_names - The individuals primary name in non latin script.
  • surname - The individual's last name.