Stripe.Params.V2.Core.AccountLinkCreateParams.UseCase (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %Stripe.Params.V2.Core.AccountLinkCreateParams.UseCase{
  account_onboarding:
    Stripe.Params.V2.Core.AccountLinkCreateParams.UseCase.AccountOnboarding.t()
    | nil,
  account_update:
    Stripe.Params.V2.Core.AccountLinkCreateParams.UseCase.AccountUpdate.t()
    | nil,
  type: String.t() | nil
}
  • account_onboarding - Hash containing configuration options for an Account Link object that onboards a new account.
  • account_update - Hash containing configuration options for an Account Link that updates an existing account.
  • type - Open Enum. The type of Account Link the user is requesting. Possible values: account_onboarding, account_update.