Stripe.Params.V2.Core.AccountTokenCreateParams.Identity.BusinessDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • address - The business registration address of the business entity.
  • annual_revenue - The business gross annual revenue for its preceding fiscal year.
  • documents - A document verifying the business.
  • estimated_worker_count - Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
  • id_numbers - The ID numbers of a business entity.
  • monthly_estimated_revenue - An estimate of the monthly revenue of the business.
  • phone - The phone number of the Business Entity.
  • registered_name - The business legal name.
  • registration_date - When the business was incorporated or registered.
  • script_addresses - The business registration address of the business entity in non latin script.
  • script_names - The business legal name in non latin script.
  • structure - The category identifying the legal structure of the business. Possible values: cooperative, free_zone_establishment, free_zone_llc, governmental_unit, government_instrumentality, incorporated_association, incorporated_non_profit, incorporated_partnership, limited_liability_partnership, llc, multi_member_llc, private_company, private_corporation, private_partnership, public_company, public_corporation, public_listed_corporation, public_partnership, registered_charity, single_member_llc, sole_establishment, sole_proprietorship, tax_exempt_government_instrumentality, trust, unincorporated_association, unincorporated_non_profit, unincorporated_partnership.