Stripe.Params.V2.Core.AccountTokenCreateParams.Identity.Individual.Relationship (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.V2.Core.AccountTokenCreateParams.Identity.Individual.Relationship{
    director: boolean() | nil,
    executive: boolean() | nil,
    owner: boolean() | nil,
    percent_ownership: String.t() | nil,
    title: String.t() | nil
  }
  • director - Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
  • executive - Whether the person has significant responsibility to control, manage, or direct the organization.
  • owner - Whether the person is an owner of the account’s identity.
  • percent_ownership - The percent owned by the person of the account's legal entity. Format: decimal string.
  • title - The person's title (e.g., CEO, Support Engineer).