Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Customer.AutomaticIndirectTax
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Customer.AutomaticIndirectTax{ exempt: String.t() | nil, ip_address: String.t() | nil, validate_location: String.t() | nil }
exempt- The customer account's tax exemption status:none,exempt, orreverse. Whenreverse, invoice and receipt PDFs include "Reverse charge". Possible values:exempt,none,reverse.ip_address- A recent IP address of the customer used for tax reporting and tax location inference.validate_location- A per-request flag that indicates when Stripe should validate the customer tax location - defaults toauto. Possible values:auto,deferred,immediately.