Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Customer.Billing.Invoice.Rendering (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Customer.Billing.Invoice.Rendering{
    amount_tax_display: String.t() | nil,
    template: String.t() | nil
  }
  • amount_tax_display - Indicates whether displayed line item prices and amounts on invoice PDFs include inclusive tax amounts. Must be either include_inclusive_tax or exclude_tax. Possible values: exclude_tax, include_inclusive_tax.
  • template - ID of the invoice rendering template to use for future invoices.