Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

  • applied - Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.
  • bacs_debit_payments - Settings for Bacs Direct Debit payments.
  • branding - Settings used to apply the merchant's branding to email receipts, invoices, Checkout, and other products.
  • capabilities - Capabilities to request on the Merchant Configuration.
  • card_payments - Card payments settings.
  • konbini_payments - Settings specific to Konbini payments on the account.
  • mcc - The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.
  • script_statement_descriptor - Settings for the default text that appears on statements for language variations.
  • statement_descriptor - Settings for the default statement descriptor text.
  • support - Publicly available contact information for sending support issues to.