Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Branding
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Branding{ icon: String.t() | nil, logo: String.t() | nil, primary_color: String.t() | nil, secondary_color: String.t() | nil }
icon- ID of a file upload: An icon for the merchant. Must be square and at least 128px x 128px.logo- ID of a file upload: A logo for the merchant that will be used in Checkout instead of the icon and without the merchant's name next to it if provided. Must be at least 128px x 128px.primary_color- A CSS hex color value representing the primary branding color for the merchant.secondary_color- A CSS hex color value representing the secondary branding color for the merchant.