Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Capabilities.CashappPayments
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Capabilities.CashappPayments{ requested: boolean() | nil }
requested- To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.