Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Capabilities.GrabpayPayments (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Capabilities.GrabpayPayments{
    requested: boolean() | nil
  }
  • requested - To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.