Stripe.Params.V2.Core.Accounts.PersonCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for person create.

Summary

Types

t()

@type t() :: %Stripe.Params.V2.Core.Accounts.PersonCreateParams{
  additional_addresses:
    [Stripe.Params.V2.Core.Accounts.PersonCreateParams.AdditionalAddresses.t()]
    | nil,
  additional_names:
    [Stripe.Params.V2.Core.Accounts.PersonCreateParams.AdditionalNames.t()]
    | nil,
  additional_terms_of_service:
    Stripe.Params.V2.Core.Accounts.PersonCreateParams.AdditionalTermsOfService.t()
    | nil,
  address: Stripe.Params.V2.Core.Accounts.PersonCreateParams.Address.t() | nil,
  date_of_birth:
    Stripe.Params.V2.Core.Accounts.PersonCreateParams.DateOfBirth.t() | nil,
  documents:
    Stripe.Params.V2.Core.Accounts.PersonCreateParams.Documents.t() | nil,
  email: String.t() | nil,
  given_name: String.t() | nil,
  id_numbers:
    [Stripe.Params.V2.Core.Accounts.PersonCreateParams.IdNumbers.t()] | nil,
  legal_gender: String.t() | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  nationalities: [String.t()] | nil,
  person_token: String.t() | nil,
  phone: String.t() | nil,
  political_exposure: String.t() | nil,
  relationship:
    Stripe.Params.V2.Core.Accounts.PersonCreateParams.Relationship.t() | nil,
  script_addresses:
    Stripe.Params.V2.Core.Accounts.PersonCreateParams.ScriptAddresses.t() | nil,
  script_names:
    Stripe.Params.V2.Core.Accounts.PersonCreateParams.ScriptNames.t() | nil,
  surname: String.t() | nil
}
  • additional_addresses - Additional addresses associated with the person.
  • additional_names - Additional names (e.g. aliases) associated with the person.
  • additional_terms_of_service - Attestations of accepted terms of service agreements.
  • address - The person's residential address.
  • date_of_birth - The person's date of birth.
  • documents - Documents that may be submitted to satisfy various informational requests.
  • email - Email.
  • given_name - The person's first name.
  • id_numbers - The identification numbers (e.g., SSN) associated with the person.
  • legal_gender - The person's gender (International regulations require either "male" or "female"). Possible values: female, male.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • nationalities - The nationalities (countries) this person is associated with.
  • person_token - The person token generated by the person token api.
  • phone - The phone number for this person.
  • political_exposure - The person's political exposure. Possible values: existing, none.
  • relationship - The relationship that this person has with the Account's business or legal entity.
  • script_addresses - The script addresses (e.g., non-Latin characters) associated with the person.
  • script_names - The script names (e.g. non-Latin characters) associated with the person.
  • surname - The person's last name.