Parameters for person list.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.Accounts.PersonListParams{limit: integer() | nil}
limit- The upper limit on the number of accounts returned by the List Account request.
Parameters for person list.
@type t() :: %Stripe.Params.V2.Core.Accounts.PersonListParams{limit: integer() | nil}
limit - The upper limit on the number of accounts returned by the List Account request.