Stripe.Params.V2.Core.EventDestinationCreateParams (tiger_stripe v0.1.10)

Copy Markdown View Source

Parameters for event destination create.

Summary

Types

t()

@type t() :: %Stripe.Params.V2.Core.EventDestinationCreateParams{
  amazon_eventbridge:
    Stripe.Params.V2.Core.EventDestinationCreateParams.AmazonEventbridge.t()
    | nil,
  description: String.t() | nil,
  enabled_events: [String.t()],
  event_payload: String.t(),
  events_from: [String.t()] | nil,
  include: [String.t()] | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  name: String.t(),
  snapshot_api_version: String.t() | nil,
  type: String.t(),
  webhook_endpoint:
    Stripe.Params.V2.Core.EventDestinationCreateParams.WebhookEndpoint.t() | nil
}
  • amazon_eventbridge - Amazon EventBridge configuration.
  • description - An optional description of what the event destination is used for.
  • enabled_events - The list of events to enable for this endpoint.
  • event_payload - Payload type of events being subscribed to. Possible values: snapshot, thin.
  • events_from - Where events should be routed from.
  • include - Additional fields to include in the response.
  • metadata - Metadata.
  • name - Event destination name.
  • snapshot_api_version - If using the snapshot event payload, the API version events are rendered as.
  • type - Event destination type. Possible values: amazon_eventbridge, webhook_endpoint.
  • webhook_endpoint - Webhook endpoint configuration.