Parameters for event destination update.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.EventDestinationUpdateParams{ description: String.t() | nil, enabled_events: [String.t()] | nil, include: [String.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil, name: String.t() | nil, webhook_endpoint: Stripe.Params.V2.Core.EventDestinationUpdateParams.WebhookEndpoint.t() | nil }
description- An optional description of what the event destination is used for.enabled_events- The list of events to enable for this endpoint.include- Additional fields to include in the response. Currently supportswebhook_endpoint.url.metadata- Metadata.name- Event destination name.webhook_endpoint- Webhook endpoint configuration.