Stripe.Resources.Account (tiger_stripe v0.1.10)

Copy Markdown View Source

Account

This is an object representing a Stripe account. You can retrieve it to see properties on the account like its current requirements or if the account is enabled to make live charges or receive payouts.

For accounts where controller.requirement_collection is application, which includes Custom accounts, the properties below are always returned.

For accounts where controller.requirement_collection is stripe, which includes Standard and Express accounts, some properties are only returned until you create an Account Link or Account Session to start Connect Onboarding. Learn about the differences between accounts.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account{
  business_profile: Stripe.Resources.Account.BusinessProfile.t() | nil,
  business_type: String.t() | nil,
  capabilities: Stripe.Resources.Account.Capabilities.t() | nil,
  charges_enabled: boolean() | nil,
  company: Stripe.Resources.Account.Company.t() | nil,
  controller: Stripe.Resources.Account.Controller.t() | nil,
  country: String.t() | nil,
  created: integer() | nil,
  default_currency: String.t() | nil,
  details_submitted: boolean() | nil,
  email: String.t() | nil,
  external_accounts: Stripe.Resources.Account.ExternalAccounts.t() | nil,
  future_requirements: Stripe.Resources.Account.FutureRequirements.t() | nil,
  groups: Stripe.Resources.Account.Groups.t() | nil,
  id: String.t(),
  individual: Stripe.Resources.Person.t() | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  object: String.t(),
  payouts_enabled: boolean() | nil,
  requirements: Stripe.Resources.Account.Requirements.t() | nil,
  settings: Stripe.Resources.Account.Settings.t() | nil,
  tos_acceptance: Stripe.Resources.Account.TosAcceptance.t() | nil,
  type: String.t() | nil
}
  • business_profile - Business information about the account. Nullable. Expandable.
  • business_type - The business type. Possible values: company, government_entity, individual, non_profit. Nullable.
  • capabilities - Expandable.
  • charges_enabled - Whether the account can process charges.
  • company - Expandable.
  • controller - Expandable.
  • country - The account's country. Max length: 5000.
  • created - Time at which the account was connected. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • default_currency - Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country. Max length: 5000.
  • details_submitted - Whether account details have been submitted. Accounts with Stripe Dashboard access, which includes Standard accounts, cannot receive payouts before this is true. Accounts where this is false should be directed to an onboarding flow to finish submitting account details.
  • email - An email address associated with the account. It's not used for authentication and Stripe doesn't market to this field without explicit approval from the platform. Max length: 5000. Nullable.
  • external_accounts - External accounts (bank accounts and debit cards) currently attached to this account. External accounts are only returned for requests where controller[is_controller] is true. Expandable.
  • future_requirements - Expandable.
  • groups - The groups associated with the account. Nullable. Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • individual - Expandable.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: account.
  • payouts_enabled - Whether the funds in this account can be paid out.
  • requirements - Expandable.
  • settings - Options for customizing how the account functions within Stripe. Nullable. Expandable.
  • tos_acceptance - Expandable.
  • type - The Stripe account type. Can be standard, express, custom, or none. Possible values: custom, express, none, standard.

Functions

expandable_fields()

object_name()