Stripe.Resources.Account.BusinessProfile (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.BusinessProfile{
  annual_revenue:
    Stripe.Resources.Account.BusinessProfile.AnnualRevenue.t() | nil,
  estimated_worker_count: integer() | nil,
  mcc: String.t() | nil,
  minority_owned_business_designation: [String.t()] | nil,
  monthly_estimated_revenue:
    Stripe.Resources.Account.BusinessProfile.MonthlyEstimatedRevenue.t() | nil,
  name: String.t() | nil,
  product_description: String.t() | nil,
  support_address: Stripe.Resources.Address.t() | nil,
  support_email: String.t() | nil,
  support_phone: String.t() | nil,
  support_url: String.t() | nil,
  url: String.t() | nil
}
  • annual_revenue - The applicant's gross annual revenue for its preceding fiscal year. Nullable.
  • estimated_worker_count - An estimated upper bound of employees, contractors, vendors, etc. currently working for the business. Nullable.
  • mcc - The merchant category code for the account. MCCs are used to classify businesses based on the goods or services they provide. Max length: 5000. Nullable.
  • minority_owned_business_designation - Whether the business is a minority-owned, women-owned, and/or LGBTQI+ -owned business. Nullable.
  • monthly_estimated_revenue
  • name - The customer-facing business name. Max length: 5000. Nullable.
  • product_description - Internal-only description of the product sold or service provided by the business. It's used by Stripe for risk and underwriting purposes. Max length: 40000. Nullable.
  • support_address - A publicly available mailing address for sending support issues to. Nullable.
  • support_email - A publicly available email address for sending support issues to. Max length: 5000. Nullable.
  • support_phone - A publicly available phone number to call with support issues. Max length: 5000. Nullable.
  • support_url - A publicly available website for handling support issues. Max length: 5000. Nullable.
  • url - The business's publicly available website. Max length: 5000. Nullable.