Stripe.Resources.Account.Company (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.Company{
  address: Stripe.Resources.Address.t() | nil,
  address_kana: Stripe.Resources.Account.Company.AddressKana.t() | nil,
  address_kanji: Stripe.Resources.Account.Company.AddressKanji.t() | nil,
  directors_provided: boolean() | nil,
  directorship_declaration:
    Stripe.Resources.Account.Company.DirectorshipDeclaration.t() | nil,
  executives_provided: boolean() | nil,
  export_license_id: String.t() | nil,
  export_purpose_code: String.t() | nil,
  name: String.t() | nil,
  name_kana: String.t() | nil,
  name_kanji: String.t() | nil,
  owners_provided: boolean() | nil,
  ownership_declaration:
    Stripe.Resources.Account.Company.OwnershipDeclaration.t() | nil,
  ownership_exemption_reason: String.t() | nil,
  phone: String.t() | nil,
  registration_date:
    Stripe.Resources.Account.Company.RegistrationDate.t() | nil,
  representative_declaration:
    Stripe.Resources.Account.Company.RepresentativeDeclaration.t() | nil,
  structure: String.t() | nil,
  tax_id_provided: boolean() | nil,
  tax_id_registrar: String.t() | nil,
  vat_id_provided: boolean() | nil,
  verification: Stripe.Resources.Account.Company.Verification.t() | nil
}
  • address
  • address_kana - The Kana variation of the company's primary address (Japan only). Nullable.
  • address_kanji - The Kanji variation of the company's primary address (Japan only). Nullable.
  • directors_provided - Whether the company's directors have been provided. This Boolean will be true if you've manually indicated that all directors are provided via the directors_provided parameter.
  • directorship_declaration - This hash is used to attest that the director information provided to Stripe is both current and correct. Nullable.
  • executives_provided - Whether the company's executives have been provided. This Boolean will be true if you've manually indicated that all executives are provided via the executives_provided parameter, or if Stripe determined that sufficient executives were provided.
  • export_license_id - The export license ID number of the company, also referred as Import Export Code (India only). Max length: 5000.
  • export_purpose_code - The purpose code to use for export transactions (India only). Max length: 5000.
  • name - The company's legal name. Also available for accounts where controller.requirement_collection is stripe. Max length: 5000. Nullable.
  • name_kana - The Kana variation of the company's legal name (Japan only). Also available for accounts where controller.requirement_collection is stripe. Max length: 5000. Nullable.
  • name_kanji - The Kanji variation of the company's legal name (Japan only). Also available for accounts where controller.requirement_collection is stripe. Max length: 5000. Nullable.
  • owners_provided - Whether the company's owners have been provided. This Boolean will be true if you've manually indicated that all owners are provided via the owners_provided parameter, or if Stripe determined that sufficient owners were provided. Stripe determines ownership requirements using both the number of owners provided and their total percent ownership (calculated by adding the percent_ownership of each owner together).
  • ownership_declaration - This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct. Nullable.
  • ownership_exemption_reason - This value is used to determine if a business is exempt from providing ultimate beneficial owners. See this support article and changelog for more details. Possible values: qualified_entity_exceeds_ownership_threshold, qualifies_as_financial_institution.
  • phone - The company's phone number (used for verification). Max length: 5000. Nullable.
  • registration_date
  • representative_declaration - This hash is used to attest that the representative is authorized to act as the representative of their legal entity. Nullable.
  • structure - The category identifying the legal structure of the company or legal entity. Also available for accounts where controller.requirement_collection is stripe. See Business structure for more details. Possible values: free_zone_establishment, free_zone_llc, government_instrumentality, governmental_unit, incorporated_non_profit, incorporated_partnership, limited_liability_partnership, llc, multi_member_llc, private_company, private_corporation, private_partnership, public_company, public_corporation, public_partnership, registered_charity, single_member_llc, sole_establishment, sole_proprietorship, tax_exempt_government_instrumentality, unincorporated_association, unincorporated_non_profit, unincorporated_partnership.
  • tax_id_provided - Whether the company's business ID number was provided.
  • tax_id_registrar - The jurisdiction in which the tax_id is registered (Germany-based companies only). Max length: 5000.
  • vat_id_provided - Whether the company's business VAT number was provided.
  • verification - Information on the verification state of the company. Nullable.