Stripe.Resources.Account.Company.OwnershipDeclaration (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.Company.OwnershipDeclaration{
  date: integer() | nil,
  ip: String.t() | nil,
  user_agent: String.t() | nil
}
  • date - The Unix timestamp marking when the beneficial owner attestation was made. Format: Unix timestamp. Nullable.
  • ip - The IP address from which the beneficial owner attestation was made. Max length: 5000. Nullable.
  • user_agent - The user-agent string from the browser where the beneficial owner attestation was made. Max length: 5000. Nullable.