Stripe.Resources.Account.Controller (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.Controller{
  fees: Stripe.Resources.Account.Controller.Fees.t() | nil,
  is_controller: boolean() | nil,
  losses: Stripe.Resources.Account.Controller.Losses.t() | nil,
  requirement_collection: String.t() | nil,
  stripe_dashboard:
    Stripe.Resources.Account.Controller.StripeDashboard.t() | nil,
  type: String.t() | nil
}
  • fees
  • is_controller - true if the Connect application retrieving the resource controls the account and can therefore exercise platform controls. Otherwise, this field is null.
  • losses
  • requirement_collection - A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account. Possible values: application, stripe.
  • stripe_dashboard
  • type - The controller type. Can be application, if a Connect application controls the account, or account, if the account controls itself. Possible values: account, application.