Stripe.Resources.Account.Requirements (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.Requirements{
  alternatives: [Stripe.Resources.Account.Requirements.Alternatives.t()] | nil,
  current_deadline: integer() | nil,
  currently_due: [String.t()] | nil,
  disabled_reason: String.t() | nil,
  errors: [Stripe.Resources.Account.Requirements.Errors.t()] | nil,
  eventually_due: [String.t()] | nil,
  past_due: [String.t()] | nil,
  pending_verification: [String.t()] | nil
}
  • alternatives - Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the same original_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providing original_fields_due also serves as a pathway for attempting to resolve the fields again. Nullable.
  • current_deadline - Date by which the fields in currently_due must be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected. Format: Unix timestamp. Nullable.
  • currently_due - Fields that need to be resolved to keep the account enabled. If not resolved by current_deadline, these fields will appear in past_due as well, and the account is disabled. Nullable.
  • disabled_reason - If the account is disabled, this enum describes why. Learn more about handling verification issues. Possible values: action_required.requested_capabilities, listed, other, platform_paused, rejected.fraud, rejected.incomplete_verification, rejected.listed, rejected.other, rejected.platform_fraud, rejected.platform_other, rejected.platform_terms_of_service, rejected.terms_of_service, requirements.past_due, requirements.pending_verification, under_review. Nullable.
  • errors - Details about validation and verification failures for due requirements that must be resolved. Nullable.
  • eventually_due - Fields you must collect when all thresholds are reached. As they become required, they appear in currently_due as well, and current_deadline becomes set. Nullable.
  • past_due - Fields that haven't been resolved by current_deadline. These fields need to be resolved to enable the account. Nullable.
  • pending_verification - Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending. Nullable.