Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Settings.Branding{ icon: String.t() | Stripe.Resources.File.t() | nil, logo: String.t() | Stripe.Resources.File.t() | nil, primary_color: String.t() | nil, secondary_color: String.t() | nil }
icon- (ID of a file upload) An icon for the account. Must be square and at least 128px x 128px. Nullable.logo- (ID of a file upload) A logo for the account that will be used in Checkout instead of the icon and without the account's name next to it if provided. Must be at least 128px x 128px. Nullable.primary_color- A CSS hex color value representing the primary branding color for this account Max length: 5000. Nullable.secondary_color- A CSS hex color value representing the secondary branding color for this account Max length: 5000. Nullable.