Stripe.Resources.Account.Settings.Dashboard (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.Settings.Dashboard{
  display_name: String.t() | nil,
  timezone: String.t() | nil
}
  • display_name - The display name for this account. This is used on the Stripe Dashboard to differentiate between accounts. Max length: 5000. Nullable.
  • timezone - The timezone used in the Stripe Dashboard for this account. A list of possible time zone values is maintained at the IANA Time Zone Database. Max length: 5000. Nullable.