Stripe.Resources.Account.Settings.Payouts.Schedule (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.Settings.Payouts.Schedule{
  delay_days: integer() | nil,
  interval: String.t() | nil,
  monthly_anchor: integer() | nil,
  monthly_payout_days: [integer()] | nil,
  weekly_anchor: String.t() | nil,
  weekly_payout_days: [String.t()] | nil
}
  • delay_days - The number of days charges for the account will be held before being paid out.
  • interval - How frequently funds will be paid out. One of manual (payouts only created via API call), daily, weekly, or monthly. Max length: 5000.
  • monthly_anchor - The day of the month funds will be paid out. Only shown if interval is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.
  • monthly_payout_days - The days of the month funds will be paid out. Only shown if interval is monthly. Payouts scheduled between the 29th and 31st of the month are sent on the last day of shorter months.
  • weekly_anchor - The day of the week funds will be paid out, of the style 'monday', 'tuesday', etc. Only shown if interval is weekly. Max length: 5000.
  • weekly_payout_days - The days of the week when available funds are paid out, specified as an array, for example, [monday, tuesday]. Only shown if interval is weekly.