Stripe.Resources.Account.Settings.Treasury.TosAcceptance (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Account.Settings.Treasury.TosAcceptance{
  date: integer() | nil,
  ip: String.t() | nil,
  user_agent: String.t() | nil
}
  • date - The Unix timestamp marking when the account representative accepted the service agreement. Nullable.
  • ip - The IP address from which the account representative accepted the service agreement. Max length: 5000. Nullable.
  • user_agent - The user agent of the browser from which the account representative accepted the service agreement. Max length: 5000.