Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.TosAcceptance{ date: integer() | nil, ip: String.t() | nil, service_agreement: String.t() | nil, user_agent: String.t() | nil }
date- The Unix timestamp marking when the account representative accepted their service agreement Format: Unix timestamp. Nullable.ip- The IP address from which the account representative accepted their service agreement Max length: 5000. Nullable.service_agreement- The user's service agreement type Max length: 5000.user_agent- The user agent of the browser from which the account representative accepted their service agreement Max length: 5000. Nullable.