Stripe.Resources.AdjustedForOverdraft (tiger_stripe v0.1.10)

Copy Markdown View Source

CustomerBalanceResourceCashBalanceTransactionResourceAdjustedForOverdraft

Summary

Types

t()

@type t() :: %Stripe.Resources.AdjustedForOverdraft{
  balance_transaction: String.t() | Stripe.Resources.BalanceTransaction.t(),
  linked_transaction:
    String.t() | Stripe.Resources.CustomerCashBalanceTransaction.t()
}
  • balance_transaction - The Balance Transaction that corresponds to funds taken out of your Stripe balance. Expandable.
  • linked_transaction - The Cash Balance Transaction that brought the customer balance negative, triggering the clawback of funds. Expandable.

Functions

expandable_fields()

object_name()