Stripe.Resources.ApplicationFee (tiger_stripe v0.1.10)

Copy Markdown View Source

PlatformFee

Summary

Types

t()

@type t() :: %Stripe.Resources.ApplicationFee{
  account: String.t() | Stripe.Resources.Account.t(),
  amount: integer(),
  amount_refunded: integer(),
  application: String.t() | Stripe.Resources.Application.t(),
  balance_transaction: String.t() | Stripe.Resources.BalanceTransaction.t(),
  charge: String.t() | Stripe.Resources.Charge.t(),
  created: integer(),
  currency: String.t(),
  fee_source: Stripe.Resources.ApplicationFee.FeeSource.t(),
  id: String.t(),
  livemode: boolean(),
  object: String.t(),
  originating_transaction: String.t() | Stripe.Resources.Charge.t(),
  refunded: boolean(),
  refunds: Stripe.Resources.ApplicationFee.Refunds.t()
}
  • account - ID of the Stripe account this fee was taken from. Expandable.
  • amount - Amount earned, in cents (or local equivalent).
  • amount_refunded - Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the fee if a partial refund was issued)
  • application - ID of the Connect application that earned the fee. Expandable.
  • balance_transaction - Balance transaction that describes the impact of this collected application fee on your account balance (not including refunds). Nullable. Expandable.
  • charge - ID of the charge that the application fee was taken from. Expandable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • fee_source - Polymorphic source of the application fee. Includes the ID of the object the application fee was created from. Nullable. Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: application_fee.
  • originating_transaction - ID of the corresponding charge on the platform account, if this fee was the result of a charge using the destination parameter. Nullable. Expandable.
  • refunded - Whether the fee has been fully refunded. If the fee is only partially refunded, this attribute will still be false.
  • refunds - A list of refunds that have been applied to the fee. Expandable.

Functions

expandable_fields()

object_name()