Stripe.Resources.BalanceSettings.Payments.Payouts (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.BalanceSettings.Payments.Payouts{
  minimum_balance_by_currency: %{required(String.t()) => integer()} | nil,
  schedule:
    Stripe.Resources.BalanceSettings.Payments.Payouts.Schedule.t() | nil,
  statement_descriptor: String.t() | nil,
  status: String.t() | nil
}
  • minimum_balance_by_currency - The minimum balance amount to retain per currency after automatic payouts. Only funds that exceed these amounts are paid out. Learn more about the minimum balances for automatic payouts. Nullable.
  • schedule - Details on when funds from charges are available, and when they are paid out to an external account. See our Setting Bank and Debit Card Payouts documentation for details. Nullable.
  • statement_descriptor - The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard. Max length: 5000. Nullable.
  • status - Whether the funds in this account can be paid out. Possible values: disabled, enabled.