Stripe.Resources.BankAccount.Requirements (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.BankAccount.Requirements{
  currently_due: [String.t()] | nil,
  errors: [Stripe.Resources.BankAccount.Requirements.Errors.t()] | nil,
  past_due: [String.t()] | nil,
  pending_verification: [String.t()] | nil
}
  • currently_due - Fields that need to be resolved to keep the external account enabled. If not resolved by current_deadline, these fields will appear in past_due as well, and the account is disabled. Nullable.
  • errors - Details about validation and verification failures for due requirements that must be resolved. Nullable.
  • past_due - Fields that haven't been resolved by current_deadline. These fields need to be resolved to enable the external account. Nullable.
  • pending_verification - Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending. Nullable.