Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Billing.Alert.UsageThreshold{ filters: [Stripe.Resources.Billing.Alert.UsageThreshold.Filters.t()] | nil, gte: integer() | nil, meter: String.t() | Stripe.Resources.Billing.Meter.t() | nil, recurrence: String.t() | nil }
filters- The filters allow limiting the scope of this usage alert. You can only specify up to one filter at this time. Nullable.gte- The value at which this alert will trigger.meter- The Billing Meter ID whose usage is monitored.recurrence- Defines how the alert will behave. Possible values:one_time.