Stripe.Resources.Billing.AlertTriggered (tiger_stripe v0.1.10)

Copy Markdown View Source

ThresholdsResourceAlert

Summary

Types

t()

@type t() :: %Stripe.Resources.Billing.AlertTriggered{
  alert: Stripe.Resources.Billing.Alert.t(),
  created: integer(),
  customer: String.t(),
  livemode: boolean(),
  object: String.t(),
  value: integer()
}
  • alert - Expandable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • customer - ID of customer for which the alert triggered Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: billing.alert_triggered.
  • value - The value triggering the alert

Functions

expandable_fields()

object_name()