Stripe.Resources.Billing.CreditBalanceTransaction.Credit.CreditsApplicationInvoiceVoided (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.Billing.CreditBalanceTransaction.Credit.CreditsApplicationInvoiceVoided{
    invoice: String.t() | Stripe.Resources.Invoice.t() | nil,
    invoice_line_item: String.t() | nil
  }
  • invoice - The invoice to which the reinstated billing credits were originally applied.
  • invoice_line_item - The invoice line item to which the reinstated billing credits were originally applied. Max length: 5000.