Stripe.Resources.Billing.CreditBalanceTransaction.Debit.CreditsApplied (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Billing.CreditBalanceTransaction.Debit.CreditsApplied{
  invoice: String.t() | Stripe.Resources.Invoice.t() | nil,
  invoice_line_item: String.t() | nil
}
  • invoice - The invoice to which the billing credits were applied.
  • invoice_line_item - The invoice line item to which the billing credits were applied. Max length: 5000.