Stripe.Resources.Billing.CreditGrant.ApplicabilityConfig.Scope (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Billing.CreditGrant.ApplicabilityConfig.Scope{
  price_type: String.t() | nil,
  prices:
    [Stripe.Resources.Billing.CreditGrant.ApplicabilityConfig.Scope.Prices.t()]
    | nil
}
  • price_type - The price type that credit grants can apply to. We currently only support the metered price type. This refers to prices that have a Billing Meter attached to them. Cannot be used in combination with prices. Possible values: metered.
  • prices - The prices that credit grants can apply to. We currently only support metered prices. This refers to prices that have a Billing Meter attached to them. Cannot be used in combination with price_type.