BillingMeterEventAdjustment
A billing meter event adjustment is a resource that allows you to cancel a meter event. For example, you might create a billing meter event adjustment to cancel a meter event that was created in error or attached to the wrong customer.
Summary
Types
@type t() :: %Stripe.Resources.Billing.MeterEventAdjustment{ cancel: Stripe.Resources.Billing.MeterEventAdjustment.Cancel.t(), event_name: String.t(), livemode: boolean(), object: String.t(), status: String.t(), type: String.t() }
cancel- Specifies which event to cancel. Nullable. Expandable.event_name- The name of the meter event. Corresponds with theevent_namefield on a meter. Max length: 100.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:billing.meter_event_adjustment.status- The meter event adjustment's status. Possible values:complete,pending.type- Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet. Possible values:cancel.