Stripe.Resources.BillingPortal.Configuration.Features.PaymentMethodUpdate
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.BillingPortal.Configuration.Features.PaymentMethodUpdate{ enabled: boolean() | nil, payment_method_configuration: String.t() | nil }
enabled- Whether the feature is enabled.payment_method_configuration- The Payment Method Configuration to use for this portal session. When specified, customers will be able to update their payment method to one of the options specified by the payment method configuration. If not set, the default payment method configuration is used. Max length: 5000. Nullable.