Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate{ billing_cycle_anchor: String.t() | nil, default_allowed_updates: [String.t()] | nil, enabled: boolean() | nil, products: [ Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate.Products.t() ] | nil, proration_behavior: String.t() | nil, schedule_at_period_end: Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate.ScheduleAtPeriodEnd.t() | nil, trial_update_behavior: String.t() | nil }
billing_cycle_anchor- Determines the value to use for the billing cycle anchor on subscription updates. Valid values arenoworunchanged, and the default value isunchanged. Setting the value tonowresets the subscription's billing cycle anchor to the current time (in UTC). For more information, see the billing cycle documentation. Possible values:now,unchanged. Nullable.default_allowed_updates- The types of subscription updates that are supported for items listed in theproductsattribute. When empty, subscriptions are not updateable.enabled- Whether the feature is enabled.products- The list of up to 10 products that support subscription updates. Nullable.proration_behavior- Determines how to handle prorations resulting from subscription updates. Valid values arenone,create_prorations, andalways_invoice. Defaults to a value ofnoneif you don't set it during creation. Possible values:always_invoice,create_prorations,none.schedule_at_period_endtrial_update_behavior- Determines how handle updates to trialing subscriptions. Valid values areend_trialandcontinue_trial. Defaults to a value ofend_trialif you don't set it during creation. Possible values:continue_trial,end_trial.