Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate.ScheduleAtPeriodEnd
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate.ScheduleAtPeriodEnd{ conditions: [ Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate.ScheduleAtPeriodEnd.Conditions.t() ] | nil }
conditions- List of conditions. When any condition is true, an update will be scheduled at the end of the current period.