Stripe.Resources.BillingPortal.Configuration.LoginPage (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.BillingPortal.Configuration.LoginPage{
  enabled: boolean() | nil,
  url: String.t() | nil
}
  • enabled - If true, a shareable url will be generated that will take your customers to a hosted login page for the customer portal.

If false, the previously generated url, if any, will be deactivated.

  • url - A shareable URL to the hosted portal login page. Your customers will be able to log in with their email and receive a link to their customer portal. Max length: 5000. Nullable.