Stripe.Resources.BillingPortal.Session.Flow.SubscriptionUpdateConfirm.Discounts (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.BillingPortal.Session.Flow.SubscriptionUpdateConfirm.Discounts{
    coupon: String.t() | nil,
    promotion_code: String.t() | nil
  }
  • coupon - The ID of the coupon to apply to this subscription update. Max length: 5000. Nullable.
  • promotion_code - The ID of a promotion code to apply to this subscription update. Max length: 5000. Nullable.