Stripe.Resources.Capability (tiger_stripe v0.1.10)

Copy Markdown View Source

AccountCapability

This is an object representing a capability for a Stripe account.

Related guide: Account capabilities

Summary

Types

t()

@type t() :: %Stripe.Resources.Capability{
  account: String.t() | Stripe.Resources.Account.t(),
  future_requirements: Stripe.Resources.Capability.FutureRequirements.t() | nil,
  id: String.t(),
  object: String.t(),
  requested: boolean(),
  requested_at: integer(),
  requirements: Stripe.Resources.Capability.Requirements.t() | nil,
  status: String.t()
}
  • account - The account for which the capability enables functionality. Expandable.
  • future_requirements - Expandable.
  • id - The identifier for the capability. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: capability.
  • requested - Whether the capability has been requested.
  • requested_at - Time at which the capability was requested. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.
  • requirements - Expandable.
  • status - The status of the capability. Possible values: active, inactive, pending, unrequested.

Functions

expandable_fields()

object_name()