Stripe.Resources.CashBalance (tiger_stripe v0.1.10)

Copy Markdown View Source

cash_balance

A customer's Cash balance represents real funds. Customers can add funds to their cash balance by sending a bank transfer. These funds can be used for payment and can eventually be paid out to your bank account.

Summary

Types

t()

@type t() :: %Stripe.Resources.CashBalance{
  available: %{required(String.t()) => integer()},
  customer: String.t(),
  customer_account: String.t(),
  livemode: boolean(),
  object: String.t(),
  settings: Stripe.Resources.CashBalance.Settings.t()
}
  • available - A hash of all cash balances available to this customer. You cannot delete a customer with any cash balances, even if the balance is 0. Amounts are represented in the smallest currency unit. Nullable.
  • customer - The ID of the customer whose cash balance this object represents. Max length: 5000.
  • customer_account - The ID of an Account representing a customer whose cash balance this object represents. Max length: 5000. Nullable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: cash_balance.
  • settings - Expandable.

Functions

expandable_fields()

object_name()