Stripe.Resources.CashappHandleRedirectOrDisplayQrCode (tiger_stripe v0.1.10)

Copy Markdown View Source

PaymentIntentNextActionCashappHandleRedirectOrDisplayQrCode

Summary

Types

t()

@type t() :: %Stripe.Resources.CashappHandleRedirectOrDisplayQrCode{
  hosted_instructions_url: String.t(),
  mobile_auth_url: String.t(),
  qr_code: Stripe.Resources.CashappQrCode.t()
}
  • hosted_instructions_url - The URL to the hosted Cash App Pay instructions page, which allows customers to view the QR code, and supports QR code refreshing on expiration. Max length: 5000.
  • mobile_auth_url - The url for mobile redirect based auth Max length: 5000.
  • qr_code - Expandable.

Functions

expandable_fields()

object_name()