Stripe.Resources.Charge.PaymentMethodDetails.AchCreditTransfer (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.AchCreditTransfer{
  account_number: String.t() | nil,
  bank_name: String.t() | nil,
  routing_number: String.t() | nil,
  swift_code: String.t() | nil
}
  • account_number - Account number to transfer funds to. Max length: 5000. Nullable.
  • bank_name - Name of the bank associated with the routing number. Max length: 5000. Nullable.
  • routing_number - Routing transit number for the bank account to transfer funds to. Max length: 5000. Nullable.
  • swift_code - SWIFT code of the bank associated with the routing number. Max length: 5000. Nullable.