Stripe.Resources.Charge.PaymentMethodDetails.AchDebit
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.AchDebit{ account_holder_type: String.t() | nil, bank_name: String.t() | nil, country: String.t() | nil, fingerprint: String.t() | nil, last4: String.t() | nil, routing_number: String.t() | nil }
account_holder_type- Type of entity that holds the account. This can be eitherindividualorcompany. Possible values:company,individual. Nullable.bank_name- Name of the bank associated with the bank account. Max length: 5000. Nullable.country- Two-letter ISO code representing the country the bank account is located in. Max length: 5000. Nullable.fingerprint- Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.last4- Last four digits of the bank account number. Max length: 5000. Nullable.routing_number- Routing transit number of the bank account. Max length: 5000. Nullable.