Stripe.Resources.Charge.PaymentMethodDetails.BacsDebit
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.BacsDebit{ expected_debit_date: String.t() | nil, fingerprint: String.t() | nil, last4: String.t() | nil, mandate: String.t() | nil, sort_code: String.t() | nil }
expected_debit_date- Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format. Max length: 5000.fingerprint- Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.last4- Last four digits of the bank account number. Max length: 5000. Nullable.mandate- ID of the mandate used to make this payment. Max length: 5000. Nullable.sort_code- Sort code of the bank account. (e.g.,10-20-30) Max length: 5000. Nullable.