Stripe.Resources.Charge.PaymentMethodDetails.Card.Checks (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Card.Checks{
  address_line1_check: String.t() | nil,
  address_postal_code_check: String.t() | nil,
  cvc_check: String.t() | nil
}
  • address_line1_check - If a address line1 was provided, results of the check, one of pass, fail, unavailable, or unchecked. Max length: 5000. Nullable.
  • address_postal_code_check - If a address postal code was provided, results of the check, one of pass, fail, unavailable, or unchecked. Max length: 5000. Nullable.
  • cvc_check - If a CVC was provided, results of the check, one of pass, fail, unavailable, or unchecked. Max length: 5000. Nullable.