Stripe.Resources.Charge.PaymentMethodDetails.Card.NetworkToken (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Card.NetworkToken{
  used: boolean() | nil
}
  • used - Indicates if Stripe used a network token, either user provided or Stripe managed when processing the transaction.