Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet{
  amex_express_checkout: map() | nil,
  apple_pay: map() | nil,
  dynamic_last4: String.t() | nil,
  google_pay: map() | nil,
  link: map() | nil,
  masterpass:
    Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet.Masterpass.t()
    | nil,
  samsung_pay: map() | nil,
  type: String.t() | nil,
  visa_checkout:
    Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet.VisaCheckout.t()
    | nil
}
  • amex_express_checkout
  • apple_pay
  • dynamic_last4 - (For tokenized numbers only.) The last four digits of the device account number. Max length: 5000. Nullable.
  • google_pay
  • link
  • masterpass
  • samsung_pay
  • type - The type of the card wallet, one of amex_express_checkout, apple_pay, google_pay, masterpass, samsung_pay, visa_checkout, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type. Possible values: amex_express_checkout, apple_pay, google_pay, link, masterpass, samsung_pay, visa_checkout.
  • visa_checkout