Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet.VisaCheckout (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet.VisaCheckout{
  billing_address: Stripe.Resources.Address.t() | nil,
  email: String.t() | nil,
  name: String.t() | nil,
  shipping_address: Stripe.Resources.Address.t() | nil
}
  • billing_address - Owner's verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Nullable.
  • email - Owner's verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Max length: 5000. Nullable.
  • name - Owner's verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Max length: 5000. Nullable.
  • shipping_address - Owner's verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Nullable.