Stripe.Resources.Charge.PaymentMethodDetails.Cashapp (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Cashapp{
  buyer_id: String.t() | nil,
  cashtag: String.t() | nil,
  transaction_id: String.t() | nil
}
  • buyer_id - A unique and immutable identifier assigned by Cash App to every buyer. Max length: 5000. Nullable.
  • cashtag - A public identifier for buyers using Cash App. Max length: 5000. Nullable.
  • transaction_id - A unique and immutable identifier of payments assigned by Cash App Max length: 5000. Nullable.