Stripe.Resources.Charge.PaymentMethodDetails.Giropay (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Giropay{
  bank_code: String.t() | nil,
  bank_name: String.t() | nil,
  bic: String.t() | nil,
  verified_name: String.t() | nil
}
  • bank_code - Bank code of bank associated with the bank account. Max length: 5000. Nullable.
  • bank_name - Name of the bank associated with the bank account. Max length: 5000. Nullable.
  • bic - Bank Identifier Code of the bank associated with the bank account. Max length: 5000. Nullable.
  • verified_name - Owner's verified full name. Values are verified or provided by Giropay directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Giropay rarely provides this information so the attribute is usually empty. Max length: 5000. Nullable.