Stripe.Resources.Charge.PaymentMethodDetails.Konbini (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Konbini{
  store: Stripe.Resources.Charge.PaymentMethodDetails.Konbini.Store.t() | nil
}
  • store - If the payment succeeded, this contains the details of the convenience store where the payment was completed. Nullable.