Stripe.Resources.Charge.PaymentMethodDetails.SepaDebit (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.SepaDebit{
  bank_code: String.t() | nil,
  branch_code: String.t() | nil,
  country: String.t() | nil,
  expected_debit_date: String.t() | nil,
  fingerprint: String.t() | nil,
  last4: String.t() | nil,
  mandate: String.t() | nil
}
  • bank_code - Bank code of bank associated with the bank account. Max length: 5000. Nullable.
  • branch_code - Branch code of bank associated with the bank account. Max length: 5000. Nullable.
  • country - Two-letter ISO code representing the country the bank account is located in. Max length: 5000. Nullable.
  • expected_debit_date - Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format. Max length: 5000.
  • fingerprint - Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.
  • last4 - Last four characters of the IBAN. Max length: 5000. Nullable.
  • mandate - Find the ID of the mandate used for this payment under the payment_method_details.sepa_debit.mandate property on the Charge. Use this mandate ID to retrieve the Mandate. Max length: 5000. Nullable.