Stripe.Resources.Charge.PaymentMethodDetails.Sofort (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Sofort{
  bank_code: String.t() | nil,
  bank_name: String.t() | nil,
  bic: String.t() | nil,
  country: String.t() | nil,
  generated_sepa_debit: String.t() | Stripe.Resources.PaymentMethod.t() | nil,
  generated_sepa_debit_mandate: String.t() | Stripe.Resources.Mandate.t() | nil,
  iban_last4: String.t() | nil,
  preferred_language: String.t() | nil,
  verified_name: String.t() | nil
}
  • bank_code - Bank code of bank associated with the bank account. Max length: 5000. Nullable.
  • bank_name - Name of the bank associated with the bank account. Max length: 5000. Nullable.
  • bic - Bank Identifier Code of the bank associated with the bank account. Max length: 5000. Nullable.
  • country - Two-letter ISO code representing the country the bank account is located in. Max length: 5000. Nullable.
  • generated_sepa_debit - The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge. Nullable.
  • generated_sepa_debit_mandate - The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge. Nullable.
  • iban_last4 - Last four characters of the IBAN. Max length: 5000. Nullable.
  • preferred_language - Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of de, en, es, fr, it, nl, or pl Possible values: de, en, es, fr, it, nl, pl. Nullable.
  • verified_name - Owner's verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Max length: 5000. Nullable.