Stripe.Resources.Charge.PaymentMethodDetails.Swish (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Swish{
  fingerprint: String.t() | nil,
  payment_reference: String.t() | nil,
  verified_phone_last4: String.t() | nil
}
  • fingerprint - Uniquely identifies the payer's Swish account. You can use this attribute to check whether two Swish transactions were paid for by the same payer Max length: 5000. Nullable.
  • payment_reference - Payer bank reference number for the payment Max length: 5000. Nullable.
  • verified_phone_last4 - The last four digits of the Swish account phone number Max length: 5000. Nullable.