Stripe.Resources.Charge.PaymentMethodDetails.WechatPay (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.WechatPay{
  fingerprint: String.t() | nil,
  location: String.t() | nil,
  reader: String.t() | nil,
  transaction_id: String.t() | nil
}
  • fingerprint - Uniquely identifies this particular WeChat Pay account. You can use this attribute to check whether two WeChat accounts are the same. Max length: 5000. Nullable.
  • location - ID of the location that this transaction's reader is assigned to. Max length: 5000.
  • reader - ID of the reader this transaction was made on. Max length: 5000.
  • transaction_id - Transaction ID of this particular WeChat Pay transaction. Max length: 5000. Nullable.