Stripe.Resources.Charge.TransferData (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Charge.TransferData{
  amount: integer() | nil,
  destination: String.t() | Stripe.Resources.Account.t() | nil
}
  • amount - The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account. Nullable.
  • destination - ID of an existing, connected Stripe account to transfer funds to if transfer_data was specified in the charge request.