Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Checkout.Session.AdaptivePricing{ enabled: boolean() | nil }
enabled- If enabled, Adaptive Pricing is available on eligible sessions.
Nested struct within the parent resource.
@type t() :: %Stripe.Resources.Checkout.Session.AdaptivePricing{ enabled: boolean() | nil }
enabled - If enabled, Adaptive Pricing is available on eligible sessions.