Stripe.Resources.Checkout.Session.AutomaticTax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Checkout.Session.AutomaticTax{
  enabled: boolean() | nil,
  liability: Stripe.Resources.Checkout.Session.AutomaticTax.Liability.t() | nil,
  provider: String.t() | nil,
  status: String.t() | nil
}
  • enabled - Indicates whether automatic tax is enabled for the session
  • liability - The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account. Nullable.
  • provider - The tax provider powering automatic tax. Max length: 5000. Nullable.
  • status - The status of the most recent automated tax calculation for this session. Possible values: complete, failed, requires_location_inputs. Nullable.