Stripe.Resources.Checkout.Session.CollectedInformation (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Checkout.Session.CollectedInformation{
  business_name: String.t() | nil,
  individual_name: String.t() | nil,
  shipping_details:
    Stripe.Resources.Checkout.Session.CollectedInformation.ShippingDetails.t()
    | nil
}
  • business_name - Customer’s business name for this Checkout Session Max length: 5000. Nullable.
  • individual_name - Customer’s individual name for this Checkout Session Max length: 5000. Nullable.
  • shipping_details - Shipping information for this Checkout Session. Nullable.