Stripe.Resources.Checkout.Session.Consent (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Checkout.Session.Consent{
  promotions: String.t() | nil,
  terms_of_service: String.t() | nil
}
  • promotions - If opt_in, the customer consents to receiving promotional communications from the merchant about this Checkout Session. Possible values: opt_in, opt_out. Nullable.
  • terms_of_service - If accepted, the customer in this Checkout Session has agreed to the merchant's terms of service. Possible values: accepted. Nullable.