Stripe.Resources.Checkout.Session.ConsentCollection.PaymentMethodReuseAgreement (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.Checkout.Session.ConsentCollection.PaymentMethodReuseAgreement{
    position: String.t() | nil
  }
  • position - Determines the position and visibility of the payment method reuse agreement in the UI. When set to auto, Stripe's defaults will be used.

When set to hidden, the payment method reuse agreement text will always be hidden in the UI. Possible values: auto, hidden.