Stripe.Resources.Checkout.Session.CurrencyConversion (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Checkout.Session.CurrencyConversion{
  amount_subtotal: integer() | nil,
  amount_total: integer() | nil,
  fx_rate: String.t() | nil,
  source_currency: String.t() | nil
}
  • amount_subtotal - Total of all items in source currency before discounts or taxes are applied.
  • amount_total - Total of all items in source currency after discounts and taxes are applied.
  • fx_rate - Exchange rate used to convert source currency amounts to customer currency amounts Format: decimal string.
  • source_currency - Creation currency of the CheckoutSession before localization Max length: 5000.