Stripe.Resources.Checkout.Session.InvoiceCreation.InvoiceData (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Checkout.Session.InvoiceCreation.InvoiceData{
  account_tax_ids: [String.t() | Stripe.Resources.TaxId.t()] | nil,
  custom_fields:
    [
      Stripe.Resources.Checkout.Session.InvoiceCreation.InvoiceData.CustomFields.t()
    ]
    | nil,
  description: String.t() | nil,
  footer: String.t() | nil,
  issuer:
    Stripe.Resources.Checkout.Session.InvoiceCreation.InvoiceData.Issuer.t()
    | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  rendering_options:
    Stripe.Resources.Checkout.Session.InvoiceCreation.InvoiceData.RenderingOptions.t()
    | nil
}
  • account_tax_ids - The account tax IDs associated with the invoice. Nullable.
  • custom_fields - Custom fields displayed on the invoice. Nullable.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000. Nullable.
  • footer - Footer displayed on the invoice. Max length: 5000. Nullable.
  • issuer - The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account. Nullable.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.
  • rendering_options - Options for invoice PDF rendering. Nullable.