Stripe.Resources.Checkout.Session.OptionalItems.AdjustableQuantity
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Checkout.Session.OptionalItems.AdjustableQuantity{ enabled: boolean() | nil, maximum: integer() | nil, minimum: integer() | nil }
enabled- Set to true if the quantity can be adjusted to any non-negative integer.maximum- The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999. Nullable.minimum- The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if theminimumconfigured here is greater than 0. By default this value is 0. Nullable.