Stripe.Resources.Checkout.Session.PaymentMethodOptions.UsBankAccount.FinancialConnections
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Checkout.Session.PaymentMethodOptions.UsBankAccount.FinancialConnections{ filters: Stripe.Resources.Checkout.Session.PaymentMethodOptions.UsBankAccount.FinancialConnections.Filters.t() | nil, permissions: [String.t()] | nil, prefetch: [String.t()] | nil, return_url: String.t() | nil }
filterspermissions- The list of permissions to request. Thepayment_methodpermission must be included.prefetch- Data features requested to be retrieved upon account creation. Nullable.return_url- For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app. Max length: 5000.