Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Checkout.Session.ShippingCost{ amount_subtotal: integer() | nil, amount_tax: integer() | nil, amount_total: integer() | nil, shipping_rate: String.t() | Stripe.Resources.ShippingRate.t() | nil, taxes: [Stripe.Resources.Checkout.Session.ShippingCost.Taxes.t()] | nil }
amount_subtotal- Total shipping cost before any discounts or taxes are applied.amount_tax- Total tax amount applied due to shipping costs. If no tax was applied, defaults to 0.amount_total- Total shipping cost after discounts and taxes are applied.shipping_rate- The ID of the ShippingRate for this order. Nullable.taxes- The taxes applied to the shipping rate.