Stripe.Resources.CheckoutCardRestrictions (tiger_stripe v0.1.10)

Copy Markdown View Source

PaymentPagesPrivateCardPaymentMethodOptionsResourceRestrictions

Summary

Types

t()

@type t() :: %Stripe.Resources.CheckoutCardRestrictions{
  brands_blocked: [String.t()] | nil
}
  • brands_blocked - Specify the card brands to block in the Checkout Session. If a customer enters or selects a card belonging to a blocked brand, they can't complete the Session.

Functions

object_name()