Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Climate.Order.Beneficiary{ public_name: String.t() | nil }
public_name- Publicly displayable name for the end beneficiary of carbon removal. Max length: 5000.
Nested struct within the parent resource.
@type t() :: %Stripe.Resources.Climate.Order.Beneficiary{ public_name: String.t() | nil }
public_name - Publicly displayable name for the end beneficiary of carbon removal. Max length: 5000.