Stripe.Resources.Climate.Product.CurrentPricesPerMetricTon (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Climate.Product.CurrentPricesPerMetricTon{
  amount_fees: integer() | nil,
  amount_subtotal: integer() | nil,
  amount_total: integer() | nil
}
  • amount_fees - Fees for one metric ton of carbon removal in the currency's smallest unit.
  • amount_subtotal - Subtotal for one metric ton of carbon removal (excluding fees) in the currency's smallest unit.
  • amount_total - Total for one metric ton of carbon removal (including fees) in the currency's smallest unit.