Stripe.Resources.ConfirmationToken.MandateData.CustomerAcceptance (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.ConfirmationToken.MandateData.CustomerAcceptance{
  online:
    Stripe.Resources.ConfirmationToken.MandateData.CustomerAcceptance.Online.t()
    | nil,
  type: String.t() | nil
}
  • online - If this is a Mandate accepted online, this hash contains details about the online acceptance. Nullable.
  • type - The type of customer acceptance information included with the Mandate. Max length: 5000.