Stripe.Resources.ConfirmationToken.PaymentMethodPreview (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.ConfirmationToken.PaymentMethodPreview{
  acss_debit:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.AcssDebit.t() | nil,
  affirm: map() | nil,
  afterpay_clearpay: map() | nil,
  alipay: map() | nil,
  allow_redisplay: String.t() | nil,
  alma: map() | nil,
  amazon_pay: map() | nil,
  au_becs_debit:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.AuBecsDebit.t()
    | nil,
  bacs_debit:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.BacsDebit.t() | nil,
  bancontact: map() | nil,
  billie: map() | nil,
  billing_details:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.BillingDetails.t()
    | nil,
  blik: map() | nil,
  boleto:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Boleto.t() | nil,
  card: Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Card.t() | nil,
  card_present:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.CardPresent.t()
    | nil,
  cashapp:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Cashapp.t() | nil,
  crypto: Stripe.Resources.Crypto.t() | nil,
  customer: String.t() | Stripe.Resources.Customer.t() | nil,
  customer_account: String.t() | nil,
  customer_balance: map() | nil,
  eps: Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Eps.t() | nil,
  fpx: Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Fpx.t() | nil,
  giropay: map() | nil,
  grabpay: map() | nil,
  ideal:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Ideal.t() | nil,
  interac_present:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.InteracPresent.t()
    | nil,
  kakao_pay: Stripe.Resources.KakaoPay.t() | nil,
  klarna:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Klarna.t() | nil,
  konbini: map() | nil,
  kr_card: Stripe.Resources.KrCard.t() | nil,
  link: Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Link.t() | nil,
  mb_way: Stripe.Resources.MbWay.t() | nil,
  mobilepay: map() | nil,
  multibanco: map() | nil,
  naver_pay: Stripe.Resources.NaverPay.t() | nil,
  nz_bank_account:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.NzBankAccount.t()
    | nil,
  oxxo: map() | nil,
  p24: Stripe.Resources.ConfirmationToken.PaymentMethodPreview.P24.t() | nil,
  pay_by_bank: map() | nil,
  payco: Stripe.Resources.Payco.t() | nil,
  paynow: map() | nil,
  paypal:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Paypal.t() | nil,
  payto:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Payto.t() | nil,
  pix: map() | nil,
  promptpay: map() | nil,
  revolut_pay: map() | nil,
  samsung_pay: Stripe.Resources.SamsungPay.t() | nil,
  satispay: map() | nil,
  sepa_debit:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.SepaDebit.t() | nil,
  sofort:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Sofort.t() | nil,
  swish: map() | nil,
  twint: map() | nil,
  type: String.t() | nil,
  us_bank_account:
    Stripe.Resources.ConfirmationToken.PaymentMethodPreview.UsBankAccount.t()
    | nil,
  wechat_pay: map() | nil,
  zip: map() | nil
}
  • acss_debit
  • affirm
  • afterpay_clearpay
  • alipay
  • allow_redisplay - This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”. Possible values: always, limited, unspecified.
  • alma
  • amazon_pay
  • au_becs_debit
  • bacs_debit
  • bancontact
  • billie
  • billing_details
  • blik
  • boleto
  • card
  • card_present
  • cashapp
  • crypto
  • customer - The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer. Nullable.
  • customer_account - Max length: 5000. Nullable.
  • customer_balance
  • eps
  • fpx
  • giropay
  • grabpay
  • ideal
  • interac_present
  • kakao_pay
  • klarna
  • konbini
  • kr_card
  • link
  • mb_way
  • mobilepay
  • multibanco
  • naver_pay
  • nz_bank_account
  • oxxo
  • p24
  • pay_by_bank
  • payco
  • paynow
  • paypal
  • payto
  • pix
  • promptpay
  • revolut_pay
  • samsung_pay
  • satispay
  • sepa_debit
  • sofort
  • swish
  • twint
  • type - The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type. Possible values: acss_debit, affirm, afterpay_clearpay, alipay, alma, amazon_pay, au_becs_debit, bacs_debit, bancontact, billie, blik, boleto, card, card_present, cashapp, crypto, custom, customer_balance, eps, fpx, giropay, grabpay, ideal, interac_present, kakao_pay, klarna, konbini, kr_card, link, mb_way, mobilepay, multibanco, naver_pay, nz_bank_account, oxxo, p24, pay_by_bank, payco, paynow, paypal, payto, pix, promptpay, revolut_pay, samsung_pay, satispay, sepa_debit, sofort, swish, twint, us_bank_account, wechat_pay, zip.
  • us_bank_account
  • wechat_pay
  • zip