Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Card.GeneratedFrom.PaymentMethodDetails.CardPresent.Receipt
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.ConfirmationToken.PaymentMethodPreview.Card.GeneratedFrom.PaymentMethodDetails.CardPresent.Receipt{ account_type: String.t() | nil, application_cryptogram: String.t() | nil, application_preferred_name: String.t() | nil, authorization_code: String.t() | nil, authorization_response_code: String.t() | nil, cardholder_verification_method: String.t() | nil, dedicated_file_name: String.t() | nil, terminal_verification_results: String.t() | nil, transaction_status_information: String.t() | nil }
account_type- The type of account being debited or credited Possible values:checking,credit,prepaid,unknown.application_cryptogram- The Application Cryptogram, a unique value generated by the card to authenticate the transaction with issuers. Max length: 5000. Nullable.application_preferred_name- The Application Identifier (AID) on the card used to determine which networks are eligible to process the transaction. Referenced from EMV tag 9F12, data encoded on the card's chip. Max length: 5000. Nullable.authorization_code- Identifier for this transaction. Max length: 5000. Nullable.authorization_response_code- EMV tag 8A. A code returned by the card issuer. Max length: 5000. Nullable.cardholder_verification_method- Describes the method used by the cardholder to verify ownership of the card. One of the following:approval,failure,none,offline_pin,offline_pin_and_signature,online_pin, orsignature. Max length: 5000. Nullable.dedicated_file_name- Similar to the application_preferred_name, identifying the applications (AIDs) available on the card. Referenced from EMV tag 84. Max length: 5000. Nullable.terminal_verification_results- A 5-byte string that records the checks and validations that occur between the card and the terminal. These checks determine how the terminal processes the transaction and what risk tolerance is acceptable. Referenced from EMV Tag 95. Max length: 5000. Nullable.transaction_status_information- An indication of which steps were completed during the card read process. Referenced from EMV Tag 9B. Max length: 5000. Nullable.