Stripe.Resources.CreditNote.Refunds (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.CreditNote.Refunds{
  amount_refunded: integer() | nil,
  payment_record_refund:
    Stripe.Resources.CreditNote.Refunds.PaymentRecordRefund.t() | nil,
  refund: String.t() | Stripe.Resources.Refund.t() | nil,
  type: String.t() | nil
}
  • amount_refunded - Amount of the refund that applies to this credit note, in cents (or local equivalent).
  • payment_record_refund - The PaymentRecord refund details associated with this credit note refund. Nullable.
  • refund - ID of the refund.
  • type - Type of the refund, one of refund or payment_record_refund. Possible values: payment_record_refund, refund. Nullable.