Stripe.Resources.CreditNoteLineItem (tiger_stripe v0.1.10)

Copy Markdown View Source

CreditNoteLineItem

The credit note line item object

Summary

Types

t()

@type t() :: %Stripe.Resources.CreditNoteLineItem{
  amount: integer(),
  description: String.t(),
  discount_amount: integer(),
  discount_amounts: [Stripe.Resources.CreditNoteLineItem.DiscountAmounts.t()],
  id: String.t(),
  invoice_line_item: String.t() | nil,
  livemode: boolean(),
  object: String.t(),
  pretax_credit_amounts: [
    Stripe.Resources.CreditNoteLineItem.PretaxCreditAmounts.t()
  ],
  quantity: integer(),
  tax_rates: [Stripe.Resources.TaxRate.t()],
  taxes: [Stripe.Resources.CreditNoteLineItem.Taxes.t()],
  type: String.t(),
  unit_amount: integer(),
  unit_amount_decimal: String.t()
}
  • amount - The integer amount in cents (or local equivalent) representing the gross amount being credited for this line item, excluding (exclusive) tax and discounts.
  • description - Description of the item being credited. Max length: 5000. Nullable.
  • discount_amount - The integer amount in cents (or local equivalent) representing the discount being credited for this line item.
  • discount_amounts - The amount of discount calculated per discount for this line item Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • invoice_line_item - ID of the invoice line item being credited Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: credit_note_line_item.
  • pretax_credit_amounts - The pretax credit amounts (ex: discount, credit grants, etc) for this line item. Expandable.
  • quantity - The number of units of product being credited. Nullable.
  • tax_rates - The tax rates which apply to the line item. Expandable.
  • taxes - The tax information of the line item. Nullable. Expandable.
  • type - The type of the credit note line item, one of invoice_line_item or custom_line_item. When the type is invoice_line_item there is an additional invoice_line_item property on the resource the value of which is the id of the credited line item on the invoice. Possible values: custom_line_item, invoice_line_item.
  • unit_amount - The cost of each unit of product being credited. Nullable.
  • unit_amount_decimal - Same as unit_amount, but contains a decimal value with at most 12 decimal places. Format: decimal string. Nullable.

Functions

expandable_fields()

object_name()