Stripe.Resources.CreditNoteLineItem.Taxes (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.CreditNoteLineItem.Taxes{
  amount: integer() | nil,
  tax_behavior: String.t() | nil,
  tax_rate_details:
    Stripe.Resources.CreditNoteLineItem.Taxes.TaxRateDetails.t() | nil,
  taxability_reason: String.t() | nil,
  taxable_amount: integer() | nil,
  type: String.t() | nil
}
  • amount - The amount of the tax, in cents (or local equivalent).
  • tax_behavior - Whether this tax is inclusive or exclusive. Possible values: exclusive, inclusive.
  • tax_rate_details - Additional details about the tax rate. Only present when type is tax_rate_details. Nullable.
  • taxability_reason - The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported. Possible values: customer_exempt, not_available, not_collecting, not_subject_to_tax, not_supported, portion_product_exempt, portion_reduced_rated, portion_standard_rated, product_exempt, product_exempt_holiday, proportionally_rated, reduced_rated, reverse_charge, standard_rated, taxable_basis_reduced, zero_rated.
  • taxable_amount - The amount on which tax is calculated, in cents (or local equivalent). Nullable.
  • type - The type of tax information. Possible values: tax_rate_details.