Stripe.Resources.Customer.Tax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Customer.Tax{
  automatic_tax: String.t() | nil,
  ip_address: String.t() | nil,
  location: Stripe.Resources.Customer.Tax.Location.t() | nil,
  provider: String.t() | nil
}
  • automatic_tax - Surfaces if automatic tax computation is possible given the current customer location information. Possible values: failed, not_collecting, supported, unrecognized_location.
  • ip_address - A recent IP address of the customer used for tax reporting and tax location inference. Max length: 5000. Nullable.
  • location - The identified tax location of the customer. Nullable.
  • provider - The tax calculation provider used for location resolution. Defaults to stripe when not using a third-party provider. Possible values: anrok, avalara, sphere, stripe.