Stripe.Resources.CustomerCashBalanceTransaction.Funded.BankTransfer.GbBankTransfer (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.CustomerCashBalanceTransaction.Funded.BankTransfer.GbBankTransfer{
    account_number_last4: String.t() | nil,
    sender_name: String.t() | nil,
    sort_code: String.t() | nil
  }
  • account_number_last4 - The last 4 digits of the account number of the sender of the funding. Max length: 5000. Nullable.
  • sender_name - The full name of the sender, as supplied by the sending bank. Max length: 5000. Nullable.
  • sort_code - The sort code of the bank of the sender of the funding Max length: 5000. Nullable.