Stripe.Resources.CustomerCashBalanceTransaction.Funded.BankTransfer.JpBankTransfer (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.CustomerCashBalanceTransaction.Funded.BankTransfer.JpBankTransfer{
    sender_bank: String.t() | nil,
    sender_branch: String.t() | nil,
    sender_name: String.t() | nil
  }
  • sender_bank - The name of the bank of the sender of the funding. Max length: 5000. Nullable.
  • sender_branch - The name of the bank branch of the sender of the funding. Max length: 5000. Nullable.
  • sender_name - The full name of the sender, as supplied by the sending bank. Max length: 5000. Nullable.