Stripe.Resources.CustomerSession.Components.CustomerSheet.Features (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.CustomerSession.Components.CustomerSheet.Features{
  payment_method_allow_redisplay_filters: [String.t()] | nil,
  payment_method_remove: String.t() | nil
}
  • payment_method_allow_redisplay_filters - A list of allow_redisplay values that controls which saved payment methods the customer sheet displays by filtering to only show payment methods with an allow_redisplay value that is present in this list.

If not specified, defaults to ["always"]. In order to display all saved payment methods, specify ["always", "limited", "unspecified"]. Nullable.

  • payment_method_remove - Controls whether the customer sheet displays the option to remove a saved payment method."

Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the customer object from that PaymentMethod. Possible values: disabled, enabled. Nullable.