Stripe.Resources.CustomerSession.Components.MobilePaymentElement.Features (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.CustomerSession.Components.MobilePaymentElement.Features{
    payment_method_allow_redisplay_filters: [String.t()] | nil,
    payment_method_redisplay: String.t() | nil,
    payment_method_remove: String.t() | nil,
    payment_method_save: String.t() | nil,
    payment_method_save_allow_redisplay_override: String.t() | nil
  }
  • payment_method_allow_redisplay_filters - A list of allow_redisplay values that controls which saved payment methods the mobile payment element displays by filtering to only show payment methods with an allow_redisplay value that is present in this list.

If not specified, defaults to ["always"]. In order to display all saved payment methods, specify ["always", "limited", "unspecified"]. Nullable.

  • payment_method_redisplay - Controls whether or not the mobile payment element shows saved payment methods. Possible values: disabled, enabled. Nullable.
  • payment_method_remove - Controls whether the mobile payment element displays the option to remove a saved payment method."

Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the customer object from that PaymentMethod. Possible values: disabled, enabled. Nullable.

  • payment_method_save - Controls whether the mobile payment element displays a checkbox offering to save a new payment method.

If a customer checks the box, the allow_redisplay value on the PaymentMethod is set to 'always' at confirmation time. For PaymentIntents, the setup_future_usage value is also set to the value defined in payment_method_save_usage. Possible values: disabled, enabled. Nullable.

  • payment_method_save_allow_redisplay_override - Allows overriding the value of allow_override when saving a new payment method when payment_method_save is set to disabled. Use values: "always", "limited", or "unspecified".

If not specified, defaults to nil (no override value). Possible values: always, limited, unspecified. Nullable.