Stripe.Resources.CustomerSession.Components.PaymentElement.Features
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.CustomerSession.Components.PaymentElement.Features{ payment_method_allow_redisplay_filters: [String.t()] | nil, payment_method_redisplay: String.t() | nil, payment_method_redisplay_limit: integer() | nil, payment_method_remove: String.t() | nil, payment_method_save: String.t() | nil, payment_method_save_usage: String.t() | nil }
payment_method_allow_redisplay_filters- A list ofallow_redisplayvalues that controls which saved payment methods the Payment Element displays by filtering to only show payment methods with anallow_redisplayvalue that is present in this list.
If not specified, defaults to ["always"]. In order to display all saved payment methods, specify ["always", "limited", "unspecified"].
payment_method_redisplay- Controls whether or not the Payment Element shows saved payment methods. This parameter defaults todisabled. Possible values:disabled,enabled.payment_method_redisplay_limit- Determines the max number of saved payment methods for the Payment Element to display. This parameter defaults to3. The maximum redisplay limit is10. Nullable.payment_method_remove- Controls whether the Payment Element displays the option to remove a saved payment method. This parameter defaults todisabled.
Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the customer object from that PaymentMethod. Possible values: disabled, enabled.
payment_method_save- Controls whether the Payment Element displays a checkbox offering to save a new payment method. This parameter defaults todisabled.
If a customer checks the box, the allow_redisplay value on the PaymentMethod is set to 'always' at confirmation time. For PaymentIntents, the setup_future_usage value is also set to the value defined in payment_method_save_usage. Possible values: disabled, enabled.
payment_method_save_usage- When using PaymentIntents and the customer checks the save checkbox, this field determines thesetup_future_usagevalue used to confirm the PaymentIntent.
When using SetupIntents, directly configure the usage value on SetupIntent creation. Possible values: off_session, on_session. Nullable.