Stripe.Resources.Dispute.Evidence (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Dispute.Evidence{
  access_activity_log: String.t() | nil,
  billing_address: String.t() | nil,
  cancellation_policy: String.t() | Stripe.Resources.File.t() | nil,
  cancellation_policy_disclosure: String.t() | nil,
  cancellation_rebuttal: String.t() | nil,
  customer_communication: String.t() | Stripe.Resources.File.t() | nil,
  customer_email_address: String.t() | nil,
  customer_name: String.t() | nil,
  customer_purchase_ip: String.t() | nil,
  customer_signature: String.t() | Stripe.Resources.File.t() | nil,
  duplicate_charge_documentation: String.t() | Stripe.Resources.File.t() | nil,
  duplicate_charge_explanation: String.t() | nil,
  duplicate_charge_id: String.t() | nil,
  enhanced_evidence:
    Stripe.Resources.Dispute.Evidence.EnhancedEvidence.t() | nil,
  product_description: String.t() | nil,
  receipt: String.t() | Stripe.Resources.File.t() | nil,
  refund_policy: String.t() | Stripe.Resources.File.t() | nil,
  refund_policy_disclosure: String.t() | nil,
  refund_refusal_explanation: String.t() | nil,
  service_date: String.t() | nil,
  service_documentation: String.t() | Stripe.Resources.File.t() | nil,
  shipping_address: String.t() | nil,
  shipping_carrier: String.t() | nil,
  shipping_date: String.t() | nil,
  shipping_documentation: String.t() | Stripe.Resources.File.t() | nil,
  shipping_tracking_number: String.t() | nil,
  uncategorized_file: String.t() | Stripe.Resources.File.t() | nil,
  uncategorized_text: String.t() | nil
}
  • access_activity_log - Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product. This information should include IP addresses, corresponding timestamps, and any detailed recorded activity. Max length: 150000. Nullable.
  • billing_address - The billing address provided by the customer. Max length: 5000. Nullable.
  • cancellation_policy - (ID of a file upload) Your subscription cancellation policy, as shown to the customer. Nullable.
  • cancellation_policy_disclosure - An explanation of how and when the customer was shown your refund policy prior to purchase. Max length: 150000. Nullable.
  • cancellation_rebuttal - A justification for why the customer's subscription was not canceled. Max length: 150000. Nullable.
  • customer_communication - (ID of a file upload) Any communication with the customer that you feel is relevant to your case. Examples include emails proving that the customer received the product or service, or demonstrating their use of or satisfaction with the product or service. Nullable.
  • customer_email_address - The email address of the customer. Max length: 5000. Nullable.
  • customer_name - The name of the customer. Max length: 5000. Nullable.
  • customer_purchase_ip - The IP address that the customer used when making the purchase. Max length: 5000. Nullable.
  • customer_signature - (ID of a file upload) A relevant document or contract showing the customer's signature. Nullable.
  • duplicate_charge_documentation - (ID of a file upload) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc. This document should be paired with a similar document from the disputed payment that proves the two payments are separate. Nullable.
  • duplicate_charge_explanation - An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate. Max length: 150000. Nullable.
  • duplicate_charge_id - The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge. Max length: 5000. Nullable.
  • enhanced_evidence
  • product_description - A description of the product or service that was sold. Max length: 150000. Nullable.
  • receipt - (ID of a file upload) Any receipt or message sent to the customer notifying them of the charge. Nullable.
  • refund_policy - (ID of a file upload) Your refund policy, as shown to the customer. Nullable.
  • refund_policy_disclosure - Documentation demonstrating that the customer was shown your refund policy prior to purchase. Max length: 150000. Nullable.
  • refund_refusal_explanation - A justification for why the customer is not entitled to a refund. Max length: 150000. Nullable.
  • service_date - The date on which the customer received or began receiving the purchased service, in a clear human-readable format. Max length: 5000. Nullable.
  • service_documentation - (ID of a file upload) Documentation showing proof that a service was provided to the customer. This could include a copy of a signed contract, work order, or other form of written agreement. Nullable.
  • shipping_address - The address to which a physical product was shipped. You should try to include as complete address information as possible. Max length: 5000. Nullable.
  • shipping_carrier - The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. If multiple carriers were used for this purchase, please separate them with commas. Max length: 5000. Nullable.
  • shipping_date - The date on which a physical product began its route to the shipping address, in a clear human-readable format. Max length: 5000. Nullable.
  • shipping_documentation - (ID of a file upload) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you. This could include a copy of the shipment receipt, shipping label, etc. It should show the customer's full shipping address, if possible. Nullable.
  • shipping_tracking_number - The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas. Max length: 5000. Nullable.
  • uncategorized_file - (ID of a file upload) Any additional evidence or statements. Nullable.
  • uncategorized_text - Any additional evidence or statements. Max length: 150000. Nullable.