Stripe.Resources.Dispute.Evidence.EnhancedEvidence.VisaCompellingEvidence3.PriorUndisputedTransactions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.Dispute.Evidence.EnhancedEvidence.VisaCompellingEvidence3.PriorUndisputedTransactions{
    charge: String.t() | nil,
    customer_account_id: String.t() | nil,
    customer_device_fingerprint: String.t() | nil,
    customer_device_id: String.t() | nil,
    customer_email_address: String.t() | nil,
    customer_purchase_ip: String.t() | nil,
    product_description: String.t() | nil,
    shipping_address:
      Stripe.Resources.Dispute.Evidence.EnhancedEvidence.VisaCompellingEvidence3.PriorUndisputedTransactions.ShippingAddress.t()
      | nil
  }
  • charge - Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge. Max length: 5000.
  • customer_account_id - User Account ID used to log into business platform. Must be recognizable by the user. Max length: 5000. Nullable.
  • customer_device_fingerprint - Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters. Max length: 5000. Nullable.
  • customer_device_id - Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters. Max length: 5000. Nullable.
  • customer_email_address - The email address of the customer. Max length: 5000. Nullable.
  • customer_purchase_ip - The IP address that the customer used when making the purchase. Max length: 5000. Nullable.
  • product_description - A description of the product or service that was sold. Max length: 150000. Nullable.
  • shipping_address - The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission. Nullable.