Stripe.Resources.Entitlements.ActiveEntitlementSummary (tiger_stripe v0.1.10)

Copy Markdown View Source

ActiveEntitlementSummary

A summary of a customer's active entitlements.

Summary

Types

t()

@type t() :: %Stripe.Resources.Entitlements.ActiveEntitlementSummary{
  customer: String.t(),
  entitlements:
    Stripe.Resources.Entitlements.ActiveEntitlementSummary.Entitlements.t(),
  livemode: boolean(),
  object: String.t()
}
  • customer - The customer that is entitled to this feature. Max length: 5000.
  • entitlements - The list of entitlements this customer has. Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: entitlements.active_entitlement_summary.

Functions

expandable_fields()

object_name()