Stripe.Resources.Event.Request (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Event.Request{
  id: String.t() | nil,
  idempotency_key: String.t() | nil
}
  • id - ID of the API request that caused the event. If null, the event was automatic (e.g., Stripe's automatic subscription handling). Request logs are available in the dashboard, but currently not in the API. Max length: 5000. Nullable.
  • idempotency_key - The idempotency key transmitted during the request, if any. Note: This property is populated only for events on or after May 23, 2017. Max length: 5000. Nullable.