Stripe.Resources.EventData (tiger_stripe v0.1.10)

Copy Markdown View Source

NotificationEventData

Summary

Types

t()

@type t() :: %Stripe.Resources.EventData{
  object: map(),
  previous_attributes: map() | nil
}
  • object - Object containing the API resource relevant to the event. For example, an invoice.created event will have a full invoice object as the value of the object key.
  • previous_attributes - Object containing the names of the updated attributes and their values prior to the event (only included in events of type *.updated). If an array attribute has any updated elements, this object contains the entire array. In Stripe API versions 2017-04-06 or earlier, an updated array attribute in this object includes only the updated array elements.

Functions

object_name()