FeeRefund
Application Fee Refund objects allow you to refund an application fee that
has previously been created but not yet refunded. Funds will be refunded to
the Stripe account from which the fee was originally collected.
Related guide: Refunding application fees
Summary
Types
@type t() :: %Stripe.Resources.FeeRefund{ amount: integer(), balance_transaction: String.t() | Stripe.Resources.BalanceTransaction.t(), created: integer(), currency: String.t(), fee: String.t() | Stripe.Resources.ApplicationFee.t(), id: String.t(), metadata: %{required(String.t()) => String.t()}, object: String.t() }
amount- Amount, in cents (or local equivalent).balance_transaction- Balance transaction that describes the impact on your account balance. Nullable. Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.fee- ID of the application fee that was refunded. Expandable.id- Unique identifier for the object. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.object- String representing the object's type. Objects of the same type share the same value. Possible values:fee_refund.