File
This object represents files hosted on Stripe's servers. You can upload files with the create file request (for example, when uploading dispute evidence). Stripe also creates files independently (for example, the results of a Sigma scheduled query).
Related guide: File upload guide
Summary
Types
@type t() :: %Stripe.Resources.File{ created: integer(), expires_at: integer(), filename: String.t(), id: String.t(), links: Stripe.Resources.File.Links.t() | nil, object: String.t(), purpose: String.t(), size: integer(), title: String.t(), type: String.t(), url: String.t() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.expires_at- The file expires and isn't available at this time in epoch seconds. Format: Unix timestamp. Nullable.filename- The suitable name for saving the file to a filesystem. Max length: 5000. Nullable.id- Unique identifier for the object. Max length: 5000.links- A list of file links that point at this file. Nullable. Expandable.object- String representing the object's type. Objects of the same type share the same value. Possible values:file.purpose- The purpose of the uploaded file. Possible values:account_requirement,additional_verification,business_icon,business_logo,customer_signature,dispute_evidence,document_provider_identity_document,finance_report_run,financial_account_statement,identity_document,identity_document_downloadable,issuing_regulatory_reporting,pci_document,platform_terms_of_service,selfie,sigma_scheduled_query,tax_document_user_upload,terminal_android_apk,terminal_reader_splashscreen.size- The size of the file object in bytes.title- A suitable title for the document. Max length: 5000. Nullable.type- The returned file type (for example,csv,pdf,jpg, orpng). Max length: 5000. Nullable.url- Use your live secret API key to download the file from this URL. Max length: 5000. Nullable.