Stripe.Resources.FinancialConnections.Account.AccountHolder
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.FinancialConnections.Account.AccountHolder{ account: String.t() | Stripe.Resources.Account.t() | nil, customer: String.t() | Stripe.Resources.Customer.t() | nil, customer_account: String.t() | nil, type: String.t() | nil }
account- The ID of the Stripe account that this account belongs to. Only available whenaccount_holder.typeisaccount.customer- The ID for an Account representing a customer that this account belongs to. Only available whenaccount_holder.typeiscustomer.customer_account- Max length: 5000.type- Type of account holder that this account belongs to. Possible values:account,customer.