Stripe.Resources.FinancialConnections.Account.AccountNumbers (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.FinancialConnections.Account.AccountNumbers{
  expected_expiry_date: integer() | nil,
  identifier_type: String.t() | nil,
  status: String.t() | nil,
  supported_networks: [String.t()] | nil
}
  • expected_expiry_date - When the account number is expected to expire, if applicable. Format: Unix timestamp. Nullable.
  • identifier_type - The type of account number associated with the account. Possible values: account_number, tokenized_account_number.
  • status - Whether the account number is currently active and usable for transactions. Possible values: deactivated, transactable.
  • supported_networks - The payment networks that the account number can be used for.