Stripe.Resources.FinancialConnections.Account.Balance (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.FinancialConnections.Account.Balance{
  as_of: integer() | nil,
  cash: Stripe.Resources.FinancialConnections.Account.Balance.Cash.t() | nil,
  credit:
    Stripe.Resources.FinancialConnections.Account.Balance.Credit.t() | nil,
  current: %{required(String.t()) => integer()} | nil,
  type: String.t() | nil
}
  • as_of - The time that the external institution calculated this balance. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • cash
  • credit
  • current - The balances owed to (or by) the account holder, before subtracting any outbound pending transactions or adding any inbound pending transactions.

Each key is a three-letter ISO currency code, in lowercase.

Each value is a integer amount. A positive amount indicates money owed to the account holder. A negative amount indicates money owed by the account holder.

  • type - The type of the balance. An additional hash is included on the balance with a name matching this value. Possible values: cash, credit.