Stripe.Resources.FinancialConnections.Session (tiger_stripe v0.1.10)

Copy Markdown View Source

BankConnectionsResourceLinkAccountSession

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Summary

Types

t()

@type t() :: %Stripe.Resources.FinancialConnections.Session{
  account_holder:
    Stripe.Resources.FinancialConnections.Session.AccountHolder.t(),
  accounts: Stripe.Resources.FinancialConnections.Session.Accounts.t(),
  client_secret: String.t(),
  filters: Stripe.Resources.FinancialConnections.Session.Filters.t() | nil,
  id: String.t(),
  livemode: boolean(),
  object: String.t(),
  permissions: [String.t()],
  prefetch: [String.t()],
  return_url: String.t() | nil
}
  • account_holder - The account holder for whom accounts are collected in this session. Nullable. Expandable.
  • accounts - The accounts that were collected as part of this Session. Expandable.
  • client_secret - A value that will be passed to the client to launch the authentication flow. Max length: 5000. Nullable.
  • filters - Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: financial_connections.session.
  • permissions - Permissions requested for accounts collected during this session.
  • prefetch - Data features requested to be retrieved upon account creation. Nullable.
  • return_url - For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app. Max length: 5000.

Functions

expandable_fields()

object_name()