Stripe.Resources.FinancialConnections.Session.AccountHolder (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.FinancialConnections.Session.AccountHolder{
  account: String.t() | Stripe.Resources.Account.t() | nil,
  customer: String.t() | Stripe.Resources.Customer.t() | nil,
  customer_account: String.t() | nil,
  type: String.t() | nil
}
  • account - The ID of the Stripe account that this account belongs to. Only available when account_holder.type is account.
  • customer - The ID for an Account representing a customer that this account belongs to. Only available when account_holder.type is customer.
  • customer_account - Max length: 5000.
  • type - Type of account holder that this account belongs to. Possible values: account, customer.