Stripe.Resources.Identity.VerificationReport.Document (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Identity.VerificationReport.Document{
  address: Stripe.Resources.Address.t() | nil,
  dob: Stripe.Resources.Identity.VerificationReport.Document.Dob.t() | nil,
  error: Stripe.Resources.Identity.VerificationReport.Document.Error.t() | nil,
  expiration_date:
    Stripe.Resources.Identity.VerificationReport.Document.ExpirationDate.t()
    | nil,
  files: [String.t()] | nil,
  first_name: String.t() | nil,
  issued_date:
    Stripe.Resources.Identity.VerificationReport.Document.IssuedDate.t() | nil,
  issuing_country: String.t() | nil,
  last_name: String.t() | nil,
  number: String.t() | nil,
  sex: String.t() | nil,
  status: String.t() | nil,
  type: String.t() | nil,
  unparsed_place_of_birth: String.t() | nil,
  unparsed_sex: String.t() | nil
}
  • address - Address as it appears in the document. Nullable.
  • dob - Date of birth as it appears in the document. Nullable.
  • error - Details on the verification error. Present when status is unverified. Nullable.
  • expiration_date - Expiration date of the document. Nullable.
  • files - Array of File ids containing images for this document. Nullable.
  • first_name - First name as it appears in the document. Max length: 5000. Nullable.
  • issued_date - Issued date of the document. Nullable.
  • issuing_country - Issuing country of the document. Max length: 5000. Nullable.
  • last_name - Last name as it appears in the document. Max length: 5000. Nullable.
  • number - Document ID number. Max length: 5000. Nullable.
  • sex - Sex of the person in the document. Possible values: [redacted], female, male, unknown. Nullable.
  • status - Status of this document check. Possible values: unverified, verified.
  • type - Type of the document. Possible values: driving_license, id_card, passport. Nullable.
  • unparsed_place_of_birth - Place of birth as it appears in the document. Max length: 5000. Nullable.
  • unparsed_sex - Sex as it appears in the document. Max length: 5000. Nullable.