Stripe.Resources.Invoice.Parent (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Invoice.Parent{
  quote_details: Stripe.Resources.Invoice.Parent.QuoteDetails.t() | nil,
  subscription_details:
    Stripe.Resources.Invoice.Parent.SubscriptionDetails.t() | nil,
  type: String.t() | nil
}
  • quote_details - Details about the quote that generated this invoice Nullable.
  • subscription_details - Details about the subscription that generated this invoice Nullable.
  • type - The type of parent that generated this invoice Possible values: quote_details, subscription_details.