Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

  • acss_debit - If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent. Nullable.
  • bancontact - If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent. Nullable.
  • card - If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent. Nullable.
  • customer_balance - If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent. Nullable.
  • konbini - If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent. Nullable.
  • payto - If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent. Nullable.
  • sepa_debit - If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent. Nullable.
  • us_bank_account - If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent. Nullable.