Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.Card (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.Card{
  installments:
    Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.Card.Installments.t()
    | nil,
  request_three_d_secure: String.t() | nil
}
  • installments
  • request_three_d_secure - We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine. Possible values: any, automatic, challenge. Nullable.