Stripe.Resources.Invoice.ShippingCost.Taxes (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Invoice.ShippingCost.Taxes{
  amount: integer() | nil,
  rate: Stripe.Resources.TaxRate.t() | nil,
  taxability_reason: String.t() | nil,
  taxable_amount: integer() | nil
}
  • amount - Amount of tax applied for this rate.
  • rate
  • taxability_reason - The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported. Possible values: customer_exempt, not_collecting, not_subject_to_tax, not_supported, portion_product_exempt, portion_reduced_rated, portion_standard_rated, product_exempt, product_exempt_holiday, proportionally_rated, reduced_rated, reverse_charge, standard_rated, taxable_basis_reduced, zero_rated. Nullable.
  • taxable_amount - The amount on which tax is calculated, in cents (or local equivalent). Nullable.