Stripe.Resources.Invoice.ThresholdReason.ItemReasons (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Invoice.ThresholdReason.ItemReasons{
  line_item_ids: [String.t()] | nil,
  usage_gte: integer() | nil
}
  • line_item_ids - The IDs of the line items that triggered the threshold invoice.
  • usage_gte - The quantity threshold boundary that applied to the given line item.