Stripe.Resources.Invoice.TotalPretaxCreditAmounts (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Invoice.TotalPretaxCreditAmounts{
  amount: integer() | nil,
  credit_balance_transaction:
    String.t() | Stripe.Resources.Billing.CreditBalanceTransaction.t() | nil,
  discount: String.t() | Stripe.Resources.Discount.t() | nil,
  type: String.t() | nil
}
  • amount - The amount, in cents (or local equivalent), of the pretax credit amount.
  • credit_balance_transaction - The credit balance transaction that was applied to get this pretax credit amount. Nullable.
  • discount - The discount that was applied to get this pretax credit amount.
  • type - Type of the pretax credit amount referenced. Possible values: credit_balance_transaction, discount.