Stripe.Resources.InvoiceItem.Pricing.PriceDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.InvoiceItem.Pricing.PriceDetails{
  price: String.t() | Stripe.Resources.Price.t() | nil,
  product: String.t() | nil
}
  • price - The ID of the price this item is associated with.
  • product - The ID of the product this item is associated with. Max length: 5000.