Stripe.Resources.InvoiceLineItem (tiger_stripe v0.1.10)

Copy Markdown View Source

InvoiceLineItem

Invoice Line Items represent the individual lines within an invoice and only exist within the context of an invoice.

Each line item is backed by either an invoice item or a subscription item.

Summary

Types

t()

@type t() :: %Stripe.Resources.InvoiceLineItem{
  amount: integer(),
  currency: String.t(),
  description: String.t(),
  discount_amounts: [Stripe.Resources.InvoiceLineItem.DiscountAmounts.t()],
  discountable: boolean(),
  discounts: [String.t() | Stripe.Resources.Discount.t()],
  id: String.t(),
  invoice: String.t(),
  livemode: boolean(),
  metadata: %{required(String.t()) => String.t()},
  object: String.t(),
  parent: Stripe.Resources.InvoiceLineItem.Parent.t(),
  period: Stripe.Resources.InvoiceLineItem.Period.t(),
  pretax_credit_amounts: [
    Stripe.Resources.InvoiceLineItem.PretaxCreditAmounts.t()
  ],
  pricing: Stripe.Resources.InvoiceLineItem.Pricing.t(),
  quantity: integer(),
  subscription: String.t() | Stripe.Resources.Subscription.t(),
  subtotal: integer(),
  taxes: [Stripe.Resources.InvoiceLineItem.Taxes.t()]
}
  • amount - The amount, in cents (or local equivalent).
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000. Nullable.
  • discount_amounts - The amount of discount calculated per discount for this line item. Nullable. Expandable.
  • discountable - If true, discounts will apply to this line item. Always false for prorations.
  • discounts - The discounts applied to the invoice line item. Line item discounts are applied before invoice discounts. Use expand[]=discounts to expand each discount. Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • invoice - The ID of the invoice that contains this line item. Max length: 5000. Nullable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Note that for line items with type=subscription, metadata reflects the current metadata from the subscription associated with the line item, unless the invoice line was directly updated with different metadata after creation.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: line_item.
  • parent - The parent that generated this line item. Nullable. Expandable.
  • period - Expandable.
  • pretax_credit_amounts - Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this line item. Nullable. Expandable.
  • pricing - The pricing information of the line item. Nullable. Expandable.
  • quantity - The quantity of the subscription, if the line item is a subscription or a proration. Nullable.
  • subscription - Nullable. Expandable.
  • subtotal - The subtotal of the line item, in cents (or local equivalent), before any discounts or taxes.
  • taxes - The tax information of the line item. Nullable. Expandable.

Functions

expandable_fields()

object_name()