Stripe.Resources.Issuing.Authorization.Fleet.ReportedBreakdown.Tax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Authorization.Fleet.ReportedBreakdown.Tax{
  local_amount_decimal: String.t() | nil,
  national_amount_decimal: String.t() | nil
}
  • local_amount_decimal - Amount of state or provincial Sales Tax included in the transaction amount. null if not reported by merchant or not subject to tax. Format: decimal string. Nullable.
  • national_amount_decimal - Amount of national Sales Tax or VAT included in the transaction amount. null if not reported by merchant or not subject to tax. Format: decimal string. Nullable.