Stripe.Resources.Issuing.Authorization.FraudChallenges (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Authorization.FraudChallenges{
  channel: String.t() | nil,
  status: String.t() | nil,
  undeliverable_reason: String.t() | nil
}
  • channel - The method by which the fraud challenge was delivered to the cardholder. Possible values: sms.
  • status - The status of the fraud challenge. Possible values: expired, pending, rejected, undeliverable, verified.
  • undeliverable_reason - If the challenge is not deliverable, the reason why. Possible values: no_phone_number, unsupported_phone_number. Nullable.