Stripe.Resources.Issuing.Authorization.Fuel (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Authorization.Fuel{
  industry_product_code: String.t() | nil,
  quantity_decimal: String.t() | nil,
  type: String.t() | nil,
  unit: String.t() | nil,
  unit_cost_decimal: String.t() | nil
}
  • industry_product_code - Conexxus Payment System Product Code identifying the primary fuel product purchased. Max length: 5000. Nullable.
  • quantity_decimal - The quantity of units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places. Format: decimal string. Nullable.
  • type - The type of fuel that was purchased. Possible values: diesel, other, unleaded_plus, unleaded_regular, unleaded_super. Nullable.
  • unit - The units for quantity_decimal. Possible values: charging_minute, imperial_gallon, kilogram, kilowatt_hour, liter, other, pound, us_gallon. Nullable.
  • unit_cost_decimal - The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places. Format: decimal string. Nullable.