Stripe.Resources.Issuing.Authorization.VerificationData (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Authorization.VerificationData{
  address_line1_check: String.t() | nil,
  address_postal_code_check: String.t() | nil,
  authentication_exemption:
    Stripe.Resources.Issuing.Authorization.VerificationData.AuthenticationExemption.t()
    | nil,
  cvc_check: String.t() | nil,
  expiry_check: String.t() | nil,
  postal_code: String.t() | nil,
  three_d_secure:
    Stripe.Resources.Issuing.Authorization.VerificationData.ThreeDSecure.t()
    | nil
}
  • address_line1_check - Whether the cardholder provided an address first line and if it matched the cardholder’s billing.address.line1. Possible values: match, mismatch, not_provided.
  • address_postal_code_check - Whether the cardholder provided a postal code and if it matched the cardholder’s billing.address.postal_code. Possible values: match, mismatch, not_provided.
  • authentication_exemption - The exemption applied to this authorization. Nullable.
  • cvc_check - Whether the cardholder provided a CVC and if it matched Stripe’s record. Possible values: match, mismatch, not_provided.
  • expiry_check - Whether the cardholder provided an expiry date and if it matched Stripe’s record. Possible values: match, mismatch, not_provided.
  • postal_code - The postal code submitted as part of the authorization used for postal code verification. Max length: 5000. Nullable.
  • three_d_secure - 3D Secure details. Nullable.