Stripe.Resources.Issuing.Card.LatestFraudWarning (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Card.LatestFraudWarning{
  started_at: integer() | nil,
  type: String.t() | nil
}
  • started_at - Timestamp of the most recent fraud warning. Format: Unix timestamp. Nullable.
  • type - The type of fraud warning that most recently took place on this card. This field updates with every new fraud warning, so the value changes over time. If populated, cancel and reissue the card. Possible values: card_testing_exposure, fraud_dispute_filed, third_party_reported, user_indicated_fraud. Nullable.