Stripe.Resources.Issuing.Card.SpendingControls (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Card.SpendingControls{
  allowed_categories: [String.t()] | nil,
  allowed_merchant_countries: [String.t()] | nil,
  blocked_categories: [String.t()] | nil,
  blocked_merchant_countries: [String.t()] | nil,
  spending_limits:
    [Stripe.Resources.Issuing.Card.SpendingControls.SpendingLimits.t()] | nil,
  spending_limits_currency: String.t() | nil
}
  • allowed_categories - Array of strings containing categories of authorizations to allow. All other categories will be blocked. Cannot be set with blocked_categories. Nullable.
  • allowed_merchant_countries - Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. US). Cannot be set with blocked_merchant_countries. Provide an empty value to unset this control. Nullable.
  • blocked_categories - Array of strings containing categories of authorizations to decline. All other categories will be allowed. Cannot be set with allowed_categories. Nullable.
  • blocked_merchant_countries - Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. US). Cannot be set with allowed_merchant_countries. Provide an empty value to unset this control. Nullable.
  • spending_limits - Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its replacement_for card and that card's replacement_for card, up the chain). Nullable.
  • spending_limits_currency - Currency of the amounts within spending_limits. Always the same as the currency of the card. Format: ISO 4217 currency code. Nullable.