Stripe.Resources.Issuing.Cardholder (tiger_stripe v0.1.10)

Copy Markdown View Source

IssuingCardholder

An Issuing Cardholder object represents an individual or business entity who is issued cards.

Related guide: How to create a cardholder

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Cardholder{
  billing: Stripe.Resources.Issuing.Cardholder.Billing.t(),
  company: Stripe.Resources.Issuing.Cardholder.Company.t(),
  created: integer(),
  email: String.t(),
  id: String.t(),
  individual: Stripe.Resources.Issuing.Cardholder.Individual.t(),
  livemode: boolean(),
  metadata: %{required(String.t()) => String.t()},
  name: String.t(),
  object: String.t(),
  phone_number: String.t(),
  preferred_locales: [String.t()],
  requirements: Stripe.Resources.Issuing.Cardholder.Requirements.t(),
  spending_controls: Stripe.Resources.Issuing.Cardholder.SpendingControls.t(),
  status: String.t(),
  type: String.t()
}
  • billing - Expandable.
  • company - Additional information about a company cardholder. Nullable. Expandable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • email - The cardholder's email address. Max length: 5000. Nullable.
  • id - Unique identifier for the object. Max length: 5000.
  • individual - Additional information about an individual cardholder. Nullable. Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • name - The cardholder's name. This will be printed on cards issued to them. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: issuing.cardholder.
  • phone_number - The cardholder's phone number. This is required for all cardholders who will be creating EU cards. See the 3D Secure documentation for more details. Max length: 5000. Nullable.
  • preferred_locales - The cardholder’s preferred locales (languages), ordered by preference. Locales can be de, en, es, fr, or it. This changes the language of the 3D Secure flow and one-time password messages sent to the cardholder. Nullable.
  • requirements - Expandable.
  • spending_controls - Rules that control spending across this cardholder's cards. Refer to our documentation for more details. Nullable. Expandable.
  • status - Specifies whether to permit authorizations on this cardholder's cards. Possible values: active, blocked, inactive.
  • type - One of individual or company. See Choose a cardholder type for more details. Possible values: company, individual.

Functions

expandable_fields()

object_name()