Stripe.Resources.Issuing.Cardholder.Individual (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Cardholder.Individual{
  card_issuing:
    Stripe.Resources.Issuing.Cardholder.Individual.CardIssuing.t() | nil,
  dob: Stripe.Resources.Issuing.Cardholder.Individual.Dob.t() | nil,
  first_name: String.t() | nil,
  last_name: String.t() | nil,
  verification:
    Stripe.Resources.Issuing.Cardholder.Individual.Verification.t() | nil
}
  • card_issuing - Information related to the card_issuing program for this cardholder. Nullable.
  • dob - The date of birth of this cardholder. Nullable.
  • first_name - The first name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters. Max length: 5000. Nullable.
  • last_name - The last name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters. Max length: 5000. Nullable.
  • verification - Government-issued ID document for this cardholder. Nullable.