Stripe.Resources.Issuing.Cardholder.Individual.CardIssuing.UserTermsAcceptance (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.Issuing.Cardholder.Individual.CardIssuing.UserTermsAcceptance{
    date: integer() | nil,
    ip: String.t() | nil,
    user_agent: String.t() | nil
  }
  • date - The Unix timestamp marking when the cardholder accepted the Authorized User Terms. Format: Unix timestamp. Nullable.
  • ip - The IP address from which the cardholder accepted the Authorized User Terms. Max length: 5000. Nullable.
  • user_agent - The user agent of the browser from which the cardholder accepted the Authorized User Terms. Max length: 5000. Nullable.