Stripe.Resources.Issuing.Cardholder.Individual.Verification.Document (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Cardholder.Individual.Verification.Document{
  back: String.t() | Stripe.Resources.File.t() | nil,
  front: String.t() | Stripe.Resources.File.t() | nil
}
  • back - The back of a document returned by a file upload with a purpose value of identity_document. Nullable.
  • front - The front of a document returned by a file upload with a purpose value of identity_document. Nullable.