Stripe.Resources.Issuing.Cardholder.SpendingControls
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Cardholder.SpendingControls{ allowed_categories: [String.t()] | nil, allowed_merchant_countries: [String.t()] | nil, blocked_categories: [String.t()] | nil, blocked_merchant_countries: [String.t()] | nil, spending_limits: [Stripe.Resources.Issuing.Cardholder.SpendingControls.SpendingLimits.t()] | nil, spending_limits_currency: String.t() | nil }
allowed_categories- Array of strings containing categories of authorizations to allow. All other categories will be blocked. Cannot be set withblocked_categories. Nullable.allowed_merchant_countries- Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g.US). Cannot be set withblocked_merchant_countries. Provide an empty value to unset this control. Nullable.blocked_categories- Array of strings containing categories of authorizations to decline. All other categories will be allowed. Cannot be set withallowed_categories. Nullable.blocked_merchant_countries- Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g.US). Cannot be set withallowed_merchant_countries. Provide an empty value to unset this control. Nullable.spending_limits- Limit spending with amount-based rules that apply across this cardholder's cards. Nullable.spending_limits_currency- Currency of the amounts withinspending_limits. Format: ISO 4217 currency code. Nullable.