Stripe.Resources.Issuing.Dispute.Evidence.Canceled (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Dispute.Evidence.Canceled{
  additional_documentation: String.t() | Stripe.Resources.File.t() | nil,
  canceled_at: integer() | nil,
  cancellation_policy_provided: boolean() | nil,
  cancellation_reason: String.t() | nil,
  expected_at: integer() | nil,
  explanation: String.t() | nil,
  product_description: String.t() | nil,
  product_type: String.t() | nil,
  return_status: String.t() | nil,
  returned_at: integer() | nil
}
  • additional_documentation - (ID of a file upload) Additional documentation supporting the dispute. Nullable.
  • canceled_at - Date when order was canceled. Format: Unix timestamp. Nullable.
  • cancellation_policy_provided - Whether the cardholder was provided with a cancellation policy. Nullable.
  • cancellation_reason - Reason for canceling the order. Max length: 5000. Nullable.
  • expected_at - Date when the cardholder expected to receive the product. Format: Unix timestamp. Nullable.
  • explanation - Explanation of why the cardholder is disputing this transaction. Max length: 5000. Nullable.
  • product_description - Description of the merchandise or service that was purchased. Max length: 5000. Nullable.
  • product_type - Whether the product was a merchandise or service. Possible values: merchandise, service. Nullable.
  • return_status - Result of cardholder's attempt to return the product. Possible values: merchant_rejected, successful. Nullable.
  • returned_at - Date when the product was returned or attempted to be returned. Format: Unix timestamp. Nullable.