Stripe.Resources.Issuing.Dispute.Evidence.Duplicate (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Dispute.Evidence.Duplicate{
  additional_documentation: String.t() | Stripe.Resources.File.t() | nil,
  card_statement: String.t() | Stripe.Resources.File.t() | nil,
  cash_receipt: String.t() | Stripe.Resources.File.t() | nil,
  check_image: String.t() | Stripe.Resources.File.t() | nil,
  explanation: String.t() | nil,
  original_transaction: String.t() | nil
}
  • additional_documentation - (ID of a file upload) Additional documentation supporting the dispute. Nullable.
  • card_statement - (ID of a file upload) Copy of the card statement showing that the product had already been paid for. Nullable.
  • cash_receipt - (ID of a file upload) Copy of the receipt showing that the product had been paid for in cash. Nullable.
  • check_image - (ID of a file upload) Image of the front and back of the check that was used to pay for the product. Nullable.
  • explanation - Explanation of why the cardholder is disputing this transaction. Max length: 5000. Nullable.
  • original_transaction - Transaction (e.g., ipi_...) that the disputed transaction is a duplicate of. Of the two or more transactions that are copies of each other, this is original undisputed one. Max length: 5000. Nullable.