Stripe.Resources.Issuing.Dispute.Evidence.MerchandiseNotAsDescribed (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Dispute.Evidence.MerchandiseNotAsDescribed{
  additional_documentation: String.t() | Stripe.Resources.File.t() | nil,
  explanation: String.t() | nil,
  received_at: integer() | nil,
  return_description: String.t() | nil,
  return_status: String.t() | nil,
  returned_at: integer() | nil
}
  • additional_documentation - (ID of a file upload) Additional documentation supporting the dispute. Nullable.
  • explanation - Explanation of why the cardholder is disputing this transaction. Max length: 5000. Nullable.
  • received_at - Date when the product was received. Format: Unix timestamp. Nullable.
  • return_description - Description of the cardholder's attempt to return the product. Max length: 5000. Nullable.
  • return_status - Result of cardholder's attempt to return the product. Possible values: merchant_rejected, successful. Nullable.
  • returned_at - Date when the product was returned or attempted to be returned. Format: Unix timestamp. Nullable.