Stripe.Resources.Issuing.Dispute.Evidence.Other (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Dispute.Evidence.Other{
  additional_documentation: String.t() | Stripe.Resources.File.t() | nil,
  explanation: String.t() | nil,
  product_description: String.t() | nil,
  product_type: String.t() | nil
}
  • additional_documentation - (ID of a file upload) Additional documentation supporting the dispute. Nullable.
  • explanation - Explanation of why the cardholder is disputing this transaction. Max length: 5000. Nullable.
  • product_description - Description of the merchandise or service that was purchased. Max length: 5000. Nullable.
  • product_type - Whether the product was a merchandise or service. Possible values: merchandise, service. Nullable.