IssuingPersonalizationDesign
A Personalization Design is a logical grouping of a Physical Bundle, card logo, and carrier text that represents a product line.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.PersonalizationDesign{ card_logo: String.t() | Stripe.Resources.File.t(), carrier_text: Stripe.Resources.Issuing.PersonalizationDesign.CarrierText.t(), created: integer(), id: String.t(), livemode: boolean(), lookup_key: String.t(), metadata: %{required(String.t()) => String.t()}, name: String.t(), object: String.t(), physical_bundle: String.t() | Stripe.Resources.Issuing.PhysicalBundle.t(), preferences: Stripe.Resources.Issuing.PersonalizationDesign.Preferences.t(), rejection_reasons: Stripe.Resources.Issuing.PersonalizationDesign.RejectionReasons.t(), status: String.t() }
card_logo- The file for the card logo to use with physical bundles that support card logos. Must have apurposevalue ofissuing_logo. Nullable. Expandable.carrier_text- Hash containing carrier text, for use with physical bundles that support carrier text. Nullable. Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.lookup_key- A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters. Max length: 5000. Nullable.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.name- Friendly display name. Max length: 5000. Nullable.object- String representing the object's type. Objects of the same type share the same value. Possible values:issuing.personalization_design.physical_bundle- The physical bundle object belonging to this personalization design. Expandable.preferences- Expandable.rejection_reasons- Expandable.status- Whether this personalization design can be used to create cards. Possible values:active,inactive,rejected,review.