Stripe.Resources.Issuing.PhysicalBundle (tiger_stripe v0.1.10)

Copy Markdown View Source

IssuingPhysicalBundle

A Physical Bundle represents the bundle of physical items - card stock, carrier letter, and envelope - that is shipped to a cardholder when you create a physical card.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.PhysicalBundle{
  features: Stripe.Resources.Issuing.PhysicalBundle.Features.t(),
  id: String.t(),
  livemode: boolean(),
  name: String.t(),
  object: String.t(),
  status: String.t(),
  type: String.t()
}
  • features - Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • name - Friendly display name. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: issuing.physical_bundle.
  • status - Whether this physical bundle can be used to create cards. Possible values: active, inactive, review.
  • type - Whether this physical bundle is a standard Stripe offering or custom-made for you. Possible values: custom, standard.

Functions

expandable_fields()

object_name()