Stripe.Resources.Issuing.PhysicalBundle.Features (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.PhysicalBundle.Features{
  card_logo: String.t() | nil,
  carrier_text: String.t() | nil,
  second_line: String.t() | nil
}
  • card_logo - The policy for how to use card logo images in a card design with this physical bundle. Possible values: optional, required, unsupported.
  • carrier_text - The policy for how to use carrier letter text in a card design with this physical bundle. Possible values: optional, required, unsupported.
  • second_line - The policy for how to use a second line on a card with this physical bundle. Possible values: optional, required, unsupported.