Stripe.Resources.Issuing.Token.NetworkData.WalletProvider (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Token.NetworkData.WalletProvider{
  account_id: String.t() | nil,
  account_trust_score: integer() | nil,
  card_number_source: String.t() | nil,
  cardholder_address:
    Stripe.Resources.Issuing.Token.NetworkData.WalletProvider.CardholderAddress.t()
    | nil,
  cardholder_name: String.t() | nil,
  device_trust_score: integer() | nil,
  hashed_account_email_address: String.t() | nil,
  reason_codes: [String.t()] | nil,
  suggested_decision: String.t() | nil,
  suggested_decision_version: String.t() | nil
}
  • account_id - The wallet provider-given account ID of the digital wallet the token belongs to. Max length: 5000.
  • account_trust_score - An evaluation on the trustworthiness of the wallet account between 1 and 5. A higher score indicates more trustworthy.
  • card_number_source - The method used for tokenizing a card. Possible values: app, manual, on_file, other.
  • cardholder_address
  • cardholder_name - The name of the cardholder tokenizing the card. Max length: 5000.
  • device_trust_score - An evaluation on the trustworthiness of the device. A higher score indicates more trustworthy.
  • hashed_account_email_address - The hashed email address of the cardholder's account with the wallet provider. Max length: 5000.
  • reason_codes - The reasons for suggested tokenization given by the card network.
  • suggested_decision - The recommendation on responding to the tokenization request. Possible values: approve, decline, require_auth.
  • suggested_decision_version - The version of the standard for mapping reason codes followed by the wallet provider. Max length: 5000.