Stripe.Resources.Issuing.Transaction.PurchaseDetails.Fleet (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Issuing.Transaction.PurchaseDetails.Fleet{
  cardholder_prompt_data:
    Stripe.Resources.Issuing.Transaction.PurchaseDetails.Fleet.CardholderPromptData.t()
    | nil,
  purchase_type: String.t() | nil,
  reported_breakdown:
    Stripe.Resources.Issuing.Transaction.PurchaseDetails.Fleet.ReportedBreakdown.t()
    | nil,
  service_type: String.t() | nil
}
  • cardholder_prompt_data - Answers to prompts presented to cardholder at point of sale. Nullable.
  • purchase_type - The type of purchase. One of fuel_purchase, non_fuel_purchase, or fuel_and_non_fuel_purchase. Max length: 5000. Nullable.
  • reported_breakdown - More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data. Nullable.
  • service_type - The type of fuel service. One of non_fuel_transaction, full_service, or self_service. Max length: 5000. Nullable.