Stripe.Resources.IssuingCardsListFeatures (tiger_stripe v0.1.10)

Copy Markdown View Source

ConnectEmbeddedIssuingCardsListFeatures

Summary

Types

t()

@type t() :: %Stripe.Resources.IssuingCardsListFeatures{
  card_management: boolean(),
  card_spend_dispute_management: boolean(),
  cardholder_management: boolean(),
  disable_stripe_user_authentication: boolean(),
  spend_control_management: boolean()
}
  • card_management - Whether to allow card management features.
  • card_spend_dispute_management - Whether to allow card spend dispute management features.
  • cardholder_management - Whether to allow cardholder management features.
  • disable_stripe_user_authentication - Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
  • spend_control_management - Whether to allow spend control management features.

Functions

object_name()