Stripe.Resources.Mandate.PaymentMethodDetails.BacsDebit (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Mandate.PaymentMethodDetails.BacsDebit{
  network_status: String.t() | nil,
  reference: String.t() | nil,
  revocation_reason: String.t() | nil,
  url: String.t() | nil
}
  • network_status - The status of the mandate on the Bacs network. Can be one of pending, revoked, refused, or accepted. Possible values: accepted, pending, refused, revoked.
  • reference - The unique reference identifying the mandate on the Bacs network. Max length: 5000.
  • revocation_reason - When the mandate is revoked on the Bacs network this field displays the reason for the revocation. Possible values: account_closed, bank_account_restricted, bank_ownership_changed, could_not_process, debit_not_authorized. Nullable.
  • url - The URL that will contain the mandate that the customer has signed. Max length: 5000.