Stripe.Resources.Mandate.SingleUse (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Mandate.SingleUse{
  amount: integer() | nil,
  currency: String.t() | nil
}
  • amount - The amount of the payment on a single use mandate.
  • currency - The currency of the payment on a single use mandate. Format: ISO 4217 currency code.