Stripe.Resources.NextActionCardAwaitNotification (tiger_stripe v0.1.10)

Copy Markdown View Source

PaymentIntentNextActionCardAwaitNotification

Summary

Types

t()

@type t() :: %Stripe.Resources.NextActionCardAwaitNotification{
  charge_attempt_at: integer(),
  customer_approval_required: boolean()
}
  • charge_attempt_at - The time that payment will be attempted. If customer approval is required, they need to provide approval before this time. Format: Unix timestamp. Nullable.
  • customer_approval_required - For payments greater than INR 15000, the customer must provide explicit approval of the payment with their bank. For payments of lower amount, no customer action is required. Nullable.

Functions

object_name()