Stripe.Resources.NextActionKonbiniDisplayDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

payment_intent_next_action_konbini

Summary

Types

t()

@type t() :: %Stripe.Resources.NextActionKonbiniDisplayDetails{
  expires_at: integer(),
  hosted_voucher_url: String.t(),
  stores: Stripe.Resources.Stores.t()
}
  • expires_at - The timestamp at which the pending Konbini payment expires. Format: Unix timestamp.
  • hosted_voucher_url - The URL for the Konbini payment instructions page, which allows customers to view and print a Konbini voucher. Max length: 5000. Nullable.
  • stores - Expandable.

Functions

expandable_fields()

object_name()