Stripe.Resources.Offline (tiger_stripe v0.1.10)

Copy Markdown View Source

payment_method_details_card_present_offline

Summary

Types

t()

@type t() :: %Stripe.Resources.Offline{stored_at: integer(), type: String.t()}
  • stored_at - Time at which the payment was collected while offline Format: Unix timestamp. Nullable.
  • type - The method used to process this payment method offline. Only deferred is allowed. Possible values: deferred. Nullable.

Functions

object_name()