Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Card.Wallet (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Card.Wallet{
  apple_pay:
    Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Card.Wallet.ApplePay.t()
    | nil,
  dynamic_last4: String.t() | nil,
  google_pay: map() | nil,
  type: String.t() | nil
}
  • apple_pay
  • dynamic_last4 - (For tokenized numbers only.) The last four digits of the device account number. Max length: 5000.
  • google_pay
  • type - The type of the card wallet, one of apple_pay or google_pay. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type. Max length: 5000.