Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Mobilepay.Card (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Mobilepay.Card{
    brand: String.t() | nil,
    country: String.t() | nil,
    exp_month: integer() | nil,
    exp_year: integer() | nil,
    last4: String.t() | nil
  }
  • brand - Brand of the card used in the transaction Max length: 5000. Nullable.
  • country - Two-letter ISO code representing the country of the card Max length: 5000. Nullable.
  • exp_month - Two digit number representing the card's expiration month Nullable.
  • exp_year - Two digit number representing the card's expiration year Nullable.
  • last4 - The last 4 digits of the card Max length: 5000. Nullable.