Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.NzBankAccount (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.NzBankAccount{
    account_holder_name: String.t() | nil,
    bank_code: String.t() | nil,
    bank_name: String.t() | nil,
    branch_code: String.t() | nil,
    expected_debit_date: String.t() | nil,
    last4: String.t() | nil,
    suffix: String.t() | nil
  }
  • account_holder_name - The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details. Max length: 5000. Nullable.
  • bank_code - The numeric code for the bank account's bank. Max length: 5000.
  • bank_name - The name of the bank. Max length: 5000.
  • branch_code - The numeric code for the bank account's bank branch. Max length: 5000.
  • expected_debit_date - Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format. Max length: 5000.
  • last4 - Last four digits of the bank account number. Max length: 5000.
  • suffix - The suffix of the bank account number. Max length: 5000. Nullable.