Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.SepaCreditTransfer (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.SepaCreditTransfer{
    bank_name: String.t() | nil,
    bic: String.t() | nil,
    iban: String.t() | nil
  }
  • bank_name - Name of the bank associated with the bank account. Max length: 5000. Nullable.
  • bic - Bank Identifier Code of the bank associated with the bank account. Max length: 5000. Nullable.
  • iban - IBAN of the bank account to transfer funds to. Max length: 5000. Nullable.