Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.UsBankAccount (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.UsBankAccount{
    account_holder_type: String.t() | nil,
    account_type: String.t() | nil,
    bank_name: String.t() | nil,
    expected_debit_date: String.t() | nil,
    fingerprint: String.t() | nil,
    last4: String.t() | nil,
    mandate: String.t() | Stripe.Resources.Mandate.t() | nil,
    payment_reference: String.t() | nil,
    routing_number: String.t() | nil
  }
  • account_holder_type - The type of entity that holds the account. This can be either 'individual' or 'company'. Possible values: company, individual. Nullable.
  • account_type - The type of the bank account. This can be either 'checking' or 'savings'. Possible values: checking, savings. Nullable.
  • bank_name - Name of the bank associated with the bank account. Max length: 5000. Nullable.
  • expected_debit_date - Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format. Max length: 5000. Nullable.
  • fingerprint - Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.
  • last4 - Last four digits of the bank account number. Max length: 5000. Nullable.
  • mandate - ID of the mandate used to make this payment.
  • payment_reference - The ACH payment reference for this transaction. Max length: 5000. Nullable.
  • routing_number - The routing number for the bank account. Max length: 5000. Nullable.