Stripe.Resources.PaymentAttemptRecord.ProcessorDetails.Custom (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentAttemptRecord.ProcessorDetails.Custom{
  payment_reference: String.t() | nil
}
  • payment_reference - An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID. Max length: 5000. Nullable.