Stripe.Resources.PaymentIntent.AmountDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

  • discount_amount - The total discount applied on the transaction represented in the smallest currency unit. An integer greater than 0.

This field is mutually exclusive with the amount_details[line_items][#][discount_amount] field.

  • error
  • line_items - A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 200 line items.
  • shipping
  • tax
  • tip