Stripe.Resources.PaymentIntent.AmountDetails.LineItems
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentIntent.AmountDetails.LineItems{ data: [Stripe.Resources.PaymentIntentAmountDetailsLineItem.t()] | nil, has_more: boolean() | nil, object: String.t() | nil, url: String.t() | nil }
data- Details about each object.has_more- True if this list has another page of items after this one that can be fetched.object- String representing the object's type. Objects of the same type share the same value. Always has the valuelist. Possible values:list.url- The URL where this list can be accessed. Max length: 5000.