Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentIntent.AmountDetails.Tip{ amount: integer() | nil }
amount- Portion of the amount that corresponds to a tip.
Nested struct within the parent resource.
@type t() :: %Stripe.Resources.PaymentIntent.AmountDetails.Tip{ amount: integer() | nil }
amount - Portion of the amount that corresponds to a tip.