Stripe.Resources.PaymentIntent.PaymentMethodOptions.Card.Installments.Plan (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.PaymentIntent.PaymentMethodOptions.Card.Installments.Plan{
    count: integer() | nil,
    interval: String.t() | nil,
    type: String.t() | nil
  }
  • count - For fixed_count installment plans, this is the number of installment payments your customer will make to their credit card. Nullable.
  • interval - For fixed_count installment plans, this is the interval between installment payments your customer will make to their credit card. One of month. Possible values: month. Nullable.
  • type - Type of installment plan, one of fixed_count, bonus, or revolving. Possible values: bonus, fixed_count, revolving.