Stripe.Resources.PaymentIntent.PaymentMethodOptions.CustomerBalance.BankTransfer
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentIntent.PaymentMethodOptions.CustomerBalance.BankTransfer{ eu_bank_transfer: Stripe.Resources.PaymentIntent.PaymentMethodOptions.CustomerBalance.BankTransfer.EuBankTransfer.t() | nil, requested_address_types: [String.t()] | nil, type: String.t() | nil }
eu_bank_transferrequested_address_types- List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: sort_code, zengin, iban, or spei.
type- The bank transfer type that this PaymentIntent is allowed to use for funding Permitted values include:eu_bank_transfer,gb_bank_transfer,jp_bank_transfer,mx_bank_transfer, orus_bank_transfer. Possible values:eu_bank_transfer,gb_bank_transfer,jp_bank_transfer,mx_bank_transfer,us_bank_transfer. Nullable.