Stripe.Resources.PaymentIntent.PaymentMethodOptions.UsBankAccount.FinancialConnections (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.PaymentIntent.PaymentMethodOptions.UsBankAccount.FinancialConnections{
    filters:
      Stripe.Resources.PaymentIntent.PaymentMethodOptions.UsBankAccount.FinancialConnections.Filters.t()
      | nil,
    permissions: [String.t()] | nil,
    prefetch: [String.t()] | nil,
    return_url: String.t() | nil
  }
  • filters
  • permissions - The list of permissions to request. The payment_method permission must be included.
  • prefetch - Data features requested to be retrieved upon account creation. Nullable.
  • return_url - For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app. Max length: 5000.