Stripe.Resources.PaymentIntentAmountDetailsLineItem.PaymentMethodOptions.Paypal (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.PaymentIntentAmountDetailsLineItem.PaymentMethodOptions.Paypal{
    category: String.t() | nil,
    description: String.t() | nil,
    sold_by: String.t() | nil
  }
  • category - Type of the line item. Possible values: digital_goods, donation, physical_goods.
  • description - Description of the line item. Max length: 5000.
  • sold_by - The Stripe account ID of the connected account that sells the item. This is only needed when using Separate Charges and Transfers. Max length: 5000.