Stripe.Resources.PaymentLink.ConsentCollection (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentLink.ConsentCollection{
  payment_method_reuse_agreement:
    Stripe.Resources.PaymentLink.ConsentCollection.PaymentMethodReuseAgreement.t()
    | nil,
  promotions: String.t() | nil,
  terms_of_service: String.t() | nil
}
  • payment_method_reuse_agreement - Settings related to the payment method reuse text shown in the Checkout UI. Nullable.
  • promotions - If set to auto, enables the collection of customer consent for promotional communications. Possible values: auto, none. Nullable.
  • terms_of_service - If set to required, it requires cutomers to accept the terms of service before being able to pay. If set to none, customers won't be shown a checkbox to accept the terms of service. Possible values: none, required. Nullable.