Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentLink.CustomFields{ dropdown: Stripe.Resources.PaymentLink.CustomFields.Dropdown.t() | nil, key: String.t() | nil, label: Stripe.Resources.PaymentLink.CustomFields.Label.t() | nil, numeric: Stripe.Resources.PaymentLink.CustomFields.Numeric.t() | nil, optional: boolean() | nil, text: Stripe.Resources.PaymentLink.CustomFields.Text.t() | nil, type: String.t() | nil }
dropdownkey- String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters. Max length: 5000.labelnumericoptional- Whether the customer is required to complete the field before completing the Checkout Session. Defaults tofalse.texttype- The type of the field. Possible values:dropdown,numeric,text.