Stripe.Resources.PaymentLink.PaymentIntentData (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentLink.PaymentIntentData{
  capture_method: String.t() | nil,
  description: String.t() | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  setup_future_usage: String.t() | nil,
  statement_descriptor: String.t() | nil,
  statement_descriptor_suffix: String.t() | nil,
  transfer_group: String.t() | nil
}
  • capture_method - Indicates when the funds will be captured from the customer's account. Possible values: automatic, automatic_async, manual. Nullable.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000. Nullable.
  • metadata - Set of key-value pairs that will set metadata on Payment Intents generated from this payment link.
  • setup_future_usage - Indicates that you intend to make future payments with the payment method collected during checkout. Possible values: off_session, on_session. Nullable.
  • statement_descriptor - For a non-card payment, information about the charge that appears on the customer's statement when this payment succeeds in creating a charge. Max length: 5000. Nullable.
  • statement_descriptor_suffix - For a card payment, information about the charge that appears on the customer's statement when this payment succeeds in creating a charge. Concatenated with the account's statement descriptor prefix to form the complete statement descriptor. Max length: 5000. Nullable.
  • transfer_group - A string that identifies the resulting payment as part of a group. See the PaymentIntents use case for connected accounts for details. Max length: 5000. Nullable.