Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentLink.PhoneNumberCollection{ enabled: boolean() | nil }
enabled- Iftrue, a phone number will be collected during checkout.
Nested struct within the parent resource.
@type t() :: %Stripe.Resources.PaymentLink.PhoneNumberCollection{ enabled: boolean() | nil }
enabled - If true, a phone number will be collected during checkout.