Stripe.Resources.PaymentLink.Restrictions.CompletedSessions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentLink.Restrictions.CompletedSessions{
  count: integer() | nil,
  limit: integer() | nil
}
  • count - The current number of checkout sessions that have been completed on the payment link which count towards the completed_sessions restriction to be met.
  • limit - The maximum number of checkout sessions that can be completed for the completed_sessions restriction to be met.