Stripe.Resources.PaymentLink.ShippingOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentLink.ShippingOptions{
  shipping_amount: integer() | nil,
  shipping_rate: String.t() | Stripe.Resources.ShippingRate.t() | nil
}
  • shipping_amount - A non-negative integer in cents representing how much to charge.
  • shipping_rate - The ID of the Shipping Rate to use for this shipping option.