Stripe.Resources.PaymentMethod.AcssDebit (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentMethod.AcssDebit{
  bank_name: String.t() | nil,
  fingerprint: String.t() | nil,
  institution_number: String.t() | nil,
  last4: String.t() | nil,
  transit_number: String.t() | nil
}
  • bank_name - Name of the bank associated with the bank account. Max length: 5000. Nullable.
  • fingerprint - Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.
  • institution_number - Institution number of the bank account. Max length: 5000. Nullable.
  • last4 - Last four digits of the bank account number. Max length: 5000. Nullable.
  • transit_number - Transit number of the bank account. Max length: 5000. Nullable.