Stripe.Resources.PaymentMethod.AuBecsDebit (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentMethod.AuBecsDebit{
  bsb_number: String.t() | nil,
  fingerprint: String.t() | nil,
  last4: String.t() | nil
}
  • bsb_number - Six-digit number identifying bank and branch associated with this bank account. Max length: 5000. Nullable.
  • fingerprint - Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.
  • last4 - Last four digits of the bank account number. Max length: 5000. Nullable.