Stripe.Resources.PaymentMethod.Card (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentMethod.Card{
  brand: String.t() | nil,
  checks: Stripe.Resources.PaymentMethod.Card.Checks.t() | nil,
  country: String.t() | nil,
  description: String.t() | nil,
  display_brand: String.t() | nil,
  exp_month: integer() | nil,
  exp_year: integer() | nil,
  fingerprint: String.t() | nil,
  funding: String.t() | nil,
  generated_from: Stripe.Resources.PaymentMethod.Card.GeneratedFrom.t() | nil,
  iin: String.t() | nil,
  issuer: String.t() | nil,
  last4: String.t() | nil,
  networks: Stripe.Resources.PaymentMethod.Card.Networks.t() | nil,
  regulated_status: String.t() | nil,
  three_d_secure_usage:
    Stripe.Resources.PaymentMethod.Card.ThreeDSecureUsage.t() | nil,
  wallet: Stripe.Resources.PaymentMethod.Card.Wallet.t() | nil
}
  • brand - Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown. Max length: 5000.
  • checks - Checks on Card address and CVC if provided. Nullable.
  • country - Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected. Max length: 5000. Nullable.
  • description - A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.) Max length: 5000. Nullable.
  • display_brand - The brand to use when displaying the card, this accounts for customer's brand choice on dual-branded cards. Can be american_express, cartes_bancaires, diners_club, discover, eftpos_australia, interac, jcb, mastercard, union_pay, visa, or other and may contain more values in the future. Max length: 5000. Nullable.
  • exp_month - Two-digit number representing the card's expiration month.
  • exp_year - Four-digit number representing the card's expiration year.
  • fingerprint - Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world. Max length: 5000. Nullable.

  • funding - Card funding type. Can be credit, debit, prepaid, or unknown. Max length: 5000.
  • generated_from - Details of the original PaymentMethod that created this object. Nullable.
  • iin - Issuer identification number of the card. (For internal use only and not typically available in standard API requests.) Max length: 5000. Nullable.
  • issuer - The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.) Max length: 5000. Nullable.
  • last4 - The last four digits of the card. Max length: 5000.
  • networks - Contains information about card networks that can be used to process the payment. Nullable.
  • regulated_status - Status of a card based on the card issuer. Possible values: regulated, unregulated. Nullable.
  • three_d_secure_usage - Contains details on how this Card may be used for 3D Secure authentication. Nullable.
  • wallet - If this Card is part of a card wallet, this contains the details of the card wallet. Nullable.