Stripe.Resources.PaymentMethod.SepaDebit (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentMethod.SepaDebit{
  bank_code: String.t() | nil,
  branch_code: String.t() | nil,
  country: String.t() | nil,
  fingerprint: String.t() | nil,
  generated_from:
    Stripe.Resources.PaymentMethod.SepaDebit.GeneratedFrom.t() | nil,
  last4: String.t() | nil
}
  • bank_code - Bank code of bank associated with the bank account. Max length: 5000. Nullable.
  • branch_code - Branch code of bank associated with the bank account. Max length: 5000. Nullable.
  • country - Two-letter ISO code representing the country the bank account is located in. Max length: 5000. Nullable.
  • fingerprint - Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.
  • generated_from - Information about the object that generated this PaymentMethod. Nullable.
  • last4 - Last four characters of the IBAN. Max length: 5000. Nullable.