Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentMethod.Sofort{country: String.t() | nil}
country- Two-letter ISO code representing the country the bank account is located in. Max length: 5000. Nullable.
Nested struct within the parent resource.
@type t() :: %Stripe.Resources.PaymentMethod.Sofort{country: String.t() | nil}
country - Two-letter ISO code representing the country the bank account is located in. Max length: 5000. Nullable.