Stripe.Resources.PaymentRecord.PaymentMethodDetails.Affirm
(tiger_stripe v0.1.11)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentRecord.PaymentMethodDetails.Affirm{ location: String.t() | nil, reader: String.t() | nil, transaction_id: String.t() | nil }
location- ID of the location that this reader is assigned to. Max length: 5000.reader- ID of the reader this transaction was made on. Max length: 5000.transaction_id- The Affirm transaction ID associated with this payment. Max length: 5000. Nullable.