Stripe.Resources.PaymentRecord.PaymentMethodDetails.BillingDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PaymentRecord.PaymentMethodDetails.BillingDetails{
  address:
    Stripe.Resources.PaymentRecord.PaymentMethodDetails.BillingDetails.Address.t()
    | nil,
  email: String.t() | nil,
  name: String.t() | nil,
  phone: String.t() | nil
}
  • address
  • email - The billing email associated with the method of payment. Max length: 5000. Nullable.
  • name - The billing name associated with the method of payment. Max length: 5000. Nullable.
  • phone - The billing phone number associated with the method of payment. Max length: 5000. Nullable.