PaymentIntentNextActionPaynowDisplayQrCode
Summary
Types
@type t() :: %Stripe.Resources.PaynowDisplayQrCode{ data: String.t(), hosted_instructions_url: String.t(), image_url_png: String.t(), image_url_svg: String.t() }
data- The raw data string used to generate QR code, it should be used together with QR code library. Max length: 5000.hosted_instructions_url- The URL to the hosted PayNow instructions page, which allows customers to view the PayNow QR code. Max length: 5000. Nullable.image_url_png- The image_url_png string used to render QR code Max length: 5000.image_url_svg- The image_url_svg string used to render QR code Max length: 5000.