Stripe.Resources.Payout.TraceId (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Payout.TraceId{
  status: String.t() | nil,
  value: String.t() | nil
}
  • status - Possible values are pending, supported, and unsupported. When payout.status is pending or in_transit, this will be pending. When the payout transitions to paid, failed, or canceled, this status will become supported or unsupported shortly after in most cases. In some cases, this may appear as pending for up to 10 days after arrival_date until transitioning to supported or unsupported. Max length: 5000.
  • value - The trace ID value if trace_id.status is supported, otherwise nil. Max length: 5000. Nullable.