Stripe.Resources.Person.AdditionalTosAcceptances.Account
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Person.AdditionalTosAcceptances.Account{ date: integer() | nil, ip: String.t() | nil, user_agent: String.t() | nil }
date- The Unix timestamp marking when the legal guardian accepted the service agreement. Format: Unix timestamp. Nullable.ip- The IP address from which the legal guardian accepted the service agreement. Max length: 5000. Nullable.user_agent- The user agent of the browser from which the legal guardian accepted the service agreement. Max length: 5000. Nullable.