Stripe.Resources.Person.FutureRequirements (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Person.FutureRequirements{
  alternatives:
    [Stripe.Resources.Person.FutureRequirements.Alternatives.t()] | nil,
  currently_due: [String.t()] | nil,
  errors: [Stripe.Resources.Person.FutureRequirements.Errors.t()] | nil,
  eventually_due: [String.t()] | nil,
  past_due: [String.t()] | nil,
  pending_verification: [String.t()] | nil
}
  • alternatives - Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the same original_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providing original_fields_due also serves as a pathway for attempting to resolve the fields again. Nullable.
  • currently_due - Fields that need to be resolved to keep the person's account enabled. If not resolved by the account's future_requirements[current_deadline], these fields will transition to the main requirements hash, and may immediately become past_due, but the account may also be given a grace period depending on the account's enablement state prior to transition.
  • errors - Details about validation and verification failures for due requirements that must be resolved.
  • eventually_due - Fields you must collect when all thresholds are reached. As they become required, they appear in currently_due as well, and the account's future_requirements[current_deadline] becomes set.
  • past_due - Fields that haven't been resolved by the account's requirements.current_deadline. These fields need to be resolved to enable the person's account. future_requirements.past_due is a subset of requirements.past_due.
  • pending_verification - Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move to eventually_due, currently_due, past_due or alternatives. Fields might appear in eventually_due, currently_due, past_due or alternatives and in pending_verification if one verification fails but another is still pending.