Stripe.Resources.Plan.Tiers (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Plan.Tiers{
  flat_amount: integer() | nil,
  flat_amount_decimal: String.t() | nil,
  unit_amount: integer() | nil,
  unit_amount_decimal: String.t() | nil,
  up_to: integer() | nil
}
  • flat_amount - Price for the entire tier. Nullable.
  • flat_amount_decimal - Same as flat_amount, but contains a decimal value with at most 12 decimal places. Format: decimal string. Nullable.
  • unit_amount - Per unit price for units relevant to the tier. Nullable.
  • unit_amount_decimal - Same as unit_amount, but contains a decimal value with at most 12 decimal places. Format: decimal string. Nullable.
  • up_to - Up to and including to this quantity will be contained in the tier. Nullable.