Stripe.Resources.Price.CustomUnitAmount (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Price.CustomUnitAmount{
  maximum: integer() | nil,
  minimum: integer() | nil,
  preset: integer() | nil
}
  • maximum - The maximum unit amount the customer can specify for this item. Nullable.
  • minimum - The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount. Nullable.
  • preset - The starting unit amount which can be updated by the customer. Nullable.