Stripe.Resources.Price.Recurring (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Price.Recurring{
  interval: String.t() | nil,
  interval_count: integer() | nil,
  meter: String.t() | nil,
  trial_period_days: integer() | nil,
  usage_type: String.t() | nil
}
  • interval - The frequency at which a subscription is billed. One of day, week, month or year. Possible values: day, month, week, year.
  • interval_count - The number of intervals (specified in the interval attribute) between subscription billings. For example, interval=month and interval_count=3 bills every 3 months.
  • meter - The meter tracking the usage of a metered price Max length: 5000. Nullable.
  • trial_period_days - Default number of trial days when subscribing a customer to this price using trial_from_plan=true. Nullable.
  • usage_type - Configures how the quantity per period should be determined. Can be either metered or licensed. licensed automatically bills the quantity set when adding it to a subscription. metered aggregates the total usage based on usage records. Defaults to licensed. Possible values: licensed, metered.