Stripe.Resources.PromotionCode.Restrictions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.PromotionCode.Restrictions{
  currency_options:
    %{
      required(String.t()) =>
        Stripe.Resources.PromotionCode.Restrictions.CurrencyOptions.t()
    }
    | nil,
  first_time_transaction: boolean() | nil,
  minimum_amount: integer() | nil,
  minimum_amount_currency: String.t() | nil
}
  • currency_options - Promotion code restrictions defined in each available currency option. Each key must be a three-letter ISO currency code and a supported currency.
  • first_time_transaction - A Boolean indicating if the Promotion Code should only be redeemed for Customers without any successful payments or invoices
  • minimum_amount - Minimum amount required to redeem this Promotion Code into a Coupon (e.g., a purchase must be $100 or more to work). Nullable.
  • minimum_amount_currency - Three-letter ISO code for minimum_amount Max length: 5000. Nullable.