Stripe.Resources.PromptpayDisplayQrCode (tiger_stripe v0.1.10)

Copy Markdown View Source

PaymentIntentNextActionPromptpayDisplayQrCode

Summary

Types

t()

@type t() :: %Stripe.Resources.PromptpayDisplayQrCode{
  data: String.t(),
  hosted_instructions_url: String.t(),
  image_url_png: String.t(),
  image_url_svg: String.t()
}
  • data - The raw data string used to generate QR code, it should be used together with QR code library. Max length: 5000.
  • hosted_instructions_url - The URL to the hosted PromptPay instructions page, which allows customers to view the PromptPay QR code. Max length: 5000.
  • image_url_png - The PNG path used to render the QR code, can be used as the source in an HTML img tag Max length: 5000.
  • image_url_svg - The SVG path used to render the QR code, can be used as the source in an HTML img tag Max length: 5000.

Functions

object_name()