Stripe.Resources.Quote.Computed (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Quote.Computed{
  recurring: Stripe.Resources.Quote.Computed.Recurring.t() | nil,
  upfront: Stripe.Resources.Quote.Computed.Upfront.t() | nil
}
  • recurring - The definitive totals and line items the customer will be charged on a recurring basis. Takes into account the line items with recurring prices and discounts with duration=forever coupons only. Defaults to null if no inputted line items with recurring prices. Nullable.
  • upfront