Stripe.Resources.Quote.Computed.Recurring.TotalDetails
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Quote.Computed.Recurring.TotalDetails{ amount_discount: integer() | nil, amount_shipping: integer() | nil, amount_tax: integer() | nil, breakdown: Stripe.Resources.Quote.Computed.Recurring.TotalDetails.Breakdown.t() | nil }
amount_discount- This is the sum of all the discounts.amount_shipping- This is the sum of all the shipping amounts. Nullable.amount_tax- This is the sum of all the tax amounts.breakdown