Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Quote.Computed.Upfront{ amount_subtotal: integer() | nil, amount_total: integer() | nil, line_items: Stripe.Resources.Quote.Computed.Upfront.LineItems.t() | nil, total_details: Stripe.Resources.Quote.Computed.Upfront.TotalDetails.t() | nil }
amount_subtotal- Total before any discounts or taxes are applied.amount_total- Total after discounts and taxes are applied.line_items- The line items that will appear on the next invoice after this quote is accepted. This does not include pending invoice items that exist on the customer but may still be included in the next invoice.total_details