Stripe.Resources.Quote.Computed.Upfront.TotalDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Quote.Computed.Upfront.TotalDetails{
  amount_discount: integer() | nil,
  amount_shipping: integer() | nil,
  amount_tax: integer() | nil,
  breakdown:
    Stripe.Resources.Quote.Computed.Upfront.TotalDetails.Breakdown.t() | nil
}
  • amount_discount - This is the sum of all the discounts.
  • amount_shipping - This is the sum of all the shipping amounts. Nullable.
  • amount_tax - This is the sum of all the tax amounts.
  • breakdown