Stripe.Resources.Quote.InvoiceSettings (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Quote.InvoiceSettings{
  days_until_due: integer() | nil,
  issuer: Stripe.Resources.Quote.InvoiceSettings.Issuer.t() | nil
}
  • days_until_due - Number of days within which a customer must pay invoices generated by this quote. This value will be null for quotes where collection_method=charge_automatically. Nullable.
  • issuer