Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Quote.TransferData{ amount: integer() | nil, amount_percent: float() | nil, destination: String.t() | Stripe.Resources.Account.t() | nil }
amount- The amount in cents (or local equivalent) that will be transferred to the destination account when the invoice is paid. By default, the entire amount is transferred to the destination. Nullable.amount_percent- A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount will be transferred to the destination. Nullable.destination- The account where funds from the payment will be transferred to upon payment success.