Stripe.Resources.Radar.PaymentEvaluation.ClientDeviceMetadataDetails
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Radar.PaymentEvaluation.ClientDeviceMetadataDetails{ radar_session: String.t() | nil }
radar_session- ID for the Radar Session associated with the payment evaluation. A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments. Max length: 5000.