Stripe.Resources.Radar.PaymentEvaluation.Insights.CardIssuerDecline (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Radar.PaymentEvaluation.Insights.CardIssuerDecline{
  model_score: float() | nil,
  recommended_action: String.t() | nil
}
  • model_score - Stripe Radar's evaluation of the likelihood that the payment will be declined by the card issuer. Scores range from 0 to 100, with higher values indicating a higher likelihood of decline.
  • recommended_action - Recommended action based on the model score. Possible values are block and continue. Possible values: block, continue.