Stripe.Resources.Radar.PaymentEvaluation.PaymentDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Radar.PaymentEvaluation.PaymentDetails{
  amount: integer() | nil,
  currency: String.t() | nil,
  description: String.t() | nil,
  money_movement_details:
    Stripe.Resources.Radar.PaymentEvaluation.PaymentDetails.MoneyMovementDetails.t()
    | nil,
  payment_method_details:
    Stripe.Resources.Radar.PaymentEvaluation.PaymentDetails.PaymentMethodDetails.t()
    | nil,
  shipping_details:
    Stripe.Resources.Radar.PaymentEvaluation.PaymentDetails.ShippingDetails.t()
    | nil,
  statement_descriptor: String.t() | nil
}
  • amount - Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000. Nullable.
  • money_movement_details - Details about the payment's customer presence and type. Nullable.
  • payment_method_details - Details about the payment method used for the payment. Nullable.
  • shipping_details - Shipping details for the payment evaluation. Nullable.
  • statement_descriptor - Payment statement descriptor. Max length: 5000. Nullable.