Stripe.Resources.Radar.ValueList.ListItems (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Radar.ValueList.ListItems{
  data: [Stripe.Resources.Radar.ValueListItem.t()] | nil,
  has_more: boolean() | nil,
  object: String.t() | nil,
  url: String.t() | nil
}
  • data - Details about each object.
  • has_more - True if this list has another page of items after this one that can be fetched.
  • object - String representing the object's type. Objects of the same type share the same value. Always has the value list. Possible values: list.
  • url - The URL where this list can be accessed. Max length: 5000.