Stripe.Resources.Refund.DestinationDetails.Paypal (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Refund.DestinationDetails.Paypal{
  network_decline_code: String.t() | nil
}
  • network_decline_code - For refunds declined by the network, a decline code provided by the network which indicates the reason the refund failed. Max length: 5000. Nullable.