Stripe.Resources.Refund.DestinationDetails.Swish (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Refund.DestinationDetails.Swish{
  network_decline_code: String.t() | nil,
  reference: String.t() | nil,
  reference_status: String.t() | nil
}
  • network_decline_code - For refunds declined by the network, a decline code provided by the network which indicates the reason the refund failed. Max length: 5000. Nullable.
  • reference - The reference assigned to the refund. Max length: 5000. Nullable.
  • reference_status - Status of the reference on the refund. This can be pending, available or unavailable. Max length: 5000. Nullable.