Stripe.Resources.Review (tiger_stripe v0.1.10)

Copy Markdown View Source

RadarReview

Reviews can be used to supplement automated fraud detection with human expertise.

Learn more about Radar and reviewing payments here.

Summary

Types

t()

@type t() :: %Stripe.Resources.Review{
  billing_zip: String.t(),
  charge: String.t() | Stripe.Resources.Charge.t(),
  closed_reason: String.t(),
  created: integer(),
  id: String.t(),
  ip_address: String.t(),
  ip_address_location: Stripe.Resources.Review.IpAddressLocation.t(),
  livemode: boolean(),
  object: String.t(),
  open: boolean(),
  opened_reason: String.t(),
  payment_intent: String.t() | Stripe.Resources.PaymentIntent.t() | nil,
  reason: String.t(),
  session: Stripe.Resources.Review.Session.t()
}
  • billing_zip - The ZIP or postal code of the card used, if applicable. Max length: 5000. Nullable.
  • charge - The charge associated with this review. Nullable. Expandable.
  • closed_reason - The reason the review was closed, or null if it has not yet been closed. One of approved, refunded, refunded_as_fraud, disputed, redacted, canceled, payment_never_settled, or acknowledged. Possible values: acknowledged, approved, canceled, disputed, payment_never_settled, redacted, refunded, refunded_as_fraud. Nullable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • id - Unique identifier for the object. Max length: 5000.
  • ip_address - The IP address where the payment originated. Max length: 5000. Nullable.
  • ip_address_location - Information related to the location of the payment. Note that this information is an approximation and attempts to locate the nearest population center - it should not be used to determine a specific address. Nullable. Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: review.
  • open - If true, the review needs action.
  • opened_reason - The reason the review was opened. One of rule or manual. Possible values: manual, rule.
  • payment_intent - The PaymentIntent ID associated with this review, if one exists. Expandable.
  • reason - The reason the review is currently open or closed. One of rule, manual, approved, refunded, refunded_as_fraud, disputed, redacted, canceled, payment_never_settled, or acknowledged. Max length: 5000.
  • session - Information related to the browsing session of the user who initiated the payment. Nullable. Expandable.

Functions

expandable_fields()

object_name()