Stripe.Resources.SetupAttempt.PaymentMethodDetails.Card.Wallet (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.SetupAttempt.PaymentMethodDetails.Card.Wallet{
  apple_pay: map() | nil,
  google_pay: map() | nil,
  type: String.t() | nil
}
  • apple_pay
  • google_pay
  • type - The type of the card wallet, one of apple_pay, google_pay, or link. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type. Possible values: apple_pay, google_pay, link.