Stripe.Resources.SetupIntent.AutomaticPaymentMethods (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.SetupIntent.AutomaticPaymentMethods{
  allow_redirects: String.t() | nil,
  enabled: boolean() | nil
}
  • allow_redirects - Controls whether this SetupIntent will accept redirect-based payment methods.

Redirect-based payment methods may require your customer to be redirected to a payment method's app or site for authentication or additional steps. To confirm this SetupIntent, you may be required to provide a return_url to redirect customers back to your site after they authenticate or complete the setup. Possible values: always, never.

  • enabled - Automatically calculates compatible payment methods Nullable.