Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SetupIntent.NextAction{ cashapp_handle_redirect_or_display_qr_code: Stripe.Resources.CashappHandleRedirectOrDisplayQrCode.t() | nil, redirect_to_url: Stripe.Resources.NextActionRedirectToUrl.t() | nil, type: String.t() | nil, use_stripe_sdk: map() | nil, verify_with_microdeposits: Stripe.Resources.SetupIntent.NextAction.VerifyWithMicrodeposits.t() | nil }
cashapp_handle_redirect_or_display_qr_coderedirect_to_urltype- Type of the next action to perform. Refer to the other child attributes undernext_actionfor available values. Examples include:redirect_to_url,use_stripe_sdk,alipay_handle_redirect,oxxo_display_details, orverify_with_microdeposits. Max length: 5000.use_stripe_sdk- When confirming a SetupIntent with Stripe.js, Stripe.js depends on the contents of this dictionary to invoke authentication flows. The shape of the contents is subject to change and is only intended to be used by Stripe.js.verify_with_microdeposits