Stripe.Resources.SetupIntent.PaymentMethodOptions.Card
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SetupIntent.PaymentMethodOptions.Card{ mandate_options: Stripe.Resources.MandateOptions.t() | nil, network: String.t() | nil, request_three_d_secure: String.t() | nil }
mandate_options- Configuration options for setting up an eMandate for cards issued in India. Nullable.network- Selected network to process this SetupIntent on. Depends on the available networks of the card attached to the setup intent. Can be only set confirm-time. Possible values:amex,cartes_bancaires,diners,discover,eftpos_au,girocard,interac,jcb,link,mastercard,unionpay,unknown,visa. Nullable.request_three_d_secure- We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults toautomatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine. Possible values:any,automatic,challenge. Nullable.