Stripe.Resources.ShippingDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Shipping

Summary

Types

t()

@type t() :: %Stripe.Resources.ShippingDetails{
  address: Stripe.Resources.Address.t() | nil,
  carrier: String.t() | nil,
  name: String.t() | nil,
  phone: String.t() | nil,
  tracking_number: String.t() | nil
}
  • address - Expandable.
  • carrier - The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. Max length: 5000. Nullable.
  • name - Recipient name. Max length: 5000.
  • phone - Recipient phone (including extension). Max length: 5000. Nullable.
  • tracking_number - The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas. Max length: 5000. Nullable.

Functions

expandable_fields()

object_name()