ShippingRate
Shipping rates describe the price of shipping presented to your customers and applied to a purchase. For more information, see Charge for shipping.
Summary
Types
@type t() :: %Stripe.Resources.ShippingRate{ active: boolean(), created: integer(), delivery_estimate: Stripe.Resources.ShippingRate.DeliveryEstimate.t(), display_name: String.t(), fixed_amount: Stripe.Resources.ShippingRate.FixedAmount.t() | nil, id: String.t(), livemode: boolean(), metadata: %{required(String.t()) => String.t()}, object: String.t(), tax_behavior: String.t(), tax_code: String.t() | Stripe.Resources.TaxCode.t(), type: String.t() }
active- Whether the shipping rate can be used for new purchases. Defaults totrue.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.delivery_estimate- The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions. Nullable. Expandable.display_name- The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions. Max length: 5000. Nullable.fixed_amount- Expandable.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.object- String representing the object's type. Objects of the same type share the same value. Possible values:shipping_rate.tax_behavior- Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Possible values:exclusive,inclusive,unspecified. Nullable.tax_code- A tax code ID. The Shipping tax code istxcd_92010001. Nullable. Expandable.type- The type of calculation to use on the shipping rate. Possible values:fixed_amount.