Source objects allow you to accept a variety of payment methods. They
represent a customer's payment instrument, and can be used with the Stripe API
just like a Card object: once chargeable, they can be charged, or can be
attached to customers.
Stripe doesn't recommend using the deprecated Sources API. We recommend that you adopt the PaymentMethods API. This newer API provides access to our latest features and payment method types.
Related guides: Sources API and Sources & Customers.
Summary
Types
@type t() :: %Stripe.Resources.Source{ ach_credit_transfer: Stripe.Resources.AchCreditTransfer.t() | nil, ach_debit: Stripe.Resources.AchDebit.t() | nil, acss_debit: Stripe.Resources.AcssDebit.t() | nil, alipay: Stripe.Resources.Alipay.t() | nil, allow_redisplay: String.t(), amount: integer(), au_becs_debit: Stripe.Resources.AuBecsDebit.t() | nil, bancontact: Stripe.Resources.Bancontact.t() | nil, card: Stripe.Resources.Card.t() | nil, card_present: Stripe.Resources.CardPresent.t() | nil, client_secret: String.t(), code_verification: Stripe.Resources.Source.CodeVerification.t() | nil, created: integer(), currency: String.t(), customer: String.t() | nil, eps: Stripe.Resources.Eps.t() | nil, flow: String.t(), giropay: Stripe.Resources.Giropay.t() | nil, id: String.t(), ideal: Stripe.Resources.Ideal.t() | nil, klarna: Stripe.Resources.Klarna.t() | nil, livemode: boolean(), metadata: %{required(String.t()) => String.t()}, multibanco: Stripe.Resources.Multibanco.t() | nil, object: String.t(), owner: Stripe.Resources.Source.Owner.t(), p24: Stripe.Resources.P24.t() | nil, receiver: Stripe.Resources.Source.Receiver.t() | nil, redirect: Stripe.Resources.Source.Redirect.t() | nil, sepa_credit_transfer: Stripe.Resources.SepaCreditTransfer.t() | nil, sepa_debit: Stripe.Resources.SepaDebit.t() | nil, sofort: Stripe.Resources.Sofort.t() | nil, source_order: Stripe.Resources.Source.SourceOrder.t() | nil, statement_descriptor: String.t(), status: String.t(), three_d_secure: Stripe.Resources.ThreeDSecure.t() | nil, type: String.t(), usage: String.t(), wechat: Stripe.Resources.Wechat.t() | nil }
ach_credit_transferach_debitacss_debitalipayallow_redisplay- This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”. Possible values:always,limited,unspecified. Nullable.amount- A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount associated with the source. This is the amount for which the source will be chargeable once ready. Required forsingle_usesources. Nullable.au_becs_debitbancontactcardcard_presentclient_secret- The client secret of the source. Used for client-side retrieval using a publishable key. Max length: 5000.code_verification- Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO code for the currency associated with the source. This is the currency for which the source will be chargeable once ready. Required forsingle_usesources. Format: ISO 4217 currency code. Nullable.customer- The ID of the customer to which this source is attached. This will not be present when the source has not been attached to a customer. Max length: 5000.epsflow- The authenticationflowof the source.flowis one ofredirect,receiver,code_verification,none. Max length: 5000.giropayid- Unique identifier for the object. Max length: 5000.idealklarnalivemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.multibancoobject- String representing the object's type. Objects of the same type share the same value. Possible values:source.owner- Information about the owner of the payment instrument that may be used or required by particular source types. Nullable. Expandable.p24receiver- Expandable.redirect- Expandable.sepa_credit_transfersepa_debitsofortsource_order- Expandable.statement_descriptor- Extra information about a source. This will appear on your customer's statement every time you charge the source. Max length: 5000. Nullable.status- The status of the source, one ofcanceled,chargeable,consumed,failed, orpending. Onlychargeablesources can be used to create a charge. Max length: 5000.three_d_securetype- Thetypeof the source. Thetypeis a payment method, one ofach_credit_transfer,ach_debit,alipay,bancontact,card,card_present,eps,giropay,ideal,multibanco,klarna,p24,sepa_debit,sofort,three_d_secure, orwechat. An additional hash is included on the source with a name matching this value. It contains additional information specific to the payment method used. Possible values:ach_credit_transfer,ach_debit,acss_debit,alipay,au_becs_debit,bancontact,card,card_present,eps,giropay,ideal,klarna,multibanco,p24,sepa_credit_transfer,sepa_debit,sofort,three_d_secure,wechat.usage- Eitherreusableorsingle_use. Whether this source should be reusable or not. Some source types may or may not be reusable by construction, while others may leave the option at creation. If an incompatible value is passed, an error will be returned. Max length: 5000. Nullable.wechat