Stripe.Resources.Source.CodeVerification (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Source.CodeVerification{
  attempts_remaining: integer() | nil,
  status: String.t() | nil
}
  • attempts_remaining - The number of attempts remaining to authenticate the source object with a verification code.
  • status - The status of the code verification, either pending (awaiting verification, attempts_remaining should be greater than 0), succeeded (successful verification) or failed (failed verification, cannot be verified anymore as attempts_remaining should be 0). Max length: 5000.