Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Source.Receiver{ address: String.t() | nil, amount_charged: integer() | nil, amount_received: integer() | nil, amount_returned: integer() | nil, refund_attributes_method: String.t() | nil, refund_attributes_status: String.t() | nil }
address- The address of the receiver source. This is the value that should be communicated to the customer to send their funds to. Max length: 5000. Nullable.amount_charged- The total amount that was moved to your balance. This is almost always equal to the amount charged. In rare cases when customers deposit excess funds and we are unable to refund those, those funds get moved to your balance and show up in amount_charged as well. The amount charged is expressed in the source's currency.amount_received- The total amount received by the receiver source.amount_received = amount_returned + amount_chargedshould be true for consumed sources unless customers deposit excess funds. The amount received is expressed in the source's currency.amount_returned- The total amount that was returned to the customer. The amount returned is expressed in the source's currency.refund_attributes_method- Type of refund attribute method, one ofemail,manual, ornone. Max length: 5000.refund_attributes_status- Type of refund attribute status, one ofmissing,requested, oravailable. Max length: 5000.