Stripe.Resources.Source.SourceOrder.Items (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Source.SourceOrder.Items{
  amount: integer() | nil,
  currency: String.t() | nil,
  description: String.t() | nil,
  parent: String.t() | nil,
  quantity: integer() | nil,
  type: String.t() | nil
}
  • amount - The amount (price) for this order item. Nullable.
  • currency - This currency of this order item. Required when amount is present. Max length: 5000. Nullable.
  • description - Human-readable description for this order item. Max length: 5000. Nullable.
  • parent - The ID of the associated object for this line item. Expandable if not null (e.g., expandable to a SKU). Max length: 5000. Nullable.
  • quantity - The quantity of this order item. When type is sku, this is the number of instances of the SKU to be ordered.
  • type - The type of this order item. Must be sku, tax, or shipping. Max length: 5000. Nullable.