Stripe.Resources.Subscription.AutomaticTax (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Subscription.AutomaticTax{
  disabled_reason: String.t() | nil,
  enabled: boolean() | nil,
  liability: Stripe.Resources.Subscription.AutomaticTax.Liability.t() | nil
}
  • disabled_reason - If Stripe disabled automatic tax, this enum describes why. Possible values: requires_location_inputs. Nullable.
  • enabled - Whether Stripe automatically computes tax on this subscription.
  • liability - The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account. Nullable.