Stripe.Resources.Subscription.BillingThresholds (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Subscription.BillingThresholds{
  amount_gte: integer() | nil,
  reset_billing_cycle_anchor: boolean() | nil
}
  • amount_gte - Monetary threshold that triggers the subscription to create an invoice Nullable.
  • reset_billing_cycle_anchor - Indicates if the billing_cycle_anchor should be reset when a threshold is reached. If true, billing_cycle_anchor will be updated to the date/time the threshold was last reached; otherwise, the value will remain unchanged. This value may not be true if the subscription contains items with plans that have aggregate_usage=last_ever. Nullable.