Stripe.Resources.Subscription.PauseCollection (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Subscription.PauseCollection{
  behavior: String.t() | nil,
  resumes_at: integer() | nil
}
  • behavior - The payment collection behavior for this subscription while paused. One of keep_as_draft, mark_uncollectible, or void. Possible values: keep_as_draft, mark_uncollectible, void.
  • resumes_at - The time after which the subscription will resume collecting payments. Format: Unix timestamp. Nullable.