Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

  • acss_debit - This sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to invoices created by the subscription. Nullable.
  • bancontact - This sub-hash contains details about the Bancontact payment method options to pass to invoices created by the subscription. Nullable.
  • card - This sub-hash contains details about the Card payment method options to pass to invoices created by the subscription. Nullable.
  • customer_balance - This sub-hash contains details about the Bank transfer payment method options to pass to invoices created by the subscription. Nullable.
  • konbini - This sub-hash contains details about the Konbini payment method options to pass to invoices created by the subscription. Nullable.
  • payto - This sub-hash contains details about the PayTo payment method options to pass to invoices created by the subscription. Nullable.
  • sepa_debit - This sub-hash contains details about the SEPA Direct Debit payment method options to pass to invoices created by the subscription. Nullable.
  • us_bank_account - This sub-hash contains details about the ACH direct debit payment method options to pass to invoices created by the subscription. Nullable.