Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.Card.MandateOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.Card.MandateOptions{
    amount: integer() | nil,
    amount_type: String.t() | nil,
    description: String.t() | nil
  }
  • amount - Amount to be charged for future payments. Nullable.
  • amount_type - One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param. Possible values: fixed, maximum. Nullable.
  • description - A description of the mandate or subscription that is meant to be displayed to the customer. Max length: 200. Nullable.