Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.CustomerBalance (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.CustomerBalance{
    bank_transfer:
      Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.CustomerBalance.BankTransfer.t()
      | nil,
    funding_type: String.t() | nil
  }
  • bank_transfer
  • funding_type - The funding method type to be used when there are not enough funds in the customer balance. Permitted values include: bank_transfer. Possible values: bank_transfer. Nullable.