Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.Payto.MandateOptions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.Payto.MandateOptions{
    amount: integer() | nil,
    amount_type: String.t() | nil,
    purpose: String.t() | nil
  }
  • amount - The maximum amount that can be collected in a single invoice. If you don't specify a maximum, then there is no limit. Nullable.
  • amount_type - Only maximum is supported. Possible values: fixed, maximum. Nullable.
  • purpose - The purpose for which payments are made. Has a default value based on your merchant category code. Possible values: dependant_support, government, loan, mortgage, other, pension, personal, retail, salary, tax, utility. Nullable.