Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Subscription.PendingUpdate{ billing_cycle_anchor: integer() | nil, expires_at: integer() | nil, subscription_items: [Stripe.Resources.SubscriptionItem.t()] | nil, trial_end: integer() | nil, trial_from_plan: boolean() | nil }
billing_cycle_anchor- If the update is applied, determines the date of the first full invoice, and, for plans withmonthoryearintervals, the day of the month for subsequent invoices. The timestamp is in UTC format. Format: Unix timestamp. Nullable.expires_at- The point after which the changes reflected by this update will be discarded and no longer applied. Format: Unix timestamp.subscription_items- List of subscription items, each with an attached plan, that will be set if the update is applied. Nullable.trial_end- Unix timestamp representing the end of the trial period the customer will get before being charged for the first time, if the update is applied. Format: Unix timestamp. Nullable.trial_from_plan- Indicates if a plan'strial_period_daysshould be applied to the subscription. Settingtrial_endper subscription is preferred, and this defaults tofalse. Setting this flag totruetogether withtrial_endis not allowed. See Using trial periods on subscriptions to learn more. Nullable.