Stripe.Resources.SubscriptionSchedule.CurrentPhase (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.SubscriptionSchedule.CurrentPhase{
  end_date: integer() | nil,
  start_date: integer() | nil
}
  • end_date - The end of this phase of the subscription schedule. Format: Unix timestamp.
  • start_date - The start of this phase of the subscription schedule. Format: Unix timestamp.