Stripe.Resources.SubscriptionSchedule.DefaultSettings.BillingThresholds
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SubscriptionSchedule.DefaultSettings.BillingThresholds{ amount_gte: integer() | nil, reset_billing_cycle_anchor: boolean() | nil }
amount_gte- Monetary threshold that triggers the subscription to create an invoice Nullable.reset_billing_cycle_anchor- Indicates if thebilling_cycle_anchorshould be reset when a threshold is reached. If true,billing_cycle_anchorwill be updated to the date/time the threshold was last reached; otherwise, the value will remain unchanged. This value may not betrueif the subscription contains items with plans that haveaggregate_usage=last_ever. Nullable.