Stripe.Resources.SubscriptionSchedule.DefaultSettings.InvoiceSettings (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.SubscriptionSchedule.DefaultSettings.InvoiceSettings{
  account_tax_ids: [String.t() | Stripe.Resources.TaxId.t()] | nil,
  days_until_due: integer() | nil,
  issuer:
    Stripe.Resources.SubscriptionSchedule.DefaultSettings.InvoiceSettings.Issuer.t()
    | nil
}
  • account_tax_ids - The account tax IDs associated with the subscription schedule. Will be set on invoices generated by the subscription schedule. Nullable.
  • days_until_due - Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be null for subscription schedules where billing=charge_automatically. Nullable.
  • issuer