Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems{
  discounts:
    [Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Discounts.t()]
    | nil,
  metadata: %{required(String.t()) => String.t()} | nil,
  period:
    Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Period.t()
    | nil,
  price: String.t() | Stripe.Resources.Price.t() | nil,
  quantity: integer() | nil,
  tax_rates: [Stripe.Resources.TaxRate.t()] | nil
}
  • discounts - The stackable discounts that will be applied to the item.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.
  • period
  • price - ID of the price used to generate the invoice item.
  • quantity - The quantity of the invoice item. Nullable.
  • tax_rates - The tax rates which apply to the item. When set, the default_tax_rates do not apply to this item. Nullable.