Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Discounts
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Discounts{ coupon: String.t() | Stripe.Resources.Coupon.t() | nil, discount: String.t() | Stripe.Resources.Discount.t() | nil, promotion_code: String.t() | Stripe.Resources.PromotionCode.t() | nil }
coupon- ID of the coupon to create a new discount for. Nullable.discount- ID of an existing discount on the object (or one of its ancestors) to reuse. Nullable.promotion_code- ID of the promotion code to create a new discount for. Nullable.