Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Period.End (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Period.End{
  timestamp: integer() | nil,
  type: String.t() | nil
}
  • timestamp - A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to period.start. Format: Unix timestamp.
  • type - Select how to calculate the end of the invoice item period. Possible values: min_item_period_end, phase_end, timestamp.