Stripe.Resources.SubscriptionSchedule.Phases.InvoiceSettings
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SubscriptionSchedule.Phases.InvoiceSettings{ account_tax_ids: [String.t() | Stripe.Resources.TaxId.t()] | nil, days_until_due: integer() | nil, issuer: Stripe.Resources.SubscriptionSchedule.Phases.InvoiceSettings.Issuer.t() | nil }
account_tax_ids- The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule. Nullable.days_until_due- Number of days within which a customer must pay invoices generated by this subscription schedule. This value will benullfor subscription schedules wherebilling=charge_automatically. Nullable.issuer- The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account. Nullable.