Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SubscriptionSchedule.Phases.Items{ billing_thresholds: Stripe.Resources.SubscriptionSchedule.Phases.Items.BillingThresholds.t() | nil, discounts: [Stripe.Resources.SubscriptionSchedule.Phases.Items.Discounts.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil, plan: String.t() | Stripe.Resources.Plan.t() | nil, price: String.t() | Stripe.Resources.Price.t() | nil, quantity: integer() | nil, tax_rates: [Stripe.Resources.TaxRate.t()] | nil }
billing_thresholds- Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period Nullable.discounts- The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Useexpand[]=discountsto expand each discount.metadata- Set of key-value pairs that you can attach to an item. Metadata on this item will update the underlying subscription item'smetadatawhen the phase is entered. Nullable.plan- ID of the plan to which the customer should be subscribed.price- ID of the price to which the customer should be subscribed.quantity- Quantity of the plan to which the customer should be subscribed.tax_rates- The tax rates which apply to thisphase_item. When set, thedefault_tax_rateson the phase do not apply to thisphase_item. Nullable.