TaxProductResourceTaxCalculationLineItem
Summary
Types
@type t() :: %Stripe.Resources.Tax.CalculationLineItem{ amount: integer(), amount_tax: integer(), id: String.t(), livemode: boolean(), metadata: %{required(String.t()) => String.t()}, object: String.t(), product: String.t(), quantity: integer(), reference: String.t(), tax_behavior: String.t(), tax_breakdown: [Stripe.Resources.Tax.CalculationLineItem.TaxBreakdown.t()] | nil, tax_code: String.t() }
amount- The line item amount in the smallest currency unit. Iftax_behavior=inclusive, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.amount_tax- The amount of tax calculated for this line item, in the smallest currency unit.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.object- String representing the object's type. Objects of the same type share the same value. Possible values:tax.calculation_line_item.product- The ID of an existing Product. Max length: 5000. Nullable.quantity- The number of units of the item being purchased. For reversals, this is the quantity reversed.reference- A custom identifier for this line item. Max length: 5000.tax_behavior- Specifies whether theamountincludes taxes. Iftax_behavior=inclusive, then the amount includes taxes. Possible values:exclusive,inclusive.tax_breakdown- Detailed account of taxes relevant to this line item. Nullable. Expandable.tax_code- The tax code ID used for this resource. Max length: 5000.