Stripe.Resources.Tax.Registration (tiger_stripe v0.1.10)

Copy Markdown View Source

TaxProductRegistrationsResourceTaxRegistration

A Tax Registration lets us know that your business is registered to collect tax on payments within a region, enabling you to automatically collect tax.

Stripe doesn't register on your behalf with the relevant authorities when you create a Tax Registration object. For more information on how to register to collect tax, see our guide.

Related guide: Using the Registrations API

Summary

Types

t()

@type t() :: %Stripe.Resources.Tax.Registration{
  active_from: integer(),
  country: String.t(),
  country_options: Stripe.Resources.Tax.Registration.CountryOptions.t(),
  created: integer(),
  expires_at: integer(),
  id: String.t(),
  livemode: boolean(),
  object: String.t(),
  status: String.t()
}
  • active_from - Time at which the registration becomes active. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • country - Two-letter country code (ISO 3166-1 alpha-2). Max length: 5000.
  • country_options - Expandable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • expires_at - If set, the registration stops being active at this time. If not set, the registration will be active indefinitely. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: tax.registration.
  • status - The status of the registration. This field is present for convenience and can be deduced from active_from and expires_at. Possible values: active, expired, scheduled.

Functions

expandable_fields()

object_name()