TaxProductResourceTaxSettings
You can use Tax Settings to manage configurations used by Stripe Tax calculations.
Related guide: Using the Settings API
Summary
Types
@type t() :: %Stripe.Resources.Tax.Settings{ defaults: Stripe.Resources.Tax.Settings.Defaults.t(), head_office: Stripe.Resources.Tax.Settings.HeadOffice.t(), livemode: boolean(), object: String.t(), status: String.t(), status_details: Stripe.Resources.Tax.Settings.StatusDetails.t() }
defaults- Expandable.head_office- The place where your business is located. Nullable. Expandable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:tax.settings.status- The status of the TaxSettings. Possible values:active,pending.status_details- Expandable.