Stripe.Resources.Tax.Settings.Defaults (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Tax.Settings.Defaults{
  provider: String.t() | nil,
  tax_behavior: String.t() | nil,
  tax_code: String.t() | nil
}
  • provider - The tax calculation provider this account uses. Defaults to stripe when not using a third-party provider. Possible values: anrok, avalara, sphere, stripe.
  • tax_behavior - Default tax behavior used to specify whether the price is considered inclusive of taxes or exclusive of taxes. If the item's price has a tax behavior set, it will take precedence over the default tax behavior. Possible values: exclusive, inclusive, inferred_by_currency. Nullable.
  • tax_code - Default tax code used to classify your products and prices. Max length: 5000. Nullable.