Stripe.Resources.Tax.Settings.StatusDetails.Pending (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Tax.Settings.StatusDetails.Pending{
  missing_fields: [String.t()] | nil
}
  • missing_fields - The list of missing fields that are required to perform calculations. It includes the entry head_office when the status is pending. It is recommended to set the optional values even if they aren't listed as required for calculating taxes. Calculations can fail if missing fields aren't explicitly provided on every call. Nullable.