Stripe.Resources.Tax.Transaction.ShippingCost.TaxBreakdown (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Tax.Transaction.ShippingCost.TaxBreakdown{
  amount: integer() | nil,
  jurisdiction:
    Stripe.Resources.Tax.Transaction.ShippingCost.TaxBreakdown.Jurisdiction.t()
    | nil,
  sourcing: String.t() | nil,
  tax_rate_details:
    Stripe.Resources.Tax.Transaction.ShippingCost.TaxBreakdown.TaxRateDetails.t()
    | nil,
  taxability_reason: String.t() | nil,
  taxable_amount: integer() | nil
}
  • amount - The amount of tax, in the smallest currency unit.
  • jurisdiction
  • sourcing - Indicates whether the jurisdiction was determined by the origin (merchant's address) or destination (customer's address). Possible values: destination, origin.
  • tax_rate_details - Details regarding the rate for this tax. This field will be null when the tax is not imposed, for example if the product is exempt from tax. Nullable.
  • taxability_reason - The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported. Possible values: customer_exempt, not_collecting, not_subject_to_tax, not_supported, portion_product_exempt, portion_reduced_rated, portion_standard_rated, product_exempt, product_exempt_holiday, proportionally_rated, reduced_rated, reverse_charge, standard_rated, taxable_basis_reduced, zero_rated.
  • taxable_amount - The amount on which tax is calculated, in the smallest currency unit.