Stripe.Resources.Tax.TransactionLineItem (tiger_stripe v0.1.10)

Copy Markdown View Source

TaxProductResourceTaxTransactionLineItem

Summary

Types

t()

@type t() :: %Stripe.Resources.Tax.TransactionLineItem{
  amount: integer(),
  amount_tax: integer(),
  id: String.t(),
  livemode: boolean(),
  metadata: %{required(String.t()) => String.t()},
  object: String.t(),
  product: String.t(),
  quantity: integer(),
  reference: String.t(),
  reversal: Stripe.Resources.Tax.TransactionLineItem.Reversal.t(),
  tax_behavior: String.t(),
  tax_code: String.t(),
  type: String.t()
}
  • amount - The line item amount in the smallest currency unit. If tax_behavior=inclusive, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.
  • amount_tax - The amount of tax calculated for this line item, in the smallest currency unit.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: tax.transaction_line_item.
  • product - The ID of an existing Product. Max length: 5000. Nullable.
  • quantity - The number of units of the item being purchased. For reversals, this is the quantity reversed.
  • reference - A custom identifier for this line item in the transaction. Max length: 5000.
  • reversal - If type=reversal, contains information about what was reversed. Nullable. Expandable.
  • tax_behavior - Specifies whether the amount includes taxes. If tax_behavior=inclusive, then the amount includes taxes. Possible values: exclusive, inclusive.
  • tax_code - The tax code ID used for this resource. Max length: 5000.
  • type - If reversal, this line item reverses an earlier transaction. Possible values: reversal, transaction.

Functions

expandable_fields()

object_name()