Stripe.Resources.TaxId.Owner (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.TaxId.Owner{
  account: String.t() | Stripe.Resources.Account.t() | nil,
  application: String.t() | Stripe.Resources.Application.t() | nil,
  customer: String.t() | Stripe.Resources.Customer.t() | nil,
  customer_account: String.t() | nil,
  type: String.t() | nil
}
  • account - The account being referenced when type is account.
  • application - The Connect Application being referenced when type is application.
  • customer - The customer being referenced when type is customer.
  • customer_account - The Account representing the customer being referenced when type is customer. Max length: 5000. Nullable.
  • type - Type of owner referenced. Possible values: account, application, customer, self.