Stripe.Resources.Terminal.Reader.Action.CollectInputs
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Terminal.Reader.Action.CollectInputs{ inputs: [Stripe.Resources.Terminal.Reader.Action.CollectInputs.Inputs.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil }
inputs- List of inputs to be collected.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.