Stripe.Resources.Terminal.Reader.Action.CollectInputs.Inputs (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

  • custom_text - Default text of input being collected. Nullable.
  • email
  • numeric
  • phone
  • required - Indicate that this input is required, disabling the skip button. Nullable.
  • selection
  • signature
  • skipped - Indicate that this input was skipped by the user.
  • text
  • toggles - List of toggles being collected. Values are present if collection is complete. Nullable.
  • type - Type of input being collected. Possible values: email, numeric, phone, selection, signature, text.