Stripe.Resources.Terminal.Reader.Action.SetReaderDisplay (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Terminal.Reader.Action.SetReaderDisplay{
  cart: Stripe.Resources.Terminal.Reader.Action.SetReaderDisplay.Cart.t() | nil,
  type: String.t() | nil
}
  • cart - Cart object to be displayed by the reader, including line items, amounts, and currency. Nullable.
  • type - Type of information to be displayed by the reader. Only cart is currently supported. Possible values: cart.