Stripe.Resources.Topup (tiger_stripe v0.1.10)

Copy Markdown View Source

Topup

To top up your Stripe balance, you create a top-up object. You can retrieve individual top-ups, as well as list all top-ups. Top-ups are identified by a unique, random ID.

Related guide: Topping up your platform account

Summary

Types

t()

@type t() :: %Stripe.Resources.Topup{
  amount: integer(),
  balance_transaction: String.t() | Stripe.Resources.BalanceTransaction.t(),
  created: integer(),
  currency: String.t(),
  description: String.t(),
  expected_availability_date: integer(),
  failure_code: String.t(),
  failure_message: String.t(),
  id: String.t(),
  livemode: boolean(),
  metadata: %{required(String.t()) => String.t()},
  object: String.t(),
  source: Stripe.Resources.Source.t(),
  statement_descriptor: String.t(),
  status: String.t(),
  transfer_group: String.t()
}
  • amount - Amount transferred.
  • balance_transaction - ID of the balance transaction that describes the impact of this top-up on your account balance. May not be specified depending on status of top-up. Nullable. Expandable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Max length: 5000.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000. Nullable.
  • expected_availability_date - Date the funds are expected to arrive in your Stripe account for payouts. This factors in delays like weekends or bank holidays. May not be specified depending on status of top-up. Nullable.
  • failure_code - Error code explaining reason for top-up failure if available (see the errors section for a list of codes). Max length: 5000. Nullable.
  • failure_message - Message to user further explaining reason for top-up failure if available. Max length: 5000. Nullable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: topup.
  • source - The source field is deprecated. It might not always be present in the API response. Nullable. Expandable.
  • statement_descriptor - Extra information about a top-up. This will appear on your source's bank statement. It must contain at least one letter. Max length: 5000. Nullable.
  • status - The status of the top-up is either canceled, failed, pending, reversed, or succeeded. Possible values: canceled, failed, pending, reversed, succeeded.
  • transfer_group - A string that identifies this top-up as part of a group. Max length: 5000. Nullable.

Functions

expandable_fields()

object_name()