Stripe.Resources.TransferReversal (tiger_stripe v0.1.10)

Copy Markdown View Source

TransferReversal

Stripe Connect platforms can reverse transfers made to a connected account, either entirely or partially, and can also specify whether to refund any related application fees. Transfer reversals add to the platform's balance and subtract from the destination account's balance.

Reversing a transfer that was made for a destination charge is allowed only up to the amount of the charge. It is possible to reverse a transfer_group transfer only if the destination account has enough balance to cover the reversal.

Related guide: Reverse transfers

Summary

Types

t()

@type t() :: %Stripe.Resources.TransferReversal{
  amount: integer(),
  balance_transaction: String.t() | Stripe.Resources.BalanceTransaction.t(),
  created: integer(),
  currency: String.t(),
  destination_payment_refund: String.t() | Stripe.Resources.Refund.t(),
  id: String.t(),
  metadata: %{required(String.t()) => String.t()},
  object: String.t(),
  source_refund: String.t() | Stripe.Resources.Refund.t(),
  transfer: String.t() | Stripe.Resources.Transfer.t()
}
  • amount - Amount, in cents (or local equivalent).
  • balance_transaction - Balance transaction that describes the impact on your account balance. Nullable. Expandable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • destination_payment_refund - Linked payment refund for the transfer reversal. Nullable. Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: transfer_reversal.
  • source_refund - ID of the refund responsible for the transfer reversal. Nullable. Expandable.
  • transfer - ID of the transfer that was reversed. Expandable.

Functions

expandable_fields()

object_name()