Stripe.Resources.Treasury.CreditReversal (tiger_stripe v0.1.10)

Copy Markdown View Source

TreasuryReceivedCreditsResourceCreditReversal

You can reverse some ReceivedCredits depending on their network and source flow. Reversing a ReceivedCredit leads to the creation of a new object known as a CreditReversal.

Summary

Types

t()

@type t() :: %Stripe.Resources.Treasury.CreditReversal{
  amount: integer(),
  created: integer(),
  currency: String.t(),
  financial_account: String.t(),
  hosted_regulatory_receipt_url: String.t(),
  id: String.t(),
  livemode: boolean(),
  metadata: %{required(String.t()) => String.t()},
  network: String.t(),
  object: String.t(),
  received_credit: String.t(),
  status: String.t(),
  status_transitions:
    Stripe.Resources.Treasury.CreditReversal.StatusTransitions.t(),
  transaction: String.t() | Stripe.Resources.Treasury.Transaction.t()
}
  • amount - Amount (in cents) transferred.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • financial_account - The FinancialAccount to reverse funds from. Max length: 5000.
  • hosted_regulatory_receipt_url - A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe's money transmission licenses. Max length: 5000. Nullable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • network - The rails used to reverse the funds. Possible values: ach, stripe.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: treasury.credit_reversal.
  • received_credit - The ReceivedCredit being reversed. Max length: 5000.
  • status - Status of the CreditReversal Possible values: canceled, posted, processing.
  • status_transitions - Expandable.
  • transaction - The Transaction associated with this object. Nullable. Expandable.

Functions

expandable_fields()

object_name()