Stripe.Resources.Treasury.FinancialAccountFeatures (tiger_stripe v0.1.10)

Copy Markdown View Source

TreasuryFinancialAccountsResourceFinancialAccountFeatures

Encodes whether a FinancialAccount has access to a particular Feature, with a status enum and associated status_details. Stripe or the platform can control Features via the requested field.

Summary

Types

t()

@type t() :: %Stripe.Resources.Treasury.FinancialAccountFeatures{
  card_issuing: Stripe.Resources.ToggleSettings.t() | nil,
  deposit_insurance: Stripe.Resources.ToggleSettings.t() | nil,
  financial_addresses: Stripe.Resources.FinancialAddresses.t() | nil,
  inbound_transfers: Stripe.Resources.InboundTransfers.t() | nil,
  intra_stripe_flows: Stripe.Resources.ToggleSettings.t() | nil,
  object: String.t(),
  outbound_payments: Stripe.Resources.OutboundPayments.t() | nil,
  outbound_transfers: Stripe.Resources.OutboundTransfers.t() | nil
}
  • card_issuing - Expandable.
  • deposit_insurance - Expandable.
  • financial_addresses - Expandable.
  • inbound_transfers - Expandable.
  • intra_stripe_flows - Expandable.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: treasury.financial_account_features.
  • outbound_payments - Expandable.
  • outbound_transfers - Expandable.

Functions

expandable_fields()

object_name()