Stripe.Resources.Treasury.OutboundPayment.EndUserDetails (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Treasury.OutboundPayment.EndUserDetails{
  ip_address: String.t() | nil,
  present: boolean() | nil
}
  • ip_address - IP address of the user initiating the OutboundPayment. Set if present is set to true. IP address collection is required for risk and compliance reasons. This will be used to help determine if the OutboundPayment is authorized or should be blocked. Max length: 5000. Nullable.
  • present - true if the OutboundPayment creation request is being made on behalf of an end user by a platform. Otherwise, false.