TreasuryOutboundTransfersResourceOutboundTransfer
Use OutboundTransfers to transfer funds from a FinancialAccount to a PaymentMethod belonging to the same entity. To send funds to a different party, use OutboundPayments instead. You can send funds over ACH rails or through a domestic wire transfer to a user's own external bank account.
Simulate OutboundTransfer state changes with the /v1/test_helpers/treasury/outbound_transfers endpoints. These methods can only be called on test mode objects.
Related guide: Moving money with Treasury using OutboundTransfer objects
Summary
Types
@type t() :: %Stripe.Resources.Treasury.OutboundTransfer{ amount: integer(), cancelable: boolean(), created: integer(), currency: String.t(), description: String.t(), destination_payment_method: String.t(), destination_payment_method_details: Stripe.Resources.DestinationPaymentMethodDetails.t(), expected_arrival_date: integer(), financial_account: String.t(), hosted_regulatory_receipt_url: String.t(), id: String.t(), livemode: boolean(), metadata: %{required(String.t()) => String.t()}, object: String.t(), returned_details: Stripe.Resources.ReturnedDetails.t(), statement_descriptor: String.t(), status: String.t(), status_transitions: Stripe.Resources.StatusTransitions.t(), tracking_details: Stripe.Resources.Treasury.OutboundTransfer.TrackingDetails.t(), transaction: String.t() | Stripe.Resources.Treasury.Transaction.t() }
amount- Amount (in cents) transferred.cancelable- Returnstrueif the object can be canceled, andfalseotherwise.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000. Nullable.destination_payment_method- The PaymentMethod used as the payment instrument for an OutboundTransfer. Max length: 5000. Nullable.destination_payment_method_details- Expandable.expected_arrival_date- The date when funds are expected to arrive in the destination account. Format: Unix timestamp.financial_account- The FinancialAccount that funds were pulled from. Max length: 5000.hosted_regulatory_receipt_url- A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe's money transmission licenses. Max length: 5000. Nullable.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.object- String representing the object's type. Objects of the same type share the same value. Possible values:treasury.outbound_transfer.returned_details- Details about a returned OutboundTransfer. Only set when the status isreturned. Nullable. Expandable.statement_descriptor- Information about the OutboundTransfer to be sent to the recipient account. Max length: 5000.status- Current status of the OutboundTransfer:processing,failed,canceled,posted,returned. An OutboundTransfer isprocessingif it has been created and is pending. The status changes topostedonce the OutboundTransfer has been "confirmed" and funds have left the account, or tofailedorcanceled. If an OutboundTransfer fails to arrive at its destination, its status will change toreturned. Possible values:canceled,failed,posted,processing,returned.status_transitions- Expandable.tracking_details- Details about network-specific tracking information if available. Nullable. Expandable.transaction- The Transaction associated with this object. Expandable.