Stripe.Resources.Treasury.ReceivedCredit (tiger_stripe v0.1.10)

Copy Markdown View Source

TreasuryReceivedCreditsResourceReceivedCredit

ReceivedCredits represent funds sent to a FinancialAccount (for example, via ACH or wire). These money movements are not initiated from the FinancialAccount.

Summary

Types

t()

@type t() :: %Stripe.Resources.Treasury.ReceivedCredit{
  amount: integer(),
  created: integer(),
  currency: String.t(),
  description: String.t(),
  failure_code: String.t(),
  financial_account: String.t(),
  hosted_regulatory_receipt_url: String.t(),
  id: String.t(),
  initiating_payment_method_details:
    Stripe.Resources.Treasury.ReceivedCredit.InitiatingPaymentMethodDetails.t(),
  linked_flows: Stripe.Resources.Treasury.ReceivedCredit.LinkedFlows.t(),
  livemode: boolean(),
  network: String.t(),
  object: String.t(),
  reversal_details:
    Stripe.Resources.Treasury.ReceivedCredit.ReversalDetails.t(),
  status: String.t(),
  transaction: String.t() | Stripe.Resources.Treasury.Transaction.t()
}
  • amount - Amount (in cents) transferred.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.
  • failure_code - Reason for the failure. A ReceivedCredit might fail because the receiving FinancialAccount is closed or frozen. Possible values: account_closed, account_frozen, international_transaction, other. Nullable.
  • financial_account - The FinancialAccount that received the funds. Max length: 5000. Nullable.
  • hosted_regulatory_receipt_url - A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe's money transmission licenses. Max length: 5000. Nullable.
  • id - Unique identifier for the object. Max length: 5000.
  • initiating_payment_method_details - Expandable.
  • linked_flows - Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • network - The rails used to send the funds. Possible values: ach, card, stripe, us_domestic_wire.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: treasury.received_credit.
  • reversal_details - Details describing when a ReceivedCredit may be reversed. Nullable. Expandable.
  • status - Status of the ReceivedCredit. ReceivedCredits are created either succeeded (approved) or failed (declined). If a ReceivedCredit is declined, the failure reason can be found in the failure_code field. Possible values: failed, succeeded.
  • transaction - The Transaction associated with this object. Nullable. Expandable.

Functions

expandable_fields()

object_name()