Stripe.Resources.Treasury.ReceivedCredit.LinkedFlows (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Treasury.ReceivedCredit.LinkedFlows{
  credit_reversal: String.t() | nil,
  issuing_authorization: String.t() | nil,
  issuing_transaction: String.t() | nil,
  source_flow: String.t() | nil,
  source_flow_details:
    Stripe.Resources.Treasury.ReceivedCredit.LinkedFlows.SourceFlowDetails.t()
    | nil,
  source_flow_type: String.t() | nil
}
  • credit_reversal - The CreditReversal created as a result of this ReceivedCredit being reversed. Max length: 5000. Nullable.
  • issuing_authorization - Set if the ReceivedCredit was created due to an Issuing Authorization object. Max length: 5000. Nullable.
  • issuing_transaction - Set if the ReceivedCredit is also viewable as an Issuing transaction object. Max length: 5000. Nullable.
  • source_flow - ID of the source flow. Set if network is stripe and the source flow is visible to the user. Examples of source flows include OutboundPayments, payouts, or CreditReversals. Max length: 5000. Nullable.
  • source_flow_details - The expandable object of the source flow. Nullable.
  • source_flow_type - The type of flow that originated the ReceivedCredit (for example, outbound_payment). Max length: 5000. Nullable.