Stripe.Resources.Treasury.ReceivedDebit.LinkedFlows (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Treasury.ReceivedDebit.LinkedFlows{
  debit_reversal: String.t() | nil,
  inbound_transfer: String.t() | nil,
  issuing_authorization: String.t() | nil,
  issuing_transaction: String.t() | nil,
  payout: String.t() | nil,
  topup: String.t() | nil
}
  • debit_reversal - The DebitReversal created as a result of this ReceivedDebit being reversed. Max length: 5000. Nullable.
  • inbound_transfer - Set if the ReceivedDebit is associated with an InboundTransfer's return of funds. Max length: 5000. Nullable.
  • issuing_authorization - Set if the ReceivedDebit was created due to an Issuing Authorization object. Max length: 5000. Nullable.
  • issuing_transaction - Set if the ReceivedDebit is also viewable as an Issuing Dispute object. Max length: 5000. Nullable.
  • payout - Set if the ReceivedDebit was created due to a Payout object. Max length: 5000. Nullable.
  • topup - Set if the ReceivedDebit was created due to a Topup object. Max length: 5000. Nullable.