Stripe.Resources.Treasury.Transaction.StatusTransitions (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.Treasury.Transaction.StatusTransitions{
  posted_at: integer() | nil,
  void_at: integer() | nil
}
  • posted_at - Timestamp describing when the Transaction changed status to posted. Format: Unix timestamp. Nullable.
  • void_at - Timestamp describing when the Transaction changed status to void. Format: Unix timestamp. Nullable.