Stripe.Resources.V2.Core.Account (tiger_stripe v0.1.10)

Copy Markdown View Source

Account

A V2 Account is a representation of a company or individual that a Stripe user does business with. Accounts contain the contact details, Legal Entity information, and configuration required to enable the Account for use across Stripe products.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.Account{
  applied_configurations: [String.t()],
  closed: boolean() | nil,
  configuration: Stripe.Resources.V2.Core.Account.Configuration.t() | nil,
  contact_email: String.t() | nil,
  contact_phone: String.t() | nil,
  created: String.t(),
  dashboard: String.t() | nil,
  defaults: Stripe.Resources.V2.Core.Account.Defaults.t() | nil,
  display_name: String.t() | nil,
  future_requirements:
    Stripe.Resources.V2.Core.Account.FutureRequirements.t() | nil,
  id: String.t(),
  identity: Stripe.Resources.V2.Core.Account.Identity.t() | nil,
  livemode: boolean(),
  metadata: %{required(String.t()) => String.t()} | nil,
  object: String.t(),
  requirements: Stripe.Resources.V2.Core.Account.Requirements.t() | nil
}
  • applied_configurations - The configurations that have been applied to this account.
  • closed - Indicates whether the account has been closed.
  • configuration - An Account represents a company, individual, or other entity that a user interacts with. Accounts store identity information and one or more configurations that enable product-specific capabilities. You can assign configurations at creation or add them later.
  • contact_email - The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
  • contact_phone - The default contact phone for the Account.
  • created - Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z. Format: date-time.
  • dashboard - A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account. Possible values: express, full, none.
  • defaults - Default values for settings shared across Account configurations.
  • display_name - A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
  • future_requirements - Information about the future requirements for the Account that will eventually come into effect, including what information needs to be collected, and by when.
  • id - Unique identifier for the Account.
  • identity - Information about the company, individual, and business represented by the Account.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • object - String representing the object's type. Objects of the same type share the same value of the object field. Possible values: v2.core.account.
  • requirements - Information about the active requirements for the Account, including what information needs to be collected, and by when.

Functions

object_name()