Stripe.Resources.V2.Core.Account.Configuration.Customer
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Configuration.Customer{ applied: boolean() | nil, automatic_indirect_tax: Stripe.Resources.V2.Core.Account.Configuration.Customer.AutomaticIndirectTax.t() | nil, billing: Stripe.Resources.V2.Core.Account.Configuration.Customer.Billing.t() | nil, capabilities: Stripe.Resources.V2.Core.Account.Configuration.Customer.Capabilities.t() | nil, shipping: Stripe.Resources.V2.Core.Account.Configuration.Customer.Shipping.t() | nil, test_clock: String.t() | nil }
applied- Indicates whether the customer configuration is active. You can deactivate or reactivate the customer configuration by updating this property. Deactivating the configuration by setting this value to false will unrequest all capabilities within the configuration. It will not delete any of the configuration's other properties.automatic_indirect_tax- Settings for automatic indirect tax calculation on the customer's invoices, subscriptions, Checkout Sessions, and Payment Links. Available when automatic tax calculation is available for the customer account's location.billing- Default Billing settings for the customer account, used in Invoices and Subscriptions.capabilities- Capabilities that have been requested on the Customer Configuration.shipping- The customer's shipping information. Appears on invoices emailed to this customer.test_clock- ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.