Stripe.Resources.V2.Core.Account.Configuration.Customer.Billing.Invoice.Rendering
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Configuration.Customer.Billing.Invoice.Rendering{ amount_tax_display: String.t() | nil, template: String.t() | nil }
amount_tax_display- Indicates whether displayed line item prices and amounts on invoice PDFs include inclusive tax amounts. Must be eitherinclude_inclusive_taxorexclude_tax. Possible values:exclude_tax,include_inclusive_tax.template- ID of the invoice rendering template to use for future invoices.