Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities{
  ach_debit_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.AchDebitPayments.t()
    | nil,
  acss_debit_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.AcssDebitPayments.t()
    | nil,
  affirm_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.AffirmPayments.t()
    | nil,
  afterpay_clearpay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.AfterpayClearpayPayments.t()
    | nil,
  alma_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.AlmaPayments.t()
    | nil,
  amazon_pay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.AmazonPayPayments.t()
    | nil,
  au_becs_debit_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.AuBecsDebitPayments.t()
    | nil,
  bacs_debit_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.BacsDebitPayments.t()
    | nil,
  bancontact_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.BancontactPayments.t()
    | nil,
  blik_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.BlikPayments.t()
    | nil,
  boleto_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.BoletoPayments.t()
    | nil,
  card_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.CardPayments.t()
    | nil,
  cartes_bancaires_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.CartesBancairesPayments.t()
    | nil,
  cashapp_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.CashappPayments.t()
    | nil,
  eps_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.EpsPayments.t()
    | nil,
  fpx_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.FpxPayments.t()
    | nil,
  gb_bank_transfer_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.GbBankTransferPayments.t()
    | nil,
  grabpay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.GrabpayPayments.t()
    | nil,
  ideal_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.IdealPayments.t()
    | nil,
  jcb_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.JcbPayments.t()
    | nil,
  jp_bank_transfer_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.JpBankTransferPayments.t()
    | nil,
  kakao_pay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.KakaoPayPayments.t()
    | nil,
  klarna_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.KlarnaPayments.t()
    | nil,
  konbini_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.KonbiniPayments.t()
    | nil,
  kr_card_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.KrCardPayments.t()
    | nil,
  link_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.LinkPayments.t()
    | nil,
  mobilepay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.MobilepayPayments.t()
    | nil,
  multibanco_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.MultibancoPayments.t()
    | nil,
  mx_bank_transfer_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.MxBankTransferPayments.t()
    | nil,
  naver_pay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.NaverPayPayments.t()
    | nil,
  oxxo_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.OxxoPayments.t()
    | nil,
  p24_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.P24Payments.t()
    | nil,
  pay_by_bank_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.PayByBankPayments.t()
    | nil,
  payco_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.PaycoPayments.t()
    | nil,
  paynow_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.PaynowPayments.t()
    | nil,
  promptpay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.PromptpayPayments.t()
    | nil,
  revolut_pay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.RevolutPayPayments.t()
    | nil,
  samsung_pay_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.SamsungPayPayments.t()
    | nil,
  sepa_bank_transfer_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.SepaBankTransferPayments.t()
    | nil,
  sepa_debit_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.SepaDebitPayments.t()
    | nil,
  stripe_balance:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.StripeBalance.t()
    | nil,
  swish_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.SwishPayments.t()
    | nil,
  twint_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.TwintPayments.t()
    | nil,
  us_bank_transfer_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.UsBankTransferPayments.t()
    | nil,
  zip_payments:
    Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.ZipPayments.t()
    | nil
}
  • ach_debit_payments - Allow the merchant to process ACH debit payments.
  • acss_debit_payments - Allow the merchant to process ACSS debit payments.
  • affirm_payments - Allow the merchant to process Affirm payments.
  • afterpay_clearpay_payments - Allow the merchant to process Afterpay/Clearpay payments.
  • alma_payments - Allow the merchant to process Alma payments.
  • amazon_pay_payments - Allow the merchant to process Amazon Pay payments.
  • au_becs_debit_payments - Allow the merchant to process Australian BECS Direct Debit payments.
  • bacs_debit_payments - Allow the merchant to process BACS Direct Debit payments.
  • bancontact_payments - Allow the merchant to process Bancontact payments.
  • blik_payments - Allow the merchant to process BLIK payments.
  • boleto_payments - Allow the merchant to process Boleto payments.
  • card_payments - Allow the merchant to collect card payments.
  • cartes_bancaires_payments - Allow the merchant to process Cartes Bancaires payments.
  • cashapp_payments - Allow the merchant to process Cash App payments.
  • eps_payments - Allow the merchant to process EPS payments.
  • fpx_payments - Allow the merchant to process FPX payments.
  • gb_bank_transfer_payments - Allow the merchant to process UK bank transfer payments.
  • grabpay_payments - Allow the merchant to process GrabPay payments.
  • ideal_payments - Allow the merchant to process iDEAL payments.
  • jcb_payments - Allow the merchant to process JCB card payments.
  • jp_bank_transfer_payments - Allow the merchant to process Japanese bank transfer payments.
  • kakao_pay_payments - Allow the merchant to process Kakao Pay payments.
  • klarna_payments - Allow the merchant to process Klarna payments.
  • konbini_payments - Allow the merchant to process Konbini convenience store payments.
  • kr_card_payments - Allow the merchant to process Korean card payments.
  • link_payments - Allow the merchant to process Link payments.
  • mobilepay_payments - Allow the merchant to process MobilePay payments.
  • multibanco_payments - Allow the merchant to process Multibanco payments.
  • mx_bank_transfer_payments - Allow the merchant to process Mexican bank transfer payments.
  • naver_pay_payments - Allow the merchant to process Naver Pay payments.
  • oxxo_payments - Allow the merchant to process OXXO payments.
  • p24_payments - Allow the merchant to process Przelewy24 (P24) payments.
  • pay_by_bank_payments - Allow the merchant to process Pay by Bank payments.
  • payco_payments - Allow the merchant to process PAYCO payments.
  • paynow_payments - Allow the merchant to process PayNow payments.
  • promptpay_payments - Allow the merchant to process PromptPay payments.
  • revolut_pay_payments - Allow the merchant to process Revolut Pay payments.
  • samsung_pay_payments - Allow the merchant to process Samsung Pay payments.
  • sepa_bank_transfer_payments - Allow the merchant to process SEPA bank transfer payments.
  • sepa_debit_payments - Allow the merchant to process SEPA Direct Debit payments.
  • stripe_balance - Capabilities that enable the merchant to manage their Stripe Balance (/v1/balance).
  • swish_payments - Allow the merchant to process Swish payments.
  • twint_payments - Allow the merchant to process TWINT payments.
  • us_bank_transfer_payments - Allow the merchant to process US bank transfer payments.
  • zip_payments - Allow the merchant to process Zip payments.