Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.IdealPayments.StatusDetails
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Configuration.Merchant.Capabilities.IdealPayments.StatusDetails{ code: String.t() | nil, resolution: String.t() | nil }
code- Machine-readable code explaining the reason for the Capability to be in its current status. Possible values:determining_status,requirements_past_due,requirements_pending_verification,restricted_other,unsupported_business,unsupported_country,unsupported_entity_type.resolution- Machine-readable code explaining how to make the Capability active. Possible values:contact_stripe,no_resolution,provide_info.