Stripe.Resources.V2.Core.Account.Configuration.Recipient (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.Account.Configuration.Recipient{
  applied: boolean() | nil,
  capabilities:
    Stripe.Resources.V2.Core.Account.Configuration.Recipient.Capabilities.t()
    | nil
}
  • applied - Indicates whether the recipient configuration is active. You can deactivate or reactivate the recipient configuration by updating this property. Deactivating the configuration by setting this value to false unrequest all capabilities within the configuration. It will not delete any of the configuration's other properties.
  • capabilities - Capabilities that have been requested on the Recipient Configuration.