Stripe.Resources.V2.Core.Account.Defaults.Profile (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.Account.Defaults.Profile{
  business_url: String.t() | nil,
  doing_business_as: String.t() | nil,
  product_description: String.t() | nil
}
  • business_url - The business's publicly-available website.
  • doing_business_as - The customer-facing business name.
  • product_description - Internal-only description of the product sold or service provided by the business. It's used by Stripe for risk and underwriting purposes.