Stripe.Resources.V2.Core.Account.FutureRequirements
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.FutureRequirements{ entries: [Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.t()] | nil, minimum_transition_date: String.t() | nil, summary: Stripe.Resources.V2.Core.Account.FutureRequirements.Summary.t() | nil }
entries- A list of requirements for the Account.minimum_transition_date- The time at which the future requirements become effective. Format: date-time.summary- An object containing an overview of requirements for the Account.