Stripe.Resources.V2.Core.Account.FutureRequirements.Entries (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.Account.FutureRequirements.Entries{
  awaiting_action_from: String.t() | nil,
  description: String.t() | nil,
  errors:
    [Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.Errors.t()]
    | nil,
  impact:
    Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.Impact.t() | nil,
  minimum_deadline:
    Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.MinimumDeadline.t()
    | nil,
  reference:
    Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.Reference.t()
    | nil,
  requested_reasons:
    [
      Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.RequestedReasons.t()
    ]
    | nil
}
  • awaiting_action_from - Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can be user or stripe. Possible values: stripe, user.
  • description - Machine-readable string describing the requirement.
  • errors - Descriptions of why the requirement must be collected, or why the collected information isn't satisfactory to Stripe.
  • impact - A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.
  • minimum_deadline - The soonest point when the account will be impacted by not providing the requirement.
  • reference - A reference to the location of the requirement.
  • requested_reasons - A list of reasons why Stripe is collecting the requirement.