Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.Impact.RestrictsCapabilities (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() ::
  %Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.Impact.RestrictsCapabilities{
    capability: String.t() | nil,
    configuration: String.t() | nil,
    deadline:
      Stripe.Resources.V2.Core.Account.FutureRequirements.Entries.Impact.RestrictsCapabilities.Deadline.t()
      | nil
  }
  • capability - The name of the Capability which will be restricted. Possible values: ach_debit_payments, acss_debit_payments, affirm_payments, afterpay_clearpay_payments, alma_payments, amazon_pay_payments, automatic_indirect_tax, au_becs_debit_payments, bacs_debit_payments, bancontact_payments, bank_accounts.local, bank_accounts.wire, blik_payments, boleto_payments, cards, card_payments, cartes_bancaires_payments, cashapp_payments, eps_payments, fpx_payments, gb_bank_transfer_payments, grabpay_payments, ideal_payments, jcb_payments, jp_bank_transfer_payments, kakao_pay_payments, klarna_payments, konbini_payments, kr_card_payments, link_payments, mobilepay_payments, multibanco_payments, mx_bank_transfer_payments, naver_pay_payments, oxxo_payments, p24_payments, payco_payments, paynow_payments, pay_by_bank_payments, promptpay_payments, revolut_pay_payments, samsung_pay_payments, sepa_bank_transfer_payments, sepa_debit_payments, stripe_balance.payouts, stripe_balance.stripe_transfers, swish_payments, twint_payments, us_bank_transfer_payments, zip_payments.
  • configuration - The configuration which specifies the Capability which will be restricted. Possible values: customer, merchant, recipient.
  • deadline - Details about when in the account lifecycle the requirement must be collected by the avoid the Capability restriction.