Stripe.Resources.V2.Core.Account.Identity.Attestations.PersonsProvided (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.Account.Identity.Attestations.PersonsProvided{
  directors: boolean() | nil,
  executives: boolean() | nil,
  owners: boolean() | nil,
  ownership_exemption_reason: String.t() | nil
}
  • directors - Whether the company’s directors have been provided. Set this Boolean to true after creating all the company’s directors with the Persons API.
  • executives - Whether the company’s executives have been provided. Set this Boolean to true after creating all the company’s executives with the Persons API.
  • owners - Whether the company’s owners have been provided. Set this Boolean to true after creating all the company’s owners with the Persons API.
  • ownership_exemption_reason - Reason for why the company is exempt from providing ownership information. Possible values: qualified_entity_exceeds_ownership_threshold, qualifies_as_financial_institution.