Stripe.Resources.V2.Core.Account.Identity.Individual
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Identity.Individual{ account: String.t() | nil, additional_addresses: [ Stripe.Resources.V2.Core.Account.Identity.Individual.AdditionalAddresses.t() ] | nil, additional_names: [Stripe.Resources.V2.Core.Account.Identity.Individual.AdditionalNames.t()] | nil, additional_terms_of_service: Stripe.Resources.V2.Core.Account.Identity.Individual.AdditionalTermsOfService.t() | nil, address: Stripe.Resources.V2.Core.Account.Identity.Individual.Address.t() | nil, created: String.t() | nil, date_of_birth: Stripe.Resources.V2.Core.Account.Identity.Individual.DateOfBirth.t() | nil, documents: Stripe.Resources.V2.Core.Account.Identity.Individual.Documents.t() | nil, email: String.t() | nil, given_name: String.t() | nil, id: String.t() | nil, id_numbers: [Stripe.Resources.V2.Core.Account.Identity.Individual.IdNumbers.t()] | nil, legal_gender: String.t() | nil, metadata: %{required(String.t()) => String.t()} | nil, nationalities: [String.t()] | nil, object: String.t() | nil, phone: String.t() | nil, political_exposure: String.t() | nil, relationship: Stripe.Resources.V2.Core.Account.Identity.Individual.Relationship.t() | nil, script_addresses: Stripe.Resources.V2.Core.Account.Identity.Individual.ScriptAddresses.t() | nil, script_names: Stripe.Resources.V2.Core.Account.Identity.Individual.ScriptNames.t() | nil, surname: String.t() | nil, updated: String.t() | nil }
account- The account ID which the individual belongs to.additional_addresses- Additional addresses associated with the individual.additional_names- Additional names (e.g. aliases) associated with the individual.additional_terms_of_service- Terms of service acceptances.address- The individual's residential address.created- Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z. Format: date-time.date_of_birth- The individual's date of birth.documents- Documents that may be submitted to satisfy various informational requests.email- The individual's email address.given_name- The individual's first name.id- Unique identifier for the object.id_numbers- The identification numbers (e.g., SSN) associated with the individual.legal_gender- The individual's gender (International regulations require either "male” or "female"). Possible values:female,male.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.nationalities- The countries where the individual is a national. Two-letter country code (ISO 3166-1 alpha-2).object- String representing the object's type. Objects of the same type share the same value.phone- The individual's phone number.political_exposure- Indicates if the individual or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction. Possible values:existing,none.relationship- The relationship that this individual has with the Account's identity.script_addresses- The script addresses (e.g., non-Latin characters) associated with the individual.script_names- The script names (e.g. non-Latin characters) associated with the individual.surname- The individual's last name.updated- Time at which the object was last updated. Format: date-time.