Stripe.Resources.V2.Core.Account.Identity.Individual.Relationship
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Identity.Individual.Relationship{ authorizer: boolean() | nil, director: boolean() | nil, executive: boolean() | nil, legal_guardian: boolean() | nil, owner: boolean() | nil, percent_ownership: String.t() | nil, representative: boolean() | nil, title: String.t() | nil }
authorizer- Whether the individual is an authorizer of the Account's identity.director- Whether the individual is a director of the Account's identity. Directors are typically members of the governing board of the company or are responsible for making sure that the company meets its regulatory obligations.executive- Whether the individual has significant responsibility to control, manage, or direct the organization.legal_guardian- Whether the individual is the legal guardian of the Account's representative.owner- Whether the individual is an owner of the Account's identity.percent_ownership- The percentage of the Account's identity that the individual owns. Format: decimal string.representative- Whether the individual is authorized as the primary representative of the Account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.title- The individual's title (e.g., CEO, Support Engineer).