Stripe.Resources.V2.Core.Account.Requirements.Entries
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Requirements.Entries{ awaiting_action_from: String.t() | nil, description: String.t() | nil, errors: [Stripe.Resources.V2.Core.Account.Requirements.Entries.Errors.t()] | nil, impact: Stripe.Resources.V2.Core.Account.Requirements.Entries.Impact.t() | nil, minimum_deadline: Stripe.Resources.V2.Core.Account.Requirements.Entries.MinimumDeadline.t() | nil, reference: Stripe.Resources.V2.Core.Account.Requirements.Entries.Reference.t() | nil, requested_reasons: [Stripe.Resources.V2.Core.Account.Requirements.Entries.RequestedReasons.t()] | nil }
awaiting_action_from- Indicates whether the platform or Stripe is currently responsible for taking action on the requirement. Value can beuserorstripe. Possible values:stripe,user.description- Machine-readable string describing the requirement.errors- Descriptions of why the requirement must be collected, or why the collected information isn't satisfactory to Stripe.impact- A hash describing the impact of not collecting the requirement, or Stripe not being able to verify the collected information.minimum_deadline- The soonest point when the account will be impacted by not providing the requirement.reference- A reference to the location of the requirement.requested_reasons- A list of reasons why Stripe is collecting the requirement.