Stripe.Resources.V2.Core.Account.Requirements.Entries.Reference (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.Account.Requirements.Entries.Reference{
  inquiry: String.t() | nil,
  resource: String.t() | nil,
  type: String.t() | nil
}
  • inquiry - If inquiry is the type, the inquiry token.
  • resource - If resource is the type, the resource token.
  • type - The type of the reference. If the type is "inquiry", the inquiry token can be found in the "inquiry" field. Otherwise the type is an API resource, the token for which can be found in the "resource" field. Possible values: inquiry, payment_method, person.