Stripe.Resources.V2.Core.AccountLink.UseCase (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.AccountLink.UseCase{
  account_onboarding:
    Stripe.Resources.V2.Core.AccountLink.UseCase.AccountOnboarding.t() | nil,
  account_update:
    Stripe.Resources.V2.Core.AccountLink.UseCase.AccountUpdate.t() | nil,
  type: String.t() | nil
}
  • account_onboarding - Hash containing configuration options for an Account Link object that onboards a new account.
  • account_update - Hash containing configuration options for an Account Link that updates an existing account.
  • type - Open Enum. The type of Account Link the user is requesting. Possible values: account_onboarding, account_update.