Stripe.Resources.V2.Core.AccountLink.UseCase.AccountOnboarding (tiger_stripe v0.1.10)

Copy Markdown View Source

Nested struct within the parent resource.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.AccountLink.UseCase.AccountOnboarding{
  collection_options:
    Stripe.Resources.V2.Core.AccountLink.UseCase.AccountOnboarding.CollectionOptions.t()
    | nil,
  configurations: [String.t()] | nil,
  refresh_url: String.t() | nil,
  return_url: String.t() | nil
}
  • collection_options - Specifies the requirements that Stripe collects from v2/core/accounts in the Onboarding flow.
  • configurations - Open Enum. A v2/core/account can be configured to enable certain functionality. The configuration param targets the v2/core/account_link to collect information for the specified v2/core/account configuration/s.
  • refresh_url - The URL the user will be redirected to if the AccountLink is expired, has been used, or is otherwise invalid. The URL you specify should attempt to generate a new AccountLink with the same parameters used to create the original AccountLink, then redirect the user to the new AccountLink’s URL so they can continue the flow. If a new AccountLink cannot be generated or the redirect fails you should display a useful error to the user. Please make sure to implement authentication before redirecting the user in case this URL is leaked to a third party.
  • return_url - The URL that the user will be redirected to upon completing the linked flow.