Stripe.Resources.V2.Core.EventDestination (tiger_stripe v0.1.10)

Copy Markdown View Source

Event Destination

Set up an event destination to receive events from Stripe across multiple destination types, including webhook endpoints and Amazon EventBridge. Event destinations support receiving thin events and snapshot events.

Summary

Types

t()

@type t() :: %Stripe.Resources.V2.Core.EventDestination{
  amazon_eventbridge:
    Stripe.Resources.V2.Core.EventDestination.AmazonEventbridge.t() | nil,
  created: String.t(),
  description: String.t(),
  enabled_events: [String.t()],
  event_payload: String.t(),
  events_from: [String.t()] | nil,
  id: String.t(),
  livemode: boolean(),
  metadata: %{required(String.t()) => String.t()} | nil,
  name: String.t(),
  object: String.t(),
  snapshot_api_version: String.t() | nil,
  status: String.t(),
  status_details:
    Stripe.Resources.V2.Core.EventDestination.StatusDetails.t() | nil,
  type: String.t(),
  updated: String.t(),
  webhook_endpoint:
    Stripe.Resources.V2.Core.EventDestination.WebhookEndpoint.t() | nil
}
  • amazon_eventbridge - Amazon EventBridge configuration.
  • created - Time at which the object was created. Format: date-time.
  • description - An optional description of what the event destination is used for.
  • enabled_events - The list of events to enable for this endpoint.
  • event_payload - Payload type of events being subscribed to. Possible values: snapshot, thin.
  • events_from - Where events should be routed from.
  • id - Unique identifier for the object.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Metadata.
  • name - Event destination name.
  • object - String representing the object's type. Objects of the same type share the same value of the object field. Possible values: v2.core.event_destination.
  • snapshot_api_version - If using the snapshot event payload, the API version events are rendered as.
  • status - Status. It can be set to either enabled or disabled. Possible values: disabled, enabled.
  • status_details - Additional information about event destination status.
  • type - Event destination type. Possible values: amazon_eventbridge, webhook_endpoint.
  • updated - Time at which the object was last updated. Format: date-time.
  • webhook_endpoint - Webhook endpoint configuration.

Functions

object_name()