Stripe.SearchResult (tiger_stripe v0.1.10)

Copy Markdown View Source

Represents a V1 search result response (object: "search_result").

Auto-paging

{:ok, page} = Stripe.Client.request(client, :get, "/v1/charges/search",
  params: %{"query" => "status:'succeeded'"})

page
|> Stripe.SearchResult.auto_paging_stream(client)
|> Enum.to_list()

Summary

Functions

Returns a lazy Stream that yields every item across all search result pages.

Types

t()

@type t() :: %Stripe.SearchResult{
  data: [struct() | map()] | nil,
  has_more: boolean() | nil,
  next_page: String.t() | nil,
  object: String.t() | nil,
  total_count: integer() | nil,
  url: String.t() | nil
}

Functions

auto_paging_stream(page, client, opts \\ [])

@spec auto_paging_stream(t(), Stripe.Client.t(), keyword()) :: Enumerable.t()

Returns a lazy Stream that yields every item across all search result pages.

Uses page token pagination (the next_page field from each response).