Stripe.Services.AccountPersonService (tiger_stripe v0.1.10)

Copy Markdown View Source

AccountPerson API operations.

Summary

Functions

create(client, account, params \\ %{}, opts \\ [])

@spec create(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create a person

Creates a new person.

delete(client, account, person, params \\ %{}, opts \\ [])

@spec delete(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Delete a person

Deletes an existing person’s relationship to the account’s legal entity. Any person with a relationship for an account can be deleted through the API, except if the person is the account_opener. If your integration is using the executive parameter, you cannot delete the only verified executive on file.

list(client, account, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List all persons

Returns a list of people associated with the account’s legal entity. The people are returned sorted by creation date, with the most recent people appearing first.

retrieve(client, account, person, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a person

Retrieves an existing person.

update(client, account, person, params \\ %{}, opts \\ [])

@spec update(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Update a person

Updates an existing person.