Stripe.Services.Billing.MeterEventSummaryService (tiger_stripe v0.1.10)

Copy Markdown View Source

BillingMeterEventSummary

A billing meter event summary represents an aggregated view of a customer's billing meter events within a specified timeframe. It indicates how much usage was accrued by a customer for that period.

Note: Meters events are aggregated asynchronously so the meter event summaries provide an eventually consistent view of the reported usage.

Summary

Functions

List billing meter event summaries

Functions

list(client, id, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List billing meter event summaries

Retrieve a list of billing meter event summaries.