Stripe.Services.BillingPortal.ConfigurationService (tiger_stripe v0.1.10)

Copy Markdown View Source

PortalConfiguration

A portal configuration describes the functionality and behavior you embed in a portal session. Related guide: Configure the customer portal.

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create a portal configuration

Creates a configuration that describes the functionality and behavior of a PortalSession

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List portal configurations

Returns a list of configurations that describe the functionality of the customer portal.

retrieve(client, configuration, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a portal configuration

Retrieves a configuration that describes the functionality of the customer portal.

update(client, configuration, params \\ %{}, opts \\ [])

@spec update(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Update a portal configuration

Updates a configuration that describes the functionality of the customer portal.