Stripe.Services.Checkout.SessionLineItemService (tiger_stripe v0.1.10)

Copy Markdown View Source

SessionLineItem API operations.

Summary

Functions

list_line_items(client, session, params \\ %{}, opts \\ [])

@spec list_line_items(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a Checkout Session's line items

When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.