Stripe.Services.Climate.ProductService (tiger_stripe v0.1.10)

Copy Markdown View Source

ClimateRemovalsProducts

A Climate product represents a type of carbon removal unit available for reservation. You can retrieve it to see the current price and availability.

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List products

Lists all available Climate product objects.

retrieve(client, product, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a product

Retrieves the details of a Climate product with the given ID.