Stripe.Services.ConfirmationTokenService (tiger_stripe v0.1.10)

Copy Markdown View Source

ConfirmationTokensResourceConfirmationToken

ConfirmationTokens help transport client side data collected by Stripe JS over to your server for confirming a PaymentIntent or SetupIntent. If the confirmation is successful, values present on the ConfirmationToken are written onto the Intent.

To learn more about how to use ConfirmationToken, visit the related guides:

Summary

Functions

retrieve(client, confirmation_token, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a ConfirmationToken

Retrieves an existing ConfirmationToken object