Stripe.Services.CountrySpecService (tiger_stripe v0.1.10)

Copy Markdown View Source

CountrySpec

Stripe needs to collect certain pieces of information about each account created. These requirements can differ depending on the account's country. The Country Specs API makes these rules available to your integration.

You can also view the information from this API call as an online guide.

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List Country Specs

Lists all Country Spec objects available in the API.

retrieve(client, country, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a Country Spec

Returns a Country Spec for a given Country code.