CustomerPaymentSource API operations.
Summary
Functions
Create a card
Delete a customer source
List sources for a specified customer.
Retrieve a specified source for a given customer.
Update a specified source for a given customer.
Verify a bank account
Functions
@spec create(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create a card
When you create a new credit card, you must specify a customer or recipient on which to create it.
If the card’s owner has no default card, then the new card will become the default.
However, if the owner already has a default, then it will not change.
To change the default, you should update the customer to have a new default_source.
@spec delete(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Delete a customer source
Delete a specified source for a given customer.
@spec list(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List sources for a specified customer.
@spec retrieve(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve a specified source for a given customer.
@spec update(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Update a specified source for a given customer.
@spec verify(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Verify a bank account
Verify a specified bank account for a given customer.