Stripe.Services.Entitlements.ActiveEntitlementService
(tiger_stripe v0.1.10)
ActiveEntitlement
An active entitlement describes access to a feature for a customer.
Summary
Functions
@spec list(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List all active entitlements
Retrieve a list of active entitlements for a customer
@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve an active entitlement
Retrieve an active entitlement