Stripe.Services.Issuing.PhysicalBundleService (tiger_stripe v0.1.10)

Copy Markdown View Source

IssuingPhysicalBundle

A Physical Bundle represents the bundle of physical items - card stock, carrier letter, and envelope - that is shipped to a cardholder when you create a physical card.

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List all physical bundles

Returns a list of physical bundle objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.

retrieve(client, physical_bundle, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a physical bundle

Retrieves a physical bundle object.