Stripe.Services.MandateService (tiger_stripe v0.1.10)

Copy Markdown View Source

Mandate

A Mandate is a record of the permission that your customer gives you to debit their payment method.

Summary

Functions

retrieve(client, mandate, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a Mandate

Retrieves a Mandate object.