Stripe.Services.PaymentAttemptRecordService (tiger_stripe v0.1.10)

Copy Markdown View Source

PaymentAttemptRecord

A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.

Summary

Functions

List Payment Attempt Records

Retrieve a Payment Attempt Record

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List Payment Attempt Records

List all the Payment Attempt Records attached to the specified Payment Record.

retrieve(client, id, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a Payment Attempt Record

Retrieves a Payment Attempt Record with the given ID