Stripe.Services.ProductFeatureService (tiger_stripe v0.1.10)

Copy Markdown View Source

ProductFeature

A product_feature represents an attachment between a feature and a product. When a product is purchased that has a feature attached, Stripe will create an entitlement to the feature for the purchasing customer.

Summary

Functions

create(client, product, params \\ %{}, opts \\ [])

@spec create(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Attach a feature to a product

Creates a product_feature, which represents a feature attachment to a product

delete(client, product, id, params \\ %{}, opts \\ [])

@spec delete(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Remove a feature from a product

Deletes the feature attachment to a product

list(client, product, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List all features attached to a product

Retrieve a list of features for a product

retrieve(client, product, id, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a product_feature

Retrieves a product_feature, which represents a feature attachment to a product