Stripe.Services.QuoteLineItemService (tiger_stripe v0.1.10)

Copy Markdown View Source

QuoteLineItem API operations.

Summary

Functions

list_line_items(client, quote, params \\ %{}, opts \\ [])

@spec list_line_items(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a quote's line items

When retrieving a quote, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.