Stripe.Services.QuoteService (tiger_stripe v0.1.10)

Copy Markdown View Source

Quote

A Quote is a way to model prices that you'd like to provide to a customer. Once accepted, it will automatically create an invoice, subscription or subscription schedule.

Summary

Functions

accept(client, quote, params \\ %{}, opts \\ [])

@spec accept(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Accept a quote

Accepts the specified quote.

cancel(client, quote, params \\ %{}, opts \\ [])

@spec cancel(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Cancel a quote

Cancels the quote.

create(client, params \\ %{}, opts \\ [])

@spec create(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create a quote

A quote models prices and services for a customer. Default options for header, description, footer, and expires_at can be set in the dashboard via the quote template.

finalize_quote(client, quote, params \\ %{}, opts \\ [])

@spec finalize_quote(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Finalize a quote

Finalizes the quote.

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List all quotes

Returns a list of your quotes.

pdf(client, quote, params \\ %{}, opts \\ [])

@spec pdf(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Download quote PDF

Download the PDF for a finalized quote. Explanation for special handling can be found here

retrieve(client, quote, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a quote

Retrieves the quote with the given ID.

update(client, quote, params \\ %{}, opts \\ [])

@spec update(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Update a quote

A quote models prices and services for a customer.