Stripe.Services.Radar.EarlyFraudWarningService (tiger_stripe v0.1.10)

Copy Markdown View Source

RadarEarlyFraudWarning

An early fraud warning indicates that the card issuer has notified us that a charge may be fraudulent.

Related guide: Early fraud warnings

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List all early fraud warnings

Returns a list of early fraud warnings.

retrieve(client, early_fraud_warning, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve an early fraud warning

Retrieves the details of an early fraud warning that has previously been created.

Please refer to the early fraud warning object reference for more details.