Stripe.Services.SourceTransactionService (tiger_stripe v0.1.10)

Copy Markdown View Source

SourceTransaction

Some payment methods have no required amount that a customer must send. Customers can be instructed to send any amount, and it can be made up of multiple transactions. As such, sources can have multiple associated transactions.

Summary

Functions

List source transactions for a given source.

Functions

source_transactions(client, source, params \\ %{}, opts \\ [])

@spec source_transactions(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List source transactions for a given source.