Stripe.Services.Terminal.LocationService (tiger_stripe v0.1.10)

Copy Markdown View Source

TerminalLocationLocation

A Location represents a grouping of readers.

Related guide: Fleet management

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create a Location

Creates a new Location object. For further details, including which address fields are required in each country, see the Manage locations guide.

delete(client, location, params \\ %{}, opts \\ [])

@spec delete(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Delete a Location

Deletes a Location object.

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List all Locations

Returns a list of Location objects.

retrieve(client, location, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a Location

Retrieves a Location object.

update(client, location, params \\ %{}, opts \\ [])

@spec update(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Update a Location

Updates a Location object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.