Stripe.Services.Terminal.ReaderService (tiger_stripe v0.1.10)

Copy Markdown View Source

TerminalReaderReader

A Reader represents a physical device for accepting payment details.

Related guide: Connecting to a reader

Summary

Functions

cancel_action(client, reader, params \\ %{}, opts \\ [])

@spec cancel_action(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Cancel the current reader action

Cancels the current reader action. See Programmatic Cancellation for more details.

collect_inputs(client, reader, params \\ %{}, opts \\ [])

@spec collect_inputs(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Collect inputs using a Reader

Initiates an input collection flow on a Reader to display input forms and collect information from your customers.

collect_payment_method(client, reader, params \\ %{}, opts \\ [])

@spec collect_payment_method(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Hand off a PaymentIntent to a Reader and collect card details

Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation. See Collecting a Payment method for more details.

confirm_payment_intent(client, reader, params \\ %{}, opts \\ [])

@spec confirm_payment_intent(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Confirm a PaymentIntent on the Reader

Finalizes a payment on a Reader. See Confirming a Payment for more details.

create(client, params \\ %{}, opts \\ [])

@spec create(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create a Reader

Creates a new Reader object.

delete(client, reader, params \\ %{}, opts \\ [])

@spec delete(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Delete a Reader

Deletes a Reader object.

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List all Readers

Returns a list of Reader objects.

process_payment_intent(client, reader, params \\ %{}, opts \\ [])

@spec process_payment_intent(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Hand-off a PaymentIntent to a Reader

Initiates a payment flow on a Reader. See process the payment for more details.

process_setup_intent(client, reader, params \\ %{}, opts \\ [])

@spec process_setup_intent(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Hand-off a SetupIntent to a Reader

Initiates a SetupIntent flow on a Reader. See Save directly without charging for more details.

refund_payment(client, reader, params \\ %{}, opts \\ [])

@spec refund_payment(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Refund a Charge or a PaymentIntent in-person

Initiates an in-person refund on a Reader. See Refund an Interac Payment for more details.

retrieve(client, reader, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve a Reader

Retrieves a Reader object.

set_reader_display(client, reader, params \\ %{}, opts \\ [])

@spec set_reader_display(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Set reader display

Sets the reader display to show cart details.

update(client, reader, params \\ %{}, opts \\ [])

@spec update(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Update a Reader

Updates a Reader object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.