Stripe.Services.TestHelpers.Issuing.PersonalizationDesignService
(tiger_stripe v0.1.10)
PersonalizationDesign API operations.
Summary
Functions
Activate a testmode personalization design
Deactivate a testmode personalization design
Reject a testmode personalization design
Functions
@spec activate(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Activate a testmode personalization design
Updates the status of the specified testmode personalization design object to active.
@spec deactivate(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Deactivate a testmode personalization design
Updates the status of the specified testmode personalization design object to inactive.
@spec reject(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Reject a testmode personalization design
Updates the status of the specified testmode personalization design object to rejected.