Stripe.Services.TestHelpers.Issuing.TransactionService (tiger_stripe v0.1.10)

Copy Markdown View Source

Transaction API operations.

Summary

Functions

create_force_capture(client, params \\ %{}, opts \\ [])

@spec create_force_capture(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create a test-mode force capture

Allows the user to capture an arbitrary amount, also known as a forced capture.

create_unlinked_refund(client, params \\ %{}, opts \\ [])

@spec create_unlinked_refund(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create a test-mode unlinked refund

Allows the user to refund an arbitrary amount, also known as a unlinked refund.

refund(client, transaction, params \\ %{}, opts \\ [])

@spec refund(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Refund a test-mode transaction

Refund a test-mode Transaction.