Stripe.Services.Treasury.FinancialAccountFeaturesService
(tiger_stripe v0.1.10)
TreasuryFinancialAccountsResourceFinancialAccountFeatures
Encodes whether a FinancialAccount has access to a particular Feature, with a status enum and associated status_details.
Stripe or the platform can control Features via the requested field.
Summary
Functions
@spec retrieve_features(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve FinancialAccount Features
Retrieves Features information associated with the FinancialAccount.
@spec update_features(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Update FinancialAccount Features
Updates the Features associated with a FinancialAccount.