Person API operations.
Summary
Functions
@spec create(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create a person
Create a Person. Adds an individual to an Account's identity. You can set relationship attributes and identity information at creation.
@spec delete(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Delete a person
Delete a Person associated with an Account.
@spec list(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List persons
Returns a paginated list of Persons associated with an Account.
@spec retrieve(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve a person
Retrieves a Person associated with an Account.
@spec update(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Update a person
Updates a Person associated with an Account.