Stripe.Services.V2.Core.EventDestinationService (tiger_stripe v0.1.10)

Copy Markdown View Source

Event Destination

Set up an event destination to receive events from Stripe across multiple destination types, including webhook endpoints and Amazon EventBridge. Event destinations support receiving thin events and snapshot events.

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Create an Event Destination

Create a new event destination.

delete(client, id, params \\ %{}, opts \\ [])

@spec delete(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Delete an Event Destination

Delete an event destination.

disable(client, id, params \\ %{}, opts \\ [])

@spec disable(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Disable an Event Destination

Disable an event destination.

enable(client, id, params \\ %{}, opts \\ [])

@spec enable(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Enable an Event Destination

Enable an event destination.

list(client, params \\ %{}, opts \\ [])

@spec list(Stripe.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

List Event Destinations

Lists all event destinations.

ping(client, id, params \\ %{}, opts \\ [])

@spec ping(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Ping an event destination

Send a ping event to an event destination.

retrieve(client, id, params \\ %{}, opts \\ [])

@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Retrieve an Event Destination

Retrieves the details of an event destination.

update(client, id, params \\ %{}, opts \\ [])

@spec update(Stripe.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, Stripe.Error.t()}

Update an Event Destination

Update the details of an event destination.