StripeElixir.Params.AccountCreateParams.Documents (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.AccountCreateParams.Documents{
  bank_account_ownership_verification: map() | nil,
  company_license: map() | nil,
  company_memorandum_of_association: map() | nil,
  company_ministerial_decree: map() | nil,
  company_registration_verification: map() | nil,
  company_tax_id_verification: map() | nil,
  proof_of_address: map() | nil,
  proof_of_registration: map() | nil,
  proof_of_ultimate_beneficial_ownership: map() | nil
}
  • bank_account_ownership_verification - One or more documents that support the Bank account ownership verification requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
  • company_license - One or more documents that demonstrate proof of a company's license to operate.
  • company_memorandum_of_association - One or more documents showing the company's Memorandum of Association.
  • company_ministerial_decree - (Certain countries only) One or more documents showing the ministerial decree legalizing the company's establishment.
  • company_registration_verification - One or more documents that demonstrate proof of a company's registration with the appropriate local authorities.
  • company_tax_id_verification - One or more documents that demonstrate proof of a company's tax ID.
  • proof_of_address - One or more documents that demonstrate proof of address.
  • proof_of_registration - One or more documents showing the company’s proof of registration with the national business registry.
  • proof_of_ultimate_beneficial_ownership - One or more documents that demonstrate proof of ultimate beneficial ownership.