StripeElixir.Params.AccountCreateParams.Settings (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.AccountCreateParams.Settings{
  bacs_debit_payments: map() | nil,
  branding: map() | nil,
  card_issuing: map() | nil,
  card_payments: map() | nil,
  invoices: map() | nil,
  payments: map() | nil,
  payouts: map() | nil,
  treasury: map() | nil
}
  • bacs_debit_payments - Settings specific to Bacs Direct Debit.
  • branding - Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
  • card_issuing - Settings specific to the account's use of the Card Issuing product.
  • card_payments - Settings specific to card charging on the account.
  • invoices - Settings specific to the account’s use of Invoices.
  • payments - Settings that apply across payment methods for charging on the account.
  • payouts - Settings specific to the account's payouts.
  • treasury - Settings specific to the account's Treasury FinancialAccounts.