StripeElixir.Params.ApplicationFeeRefundCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for application fee refund create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.ApplicationFeeRefundCreateParams{
  amount: integer() | nil,
  expand: [String.t()] | nil,
  metadata: map() | nil
}
  • amount - A positive integer, in cents (or local equivalent), representing how much of this fee to refund. Can refund only up to the remaining unrefunded amount of the fee.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.