Parameters for secret delete where.
Summary
Types
@type t() :: %StripeElixir.Params.Apps.SecretDeleteWhereParams{ expand: [String.t()] | nil, name: String.t(), scope: map() }
expand- Specifies which fields in the response should be expanded.name- A name for the secret that's unique within the scope. Max length: 5000.scope- Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.