StripeElixir.Params.Billing.MeterCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for meter create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Billing.MeterCreateParams{
  customer_mapping: map() | nil,
  default_aggregation: map(),
  display_name: String.t(),
  event_name: String.t(),
  event_time_window: String.t() | nil,
  expand: [String.t()] | nil,
  value_settings: map() | nil
}
  • customer_mapping - Fields that specify how to map a meter event to a customer.
  • default_aggregation - The default settings to aggregate a meter's events with.
  • display_name - The meter’s name. Not visible to the customer. Max length: 250.
  • event_name - The name of the meter event to record usage for. Corresponds with the event_name field on meter events. Max length: 100.
  • event_time_window - The time window which meter events have been pre-aggregated for, if any. Possible values: day, hour.
  • expand - Specifies which fields in the response should be expanded.
  • value_settings - Fields that specify how to calculate a meter event's value.