StripeElixir.Params.Billing.MeterCreateParams.ValueSettings (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Billing.MeterCreateParams.ValueSettings{
  event_payload_key: String.t() | nil
}
  • event_payload_key - The key in the usage event payload to use as the value for this meter. For example, if the event payload contains usage on a bytes_used field, then set the event_payload_key to "bytes_used". Max length: 100.