StripeElixir.Params.BillingPortal.ConfigurationUpdateParams.Features (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.BillingPortal.ConfigurationUpdateParams.Features{
  customer_update: map() | nil,
  invoice_history: map() | nil,
  payment_method_update: map() | nil,
  subscription_cancel: map() | nil,
  subscription_update: map() | nil
}
  • customer_update - Information about updating the customer details in the portal.
  • invoice_history - Information about showing the billing history in the portal.
  • payment_method_update - Information about updating payment methods in the portal.
  • subscription_cancel - Information about canceling subscriptions in the portal.
  • subscription_update - Information about updating subscriptions in the portal.