StripeElixir.Params.BillingPortal.SessionCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for session create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.BillingPortal.SessionCreateParams{
  configuration: String.t() | nil,
  customer: String.t() | nil,
  customer_account: String.t() | nil,
  expand: [String.t()] | nil,
  flow_data: map() | nil,
  locale: String.t() | nil,
  on_behalf_of: String.t() | nil,
  return_url: String.t() | nil
}
  • configuration - The ID of an existing configuration to use for this session, describing its functionality and features. If not specified, the session uses the default configuration. Max length: 5000.
  • customer - The ID of an existing customer. Max length: 5000.
  • customer_account - The ID of an existing account. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • flow_data - Information about a specific flow for the customer to go through. See the docs to learn more about using customer portal deep links and flows.
  • locale - The IETF language tag of the locale customer portal is displayed in. If blank or auto, the customer’s preferred_locales or browser’s locale is used. Possible values: auto, bg, cs, da, de, el, en, en-AU, en-CA, en-GB, en-IE, en-IN, en-NZ, en-SG, es, es-419, et, fi, fil, fr, fr-CA, hr, hu, id, it, ja, ko, lt, lv, ms, mt, nb, nl, pl, pt, pt-BR, ro, ru, sk, sl, sv, th, tr, vi, zh, zh-HK, zh-TW.
  • on_behalf_of - The on_behalf_of account to use for this session. When specified, only subscriptions and invoices with this on_behalf_of account appear in the portal. For more information, see the docs. Use the Accounts API to modify the on_behalf_of account's branding settings, which the portal displays.
  • return_url - The default URL to redirect customers to when they click on the portal's link to return to your website.