Parameters for charge list.
Summary
Types
@type t() :: %StripeElixir.Params.ChargeListParams{ created: map() | nil, customer: String.t() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, payment_intent: String.t() | nil, starting_after: String.t() | nil, transfer_group: String.t() | nil }
created- Only return charges that were created during the given date interval.customer- Only return charges for the customer specified by this customer ID. Max length: 5000.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.payment_intent- Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID. Max length: 5000.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list.transfer_group- Only return charges for this transfer group, limited to 100. Max length: 5000.