StripeElixir.Params.ChargeSearchParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for charge search.

Summary

Types

t()

@type t() :: %StripeElixir.Params.ChargeSearchParams{
  expand: [String.t()] | nil,
  limit: integer() | nil,
  page: String.t() | nil,
  query: String.t()
}
  • expand - Specifies which fields in the response should be expanded.
  • limit - A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
  • page - A cursor for pagination across multiple pages of results. Don't include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results. Max length: 5000.
  • query - The search query string. See search query language and the list of supported query fields for charges. Max length: 5000.