StripeElixir.Params.Checkout.SessionCreateParams.CustomFields
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.CustomFields{ dropdown: map() | nil, key: String.t() | nil, label: map() | nil, numeric: map() | nil, optional: boolean() | nil, text: map() | nil, type: String.t() | nil }
dropdown- Configuration fortype=dropdownfields.key- String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters. Max length: 200.label- The label for the field, displayed to the customer.numeric- Configuration fortype=numericfields.optional- Whether the customer is required to complete the field before completing the Checkout Session. Defaults tofalse.text- Configuration fortype=textfields.type- The type of the field. Possible values:dropdown,numeric,text.