StripeElixir.Params.Checkout.SessionCreateParams.OptionalItems
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.OptionalItems{ adjustable_quantity: map() | nil, price: String.t() | nil, quantity: integer() | nil }
adjustable_quantity- When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.price- The ID of the Price or Plan object. Max length: 5000.quantity- The initial quantity of the line item created when a customer chooses to add this optional item to their order.