StripeElixir.Params.Checkout.SessionCreateParams.PaymentMethodData (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.PaymentMethodData{
  allow_redisplay: String.t() | nil
}
  • allow_redisplay - Allow redisplay will be set on the payment method on confirmation and indicates whether this payment method can be shown again to the customer in a checkout flow. Only set this field if you wish to override the allow_redisplay value determined by Checkout. Possible values: always, limited, unspecified.