StripeElixir.Params.Checkout.SessionCreateParams.PaymentMethodOptions (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.PaymentMethodOptions{
  acss_debit: map() | nil,
  affirm: map() | nil,
  afterpay_clearpay: map() | nil,
  alipay: map() | nil,
  alma: map() | nil,
  amazon_pay: map() | nil,
  au_becs_debit: map() | nil,
  bacs_debit: map() | nil,
  bancontact: map() | nil,
  billie: map() | nil,
  boleto: map() | nil,
  card: map() | nil,
  cashapp: map() | nil,
  customer_balance: map() | nil,
  demo_pay: map() | nil,
  eps: map() | nil,
  fpx: map() | nil,
  giropay: map() | nil,
  grabpay: map() | nil,
  ideal: map() | nil,
  kakao_pay: map() | nil,
  klarna: map() | nil,
  konbini: map() | nil,
  kr_card: map() | nil,
  link: map() | nil,
  mobilepay: map() | nil,
  multibanco: map() | nil,
  naver_pay: map() | nil,
  oxxo: map() | nil,
  p24: map() | nil,
  pay_by_bank: map() | nil,
  payco: map() | nil,
  paynow: map() | nil,
  paypal: map() | nil,
  payto: map() | nil,
  pix: map() | nil,
  revolut_pay: map() | nil,
  samsung_pay: map() | nil,
  satispay: map() | nil,
  sepa_debit: map() | nil,
  sofort: map() | nil,
  swish: map() | nil,
  twint: map() | nil,
  us_bank_account: map() | nil,
  wechat_pay: map() | nil
}
  • acss_debit - contains details about the ACSS Debit payment method options. You can't set this parameter if ui_mode is custom.
  • affirm - contains details about the Affirm payment method options.
  • afterpay_clearpay - contains details about the Afterpay Clearpay payment method options.
  • alipay - contains details about the Alipay payment method options.
  • alma - contains details about the Alma payment method options.
  • amazon_pay - contains details about the AmazonPay payment method options.
  • au_becs_debit - contains details about the AU Becs Debit payment method options.
  • bacs_debit - contains details about the Bacs Debit payment method options.
  • bancontact - contains details about the Bancontact payment method options.
  • billie - contains details about the Billie payment method options.
  • boleto - contains details about the Boleto payment method options.
  • card - contains details about the Card payment method options.
  • cashapp - contains details about the Cashapp Pay payment method options.
  • customer_balance - contains details about the Customer Balance payment method options.
  • demo_pay - contains details about the DemoPay payment method options.
  • eps - contains details about the EPS payment method options.
  • fpx - contains details about the FPX payment method options.
  • giropay - contains details about the Giropay payment method options.
  • grabpay - contains details about the Grabpay payment method options.
  • ideal - contains details about the Ideal payment method options.
  • kakao_pay - contains details about the Kakao Pay payment method options.
  • klarna - contains details about the Klarna payment method options.
  • konbini - contains details about the Konbini payment method options.
  • kr_card - contains details about the Korean card payment method options.
  • link - contains details about the Link payment method options.
  • mobilepay - contains details about the Mobilepay payment method options.
  • multibanco - contains details about the Multibanco payment method options.
  • naver_pay - contains details about the Naver Pay payment method options.
  • oxxo - contains details about the OXXO payment method options.
  • p24 - contains details about the P24 payment method options.
  • pay_by_bank - contains details about the Pay By Bank payment method options.
  • payco - contains details about the PAYCO payment method options.
  • paynow - contains details about the PayNow payment method options.
  • paypal - contains details about the PayPal payment method options.
  • payto - contains details about the PayTo payment method options.
  • pix - contains details about the Pix payment method options.
  • revolut_pay - contains details about the RevolutPay payment method options.
  • samsung_pay - contains details about the Samsung Pay payment method options.
  • satispay - contains details about the Satispay payment method options.
  • sepa_debit - contains details about the Sepa Debit payment method options.
  • sofort - contains details about the Sofort payment method options.
  • swish - contains details about the Swish payment method options.
  • twint - contains details about the TWINT payment method options.
  • us_bank_account - contains details about the Us Bank Account payment method options.
  • wechat_pay - contains details about the WeChat Pay payment method options.