StripeElixir.Params.Checkout.SessionCreateParams.SetupIntentData (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Checkout.SessionCreateParams.SetupIntentData{
  description: String.t() | nil,
  metadata: map() | nil,
  on_behalf_of: String.t() | nil
}
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 1000.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • on_behalf_of - The Stripe account for which the setup is intended.