StripeElixir.Params.Checkout.SessionUpdateParams.LineItems (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Checkout.SessionUpdateParams.LineItems{
  adjustable_quantity: map() | nil,
  id: String.t() | nil,
  metadata: map() | nil,
  price: String.t() | nil,
  price_data: map() | nil,
  quantity: integer() | nil,
  tax_rates: map() | nil
}
  • adjustable_quantity - When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
  • id - ID of an existing line item. Max length: 5000.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • price - The ID of the Price. One of price or price_data is required when creating a new line item. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required when creating a new line item.
  • quantity - The quantity of the line item being purchased. Quantity should not be defined when recurring.usage_type=metered.
  • tax_rates - The tax rates which apply to this line item.