StripeElixir.Params.Climate.OrderUpdateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for order update.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Climate.OrderUpdateParams{
  beneficiary: map() | nil,
  expand: [String.t()] | nil,
  metadata: map() | nil
}
  • beneficiary - Publicly sharable reference for the end beneficiary of carbon removal. Assumed to be the Stripe account if not set.
  • expand - Specifies which fields in the response should be expanded.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.