Parameters for supplier retrieve.
Summary
Types
@type t() :: %StripeElixir.Params.Climate.SupplierRetrieveParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for supplier retrieve.
@type t() :: %StripeElixir.Params.Climate.SupplierRetrieveParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.