StripeElixir.Params.CreditNoteCreateParams.Refunds (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.CreditNoteCreateParams.Refunds{
  amount_refunded: integer() | nil,
  payment_record_refund: map() | nil,
  refund: String.t() | nil,
  type: String.t() | nil
}
  • amount_refunded - Amount of the refund that applies to this credit note, in cents (or local equivalent). Defaults to the entire refund amount.
  • payment_record_refund - The PaymentRecord refund details to link to this credit note. Required when type is payment_record_refund.
  • refund - ID of an existing refund to link this credit note to. Required when type is refund.
  • type - Type of the refund, one of refund or payment_record_refund. Defaults to refund. Possible values: payment_record_refund, refund.