Parameters for credit note update.
Summary
Types
@type t() :: %StripeElixir.Params.CreditNoteUpdateParams{ expand: [String.t()] | nil, memo: String.t() | nil, metadata: map() | nil }
expand- Specifies which fields in the response should be expanded.memo- Credit note memo. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.