StripeElixir.Params.CustomerUpdateParams.Tax (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.CustomerUpdateParams.Tax{
  ip_address: map() | nil,
  validate_location: String.t() | nil
}
  • ip_address - A recent IP address of the customer used for tax reporting and tax location inference. Stripe recommends updating the IP address when a new PaymentMethod is attached or the address field on the customer is updated. We recommend against updating this field more frequently since it could result in unexpected tax location/reporting outcomes.
  • validate_location - A flag that indicates when Stripe should validate the customer tax location. Defaults to auto. Possible values: auto, deferred, immediately.