StripeElixir.Params.ExchangeRateListParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for exchange rate list.

Summary

Types

t()

@type t() :: %StripeElixir.Params.ExchangeRateListParams{
  ending_before: String.t() | nil,
  expand: [String.t()] | nil,
  limit: integer() | nil,
  starting_after: String.t() | nil
}
  • ending_before - A cursor for use in pagination. ending_before is the currency that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with the exchange rate for currency X your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • limit - A limit on the number of objects to be returned. Limit can range between 1 and total number of supported payout currencies, and the default is the max.
  • starting_after - A cursor for use in pagination. starting_after is the currency that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with the exchange rate for currency X, your subsequent call can include starting_after=X in order to fetch the next page of the list. Max length: 5000.