Parameters for file link update.
Summary
Types
@type t() :: %StripeElixir.Params.FileLinkUpdateParams{ expand: [String.t()] | nil, expires_at: map() | nil, metadata: map() | nil }
expand- Specifies which fields in the response should be expanded.expires_at- A future timestamp after which the link will no longer be usable, ornowto expire the link immediately.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.