StripeElixir.Params.FinancialConnections.TransactionListParams.TransactionRefresh (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() ::
  %StripeElixir.Params.FinancialConnections.TransactionListParams.TransactionRefresh{
    after: String.t() | nil
  }
  • after - Return results where the transactions were created or updated by a refresh that took place after this refresh (non-inclusive). Max length: 5000.