StripeElixir.Params.Forwarding.RequestListParams.Created (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Forwarding.RequestListParams.Created{
  gt: integer() | nil,
  gte: integer() | nil,
  lt: integer() | nil,
  lte: integer() | nil
}
  • gt - Return results where the created field is greater than this value.
  • gte - Return results where the created field is greater than or equal to this value.
  • lt - Return results where the created field is less than this value.
  • lte - Return results where the created field is less than or equal to this value.