StripeElixir.Params.InvoiceCreatePreviewParams.ScheduleDetails
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.InvoiceCreatePreviewParams.ScheduleDetails{ billing_mode: map() | nil, end_behavior: String.t() | nil, phases: [map()] | nil, proration_behavior: String.t() | nil }
billing_mode- Controls how prorations and invoices for subscriptions are calculated and orchestrated.end_behavior- Behavior of the subscription schedule and underlying subscription when it ends. Possible values arereleaseorcancelwith the default beingrelease.releasewill end the subscription schedule and keep the underlying subscription running.cancelwill end the subscription schedule and cancel the underlying subscription. Possible values:cancel,release.phases- List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, theend_dateof one phase will always equal thestart_dateof the next phase.proration_behavior- In cases where theschedule_detailsparams update the currently active phase, specifies if and how to prorate at the time of the request. Possible values:always_invoice,create_prorations,none.