StripeElixir.Params.Issuing.AuthorizationApproveParams
(stripe_elixir v0.1.0)
Parameters for authorization approve.
Summary
Types
@type t() :: %StripeElixir.Params.Issuing.AuthorizationApproveParams{ amount: integer() | nil, expand: [String.t()] | nil, metadata: map() | nil }
amount- If the authorization'spending_request.is_amount_controllableproperty istrue, you may provide this value to control how much to hold for the authorization. Must be positive (usedeclineto decline an authorization request).expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.