StripeElixir.Params.Issuing.AuthorizationListParams
(stripe_elixir v0.1.0)
Parameters for authorization list.
Summary
Types
@type t() :: %StripeElixir.Params.Issuing.AuthorizationListParams{ card: String.t() | nil, cardholder: String.t() | nil, created: map() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, starting_after: String.t() | nil, status: String.t() | nil }
card- Only return authorizations that belong to the given card. Max length: 5000.cardholder- Only return authorizations that belong to the given cardholder. Max length: 5000.created- Only return authorizations that were created during the given date interval.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.status- Only return authorizations with the given status. One ofpending,closed, orreversed. Possible values:closed,expired,pending,reversed.