StripeElixir.Params.Issuing.CardholderCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for cardholder create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Issuing.CardholderCreateParams{
  billing: map(),
  company: map() | nil,
  email: String.t() | nil,
  expand: [String.t()] | nil,
  individual: map() | nil,
  metadata: map() | nil,
  name: String.t(),
  phone_number: String.t() | nil,
  preferred_locales: [String.t()] | nil,
  spending_controls: map() | nil,
  status: String.t() | nil,
  type: String.t() | nil
}
  • billing - The cardholder's billing address.
  • company - Additional information about a company cardholder.
  • email - The cardholder's email address.
  • expand - Specifies which fields in the response should be expanded.
  • individual - Additional information about an individual cardholder.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • name - The cardholder's name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.
  • phone_number - The cardholder's phone number. This will be transformed to E.164 if it is not provided in that format already. This is required for all cardholders who will be creating EU cards. See the 3D Secure documentation for more details.
  • preferred_locales - The cardholder’s preferred locales (languages), ordered by preference. Locales can be de, en, es, fr, or it. This changes the language of the 3D Secure flow and one-time password messages sent to the cardholder.
  • spending_controls - Rules that control spending across this cardholder's cards. Refer to our documentation for more details.
  • status - Specifies whether to permit authorizations on this cardholder's cards. Defaults to active. Possible values: active, inactive.
  • type - One of individual or company. See Choose a cardholder type for more details. Possible values: company, individual.