StripeElixir.Params.Issuing.CardholderUpdateParams.SpendingControls
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Issuing.CardholderUpdateParams.SpendingControls{ allowed_categories: [String.t()] | nil, allowed_merchant_countries: [String.t()] | nil, blocked_categories: [String.t()] | nil, blocked_merchant_countries: [String.t()] | nil, spending_limits: [map()] | nil, spending_limits_currency: String.t() | nil }
allowed_categories- Array of strings containing categories of authorizations to allow. All other categories will be blocked. Cannot be set withblocked_categories.allowed_merchant_countries- Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g.US). Cannot be set withblocked_merchant_countries. Provide an empty value to unset this control.blocked_categories- Array of strings containing categories of authorizations to decline. All other categories will be allowed. Cannot be set withallowed_categories.blocked_merchant_countries- Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g.US). Cannot be set withallowed_merchant_countries. Provide an empty value to unset this control.spending_limits- Limit spending with amount-based rules that apply across this cardholder's cards.spending_limits_currency- Currency of amounts withinspending_limits. Defaults to your merchant country's currency.