Parameters for dispute update.
Summary
Types
@type t() :: %StripeElixir.Params.Issuing.DisputeUpdateParams{ amount: integer() | nil, evidence: map() | nil, expand: [String.t()] | nil, metadata: map() | nil }
amount- The dispute amount in the card's currency and in the smallest currency unit.evidence- Evidence provided for the dispute.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.