StripeElixir.Params.Issuing.PersonalizationDesignCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for personalization design create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Issuing.PersonalizationDesignCreateParams{
  card_logo: String.t() | nil,
  carrier_text: map() | nil,
  expand: [String.t()] | nil,
  lookup_key: String.t() | nil,
  metadata: map() | nil,
  name: String.t() | nil,
  physical_bundle: String.t(),
  preferences: map() | nil,
  transfer_lookup_key: boolean() | nil
}
  • card_logo - The file for the card logo, for use with physical bundles that support card logos. Must have a purpose value of issuing_logo.
  • carrier_text - Hash containing carrier text, for use with physical bundles that support carrier text.
  • expand - Specifies which fields in the response should be expanded.
  • lookup_key - A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters. Max length: 200.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • name - Friendly display name. Max length: 200.
  • physical_bundle - The physical bundle object belonging to this personalization design. Max length: 5000.
  • preferences - Information on whether this personalization design is used to create cards when one is not specified.
  • transfer_lookup_key - If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.