StripeElixir.Params.Issuing.PersonalizationDesignUpdateParams
(stripe_elixir v0.1.0)
Parameters for personalization design update.
Summary
Types
@type t() :: %StripeElixir.Params.Issuing.PersonalizationDesignUpdateParams{ card_logo: map() | nil, carrier_text: map() | nil, expand: [String.t()] | nil, lookup_key: map() | nil, metadata: map() | nil, name: map() | nil, physical_bundle: String.t() | nil, preferences: map() | nil, transfer_lookup_key: boolean() | nil }
card_logo- The file for the card logo, for use with physical bundles that support card logos. Must have apurposevalue ofissuing_logo.carrier_text- Hash containing carrier text, for use with physical bundles that support carrier text.expand- Specifies which fields in the response should be expanded.lookup_key- A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.name- Friendly display name. Providing an empty string will set the field to null.physical_bundle- The physical bundle object belonging to this personalization design. Max length: 5000.preferences- Information on whether this personalization design is used to create cards when one is not specified.transfer_lookup_key- If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.