StripeElixir.Params.PaymentIntentCreateParams.PaymentMethodOptions (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PaymentIntentCreateParams.PaymentMethodOptions{
  acss_debit: map() | nil,
  affirm: map() | nil,
  afterpay_clearpay: map() | nil,
  alipay: map() | nil,
  alma: map() | nil,
  amazon_pay: map() | nil,
  au_becs_debit: map() | nil,
  bacs_debit: map() | nil,
  bancontact: map() | nil,
  billie: map() | nil,
  blik: map() | nil,
  boleto: map() | nil,
  card: map() | nil,
  card_present: map() | nil,
  cashapp: map() | nil,
  crypto: map() | nil,
  customer_balance: map() | nil,
  eps: map() | nil,
  fpx: map() | nil,
  giropay: map() | nil,
  grabpay: map() | nil,
  ideal: map() | nil,
  interac_present: map() | nil,
  kakao_pay: map() | nil,
  klarna: map() | nil,
  konbini: map() | nil,
  kr_card: map() | nil,
  link: map() | nil,
  mb_way: map() | nil,
  mobilepay: map() | nil,
  multibanco: map() | nil,
  naver_pay: map() | nil,
  nz_bank_account: map() | nil,
  oxxo: map() | nil,
  p24: map() | nil,
  pay_by_bank: map() | nil,
  payco: map() | nil,
  paynow: map() | nil,
  paypal: map() | nil,
  payto: map() | nil,
  pix: map() | nil,
  promptpay: map() | nil,
  revolut_pay: map() | nil,
  samsung_pay: map() | nil,
  satispay: map() | nil,
  sepa_debit: map() | nil,
  sofort: map() | nil,
  swish: map() | nil,
  twint: map() | nil,
  us_bank_account: map() | nil,
  wechat_pay: map() | nil,
  zip: map() | nil
}
  • acss_debit - If this is a acss_debit PaymentMethod, this sub-hash contains details about the ACSS Debit payment method options.
  • affirm - If this is an affirm PaymentMethod, this sub-hash contains details about the Affirm payment method options.
  • afterpay_clearpay - If this is a afterpay_clearpay PaymentMethod, this sub-hash contains details about the Afterpay Clearpay payment method options.
  • alipay - If this is a alipay PaymentMethod, this sub-hash contains details about the Alipay payment method options.
  • alma - If this is a alma PaymentMethod, this sub-hash contains details about the Alma payment method options.
  • amazon_pay - If this is a amazon_pay PaymentMethod, this sub-hash contains details about the Amazon Pay payment method options.
  • au_becs_debit - If this is a au_becs_debit PaymentMethod, this sub-hash contains details about the AU BECS Direct Debit payment method options.
  • bacs_debit - If this is a bacs_debit PaymentMethod, this sub-hash contains details about the BACS Debit payment method options.
  • bancontact - If this is a bancontact PaymentMethod, this sub-hash contains details about the Bancontact payment method options.
  • billie - If this is a billie PaymentMethod, this sub-hash contains details about the Billie payment method options.
  • blik - If this is a blik PaymentMethod, this sub-hash contains details about the BLIK payment method options.
  • boleto - If this is a boleto PaymentMethod, this sub-hash contains details about the Boleto payment method options.
  • card - Configuration for any card payments attempted on this PaymentIntent.
  • card_present - If this is a card_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.
  • cashapp - If this is a cashapp PaymentMethod, this sub-hash contains details about the Cash App Pay payment method options.
  • crypto - If this is a crypto PaymentMethod, this sub-hash contains details about the Crypto payment method options.
  • customer_balance - If this is a customer balance PaymentMethod, this sub-hash contains details about the customer balance payment method options.
  • eps - If this is a eps PaymentMethod, this sub-hash contains details about the EPS payment method options.
  • fpx - If this is a fpx PaymentMethod, this sub-hash contains details about the FPX payment method options.
  • giropay - If this is a giropay PaymentMethod, this sub-hash contains details about the Giropay payment method options.
  • grabpay - If this is a grabpay PaymentMethod, this sub-hash contains details about the Grabpay payment method options.
  • ideal - If this is a ideal PaymentMethod, this sub-hash contains details about the Ideal payment method options.
  • interac_present - If this is a interac_present PaymentMethod, this sub-hash contains details about the Card Present payment method options.
  • kakao_pay - If this is a kakao_pay PaymentMethod, this sub-hash contains details about the Kakao Pay payment method options.
  • klarna - If this is a klarna PaymentMethod, this sub-hash contains details about the Klarna payment method options.
  • konbini - If this is a konbini PaymentMethod, this sub-hash contains details about the Konbini payment method options.
  • kr_card - If this is a kr_card PaymentMethod, this sub-hash contains details about the KR Card payment method options.
  • link - If this is a link PaymentMethod, this sub-hash contains details about the Link payment method options.
  • mb_way - If this is a mb_way PaymentMethod, this sub-hash contains details about the MB WAY payment method options.
  • mobilepay - If this is a MobilePay PaymentMethod, this sub-hash contains details about the MobilePay payment method options.
  • multibanco - If this is a multibanco PaymentMethod, this sub-hash contains details about the Multibanco payment method options.
  • naver_pay - If this is a naver_pay PaymentMethod, this sub-hash contains details about the Naver Pay payment method options.
  • nz_bank_account - If this is a nz_bank_account PaymentMethod, this sub-hash contains details about the NZ BECS Direct Debit payment method options.
  • oxxo - If this is a oxxo PaymentMethod, this sub-hash contains details about the OXXO payment method options.
  • p24 - If this is a p24 PaymentMethod, this sub-hash contains details about the Przelewy24 payment method options.
  • pay_by_bank - If this is a pay_by_bank PaymentMethod, this sub-hash contains details about the PayByBank payment method options.
  • payco - If this is a payco PaymentMethod, this sub-hash contains details about the PAYCO payment method options.
  • paynow - If this is a paynow PaymentMethod, this sub-hash contains details about the PayNow payment method options.
  • paypal - If this is a paypal PaymentMethod, this sub-hash contains details about the PayPal payment method options.
  • payto - If this is a payto PaymentMethod, this sub-hash contains details about the PayTo payment method options.
  • pix - If this is a pix PaymentMethod, this sub-hash contains details about the Pix payment method options.
  • promptpay - If this is a promptpay PaymentMethod, this sub-hash contains details about the PromptPay payment method options.
  • revolut_pay - If this is a revolut_pay PaymentMethod, this sub-hash contains details about the Revolut Pay payment method options.
  • samsung_pay - If this is a samsung_pay PaymentMethod, this sub-hash contains details about the Samsung Pay payment method options.
  • satispay - If this is a satispay PaymentMethod, this sub-hash contains details about the Satispay payment method options.
  • sepa_debit - If this is a sepa_debit PaymentIntent, this sub-hash contains details about the SEPA Debit payment method options.
  • sofort - If this is a sofort PaymentMethod, this sub-hash contains details about the SOFORT payment method options.
  • swish - If this is a Swish PaymentMethod, this sub-hash contains details about the Swish payment method options.
  • twint - If this is a twint PaymentMethod, this sub-hash contains details about the TWINT payment method options.
  • us_bank_account - If this is a us_bank_account PaymentMethod, this sub-hash contains details about the US bank account payment method options.
  • wechat_pay - If this is a wechat_pay PaymentMethod, this sub-hash contains details about the WeChat Pay payment method options.
  • zip - If this is a zip PaymentMethod, this sub-hash contains details about the Zip payment method options.