StripeElixir.Params.PaymentIntentCreateParams.TransferData (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PaymentIntentCreateParams.TransferData{
  amount: integer() | nil,
  destination: String.t() | nil
}
  • amount - The amount that will be transferred automatically when a charge succeeds. The amount is capped at the total transaction amount and if no amount is set, the full amount is transferred.

If you intend to collect a fee and you need a more robust reporting experience, using application_fee_amount might be a better fit for your integration.

  • destination - If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge's transfer field.