StripeElixir.Params.PaymentLinkCreateParams.LineItems (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PaymentLinkCreateParams.LineItems{
  adjustable_quantity: map() | nil,
  price: String.t() | nil,
  price_data: map() | nil,
  quantity: integer() | nil
}
  • adjustable_quantity - When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
  • price - The ID of the Price or Plan object. One of price or price_data is required. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required.
  • quantity - The quantity of the line item being purchased.