StripeElixir.Params.PaymentLinkUpdateParams.LineItems (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PaymentLinkUpdateParams.LineItems{
  adjustable_quantity: map() | nil,
  id: String.t() | nil,
  quantity: integer() | nil
}
  • adjustable_quantity - When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.
  • id - The ID of an existing line item on the payment link. Max length: 5000.
  • quantity - The quantity of the line item being purchased.