Parameters for payment method attach.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentMethodAttachParams{ customer: String.t() | nil, customer_account: String.t() | nil, expand: [String.t()] | nil }
customer- The ID of the customer to which to attach the PaymentMethod. Max length: 5000.customer_account- The ID of the Account representing the customer to which to attach the PaymentMethod. Max length: 5000.expand- Specifies which fields in the response should be expanded.