StripeElixir.Params.PaymentRecordReportRefundParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for payment record report refund.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PaymentRecordReportRefundParams{
  amount: map() | nil,
  expand: [String.t()] | nil,
  initiated_at: integer() | nil,
  metadata: map() | nil,
  outcome: String.t(),
  processor_details: map(),
  refunded: map()
}
  • amount - A positive integer in the smallest currency unit representing how much of this payment to refund. Can refund only up to the remaining, unrefunded amount of the payment.
  • expand - Specifies which fields in the response should be expanded.
  • initiated_at - When the reported refund was initiated. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • outcome - The outcome of the reported refund. Possible values: refunded.
  • processor_details - Processor information for this refund.
  • refunded - Information about the payment attempt refund.