Parameters for product create.
Summary
Types
@type t() :: %StripeElixir.Params.ProductCreateParams{ active: boolean() | nil, default_price_data: map() | nil, description: String.t() | nil, expand: [String.t()] | nil, id: String.t() | nil, images: [String.t()] | nil, marketing_features: [map()] | nil, metadata: map() | nil, name: String.t(), package_dimensions: map() | nil, shippable: boolean() | nil, statement_descriptor: String.t() | nil, tax_code: String.t() | nil, type: String.t() | nil, unit_label: String.t() | nil, url: String.t() | nil }
active- Whether the product is currently available for purchase. Defaults totrue.default_price_data- Data used to generate a new Price object. This Price will be set as the default price for this product.description- The product's description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes. Max length: 40000.expand- Specifies which fields in the response should be expanded.id- An identifier will be randomly generated by Stripe. You can optionally override this ID, but the ID must be unique across all products in your Stripe account. Max length: 5000.images- A list of up to 8 URLs of images for this product, meant to be displayable to the customer.marketing_features- A list of up to 15 marketing features for this product. These are displayed in pricing tables.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.name- The product's name, meant to be displayable to the customer. Max length: 5000.package_dimensions- The dimensions of this product for shipping purposes.shippable- Whether this product is shipped (i.e., physical goods).statement_descriptor- An arbitrary string to be displayed on your customer's credit card or bank statement. While most banks display this information consistently, some may display it incorrectly or not at all.
This may be up to 22 characters. The statement description may not include ,`, ", ' characters, and will appear on your customer's statement in capital letters. Non-ASCII characters are automatically stripped.
It must contain at least one letter. Only used for subscription payments. Max length: 22.
tax_code- A tax code ID.type- The type of the product. Defaults toserviceif not explicitly specified, enabling use of this product with Subscriptions and Plans. Set this parameter togoodto use this product with Orders and SKUs. On API versions before2018-02-05, this field defaults togoodfor compatibility reasons. Possible values:good,service.unit_label- A label that represents units of this product. When set, this will be included in customers' receipts, invoices, Checkout, and the customer portal. Max length: 12.url- A URL of a publicly-accessible webpage for this product. Max length: 5000.