StripeElixir.Params.PromotionCodeCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for promotion code create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.PromotionCodeCreateParams{
  active: boolean() | nil,
  code: String.t() | nil,
  customer: String.t() | nil,
  customer_account: String.t() | nil,
  expand: [String.t()] | nil,
  expires_at: integer() | nil,
  max_redemptions: integer() | nil,
  metadata: map() | nil,
  promotion: map(),
  restrictions: map() | nil
}
  • active - Whether the promotion code is currently active.
  • code - The customer-facing code. Regardless of case, this code must be unique across all active promotion codes for a specific customer. Valid characters are lower case letters (a-z), upper case letters (A-Z), and digits (0-9).

If left blank, we will generate one automatically. Max length: 500.

  • customer - The customer who can use this promotion code. If not set, all customers can use the promotion code. Max length: 5000.
  • customer_account - The account representing the customer who can use this promotion code. If not set, all customers can use the promotion code. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • expires_at - The timestamp at which this promotion code will expire. If the coupon has specified a redeems_by, then this value cannot be after the coupon's redeems_by. Format: Unix timestamp.
  • max_redemptions - A positive integer specifying the number of times the promotion code can be redeemed. If the coupon has specified a max_redemptions, then this value cannot be greater than the coupon's max_redemptions.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • promotion - The promotion referenced by this promotion code.
  • restrictions - Settings that restrict the redemption of the promotion code.