Parameters for quote pdf.
Summary
Types
@type t() :: %StripeElixir.Params.QuotePdfParams{expand: [String.t()] | nil}
expand- Specifies which fields in the response should be expanded.
Parameters for quote pdf.
@type t() :: %StripeElixir.Params.QuotePdfParams{expand: [String.t()] | nil}
expand - Specifies which fields in the response should be expanded.