StripeElixir.Params.QuoteUpdateParams.LineItems (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.QuoteUpdateParams.LineItems{
  discounts: map() | nil,
  id: String.t() | nil,
  price: String.t() | nil,
  price_data: map() | nil,
  quantity: integer() | nil,
  tax_rates: map() | nil
}
  • discounts - The discounts applied to this line item.
  • id - The ID of an existing line item on the quote. Max length: 5000.
  • price - The ID of the price object. One of price or price_data is required. Max length: 5000.
  • price_data - Data used to generate a new Price object inline. One of price or price_data is required.
  • quantity - The quantity of the line item.
  • tax_rates - The tax rates which apply to the line item. When set, the default_tax_rates on the quote do not apply to this line item.