StripeElixir.Params.QuoteUpdateParams.SubscriptionData
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.QuoteUpdateParams.SubscriptionData{ description: map() | nil, effective_date: map() | nil, metadata: map() | nil, trial_period_days: map() | nil }
description- The subscription's description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.effective_date- When creating a new subscription, the date of which the subscription schedule will start after the quote is accepted. Theeffective_dateis ignored if it is in the past when the quote is accepted.metadata- Set of key-value pairs that will set metadata on the subscription or subscription schedule when the quote is accepted. If a recurring price is included inline_items, this field will be passed to the resulting subscription'smetadatafield. Ifsubscription_data.effective_dateis used, this field will be passed to the resulting subscription schedule'sphases.metadatafield. Unlike object-level metadata, this field is declarative. Updates will clear prior values.trial_period_days- Integer representing the number of trial period days before the customer is charged for the first time.