StripeElixir.Params.Radar.PaymentEvaluationCreateParams
(stripe_elixir v0.1.0)
Parameters for payment evaluation create.
Summary
Types
@type t() :: %StripeElixir.Params.Radar.PaymentEvaluationCreateParams{ client_device_metadata_details: map() | nil, customer_details: map(), expand: [String.t()] | nil, metadata: map() | nil, payment_details: map() }
client_device_metadata_details- Details about the Client Device Metadata to associate with the payment evaluation.customer_details- Details about the customer associated with the payment evaluation.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.payment_details- Details about the payment.