Parameters for report type list.
Summary
Types
@type t() :: %StripeElixir.Params.Reporting.ReportTypeListParams{ expand: [String.t()] | nil }
expand- Specifies which fields in the response should be expanded.
Parameters for report type list.
@type t() :: %StripeElixir.Params.Reporting.ReportTypeListParams{ expand: [String.t()] | nil }
expand - Specifies which fields in the response should be expanded.