StripeElixir.Params.SetupIntentRetrieveParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for setup intent retrieve.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SetupIntentRetrieveParams{
  client_secret: String.t() | nil,
  expand: [String.t()] | nil
}
  • client_secret - The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.