StripeElixir.Params.SourceCreateParams.Receiver (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SourceCreateParams.Receiver{
  refund_attributes_method: String.t() | nil
}
  • refund_attributes_method - The method Stripe should use to request information needed to process a refund or mispayment. Either email (an email is sent directly to the customer) or manual (a source.refund_attributes_required event is sent to your webhooks endpoint). Refer to each payment method's documentation to learn which refund attributes may be required. Possible values: email, manual, none. Max length: 5000.