StripeElixir.Params.SourceCreateParams.Redirect (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SourceCreateParams.Redirect{
  return_url: String.t() | nil
}
  • return_url - The URL you provide to redirect the customer back to you after they authenticated their payment. It can use your application URI scheme in the context of a mobile application.