StripeElixir.Params.SubscriptionCreateParams.BillingCycleAnchorConfig (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SubscriptionCreateParams.BillingCycleAnchorConfig{
  day_of_month: integer() | nil,
  hour: integer() | nil,
  minute: integer() | nil,
  month: integer() | nil,
  second: integer() | nil
}
  • day_of_month - The day of the month the anchor should be. Ranges from 1 to 31.
  • hour - The hour of the day the anchor should be. Ranges from 0 to 23.
  • minute - The minute of the hour the anchor should be. Ranges from 0 to 59.
  • month - The month to start full cycle periods. Ranges from 1 to 12.
  • second - The second of the minute the anchor should be. Ranges from 0 to 59.