StripeElixir.Params.SubscriptionCreateParams.Items (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SubscriptionCreateParams.Items{
  billing_thresholds: map() | nil,
  discounts: map() | nil,
  metadata: map() | nil,
  plan: String.t() | nil,
  price: String.t() | nil,
  price_data: map() | nil,
  quantity: integer() | nil,
  tax_rates: map() | nil
}
  • billing_thresholds - Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
  • discounts - The coupons to redeem into discounts for the subscription item.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
  • plan - Plan ID for this item, as a string. Max length: 5000.
  • price - The ID of the price object. Max length: 5000.
  • price_data - Data used to generate a new Price object inline.
  • quantity - Quantity for this item.
  • tax_rates - A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.