StripeElixir.Params.SubscriptionMigrateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for subscription migrate.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SubscriptionMigrateParams{
  billing_mode: map(),
  expand: [String.t()] | nil
}
  • billing_mode - Controls how prorations and invoices for subscriptions are calculated and orchestrated.
  • expand - Specifies which fields in the response should be expanded.