StripeElixir.Params.SubscriptionScheduleCreateParams.BillingMode (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SubscriptionScheduleCreateParams.BillingMode{
  flexible: map() | nil,
  type: String.t() | nil
}
  • flexible - Configure behavior for flexible billing mode.
  • type - Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is flexible. Possible values: classic, flexible.