StripeElixir.Params.SubscriptionScheduleListParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for subscription schedule list.

Summary

Types

t()

@type t() :: %StripeElixir.Params.SubscriptionScheduleListParams{
  canceled_at: map() | nil,
  completed_at: map() | nil,
  created: map() | nil,
  customer: String.t() | nil,
  customer_account: String.t() | nil,
  ending_before: String.t() | nil,
  expand: [String.t()] | nil,
  limit: integer() | nil,
  released_at: map() | nil,
  scheduled: boolean() | nil,
  starting_after: String.t() | nil
}
  • canceled_at - Only return subscription schedules that were created canceled the given date interval.
  • completed_at - Only return subscription schedules that completed during the given date interval.
  • created - Only return subscription schedules that were created during the given date interval.
  • customer - Only return subscription schedules for the given customer. Max length: 5000.
  • customer_account - Only return subscription schedules for the given account. Max length: 5000.
  • ending_before - A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list. Max length: 5000.
  • expand - Specifies which fields in the response should be expanded.
  • limit - A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
  • released_at - Only return subscription schedules that were released during the given date interval.
  • scheduled - Only return subscription schedules that have not started yet.
  • starting_after - A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list. Max length: 5000.