StripeElixir.Params.SubscriptionScheduleUpdateParams
(stripe_elixir v0.1.0)
Parameters for subscription schedule update.
Summary
Types
@type t() :: %StripeElixir.Params.SubscriptionScheduleUpdateParams{ default_settings: map() | nil, end_behavior: String.t() | nil, expand: [String.t()] | nil, metadata: map() | nil, phases: [map()] | nil, proration_behavior: String.t() | nil }
default_settings- Object representing the subscription schedule's default settings.end_behavior- Behavior of the subscription schedule and underlying subscription when it ends. Possible values arereleaseorcancelwith the default beingrelease.releasewill end the subscription schedule and keep the underlying subscription running.cancelwill end the subscription schedule and cancel the underlying subscription. Possible values:cancel,none,release,renew.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.phases- List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, theend_dateof one phase will always equal thestart_dateof the next phase. Note that past phases can be omitted.proration_behavior- If the update changes the billing configuration (item price, quantity, etc.) of the current phase, indicates how prorations from this change should be handled. The default value iscreate_prorations. Possible values:always_invoice,create_prorations,none.