StripeElixir.Params.Tax.SettingsUpdateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for settings update.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Tax.SettingsUpdateParams{
  defaults: map() | nil,
  expand: [String.t()] | nil,
  head_office: map() | nil
}
  • defaults - Default configuration to be used on Stripe Tax calculations.
  • expand - Specifies which fields in the response should be expanded.
  • head_office - The place where your business is located.