StripeElixir.Params.Terminal.ReaderCollectInputsParams
(stripe_elixir v0.1.0)
Parameters for reader collect inputs.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.ReaderCollectInputsParams{ expand: [String.t()] | nil, inputs: [map()], metadata: map() | nil }
expand- Specifies which fields in the response should be expanded.inputs- List of inputs to be collected from the customer using the Reader. Maximum 5 inputs.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.