StripeElixir.Params.Terminal.ReaderCollectInputsParams.Inputs (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Terminal.ReaderCollectInputsParams.Inputs{
  custom_text: map() | nil,
  required: boolean() | nil,
  selection: map() | nil,
  toggles: [map()] | nil,
  type: String.t() | nil
}
  • custom_text - Customize the text which will be displayed while collecting this input
  • required - Indicate that this input is required, disabling the skip button
  • selection - Options for the selection input
  • toggles - List of toggles to be displayed and customization for the toggles
  • type - The type of input to collect Possible values: email, numeric, phone, selection, signature, text.