StripeElixir.Params.Terminal.ReaderCollectPaymentMethodParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for reader collect payment method.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Terminal.ReaderCollectPaymentMethodParams{
  collect_config: map() | nil,
  expand: [String.t()] | nil,
  payment_intent: String.t()
}
  • collect_config - Configuration overrides for this collection, such as tipping, surcharging, and customer cancellation settings.
  • expand - Specifies which fields in the response should be expanded.
  • payment_intent - The ID of the PaymentIntent to collect a payment method for. Max length: 5000.