StripeElixir.Params.Terminal.ReaderProcessPaymentIntentParams
(stripe_elixir v0.1.0)
Parameters for reader process payment intent.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.ReaderProcessPaymentIntentParams{ expand: [String.t()] | nil, payment_intent: String.t(), process_config: map() | nil }
expand- Specifies which fields in the response should be expanded.payment_intent- The ID of the PaymentIntent to process on the reader. Max length: 5000.process_config- Configuration overrides for this transaction, such as tipping and customer cancellation settings.