StripeElixir.Params.Terminal.ReaderProcessSetupIntentParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for reader process setup intent.

Summary

Types

t()

@type t() :: %StripeElixir.Params.Terminal.ReaderProcessSetupIntentParams{
  allow_redisplay: String.t(),
  expand: [String.t()] | nil,
  process_config: map() | nil,
  setup_intent: String.t()
}
  • allow_redisplay - This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. Possible values: always, limited, unspecified.
  • expand - Specifies which fields in the response should be expanded.
  • process_config - Configuration overrides for this setup, such as MOTO and customer cancellation settings.
  • setup_intent - The ID of the SetupIntent to process on the reader. Max length: 5000.