StripeElixir.Params.Terminal.ReaderSetReaderDisplayParams
(stripe_elixir v0.1.0)
Parameters for reader set reader display.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.ReaderSetReaderDisplayParams{ cart: map() | nil, expand: [String.t()] | nil, type: String.t() }
cart- Cart details to display on the reader screen, including line items, amounts, and currency.expand- Specifies which fields in the response should be expanded.type- Type of information to display. Onlycartis currently supported. Possible values:cart.