StripeElixir.Params.TokenCreateParams.Account (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.TokenCreateParams.Account{
  business_type: String.t() | nil,
  company: map() | nil,
  individual: map() | nil,
  tos_shown_and_accepted: boolean() | nil
}
  • business_type - The business type. Possible values: company, government_entity, individual, non_profit.
  • company - Information about the company or business.
  • individual - Information about the person represented by the account.
  • tos_shown_and_accepted - Whether the user described by the data in the token has been shown the Stripe Connected Account Agreement. When creating an account token to create a new Connect account, this value must be true.