StripeElixir.Params.Treasury.CreditReversalListParams
(stripe_elixir v0.1.0)
Parameters for credit reversal list.
Summary
Types
@type t() :: %StripeElixir.Params.Treasury.CreditReversalListParams{ ending_before: String.t() | nil, expand: [String.t()] | nil, financial_account: String.t(), limit: integer() | nil, received_credit: String.t() | nil, starting_after: String.t() | nil, status: String.t() | nil }
ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.financial_account- Returns objects associated with this FinancialAccount.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.received_credit- Only return CreditReversals for the ReceivedCredit ID. Max length: 5000.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.status- Only return CreditReversals for a given status. Possible values:canceled,posted,processing.