StripeElixir.Params.Treasury.FinancialAccountUpdateParams
(stripe_elixir v0.1.0)
Parameters for financial account update.
Summary
Types
@type t() :: %StripeElixir.Params.Treasury.FinancialAccountUpdateParams{ expand: [String.t()] | nil, features: map() | nil, forwarding_settings: map() | nil, metadata: map() | nil, nickname: map() | nil, platform_restrictions: map() | nil }
expand- Specifies which fields in the response should be expanded.features- Encodes whether a FinancialAccount has access to a particular feature, with a status enum and associatedstatus_details. Stripe or the platform may control features via the requested field.forwarding_settings- A different bank account where funds can be deposited/debited in order to get the closing FA's balance to $0metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.nickname- The nickname for the FinancialAccount.platform_restrictions- The set of functionalities that the platform can restrict on the FinancialAccount.