StripeElixir.Params.V2.Core.AccountTokenCreateParams (stripe_elixir v0.1.0)

Copy Markdown View Source

Parameters for account token create.

Summary

Types

t()

@type t() :: %StripeElixir.Params.V2.Core.AccountTokenCreateParams{
  contact_email: String.t() | nil,
  contact_phone: String.t() | nil,
  display_name: String.t() | nil,
  identity: map() | nil
}
  • contact_email - The default contact email address for the Account. Required when configuring the account as a merchant or recipient.
  • contact_phone - The default contact phone for the Account.
  • display_name - A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
  • identity - Information about the company, individual, and business represented by the Account.