StripeElixir.Params.V2.Core.Accounts.PersonUpdateParams.Documents (stripe_elixir v0.1.0)

Copy Markdown View Source

Nested parameters.

Summary

Types

t()

@type t() :: %StripeElixir.Params.V2.Core.Accounts.PersonUpdateParams.Documents{
  company_authorization: map() | nil,
  passport: map() | nil,
  primary_verification: map() | nil,
  secondary_verification: map() | nil,
  visa: map() | nil
}
  • company_authorization - One or more documents that demonstrate proof that this person is authorized to represent the company.
  • passport - One or more documents showing the person’s passport page with photo and personal data.
  • primary_verification - An identifying document showing the person's name, either a passport or local ID card.
  • secondary_verification - A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
  • visa - One or more documents showing the person’s visa required for living in the country where they are residing.