ApplePayDomain
Summary
Types
@type t() :: %StripeElixir.Resources.ApplePayDomain{ created: integer(), domain_name: String.t(), id: String.t(), livemode: boolean(), object: String.t() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.domain_name- Max length: 5000.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:apple_pay_domain.