StripeElixir.Resources.Billing.CreditBalanceSummary
(stripe_elixir v0.1.0)
CreditBalanceSummary
Indicates the billing credit balance for billing credits granted to a customer.
Summary
Types
@type t() :: %StripeElixir.Resources.Billing.CreditBalanceSummary{ balances: [String.t() | map()], customer: map(), customer_account: String.t(), livemode: boolean(), object: String.t() }
balances- The billing credit balances. One entry per credit grant currency. If a customer only has credit grants in a single currency, then this will have a single balance entry. Expandable.customer- The customer the balance is for. Expandable.customer_account- The account the balance is for. Max length: 5000. Nullable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:billing.credit_balance_summary.