StripeElixir.Resources.Climate.Supplier (stripe_elixir v0.1.0)

Copy Markdown View Source

ClimateRemovalsSuppliers

A supplier of carbon removal.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Climate.Supplier{
  id: String.t(),
  info_url: String.t(),
  livemode: boolean(),
  locations: [map()],
  name: String.t(),
  object: String.t(),
  removal_pathway: String.t()
}
  • id - Unique identifier for the object. Max length: 5000.
  • info_url - Link to a webpage to learn more about the supplier. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • locations - The locations in which this supplier operates. Expandable.
  • name - Name of this carbon removal supplier. Max length: 5000.
  • object - String representing the object’s type. Objects of the same type share the same value. Possible values: climate.supplier.
  • removal_pathway - The scientific pathway used for carbon removal. Possible values: biomass_carbon_removal_and_storage, direct_air_capture, enhanced_weathering.

Functions

expandable_fields()

object_name()