StripeElixir.Resources.CustomerNotification (stripe_elixir v0.1.0)

Copy Markdown View Source

PaymentIntentProcessingCustomerNotification

Summary

Types

t()

@type t() :: %StripeElixir.Resources.CustomerNotification{
  approval_requested: boolean(),
  completes_at: integer()
}
  • approval_requested - Whether customer approval has been requested for this payment. For payments greater than INR 15000 or mandate amount, the customer must provide explicit approval of the payment with their bank. Nullable.
  • completes_at - If customer approval is required, they need to provide approval before this time. Format: Unix timestamp. Nullable.

Functions

object_name()