StripeElixir.Resources.Entitlements.ActiveEntitlement (stripe_elixir v0.1.0)

Copy Markdown View Source

ActiveEntitlement

An active entitlement describes access to a feature for a customer.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Entitlements.ActiveEntitlement{
  feature: String.t() | map(),
  id: String.t(),
  livemode: boolean(),
  lookup_key: String.t(),
  object: String.t()
}
  • feature - The Feature that the customer is entitled to. Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • lookup_key - A unique key you provide as your own system identifier. This may be up to 80 characters. Max length: 5000.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: entitlements.active_entitlement.

Functions

expandable_fields()

object_name()