StripeElixir.Resources.Entitlements.ActiveEntitlementSummary
(stripe_elixir v0.1.0)
ActiveEntitlementSummary
A summary of a customer's active entitlements.
Summary
Types
@type t() :: %StripeElixir.Resources.Entitlements.ActiveEntitlementSummary{ customer: String.t(), entitlements: map(), livemode: boolean(), object: String.t() }
customer- The customer that is entitled to this feature. Max length: 5000.entitlements- The list of entitlements this customer has. Expandable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:entitlements.active_entitlement_summary.