StripeElixir.Resources.NaverPay (stripe_elixir v0.1.0)

Copy Markdown View Source

payment_method_naver_pay

Summary

Types

t()

@type t() :: %StripeElixir.Resources.NaverPay{
  buyer_id: String.t(),
  funding: String.t()
}
  • buyer_id - Uniquely identifies this particular Naver Pay account. You can use this attribute to check whether two Naver Pay accounts are the same. Max length: 5000. Nullable.
  • funding - Whether to fund this transaction with Naver Pay points or a card. Possible values: card, points.

Functions

object_name()