StripeElixir.Resources.Offline (stripe_elixir v0.1.0)

Copy Markdown View Source

payment_method_details_card_present_offline

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Offline{stored_at: integer(), type: String.t()}
  • stored_at - Time at which the payment was collected while offline Format: Unix timestamp. Nullable.
  • type - The method used to process this payment method offline. Only deferred is allowed. Possible values: deferred. Nullable.

Functions

object_name()