StripeElixir.Resources.PaymentDisputesFeatures (stripe_elixir v0.1.0)

Copy Markdown View Source

ConnectEmbeddedPaymentDisputesFeatures

Summary

Types

t()

@type t() :: %StripeElixir.Resources.PaymentDisputesFeatures{
  destination_on_behalf_of_charge_management: boolean(),
  dispute_management: boolean(),
  refund_management: boolean()
}
  • destination_on_behalf_of_charge_management - Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.
  • dispute_management - Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is true by default.
  • refund_management - Whether sending refunds is enabled. This is true by default.

Functions

object_name()