StripeElixir.Resources.PaymentMethodConfiguration (stripe_elixir v0.1.0)

Copy Markdown View Source

PaymentMethodConfigResourcePaymentMethodConfiguration

PaymentMethodConfigurations control which payment methods are displayed to your customers when you don't explicitly specify payment method types. You can have multiple configurations with different sets of payment methods for different scenarios.

There are two types of PaymentMethodConfigurations. Which is used depends on the charge type:

Direct configurations apply to payments created on your account, including Connect destination charges, Connect separate charges and transfers, and payments not involving Connect.

Child configurations apply to payments created on your connected accounts using direct charges, and charges with the on_behalf_of parameter.

Child configurations have a parent that sets default values and controls which settings connected accounts may override. You can specify a parent ID at payment time, and Stripe will automatically resolve the connected account’s associated child configuration. Parent configurations are managed in the dashboard and are not available in this API.

Related guides:

Summary

Types

t()

@type t() :: %StripeElixir.Resources.PaymentMethodConfiguration{
  acss_debit: map() | nil,
  active: boolean(),
  affirm: map() | nil,
  afterpay_clearpay: map() | nil,
  alipay: map() | nil,
  alma: map() | nil,
  amazon_pay: map() | nil,
  apple_pay: map() | nil,
  application: String.t(),
  au_becs_debit: map() | nil,
  bacs_debit: map() | nil,
  bancontact: map() | nil,
  billie: map() | nil,
  blik: map() | nil,
  boleto: map() | nil,
  card: map() | nil,
  cartes_bancaires: map() | nil,
  cashapp: map() | nil,
  crypto: map() | nil,
  customer_balance: map() | nil,
  eps: map() | nil,
  fpx: map() | nil,
  giropay: map() | nil,
  google_pay: map() | nil,
  grabpay: map() | nil,
  id: String.t(),
  ideal: map() | nil,
  is_default: boolean(),
  jcb: map() | nil,
  kakao_pay: map() | nil,
  klarna: map() | nil,
  konbini: map() | nil,
  kr_card: map() | nil,
  link: map() | nil,
  livemode: boolean(),
  mb_way: map() | nil,
  mobilepay: map() | nil,
  multibanco: map() | nil,
  name: String.t(),
  naver_pay: map() | nil,
  nz_bank_account: map() | nil,
  object: String.t(),
  oxxo: map() | nil,
  p24: map() | nil,
  parent: String.t(),
  pay_by_bank: map() | nil,
  payco: map() | nil,
  paynow: map() | nil,
  paypal: map() | nil,
  payto: map() | nil,
  pix: map() | nil,
  promptpay: map() | nil,
  revolut_pay: map() | nil,
  samsung_pay: map() | nil,
  satispay: map() | nil,
  sepa_debit: map() | nil,
  sofort: map() | nil,
  swish: map() | nil,
  twint: map() | nil,
  us_bank_account: map() | nil,
  wechat_pay: map() | nil,
  zip: map() | nil
}
  • acss_debit - Expandable.
  • active - Whether the configuration can be used for new payments.
  • affirm - Expandable.
  • afterpay_clearpay - Expandable.
  • alipay - Expandable.
  • alma - Expandable.
  • amazon_pay - Expandable.
  • apple_pay - Expandable.
  • application - For child configs, the Connect application associated with the configuration. Max length: 5000. Nullable.
  • au_becs_debit - Expandable.
  • bacs_debit - Expandable.
  • bancontact - Expandable.
  • billie - Expandable.
  • blik - Expandable.
  • boleto - Expandable.
  • card - Expandable.
  • cartes_bancaires - Expandable.
  • cashapp - Expandable.
  • crypto - Expandable.
  • customer_balance - Expandable.
  • eps - Expandable.
  • fpx - Expandable.
  • giropay - Expandable.
  • google_pay - Expandable.
  • grabpay - Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • ideal - Expandable.
  • is_default - The default configuration is used whenever a payment method configuration is not specified.
  • jcb - Expandable.
  • kakao_pay - Expandable.
  • klarna - Expandable.
  • konbini - Expandable.
  • kr_card - Expandable.
  • link - Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • mb_way - Expandable.
  • mobilepay - Expandable.
  • multibanco - Expandable.
  • name - The configuration's name. Max length: 5000.
  • naver_pay - Expandable.
  • nz_bank_account - Expandable.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: payment_method_configuration.
  • oxxo - Expandable.
  • p24 - Expandable.
  • parent - For child configs, the configuration's parent configuration. Max length: 5000. Nullable.
  • pay_by_bank - Expandable.
  • payco - Expandable.
  • paynow - Expandable.
  • paypal - Expandable.
  • payto - Expandable.
  • pix - Expandable.
  • promptpay - Expandable.
  • revolut_pay - Expandable.
  • samsung_pay - Expandable.
  • satispay - Expandable.
  • sepa_debit - Expandable.
  • sofort - Expandable.
  • swish - Expandable.
  • twint - Expandable.
  • us_bank_account - Expandable.
  • wechat_pay - Expandable.
  • zip - Expandable.

Functions

expandable_fields()

object_name()