reporting_report_run
The Report Run object represents an instance of a report type generated with specific run parameters. Once the object is created, Stripe begins processing the report. When the report has finished running, it will give you a reference to a file where you can retrieve your results. For an overview, see API Access to Reports.
Note that certain report types can only be run based on your live-mode data (not test-mode data), and will error when queried without a live-mode API key.
Summary
Types
@type t() :: %StripeElixir.Resources.Reporting.ReportRun{ created: integer(), error: String.t(), id: String.t(), livemode: boolean(), object: String.t(), parameters: map(), report_type: String.t(), result: String.t() | map(), status: String.t(), succeeded_at: integer() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.error- If something should go wrong during the run, a message about the failure (populated whenstatus=failed). Max length: 5000. Nullable.id- Unique identifier for the object. Max length: 5000.livemode-trueif the report is run on live mode data andfalseif it is run on test mode data.object- String representing the object's type. Objects of the same type share the same value. Possible values:reporting.report_run.parameters- Expandable.report_type- The ID of the report type to run, such as"balance.summary.1". Max length: 5000.result- The file object representing the result of the report run (populated whenstatus=succeeded). Nullable. Expandable.status- Status of this report run. This will bependingwhen the run is initially created. When the run finishes, this will be set tosucceededand theresultfield will be populated. Rarely, we may encounter an error, at which point this will be set tofailedand theerrorfield will be populated. Max length: 5000.succeeded_at- Timestamp at which this run successfully finished (populated whenstatus=succeeded). Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.