StripeElixir.Resources.SwishHandleRedirectOrDisplayQrCode
(stripe_elixir v0.1.0)
PaymentIntentNextActionSwishHandleRedirectOrDisplayQrCode
Summary
Types
@type t() :: %StripeElixir.Resources.SwishHandleRedirectOrDisplayQrCode{ hosted_instructions_url: String.t(), mobile_auth_url: String.t(), qr_code: String.t() | map() }
hosted_instructions_url- The URL to the hosted Swish instructions page, which allows customers to view the QR code. Max length: 5000.mobile_auth_url- The url for mobile redirect based auth (for internal use only and not typically available in standard API requests). Max length: 5000.qr_code- Expandable.