StripeElixir.Resources.Tax.Settings (stripe_elixir v0.1.0)

Copy Markdown View Source

TaxProductResourceTaxSettings

You can use Tax Settings to manage configurations used by Stripe Tax calculations.

Related guide: Using the Settings API

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Tax.Settings{
  defaults: map(),
  head_office: map(),
  livemode: boolean(),
  object: String.t(),
  status: String.t(),
  status_details: map()
}
  • defaults - Expandable.
  • head_office - The place where your business is located. Nullable. Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: tax.settings.
  • status - The status of the Tax Settings. Possible values: active, pending.
  • status_details - Expandable.

Functions

expandable_fields()

object_name()