StripeElixir.Resources.Tax.Transaction (stripe_elixir v0.1.0)

Copy Markdown View Source

TaxProductResourceTaxTransaction

A Tax Transaction records the tax collected from or refunded to your customer.

Related guide: Calculate tax in your custom payment flow

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Tax.Transaction{
  created: integer(),
  currency: String.t(),
  customer: String.t(),
  customer_details: map(),
  id: String.t(),
  line_items: map() | nil,
  livemode: boolean(),
  metadata: map(),
  object: String.t(),
  posted_at: integer(),
  reference: String.t(),
  reversal: map(),
  ship_from_details: map(),
  shipping_cost: map(),
  tax_date: integer(),
  type: String.t()
}
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Max length: 5000.
  • customer - The ID of an existing Customer used for the resource. Max length: 5000. Nullable.
  • customer_details - Expandable.
  • id - Unique identifier for the transaction. Max length: 5000.
  • line_items - The tax collected or refunded, by line item. Nullable. Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: tax.transaction.
  • posted_at - The Unix timestamp representing when the tax liability is assumed or reduced. Format: Unix timestamp.
  • reference - A custom unique identifier, such as 'myOrder_123'. Max length: 5000.
  • reversal - If type=reversal, contains information about what was reversed. Nullable. Expandable.
  • ship_from_details - The details of the ship from location, such as the address. Nullable. Expandable.
  • shipping_cost - The shipping cost details for the transaction. Nullable. Expandable.
  • tax_date - Timestamp of date at which the tax rules and rates in effect applies for the calculation. Format: Unix timestamp.
  • type - If reversal, this transaction reverses an earlier transaction. Possible values: reversal, transaction.

Functions

expandable_fields()

object_name()