StripeElixir.Resources.Terminal.Configuration (stripe_elixir v0.1.0)

Copy Markdown View Source

TerminalConfigurationConfiguration

A Configurations object represents how features should be configured for terminal readers. For information about how to use it, see the Terminal configurations documentation.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Terminal.Configuration{
  bbpos_wisepad3: map() | nil,
  bbpos_wisepos_e: map() | nil,
  id: String.t(),
  is_account_default: boolean(),
  livemode: boolean(),
  name: String.t(),
  object: String.t(),
  offline: map() | nil,
  reboot_window: map() | nil,
  stripe_s700: map() | nil,
  tipping: map() | nil,
  verifone_p400: map() | nil,
  wifi: map() | nil
}
  • bbpos_wisepad3 - Expandable.
  • bbpos_wisepos_e - Expandable.
  • id - Unique identifier for the object. Max length: 5000.
  • is_account_default - Whether this Configuration is the default for your account Nullable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • name - String indicating the name of the Configuration object, set by the user Max length: 5000. Nullable.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: terminal.configuration.
  • offline - Expandable.
  • reboot_window - Expandable.
  • stripe_s700 - Expandable.
  • tipping - Expandable.
  • verifone_p400 - Expandable.
  • wifi - Expandable.

Functions

expandable_fields()

object_name()