StripeElixir.Resources.Treasury.ReceivedDebit (stripe_elixir v0.1.0)

Copy Markdown View Source

TreasuryReceivedDebitsResourceReceivedDebit

ReceivedDebits represent funds pulled from a FinancialAccount. These are not initiated from the FinancialAccount.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Treasury.ReceivedDebit{
  amount: integer(),
  created: integer(),
  currency: String.t(),
  description: String.t(),
  failure_code: String.t(),
  financial_account: String.t(),
  hosted_regulatory_receipt_url: String.t(),
  id: String.t(),
  initiating_payment_method_details: map() | nil,
  linked_flows: map(),
  livemode: boolean(),
  network: String.t(),
  object: String.t(),
  reversal_details: map(),
  status: String.t(),
  transaction: String.t() | map()
}
  • amount - Amount (in cents) transferred.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.
  • failure_code - Reason for the failure. A ReceivedDebit might fail because the FinancialAccount doesn't have sufficient funds, is closed, or is frozen. Possible values: account_closed, account_frozen, insufficient_funds, international_transaction, other. Nullable.
  • financial_account - The FinancialAccount that funds were pulled from. Max length: 5000. Nullable.
  • hosted_regulatory_receipt_url - A hosted transaction receipt URL that is provided when money movement is considered regulated under Stripe's money transmission licenses. Max length: 5000. Nullable.
  • id - Unique identifier for the object. Max length: 5000.
  • initiating_payment_method_details - Expandable.
  • linked_flows - Expandable.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • network - The network used for the ReceivedDebit. Possible values: ach, card, stripe.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: treasury.received_debit.
  • reversal_details - Details describing when a ReceivedDebit might be reversed. Nullable. Expandable.
  • status - Status of the ReceivedDebit. ReceivedDebits are created with a status of either succeeded (approved) or failed (declined). The failure reason can be found under the failure_code. Possible values: failed, succeeded.
  • transaction - The Transaction associated with this object. Nullable. Expandable.

Functions

expandable_fields()

object_name()