StripeElixir.Resources.Treasury.Transaction (stripe_elixir v0.1.0)

Copy Markdown View Source

TreasuryTransactionsResourceTransaction

Transactions represent changes to a FinancialAccount's balance.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.Treasury.Transaction{
  amount: integer(),
  balance_impact: map(),
  created: integer(),
  currency: String.t(),
  description: String.t(),
  entries: map() | nil,
  financial_account: String.t(),
  flow: String.t(),
  flow_details: map() | nil,
  flow_type: String.t(),
  id: String.t(),
  livemode: boolean(),
  object: String.t(),
  status: String.t(),
  status_transitions: map()
}
  • amount - Amount (in cents) transferred.
  • balance_impact - Expandable.
  • created - Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.
  • currency - Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.
  • description - An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.
  • entries - A list of TransactionEntries that are part of this Transaction. This cannot be expanded in any list endpoints. Nullable. Expandable.
  • financial_account - The FinancialAccount associated with this object. Max length: 5000.
  • flow - ID of the flow that created the Transaction. Max length: 5000. Nullable.
  • flow_details - Details of the flow that created the Transaction. Nullable. Expandable.
  • flow_type - Type of the flow that created the Transaction. Possible values: credit_reversal, debit_reversal, inbound_transfer, issuing_authorization, other, outbound_payment, outbound_transfer, received_credit, received_debit.
  • id - Unique identifier for the object. Max length: 5000.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • object - String representing the object's type. Objects of the same type share the same value. Possible values: treasury.transaction.
  • status - Status of the Transaction. Possible values: open, posted, void.
  • status_transitions - Expandable.

Functions

expandable_fields()

object_name()