Account Link
Account Links let a platform create a temporary, single-use URL that an account can use to access a Stripe-hosted flow for collecting or updating required information.
Summary
Types
@type t() :: %StripeElixir.Resources.V2.Core.AccountLink{ account: String.t(), created: String.t(), expires_at: String.t(), livemode: boolean(), object: String.t(), url: String.t(), use_case: map() }
account- The ID of the connected account this Account Link applies to.created- The timestamp at which this Account Link was created. Format: date-time.expires_at- The timestamp at which this Account Link will expire. Format: date-time.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value of the object field. Possible values:v2.core.account_link.url- The URL at which the account can access the Stripe-hosted flow.use_case- Hash containing usage options.