StripeElixir.Resources.V2.Core.AccountPerson (stripe_elixir v0.1.0)

Copy Markdown View Source

Person

A Person represents an individual associated with an Account's identity (for example, an owner, director, executive, or representative). Use Persons to provide and update identity information for verification and compliance.

Summary

Types

t()

@type t() :: %StripeElixir.Resources.V2.Core.AccountPerson{
  account: String.t(),
  additional_addresses: [map()] | nil,
  additional_names: [map()] | nil,
  additional_terms_of_service: map() | nil,
  address: map() | nil,
  created: String.t(),
  date_of_birth: map() | nil,
  documents: map() | nil,
  email: String.t() | nil,
  given_name: String.t() | nil,
  id: String.t(),
  id_numbers: [map()] | nil,
  legal_gender: String.t() | nil,
  livemode: boolean(),
  metadata: map() | nil,
  nationalities: [String.t()] | nil,
  object: String.t(),
  phone: String.t() | nil,
  political_exposure: String.t() | nil,
  relationship: map() | nil,
  script_addresses: map() | nil,
  script_names: map() | nil,
  surname: String.t() | nil,
  updated: String.t()
}
  • account - The account ID which the individual belongs to.
  • additional_addresses - Additional addresses associated with the person.
  • additional_names - Additional names (e.g. aliases) associated with the person.
  • additional_terms_of_service - Attestations of accepted terms of service agreements.
  • address - The person's residential address.
  • created - Time at which the object was created. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z. Format: date-time.
  • date_of_birth - The person's date of birth.
  • documents - Documents that may be submitted to satisfy various informational requests.
  • email - The person's email address.
  • given_name - The person's first name.
  • id - Unique identifier for the Person.
  • id_numbers - The identification numbers (e.g., SSN) associated with the person.
  • legal_gender - The person's gender (International regulations require either "male" or "female"). Possible values: female, male.
  • livemode - Has the value true if the object exists in live mode or the value false if the object exists in test mode.
  • metadata - Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
  • nationalities - The countries where the person is a national. Two-letter country code (ISO 3166-1 alpha-2).
  • object - String representing the object's type. Objects of the same type share the same value of the object field. Possible values: v2.core.account_person.
  • phone - The person's phone number.
  • political_exposure - The person's political exposure. Possible values: existing, none.
  • relationship - The relationship that this person has with the Account's business or legal entity.
  • script_addresses - The script addresses (e.g., non-Latin characters) associated with the person.
  • script_names - The script names (e.g. non-Latin characters) associated with the person.
  • surname - The person's last name.
  • updated - Time at which the object was last updated. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z. Format: date-time.

Functions

object_name()