Event
Events are generated to keep you informed of activity in your business account. APIs in the /v2 namespace generate thin events which have small, unversioned payloads that include a reference to the ID of the object that has changed. The Events v2 API returns these new thin events. Retrieve the event object for additional data about the event. Use the related object ID in the event payload to fetch the API resource of the object associated with the event. Comparatively, events generated by most API v1 include a versioned snapshot of an API object in their payload.
Summary
Types
@type t() :: %StripeElixir.Resources.V2.Core.Event{ changes: map() | nil, context: String.t() | nil, created: String.t(), id: String.t(), livemode: boolean(), object: String.t(), reason: map() | nil, type: String.t() }
changes- Before and after changes for the primary related object.context- Authentication context needed to fetch the event or related object.created- Time at which the object was created. Format: date-time.id- Unique identifier for the event.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value of the object field. Possible values:v2.core.event.reason- Reason for the event.type- The type of the event.