StripeElixir.Services.AccountPersonService (stripe_elixir v0.1.0)

Copy Markdown View Source

AccountPerson API operations.

Summary

Functions

create(client, account, params \\ %{}, opts \\ [])

@spec create(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a person

Creates a new person.

delete(client, account, person, params \\ %{}, opts \\ [])

@spec delete(StripeElixir.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Delete a person

Deletes an existing person’s relationship to the account’s legal entity. Any person with a relationship for an account can be deleted through the API, except if the person is the account_opener. If your integration is using the executive parameter, you cannot delete the only verified executive on file.

list(client, account, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List all persons

Returns a list of people associated with the account’s legal entity. The people are returned sorted by creation date, with the most recent people appearing first.

retrieve(client, account, person, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve a person

Retrieves an existing person.

update(client, account, person, params \\ %{}, opts \\ [])

@spec update(StripeElixir.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Update a person

Updates an existing person.