PlatformFee
Summary
Functions
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List all application fees
Returns a list of application fees you’ve previously collected. The application fees are returned in sorted order, with the most recent fees appearing first.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve an application fee
Retrieves the details of an application fee that your account has collected. The same information is returned when refunding the application fee.