StripeElixir.Services.Billing.MeterEventAdjustmentService (stripe_elixir v0.1.0)

Copy Markdown View Source

BillingMeterEventAdjustment

A billing meter event adjustment is a resource that allows you to cancel a meter event. For example, you might create a billing meter event adjustment to cancel a meter event that was created in error or attached to the wrong customer.

Summary

Functions

Create a billing meter event adjustment

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a billing meter event adjustment

Creates a billing meter event adjustment.