StripeElixir.Services.FinancialConnections.AccountService (stripe_elixir v0.1.0)

Copy Markdown View Source

BankConnectionsResourceLinkedAccount

A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.

Summary

Functions

disconnect(client, account, params \\ %{}, opts \\ [])

@spec disconnect(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Disconnect an Account

Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).

list(client, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List Accounts

Returns a list of Financial Connections Account objects.

refresh(client, account, params \\ %{}, opts \\ [])

@spec refresh(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Refresh Account data

Refreshes the data associated with a Financial Connections Account.

retrieve(client, account, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve an Account

Retrieves the details of an Financial Connections Account.

subscribe(client, account, params \\ %{}, opts \\ [])

@spec subscribe(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Subscribe to data refreshes for an Account

Subscribes to periodic refreshes of data associated with a Financial Connections Account. When the account status is active, data is typically refreshed once a day.

unsubscribe(client, account, params \\ %{}, opts \\ [])

@spec unsubscribe(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Unsubscribe from data refreshes for an Account

Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.