StripeElixir.Services.MandateService (stripe_elixir v0.1.0)

Copy Markdown View Source

Mandate

A Mandate is a record of the permission that your customer gives you to debit their payment method.

Summary

Functions

retrieve(client, mandate, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve a Mandate

Retrieves a Mandate object.