PaymentLinkLineItem API operations.
Summary
Functions
Retrieve a payment link's line items
Functions
@spec list_line_items(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve a payment link's line items
When retrieving a payment link, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.