StripeElixir.Services.Radar.EarlyFraudWarningService (stripe_elixir v0.1.0)

Copy Markdown View Source

RadarEarlyFraudWarning

An early fraud warning indicates that the card issuer has notified us that a charge may be fraudulent.

Related guide: Early fraud warnings

Summary

Functions

list(client, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List all early fraud warnings

Returns a list of early fraud warnings.

retrieve(client, early_fraud_warning, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve an early fraud warning

Retrieves the details of an early fraud warning that has previously been created.

Please refer to the early fraud warning object reference for more details.