StripeElixir.Services.Terminal.ConnectionTokenService (stripe_elixir v0.1.0)

Copy Markdown View Source

TerminalConnectionToken

A Connection Token is used by the Stripe Terminal SDK to connect to a reader.

Related guide: Fleet management

Summary

Functions

create(client, params \\ %{}, opts \\ [])

@spec create(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a Connection Token

To connect to a reader the Stripe Terminal SDK needs to retrieve a short-lived connection token from Stripe, proxied through your server. On your backend, add an endpoint that creates and returns a connection token.