StripeElixir.Services.TestHelpers.Issuing.TransactionService (stripe_elixir v0.1.0)

Copy Markdown View Source

Transaction API operations.

Summary

Functions

create_force_capture(client, params \\ %{}, opts \\ [])

@spec create_force_capture(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a test-mode force capture

Allows the user to capture an arbitrary amount, also known as a forced capture.

create_unlinked_refund(client, params \\ %{}, opts \\ [])

@spec create_unlinked_refund(StripeElixir.Client.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a test-mode unlinked refund

Allows the user to refund an arbitrary amount, also known as a unlinked refund.

refund(client, transaction, params \\ %{}, opts \\ [])

@spec refund(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Refund a test-mode transaction

Refund a test-mode Transaction.