StripeElixir.Services.V2.Core.Accounts.PersonService (stripe_elixir v0.1.0)

Copy Markdown View Source

Person API operations.

Summary

Functions

create(client, account_id, params \\ %{}, opts \\ [])

@spec create(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Create a person

Create a Person. Adds an individual to an Account's identity. You can set relationship attributes and identity information at creation.

delete(client, account_id, id, params \\ %{}, opts \\ [])

@spec delete(StripeElixir.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Delete a person

Delete a Person associated with an Account.

list(client, account_id, params \\ %{}, opts \\ [])

@spec list(StripeElixir.Client.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

List persons

Returns a paginated list of Persons associated with an Account.

retrieve(client, account_id, id, params \\ %{}, opts \\ [])

@spec retrieve(StripeElixir.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Retrieve a person

Retrieves a Person associated with an Account.

update(client, account_id, id, params \\ %{}, opts \\ [])

@spec update(StripeElixir.Client.t(), String.t(), String.t(), map(), keyword()) ::
  {:ok, term()} | {:error, StripeElixir.Error.t()}

Update a person

Updates a Person associated with an Account.