Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountCreateParams.Controller{ fees: Stripe.Params.AccountCreateParams.Controller.Fees.t() | nil, losses: Stripe.Params.AccountCreateParams.Controller.Losses.t() | nil, requirement_collection: String.t() | nil, stripe_dashboard: Stripe.Params.AccountCreateParams.Controller.StripeDashboard.t() | nil }
fees- A hash of configuration for who pays Stripe fees for product usage on this account.losses- A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.requirement_collection- A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults tostripe. Possible values:application,stripe.stripe_dashboard- A hash of configuration for Stripe-hosted dashboards.