Stripe.Params.AccountCreateParams.Settings.Invoices
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountCreateParams.Settings.Invoices{ hosted_payment_method_save: String.t() | nil }
hosted_payment_method_save- Whether to save the payment method after a payment is completed for a one-time invoice or a subscription invoice when the customer already has a default payment method on the hosted invoice page. Possible values:always,never,offer.