Stripe.Params.AccountPersonUpdateParams.AdditionalTosAcceptances.Account
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountPersonUpdateParams.AdditionalTosAcceptances.Account{ date: integer() | nil, ip: String.t() | nil, user_agent: map() | nil }
date- The Unix timestamp marking when the account representative accepted the service agreement. Format: Unix timestamp.ip- The IP address from which the account representative accepted the service agreement.user_agent- The user agent of the browser from which the account representative accepted the service agreement.