Stripe.Params.AccountUpdateParams.Documents.ProofOfRegistration
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.AccountUpdateParams.Documents.ProofOfRegistration{ files: [String.t()] | nil, signer: Stripe.Params.AccountUpdateParams.Documents.ProofOfRegistration.Signer.t() | nil }
files- One or more document ids returned by a file upload with apurposevalue ofaccount_requirement.signer- Information regarding the person signing the document if applicable.