Stripe.Params.BalanceSettingsUpdateParams.Payments.SettlementTiming
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.BalanceSettingsUpdateParams.Payments.SettlementTiming{ delay_days_override: map() | nil }
delay_days_override- Changedelay_daysfor this account, which determines the number of days charge funds are held before becoming available. The maximum value is 31. Passing an empty string todelay_days_overridewill returndelay_daysto the default, which is the lowest available value for the account. Learn more about controlling delay days.