Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams
(tiger_stripe v0.1.10)
Parameters for credit balance summary retrieve.
Summary
Types
@type t() :: %Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams{ customer: String.t() | nil, customer_account: String.t() | nil, expand: [String.t()] | nil, filter: Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams.Filter.t() }
customer- The customer whose credit balance summary you're retrieving. Max length: 5000.customer_account- The account representing the customer whose credit balance summary you're retrieving. Max length: 5000.expand- Specifies which fields in the response should be expanded.filter- The filter criteria for the credit balance summary.