Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams.Filter
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams.Filter{ applicability_scope: Stripe.Params.Billing.CreditBalanceSummaryRetrieveParams.Filter.ApplicabilityScope.t() | nil, credit_grant: String.t() | nil, type: String.t() | nil }
applicability_scope- The billing credit applicability scope for which to fetch credit balance summary.credit_grant- The credit grant for which to fetch credit balance summary. Max length: 5000.type- Specify the type of this filter. Possible values:applicability_scope,credit_grant.