Stripe.Params.Billing.CreditGrantCreateParams.ApplicabilityConfig.Scope
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Billing.CreditGrantCreateParams.ApplicabilityConfig.Scope{ price_type: String.t() | nil, prices: [ Stripe.Params.Billing.CreditGrantCreateParams.ApplicabilityConfig.Scope.Prices.t() ] | nil }
price_type- The price type that credit grants can apply to. We currently only support themeteredprice type. Cannot be used in combination withprices. Possible values:metered.prices- A list of prices that the credit grant can apply to. We currently only support themeteredprices. Cannot be used in combination withprice_type.