Parameters for credit grant update.
Summary
Types
@type t() :: %Stripe.Params.Billing.CreditGrantUpdateParams{ expand: [String.t()] | nil, expires_at: map() | nil, metadata: %{required(String.t()) => String.t()} | nil }
expand- Specifies which fields in the response should be expanded.expires_at- The time when the billing credits created by this credit grant expire. If set to empty, the billing credits never expire.metadata- Set of key-value pairs you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.