Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.SubscriptionUpdate.ScheduleAtPeriodEnd
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.BillingPortal.ConfigurationUpdateParams.Features.SubscriptionUpdate.ScheduleAtPeriodEnd{ conditions: map() | nil }
conditions- List of conditions. When any condition is true, the update will be scheduled at the end of the current period.