Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.ChargeCreateParams.TransferData{ amount: integer() | nil, destination: String.t() | nil }
amount- The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.destination- ID of an existing, connected Stripe account. Max length: 5000.