Stripe.Params.Checkout.SessionCreateParams.ConsentCollection
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.ConsentCollection{ payment_method_reuse_agreement: Stripe.Params.Checkout.SessionCreateParams.ConsentCollection.PaymentMethodReuseAgreement.t() | nil, promotions: String.t() | nil, terms_of_service: String.t() | nil }
payment_method_reuse_agreement- Determines the display of payment method reuse agreement text in the UI. If set tohidden, it will hide legal text related to the reuse of a payment method.promotions- If set toauto, enables the collection of customer consent for promotional communications. The Checkout Session will determine whether to display an option to opt into promotional communication from the merchant depending on the customer's locale. Only available to US merchants. Possible values:auto,none.terms_of_service- If set torequired, it requires customers to check a terms of service checkbox before being able to pay. There must be a valid terms of service URL set in your Dashboard settings. Possible values:none,required.