Stripe.Params.Checkout.SessionCreateParams.LineItems
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.LineItems{ adjustable_quantity: Stripe.Params.Checkout.SessionCreateParams.LineItems.AdjustableQuantity.t() | nil, dynamic_tax_rates: [String.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil, price: String.t() | nil, price_data: Stripe.Params.Checkout.SessionCreateParams.LineItems.PriceData.t() | nil, quantity: integer() | nil, tax_rates: [String.t()] | nil }
adjustable_quantity- When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.dynamic_tax_rates- The tax rates that will be applied to this line item depending on the customer's billing/shipping address. We currently support the following countries: US, GB, AU, and all countries in the EU. You can't set this parameter ifui_modeiscustom.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.price- The ID of the Price or Plan object. One ofpriceorprice_datais required. Max length: 5000.price_data- Data used to generate a new Price object inline. One ofpriceorprice_datais required.quantity- The quantity of the line item being purchased. Quantity should not be defined whenrecurring.usage_type=metered.tax_rates- The tax rates which apply to this line item.