Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Card.Installments
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Card.Installments{ enabled: boolean() | nil }
enabled- Setting to true enables installments for this Checkout Session. Setting to false will prevent any installment plan from applying to a payment.