Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Card.Restrictions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.PaymentMethodOptions.Card.Restrictions{ brands_blocked: [String.t()] | nil }
brands_blocked- Specify the card brands to block in the Checkout Session. If a customer enters or selects a card belonging to a blocked brand, they can't complete the Session.