Stripe.Params.Checkout.SessionCreateParams.SetupIntentData
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.SetupIntentData{ description: String.t() | nil, metadata: %{required(String.t()) => String.t()} | nil, on_behalf_of: String.t() | nil }
description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 1000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.on_behalf_of- The Stripe account for which the setup is intended.