Stripe.Params.Checkout.SessionCreateParams.ShippingOptions.ShippingRateData.FixedAmount.CurrencyOptions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Checkout.SessionCreateParams.ShippingOptions.ShippingRateData.FixedAmount.CurrencyOptions{ amount: integer() | nil, tax_behavior: String.t() | nil }
amount- A non-negative integer in cents representing how much to charge.tax_behavior- Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Possible values:exclusive,inclusive,unspecified.