Parameters for order create.
Summary
Types
@type t() :: %Stripe.Params.Climate.OrderCreateParams{ amount: integer() | nil, beneficiary: Stripe.Params.Climate.OrderCreateParams.Beneficiary.t() | nil, currency: String.t() | nil, expand: [String.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil, metric_tons: String.t() | nil, product: String.t() }
amount- Requested amount of carbon removal units. Either this ormetric_tonsmust be specified.beneficiary- Publicly sharable reference for the end beneficiary of carbon removal. Assumed to be the Stripe account if not set.currency- Request currency for the order as a three-letter ISO currency code, in lowercase. Must be a supported settlement currency for your account. If omitted, the account's default currency will be used. Max length: 5000.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.metric_tons- Requested number of tons for the order. Either this oramountmust be specified. Format: decimal string.product- Unique identifier of the Climate product. Max length: 5000.