Parameters for coupon update.
Summary
Types
@type t() :: %Stripe.Params.CouponUpdateParams{ currency_options: %{ required(String.t()) => Stripe.Params.CouponUpdateParams.CurrencyOptions.t() } | nil, expand: [String.t()] | nil, metadata: map() | nil, name: String.t() | nil }
currency_options- Coupons defined in each available currency option (only supported if the coupon is amount-based). Each key must be a three-letter ISO currency code and a supported currency.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.name- Name of the coupon displayed to customers on, for instance invoices, or receipts. By default theidis shown ifnameis not set. Max length: 40.