Stripe.Params.FinancialConnections.SessionCreateParams
(tiger_stripe v0.1.10)
Parameters for session create.
Summary
Types
@type t() :: %Stripe.Params.FinancialConnections.SessionCreateParams{ account_holder: Stripe.Params.FinancialConnections.SessionCreateParams.AccountHolder.t(), expand: [String.t()] | nil, filters: Stripe.Params.FinancialConnections.SessionCreateParams.Filters.t() | nil, permissions: [String.t()], prefetch: [String.t()] | nil, return_url: String.t() | nil }
account_holder- The account holder to link accounts for.expand- Specifies which fields in the response should be expanded.filters- Filters to restrict the kinds of accounts to collect.permissions- List of data features that you would like to request access to.
Possible values are balances, transactions, ownership, and payment_method.
prefetch- List of data features that you would like to retrieve upon account creation.return_url- For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app. Max length: 5000.