Parameters for request create.
Summary
Types
@type t() :: %Stripe.Params.Forwarding.RequestCreateParams{ expand: [String.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil, payment_method: String.t(), replacements: [String.t()], request: Stripe.Params.Forwarding.RequestCreateParams.Request.t() | nil, url: String.t() }
expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.payment_method- The PaymentMethod to insert into the forwarded request. Forwarding previously consumed PaymentMethods is allowed. Max length: 5000.replacements- The field kinds to be replaced in the forwarded request.request- The request body and headers to be sent to the destination endpoint.url- The destination URL for the forwarded request. Must be supported by the config. Max length: 5000.