Stripe.Params.Identity.VerificationSessionUpdateParams
(tiger_stripe v0.1.10)
Parameters for verification session update.
Summary
Types
@type t() :: %Stripe.Params.Identity.VerificationSessionUpdateParams{ expand: [String.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil, options: Stripe.Params.Identity.VerificationSessionUpdateParams.Options.t() | nil, provided_details: Stripe.Params.Identity.VerificationSessionUpdateParams.ProvidedDetails.t() | nil, type: String.t() | nil }
expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.options- A set of options for the session’s verification checks.provided_details- Details provided about the user being verified. These details may be shown to the user.type- The type of verification check to be performed. Possible values:document,id_number.