Stripe.Params.InvoiceCreatePreviewParams.CustomerDetails.Tax
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.InvoiceCreatePreviewParams.CustomerDetails.Tax{ ip_address: map() | nil }
ip_address- A recent IP address of the customer used for tax reporting and tax location inference. Stripe recommends updating the IP address when a new PaymentMethod is attached or the address field on the customer is updated. We recommend against updating this field more frequently since it could result in unexpected tax location/reporting outcomes.