Parameters for card list.
Summary
Types
@type t() :: %Stripe.Params.Issuing.CardListParams{ cardholder: String.t() | nil, created: map() | nil, ending_before: String.t() | nil, exp_month: integer() | nil, exp_year: integer() | nil, expand: [String.t()] | nil, last4: String.t() | nil, limit: integer() | nil, personalization_design: String.t() | nil, starting_after: String.t() | nil, status: String.t() | nil, type: String.t() | nil }
cardholder- Only return cards belonging to the Cardholder with the provided ID. Max length: 5000.created- Only return cards that were issued during the given date interval.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.exp_month- Only return cards that have the given expiration month.exp_year- Only return cards that have the given expiration year.expand- Specifies which fields in the response should be expanded.last4- Only return cards that have the given last four digits. Max length: 5000.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.personalization_design- Max length: 5000.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.status- Only return cards that have the given status. One ofactive,inactive, orcanceled. Possible values:active,canceled,inactive.type- Only return cards that have the given type. One ofvirtualorphysical. Possible values:physical,virtual.