Stripe.Params.Issuing.CardholderCreateParams.Individual.Verification.Document
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Issuing.CardholderCreateParams.Individual.Verification.Document{ back: String.t() | nil, front: String.t() | nil }
back- The back of an ID returned by a file upload with apurposevalue ofidentity_document. Max length: 5000.front- The front of an ID returned by a file upload with apurposevalue ofidentity_document. Max length: 5000.