Stripe.Params.Issuing.CardholderUpdateParams.Individual.CardIssuing.UserTermsAcceptance
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Issuing.CardholderUpdateParams.Individual.CardIssuing.UserTermsAcceptance{ date: integer() | nil, ip: String.t() | nil, user_agent: map() | nil }
date- The Unix timestamp marking when the cardholder accepted the Authorized User Terms. Required for Celtic Spend Card users. Format: Unix timestamp.ip- The IP address from which the cardholder accepted the Authorized User Terms. Required for Celtic Spend Card users.user_agent- The user agent of the browser from which the cardholder accepted the Authorized User Terms.