Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PaymentLinkCreateParams.CustomText{ after_submit: map() | nil, shipping_address: map() | nil, submit: map() | nil, terms_of_service_acceptance: map() | nil }
after_submit- Custom text that should be displayed after the payment confirmation button.shipping_address- Custom text that should be displayed alongside shipping address collection.submit- Custom text that should be displayed alongside the payment confirmation button.terms_of_service_acceptance- Custom text that should be displayed in place of the default terms of service agreement text.