Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PaymentLinkUpdateParams.AutomaticTax{ enabled: boolean() | nil, liability: Stripe.Params.PaymentLinkUpdateParams.AutomaticTax.Liability.t() | nil }
enabled- Set totrueto calculate tax automatically using the customer's location.
Enabling this parameter causes the payment link to collect any billing address information necessary for tax calculation.
liability- The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.