Stripe.Params.PaymentRecordReportPaymentAttemptParams
(tiger_stripe v0.1.10)
Parameters for payment record report payment attempt.
Summary
Types
@type t() :: %Stripe.Params.PaymentRecordReportPaymentAttemptParams{ description: String.t() | nil, expand: [String.t()] | nil, failed: Stripe.Params.PaymentRecordReportPaymentAttemptParams.Failed.t() | nil, guaranteed: Stripe.Params.PaymentRecordReportPaymentAttemptParams.Guaranteed.t() | nil, initiated_at: integer(), metadata: map() | nil, outcome: String.t() | nil, payment_method_details: Stripe.Params.PaymentRecordReportPaymentAttemptParams.PaymentMethodDetails.t() | nil, shipping_details: Stripe.Params.PaymentRecordReportPaymentAttemptParams.ShippingDetails.t() | nil }
description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.expand- Specifies which fields in the response should be expanded.failed- Information about the payment attempt failure.guaranteed- Information about the payment attempt guarantee.initiated_at- When the reported payment was initiated. Measured in seconds since the Unix epoch. Format: Unix timestamp.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.outcome- The outcome of the reported payment. Possible values:failed,guaranteed.payment_method_details- Information about the Payment Method debited for this payment.shipping_details- Shipping information for this payment.