Parameters for payout reverse.
Summary
Types
@type t() :: %Stripe.Params.PayoutReverseParams{ expand: [String.t()] | nil, metadata: %{required(String.t()) => String.t()} | nil }
expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.