Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.PriceCreateParams.Recurring{ interval: String.t() | nil, interval_count: integer() | nil, meter: String.t() | nil, trial_period_days: integer() | nil, usage_type: String.t() | nil }
interval- Specifies billing frequency. Eitherday,week,monthoryear. Possible values:day,month,week,year.interval_count- The number of intervals between subscription billings. For example,interval=monthandinterval_count=3bills every 3 months. Maximum of three years interval allowed (3 years, 36 months, or 156 weeks).meter- The meter tracking the usage of a metered price Max length: 5000.trial_period_days- Default number of trial days when subscribing a customer to this price usingtrial_from_plan=true.usage_type- Configures how the quantity per period should be determined. Can be eithermeteredorlicensed.licensedautomatically bills thequantityset when adding it to a subscription.meteredaggregates the total usage based on usage records. Defaults tolicensed. Possible values:licensed,metered.