Parameters for product list.
Summary
Types
@type t() :: %Stripe.Params.ProductListParams{ active: boolean() | nil, created: map() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, ids: [String.t()] | nil, limit: integer() | nil, shippable: boolean() | nil, starting_after: String.t() | nil, type: String.t() | nil, url: String.t() | nil }
active- Only return products that are active or inactive (e.g., passfalseto list all inactive products).created- Only return products that were created during the given date interval.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.ids- Only return products with the given IDs. Cannot be used with starting_after or ending_before.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.shippable- Only return products that can be shipped (i.e., physical, not digital products).starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.type- Only return products of this type. Possible values:good,service.url- Only return products with the given url. Max length: 5000.