Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.QuoteCreateParams.LineItems{ discounts: map() | nil, price: String.t() | nil, price_data: Stripe.Params.QuoteCreateParams.LineItems.PriceData.t() | nil, quantity: integer() | nil, tax_rates: map() | nil }
discounts- The discounts applied to this line item.price- The ID of the price object. One ofpriceorprice_datais required. Max length: 5000.price_data- Data used to generate a new Price object inline. One ofpriceorprice_datais required.quantity- The quantity of the line item.tax_rates- The tax rates which apply to the line item. When set, thedefault_tax_rateson the quote do not apply to this line item.