Parameters for quote finalize quote.
Summary
Types
@type t() :: %Stripe.Params.QuoteFinalizeQuoteParams{ expand: [String.t()] | nil, expires_at: integer() | nil }
expand- Specifies which fields in the response should be expanded.expires_at- A future timestamp on which the quote will be canceled if inopenordraftstatus. Measured in seconds since the Unix epoch. Format: Unix timestamp.