Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.QuoteUpdateParams.InvoiceSettings{ days_until_due: integer() | nil, issuer: Stripe.Params.QuoteUpdateParams.InvoiceSettings.Issuer.t() | nil }
days_until_due- Number of days within which a customer must pay the invoice generated by this quote. This value will benullfor quotes wherecollection_method=charge_automatically.issuer- The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.