Stripe.Params.Radar.PaymentEvaluationCreateParams.PaymentDetails
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Radar.PaymentEvaluationCreateParams.PaymentDetails{ amount: integer() | nil, currency: String.t() | nil, description: String.t() | nil, money_movement_details: Stripe.Params.Radar.PaymentEvaluationCreateParams.PaymentDetails.MoneyMovementDetails.t() | nil, payment_method_details: Stripe.Params.Radar.PaymentEvaluationCreateParams.PaymentDetails.PaymentMethodDetails.t() | nil, shipping_details: Stripe.Params.Radar.PaymentEvaluationCreateParams.PaymentDetails.ShippingDetails.t() | nil, statement_descriptor: String.t() | nil }
amount- The intended amount to collect with this payment. A positive integer representing how much to charge in the smallest currency unit (for example, 100 cents to charge 1.00 USD or 100 to charge 100 Yen, a zero-decimal currency).currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.money_movement_details- Details about the payment's customer presence and type.payment_method_details- Details about the payment method to use for the payment.shipping_details- Shipping details for the payment evaluation.statement_descriptor- Payment statement descriptor. Max length: 5000.