Stripe.Params.SetupIntentCreateParams.PaymentMethodData.NzBankAccount
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SetupIntentCreateParams.PaymentMethodData.NzBankAccount{ account_holder_name: String.t() | nil, account_number: String.t() | nil, bank_code: String.t() | nil, branch_code: String.t() | nil, reference: String.t() | nil, suffix: String.t() | nil }
account_holder_name- The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details. Max length: 5000.account_number- The account number for the bank account. Max length: 5000.bank_code- The numeric code for the bank account's bank. Max length: 5000.branch_code- The numeric code for the bank account's bank branch. Max length: 5000.reference- Max length: 128.suffix- The suffix of the bank account number. Max length: 5000.