Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions{ acss_debit: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.AcssDebit.t() | nil, amazon_pay: map() | nil, bacs_debit: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.BacsDebit.t() | nil, card: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Card.t() | nil, card_present: map() | nil, klarna: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Klarna.t() | nil, link: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Link.t() | nil, paypal: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Paypal.t() | nil, payto: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Payto.t() | nil, sepa_debit: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.SepaDebit.t() | nil, us_bank_account: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.UsBankAccount.t() | nil }
acss_debit- If this is aacss_debitSetupIntent, this sub-hash contains details about the ACSS Debit payment method options.amazon_pay- If this is aamazon_paySetupIntent, this sub-hash contains details about the AmazonPay payment method options.bacs_debit- If this is abacs_debitSetupIntent, this sub-hash contains details about the Bacs Debit payment method options.card- Configuration for any card setup attempted on this SetupIntent.card_present- If this is acard_presentPaymentMethod, this sub-hash contains details about the card-present payment method options.klarna- If this is aklarnaPaymentMethod, this hash contains details about the Klarna payment method options.link- If this is alinkPaymentMethod, this sub-hash contains details about the Link payment method options.paypal- If this is apaypalPaymentMethod, this sub-hash contains details about the PayPal payment method options.payto- If this is apaytoSetupIntent, this sub-hash contains details about the PayTo payment method options.sepa_debit- If this is asepa_debitSetupIntent, this sub-hash contains details about the SEPA Debit payment method options.us_bank_account- If this is aus_bank_accountSetupIntent, this sub-hash contains details about the US bank account payment method options.