Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Klarna.OnDemand
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.Klarna.OnDemand{ average_amount: integer() | nil, maximum_amount: integer() | nil, minimum_amount: integer() | nil, purchase_interval: String.t() | nil, purchase_interval_count: integer() | nil }
average_amount- Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.maximum_amount- The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.minimum_amount- The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.purchase_interval- Interval at which the customer is making purchases Possible values:day,month,week,year.purchase_interval_count- The number ofpurchase_intervalbetween charges