Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.UsBankAccount.FinancialConnections
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.UsBankAccount.FinancialConnections{ filters: Stripe.Params.SetupIntentCreateParams.PaymentMethodOptions.UsBankAccount.FinancialConnections.Filters.t() | nil, permissions: [String.t()] | nil, prefetch: [String.t()] | nil, return_url: String.t() | nil }
filters- Provide filters for the linked accounts that the customer can select for the payment method.permissions- The list of permissions to request. If this parameter is passed, thepayment_methodpermission must be included. Valid permissions include:balances,ownership,payment_method, andtransactions.prefetch- List of data features that you would like to retrieve upon account creation.return_url- For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app. Max length: 5000.