Parameters for shipping rate update.
Summary
Types
@type t() :: %Stripe.Params.ShippingRateUpdateParams{ active: boolean() | nil, expand: [String.t()] | nil, fixed_amount: Stripe.Params.ShippingRateUpdateParams.FixedAmount.t() | nil, metadata: map() | nil, tax_behavior: String.t() | nil }
active- Whether the shipping rate can be used for new purchases. Defaults totrue.expand- Specifies which fields in the response should be expanded.fixed_amount- Describes a fixed amount to charge for shipping. Must be present if type isfixed_amount.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.tax_behavior- Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One ofinclusive,exclusive, orunspecified. Possible values:exclusive,inclusive,unspecified.