Stripe.Params.SourceUpdateParams.Mandate.Acceptance
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SourceUpdateParams.Mandate.Acceptance{ date: integer() | nil, ip: String.t() | nil, offline: Stripe.Params.SourceUpdateParams.Mandate.Acceptance.Offline.t() | nil, online: Stripe.Params.SourceUpdateParams.Mandate.Acceptance.Online.t() | nil, status: String.t() | nil, type: String.t() | nil, user_agent: String.t() | nil }
date- The Unix timestamp (in seconds) when the mandate was accepted or refused by the customer. Format: Unix timestamp.ip- The IP address from which the mandate was accepted or refused by the customer.offline- The parameters required to store a mandate accepted offline. Should only be set ifmandate[type]isofflineonline- The parameters required to store a mandate accepted online. Should only be set ifmandate[type]isonlinestatus- The status of the mandate acceptance. Eitheraccepted(the mandate was accepted) orrefused(the mandate was refused). Possible values:accepted,pending,refused,revoked. Max length: 5000.type- The type of acceptance information included with the mandate. EitheronlineorofflinePossible values:offline,online. Max length: 5000.user_agent- The user agent of the browser from which the mandate was accepted or refused by the customer. Max length: 5000.