Stripe.Params.SubscriptionCreateParams.InvoiceSettings
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionCreateParams.InvoiceSettings{ account_tax_ids: map() | nil, issuer: Stripe.Params.SubscriptionCreateParams.InvoiceSettings.Issuer.t() | nil }
account_tax_ids- The account tax IDs associated with the subscription. Will be set on invoices generated by the subscription.issuer- The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.