Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionListParams.AutomaticTax{ enabled: boolean() | nil }
enabled- Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.