Parameters for subscription schedule cancel.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionScheduleCancelParams{ expand: [String.t()] | nil, invoice_now: boolean() | nil, prorate: boolean() | nil }
expand- Specifies which fields in the response should be expanded.invoice_now- If the subscription schedule isactive, indicates if a final invoice will be generated that contains any un-invoiced metered usage and new/pending proration invoice items. Defaults totrue.prorate- If the subscription schedule isactive, indicates if the cancellation should be prorated. Defaults totrue.