Stripe.Params.SubscriptionUpdateParams.CancellationDetails
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.SubscriptionUpdateParams.CancellationDetails{ comment: map() | nil, feedback: String.t() | nil }
comment- Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user.feedback- The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user. Possible values:customer_service,low_quality,missing_features,other,switched_service,too_complex,too_expensive,unused.