Stripe.Params.Tax.CalculationCreateParams.LineItems
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Tax.CalculationCreateParams.LineItems{ amount: integer() | nil, metadata: %{required(String.t()) => String.t()} | nil, product: String.t() | nil, quantity: integer() | nil, reference: String.t() | nil, tax_behavior: String.t() | nil, tax_code: String.t() | nil }
amount- A positive integer representing the line item's total price in the smallest currency unit. Iftax_behavior=inclusive, then this amount includes taxes. Otherwise, taxes are calculated on top of this amount.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.product- If provided, the product'stax_codewill be used as the line item'stax_code. Max length: 5000.quantity- The number of units of the item being purchased. Used to calculate the per-unit price from the totalamountfor the line. For example, ifamount=100andquantity=4, the calculated unit price is 25.reference- A custom identifier for this line item, which must be unique across the line items in the calculation. The reference helps identify each line item in exported tax reports. Max length: 500.tax_behavior- Specifies whether theamountincludes taxes. Defaults toexclusive. Possible values:exclusive,inclusive.tax_code- A tax code ID to use for this line item. If not provided, we will use the tax code from the providedproductparam. If neithertax_codenorproductis provided, we will use the default tax code from your Tax Settings.