Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.CustomText
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.CustomText{ description: String.t() | nil, skip_button: String.t() | nil, submit_button: String.t() | nil, title: String.t() | nil }
description- The description which will be displayed when collecting this input Max length: 500.skip_button- Custom text for the skip button. Maximum 14 characters. Max length: 14.submit_button- Custom text for the submit button. Maximum 30 characters. Max length: 30.title- The title which will be displayed when collecting this input Max length: 40.