Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Selection.Choices
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Selection.Choices{ id: String.t() | nil, style: String.t() | nil, text: String.t() | nil }
id- The unique identifier for this choice Max length: 50.style- The style of the button which will be shown for this choice. Can beprimaryorsecondary. Possible values:primary,secondary.text- The text which will be shown on the button for this choice Max length: 30.