Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Toggles
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderCollectInputsParams.Inputs.Toggles{ default_value: String.t() | nil, description: String.t() | nil, title: String.t() | nil }
default_value- The default value of the toggle. Can beenabledordisabled. Possible values:disabled,enabled.description- The description which will be displayed for the toggle. Maximum 50 characters. At least one of title or description must be provided. Max length: 50.title- The title which will be displayed for the toggle. Maximum 50 characters. At least one of title or description must be provided. Max length: 50.