Parameters for reader create.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderCreateParams{ expand: [String.t()] | nil, label: String.t() | nil, location: String.t() | nil, metadata: map() | nil, registration_code: String.t() }
expand- Specifies which fields in the response should be expanded.label- Custom label given to the reader for easier identification. If no label is specified, the registration code will be used. Max length: 5000.location- The location to assign the reader to. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.registration_code- A code generated by the reader used for registering to an account. Max length: 5000.