Stripe.Params.Terminal.ReaderProcessPaymentIntentParams
(tiger_stripe v0.1.10)
Parameters for reader process payment intent.
Summary
Types
@type t() :: %Stripe.Params.Terminal.ReaderProcessPaymentIntentParams{ expand: [String.t()] | nil, payment_intent: String.t(), process_config: Stripe.Params.Terminal.ReaderProcessPaymentIntentParams.ProcessConfig.t() | nil }
expand- Specifies which fields in the response should be expanded.payment_intent- The ID of the PaymentIntent to process on the reader. Max length: 5000.process_config- Configuration overrides for this transaction, such as tipping and customer cancellation settings.