Stripe.Params.TestHelpers.Issuing.AuthorizationFinalizeAmountParams
(tiger_stripe v0.1.10)
Parameters for authorization finalize amount.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.Issuing.AuthorizationFinalizeAmountParams{ expand: [String.t()] | nil, final_amount: integer(), fleet: Stripe.Params.TestHelpers.Issuing.AuthorizationFinalizeAmountParams.Fleet.t() | nil, fuel: Stripe.Params.TestHelpers.Issuing.AuthorizationFinalizeAmountParams.Fuel.t() | nil }
expand- Specifies which fields in the response should be expanded.final_amount- The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the smallest currency unit.fleet- Fleet-specific information for authorizations using Fleet cards.fuel- Information about fuel that was purchased with this transaction.