Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails{ fleet: Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Fleet.t() | nil, flight: Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Flight.t() | nil, fuel: Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Fuel.t() | nil, lodging: Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Lodging.t() | nil, receipt: [ Stripe.Params.TestHelpers.Issuing.TransactionCreateUnlinkedRefundParams.PurchaseDetails.Receipt.t() ] | nil, reference: String.t() | nil }
fleet- Fleet-specific information for transactions using Fleet cards.flight- Information about the flight that was purchased with this transaction.fuel- Information about fuel that was purchased with this transaction.lodging- Information about lodging that was purchased with this transaction.receipt- The line items in the purchase.reference- A merchant-specific order number. Max length: 5000.