Parameters for outbound payment create.
Summary
Types
@type t() :: %Stripe.Params.Treasury.OutboundPaymentCreateParams{ amount: integer(), currency: String.t(), customer: String.t() | nil, description: String.t() | nil, destination_payment_method: String.t() | nil, destination_payment_method_data: Stripe.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodData.t() | nil, destination_payment_method_options: Stripe.Params.Treasury.OutboundPaymentCreateParams.DestinationPaymentMethodOptions.t() | nil, end_user_details: Stripe.Params.Treasury.OutboundPaymentCreateParams.EndUserDetails.t() | nil, expand: [String.t()] | nil, financial_account: String.t(), metadata: %{required(String.t()) => String.t()} | nil, statement_descriptor: String.t() | nil }
amount- Amount (in cents) to be transferred.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.customer- ID of the customer to whom the OutboundPayment is sent. Must match the Customer attached to thedestination_payment_methodpassed in. Max length: 5000.description- An arbitrary string attached to the object. Often useful for displaying to users. Max length: 5000.destination_payment_method- The PaymentMethod to use as the payment instrument for the OutboundPayment. Exclusive withdestination_payment_method_data. Max length: 5000.destination_payment_method_data- Hash used to generate the PaymentMethod to be used for this OutboundPayment. Exclusive withdestination_payment_method.destination_payment_method_options- Payment method-specific configuration for this OutboundPayment.end_user_details- End user details.expand- Specifies which fields in the response should be expanded.financial_account- The FinancialAccount to pull funds from.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.statement_descriptor- The description that appears on the receiving end for this OutboundPayment (for example, bank statement for external bank transfer). Maximum 10 characters forachpayments, 140 characters forus_domestic_wirepayments, or 500 characters forstripenetwork transfers. Can only include -#.$&*, spaces, and alphanumeric characters. The default value is "payment". Max length: 5000.