Parameters for transaction list.
Summary
Types
@type t() :: %Stripe.Params.Treasury.TransactionListParams{ created: map() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, financial_account: String.t(), limit: integer() | nil, order_by: String.t() | nil, starting_after: String.t() | nil, status: String.t() | nil, status_transitions: Stripe.Params.Treasury.TransactionListParams.StatusTransitions.t() | nil }
created- Only return Transactions that were created during the given date interval.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.financial_account- Returns objects associated with this FinancialAccount.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.order_by- The results are in reverse chronological order bycreatedorposted_at. The default iscreated. Possible values:created,posted_at.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.status- Only return Transactions that have the given status:open,posted, orvoid. Possible values:open,posted,void.status_transitions- A filter for thestatus_transitions.posted_attimestamp. When using this filter,status=postedandorder_by=posted_atmust also be specified.