Parameters for meter event create.
Summary
Types
@type t() :: %Stripe.Params.V2.Billing.MeterEventCreateParams{ event_name: String.t(), identifier: String.t() | nil, payload: %{required(String.t()) => String.t()}, timestamp: String.t() | nil }
event_name- The name of the meter event. Corresponds with theevent_namefield on a meter.identifier- A unique identifier for the event. If not provided, one will be generated. We recommend using a globally unique identifier for this. We’ll enforce uniqueness within a rolling 24 hour period.payload- The payload of the event. This must contain the fields corresponding to a meter’scustomer_mapping.event_payload_key(default isstripe_customer_id) andvalue_settings.event_payload_key(default isvalue). Read more about the payload.timestamp- The time of the event. Must be within the past 35 calendar days or up to 5 minutes in the future. Defaults to current timestamp if not specified. Format: date-time.