Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations{ directorship_declaration: Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.DirectorshipDeclaration.t() | nil, ownership_declaration: Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.OwnershipDeclaration.t() | nil, persons_provided: Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.PersonsProvided.t() | nil, representative_declaration: Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.RepresentativeDeclaration.t() | nil, terms_of_service: Stripe.Params.V2.Core.AccountCreateParams.Identity.Attestations.TermsOfService.t() | nil }
directorship_declaration- This hash is used to attest that the directors information provided to Stripe is both current and correct.ownership_declaration- This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.persons_provided- Attestation that all Persons with a specific Relationship value have been provided.representative_declaration- This hash is used to attest that the representative is authorized to act as the representative of their legal entity.terms_of_service- Attestations of accepted terms of service agreements.