Stripe.Params.V2.Core.AccountTokenCreateParams.Identity.Attestations.RepresentativeDeclaration
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountTokenCreateParams.Identity.Attestations.RepresentativeDeclaration{ attested: boolean() | nil }
attested- A boolean indicating if the representative is authorized to act as the representative of their legal entity.