Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant{ applied: boolean() | nil, bacs_debit_payments: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.BacsDebitPayments.t() | nil, branding: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Branding.t() | nil, capabilities: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Capabilities.t() | nil, card_payments: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.CardPayments.t() | nil, konbini_payments: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.KonbiniPayments.t() | nil, mcc: String.t() | nil, script_statement_descriptor: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.ScriptStatementDescriptor.t() | nil, statement_descriptor: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.StatementDescriptor.t() | nil, support: Stripe.Params.V2.Core.AccountUpdateParams.Configuration.Merchant.Support.t() | nil }
applied- Represents the state of the configuration, and can be updated to deactivate or re-apply a configuration.bacs_debit_payments- Settings for Bacs Direct Debit payments.branding- Settings used to apply the merchant's branding to email receipts, invoices, Checkout, and other products.capabilities- Capabilities to request on the Merchant Configuration.card_payments- Card payments settings.konbini_payments- Settings specific to Konbini payments on the account.mcc- The Merchant Category Code (MCC) for the merchant. MCCs classify businesses based on the goods or services they provide.script_statement_descriptor- Settings for the default text that appears on statements for language variations.statement_descriptor- Settings for the default statement descriptor text.support- Publicly available contact information for sending support issues to.