Stripe.Params.V2.Core.AccountUpdateParams.Identity.BusinessDetails.AnnualRevenue
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.AccountUpdateParams.Identity.BusinessDetails.AnnualRevenue{ amount: Stripe.Params.V2.Core.AccountUpdateParams.Identity.BusinessDetails.AnnualRevenue.Amount.t() | nil, fiscal_year_end: String.t() | nil }
amount- A non-negative integer representing the amount in the smallest currency unit.fiscal_year_end- The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.