Stripe.Params.V2.Core.Accounts.PersonCreateParams.Documents.PrimaryVerification.FrontBack
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.Accounts.PersonCreateParams.Documents.PrimaryVerification.FrontBack{ back: String.t() | nil, front: String.t() | nil }
back- A file upload token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.front- A file upload token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.