Stripe.Params.V2.Core.Accounts.PersonTokenCreateParams.Documents
(tiger_stripe v0.1.10)
Nested parameters.
Summary
Types
@type t() :: %Stripe.Params.V2.Core.Accounts.PersonTokenCreateParams.Documents{ company_authorization: Stripe.Params.V2.Core.Accounts.PersonTokenCreateParams.Documents.CompanyAuthorization.t() | nil, passport: Stripe.Params.V2.Core.Accounts.PersonTokenCreateParams.Documents.Passport.t() | nil, primary_verification: Stripe.Params.V2.Core.Accounts.PersonTokenCreateParams.Documents.PrimaryVerification.t() | nil, secondary_verification: Stripe.Params.V2.Core.Accounts.PersonTokenCreateParams.Documents.SecondaryVerification.t() | nil, visa: Stripe.Params.V2.Core.Accounts.PersonTokenCreateParams.Documents.Visa.t() | nil }
company_authorization- One or more documents that demonstrate proof that this person is authorized to represent the company.passport- One or more documents showing the person’s passport page with photo and personal data.primary_verification- An identifying document showing the person's name, either a passport or local ID card.secondary_verification- A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.visa- One or more documents showing the person’s visa required for living in the country where they are residing.