Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Capabilities{ acss_debit_payments: String.t() | nil, affirm_payments: String.t() | nil, afterpay_clearpay_payments: String.t() | nil, alma_payments: String.t() | nil, amazon_pay_payments: String.t() | nil, au_becs_debit_payments: String.t() | nil, bacs_debit_payments: String.t() | nil, bancontact_payments: String.t() | nil, bank_transfer_payments: String.t() | nil, billie_payments: String.t() | nil, blik_payments: String.t() | nil, boleto_payments: String.t() | nil, card_issuing: String.t() | nil, card_payments: String.t() | nil, cartes_bancaires_payments: String.t() | nil, cashapp_payments: String.t() | nil, crypto_payments: String.t() | nil, eps_payments: String.t() | nil, fpx_payments: String.t() | nil, gb_bank_transfer_payments: String.t() | nil, giropay_payments: String.t() | nil, grabpay_payments: String.t() | nil, ideal_payments: String.t() | nil, india_international_payments: String.t() | nil, jcb_payments: String.t() | nil, jp_bank_transfer_payments: String.t() | nil, kakao_pay_payments: String.t() | nil, klarna_payments: String.t() | nil, konbini_payments: String.t() | nil, kr_card_payments: String.t() | nil, legacy_payments: String.t() | nil, link_payments: String.t() | nil, mb_way_payments: String.t() | nil, mobilepay_payments: String.t() | nil, multibanco_payments: String.t() | nil, mx_bank_transfer_payments: String.t() | nil, naver_pay_payments: String.t() | nil, nz_bank_account_becs_debit_payments: String.t() | nil, oxxo_payments: String.t() | nil, p24_payments: String.t() | nil, pay_by_bank_payments: String.t() | nil, payco_payments: String.t() | nil, paynow_payments: String.t() | nil, payto_payments: String.t() | nil, pix_payments: String.t() | nil, promptpay_payments: String.t() | nil, revolut_pay_payments: String.t() | nil, samsung_pay_payments: String.t() | nil, satispay_payments: String.t() | nil, sepa_bank_transfer_payments: String.t() | nil, sepa_debit_payments: String.t() | nil, sofort_payments: String.t() | nil, swish_payments: String.t() | nil, tax_reporting_us_1099_k: String.t() | nil, tax_reporting_us_1099_misc: String.t() | nil, transfers: String.t() | nil, treasury: String.t() | nil, twint_payments: String.t() | nil, us_bank_account_ach_payments: String.t() | nil, us_bank_transfer_payments: String.t() | nil, zip_payments: String.t() | nil }
acss_debit_payments- The status of the Canadian pre-authorized debits payments capability of the account, or whether the account can directly process Canadian pre-authorized debits charges. Possible values:active,inactive,pending.affirm_payments- The status of the Affirm capability of the account, or whether the account can directly process Affirm charges. Possible values:active,inactive,pending.afterpay_clearpay_payments- The status of the Afterpay Clearpay capability of the account, or whether the account can directly process Afterpay Clearpay charges. Possible values:active,inactive,pending.alma_payments- The status of the Alma capability of the account, or whether the account can directly process Alma payments. Possible values:active,inactive,pending.amazon_pay_payments- The status of the AmazonPay capability of the account, or whether the account can directly process AmazonPay payments. Possible values:active,inactive,pending.au_becs_debit_payments- The status of the BECS Direct Debit (AU) payments capability of the account, or whether the account can directly process BECS Direct Debit (AU) charges. Possible values:active,inactive,pending.bacs_debit_payments- The status of the Bacs Direct Debits payments capability of the account, or whether the account can directly process Bacs Direct Debits charges. Possible values:active,inactive,pending.bancontact_payments- The status of the Bancontact payments capability of the account, or whether the account can directly process Bancontact charges. Possible values:active,inactive,pending.bank_transfer_payments- The status of the customer_balance payments capability of the account, or whether the account can directly process customer_balance charges. Possible values:active,inactive,pending.billie_payments- The status of the Billie capability of the account, or whether the account can directly process Billie payments. Possible values:active,inactive,pending.blik_payments- The status of the blik payments capability of the account, or whether the account can directly process blik charges. Possible values:active,inactive,pending.boleto_payments- The status of the boleto payments capability of the account, or whether the account can directly process boleto charges. Possible values:active,inactive,pending.card_issuing- The status of the card issuing capability of the account, or whether you can use Issuing to distribute funds on cards Possible values:active,inactive,pending.card_payments- The status of the card payments capability of the account, or whether the account can directly process credit and debit card charges. Possible values:active,inactive,pending.cartes_bancaires_payments- The status of the Cartes Bancaires payments capability of the account, or whether the account can directly process Cartes Bancaires card charges in EUR currency. Possible values:active,inactive,pending.cashapp_payments- The status of the Cash App Pay capability of the account, or whether the account can directly process Cash App Pay payments. Possible values:active,inactive,pending.crypto_payments- The status of the Crypto capability of the account, or whether the account can directly process Crypto payments. Possible values:active,inactive,pending.eps_payments- The status of the EPS payments capability of the account, or whether the account can directly process EPS charges. Possible values:active,inactive,pending.fpx_payments- The status of the FPX payments capability of the account, or whether the account can directly process FPX charges. Possible values:active,inactive,pending.gb_bank_transfer_payments- The status of the GB customer_balance payments (GBP currency) capability of the account, or whether the account can directly process GB customer_balance charges. Possible values:active,inactive,pending.giropay_payments- The status of the giropay payments capability of the account, or whether the account can directly process giropay charges. Possible values:active,inactive,pending.grabpay_payments- The status of the GrabPay payments capability of the account, or whether the account can directly process GrabPay charges. Possible values:active,inactive,pending.ideal_payments- The status of the iDEAL payments capability of the account, or whether the account can directly process iDEAL charges. Possible values:active,inactive,pending.india_international_payments- The status of the india_international_payments capability of the account, or whether the account can process international charges (non INR) in India. Possible values:active,inactive,pending.jcb_payments- The status of the JCB payments capability of the account, or whether the account (Japan only) can directly process JCB credit card charges in JPY currency. Possible values:active,inactive,pending.jp_bank_transfer_payments- The status of the Japanese customer_balance payments (JPY currency) capability of the account, or whether the account can directly process Japanese customer_balance charges. Possible values:active,inactive,pending.kakao_pay_payments- The status of the KakaoPay capability of the account, or whether the account can directly process KakaoPay payments. Possible values:active,inactive,pending.klarna_payments- The status of the Klarna payments capability of the account, or whether the account can directly process Klarna charges. Possible values:active,inactive,pending.konbini_payments- The status of the konbini payments capability of the account, or whether the account can directly process konbini charges. Possible values:active,inactive,pending.kr_card_payments- The status of the KrCard capability of the account, or whether the account can directly process KrCard payments. Possible values:active,inactive,pending.legacy_payments- The status of the legacy payments capability of the account. Possible values:active,inactive,pending.link_payments- The status of the link_payments capability of the account, or whether the account can directly process Link charges. Possible values:active,inactive,pending.mb_way_payments- The status of the MB WAY payments capability of the account, or whether the account can directly process MB WAY charges. Possible values:active,inactive,pending.mobilepay_payments- The status of the MobilePay capability of the account, or whether the account can directly process MobilePay charges. Possible values:active,inactive,pending.multibanco_payments- The status of the Multibanco payments capability of the account, or whether the account can directly process Multibanco charges. Possible values:active,inactive,pending.mx_bank_transfer_payments- The status of the Mexican customer_balance payments (MXN currency) capability of the account, or whether the account can directly process Mexican customer_balance charges. Possible values:active,inactive,pending.naver_pay_payments- The status of the NaverPay capability of the account, or whether the account can directly process NaverPay payments. Possible values:active,inactive,pending.nz_bank_account_becs_debit_payments- The status of the New Zealand BECS Direct Debit payments capability of the account, or whether the account can directly process New Zealand BECS Direct Debit charges. Possible values:active,inactive,pending.oxxo_payments- The status of the OXXO payments capability of the account, or whether the account can directly process OXXO charges. Possible values:active,inactive,pending.p24_payments- The status of the P24 payments capability of the account, or whether the account can directly process P24 charges. Possible values:active,inactive,pending.pay_by_bank_payments- The status of the pay_by_bank payments capability of the account, or whether the account can directly process pay_by_bank charges. Possible values:active,inactive,pending.payco_payments- The status of the Payco capability of the account, or whether the account can directly process Payco payments. Possible values:active,inactive,pending.paynow_payments- The status of the paynow payments capability of the account, or whether the account can directly process paynow charges. Possible values:active,inactive,pending.payto_payments- The status of the PayTo capability of the account, or whether the account can directly process PayTo charges. Possible values:active,inactive,pending.pix_payments- The status of the pix payments capability of the account, or whether the account can directly process pix charges. Possible values:active,inactive,pending.promptpay_payments- The status of the promptpay payments capability of the account, or whether the account can directly process promptpay charges. Possible values:active,inactive,pending.revolut_pay_payments- The status of the RevolutPay capability of the account, or whether the account can directly process RevolutPay payments. Possible values:active,inactive,pending.samsung_pay_payments- The status of the SamsungPay capability of the account, or whether the account can directly process SamsungPay payments. Possible values:active,inactive,pending.satispay_payments- The status of the Satispay capability of the account, or whether the account can directly process Satispay payments. Possible values:active,inactive,pending.sepa_bank_transfer_payments- The status of the SEPA customer_balance payments (EUR currency) capability of the account, or whether the account can directly process SEPA customer_balance charges. Possible values:active,inactive,pending.sepa_debit_payments- The status of the SEPA Direct Debits payments capability of the account, or whether the account can directly process SEPA Direct Debits charges. Possible values:active,inactive,pending.sofort_payments- The status of the Sofort payments capability of the account, or whether the account can directly process Sofort charges. Possible values:active,inactive,pending.swish_payments- The status of the Swish capability of the account, or whether the account can directly process Swish payments. Possible values:active,inactive,pending.tax_reporting_us_1099_k- The status of the tax reporting 1099-K (US) capability of the account. Possible values:active,inactive,pending.tax_reporting_us_1099_misc- The status of the tax reporting 1099-MISC (US) capability of the account. Possible values:active,inactive,pending.transfers- The status of the transfers capability of the account, or whether your platform can transfer funds to the account. Possible values:active,inactive,pending.treasury- The status of the banking capability, or whether the account can have bank accounts. Possible values:active,inactive,pending.twint_payments- The status of the TWINT capability of the account, or whether the account can directly process TWINT charges. Possible values:active,inactive,pending.us_bank_account_ach_payments- The status of the US bank account ACH payments capability of the account, or whether the account can directly process US bank account charges. Possible values:active,inactive,pending.us_bank_transfer_payments- The status of the US customer_balance payments (USD currency) capability of the account, or whether the account can directly process US customer_balance charges. Possible values:active,inactive,pending.zip_payments- The status of the Zip capability of the account, or whether the account can directly process Zip charges. Possible values:active,inactive,pending.