Stripe.Resources.Account.Company.Verification.Document
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Company.Verification.Document{ back: String.t() | Stripe.Resources.File.t() | nil, details: String.t() | nil, details_code: String.t() | nil, front: String.t() | Stripe.Resources.File.t() | nil }
back- The back of a document returned by a file upload with apurposevalue ofadditional_verification. Note thatadditional_verificationfiles are not downloadable. Nullable.details- A user-displayable string describing the verification state of this document. Max length: 5000. Nullable.details_code- One ofdocument_corrupt,document_expired,document_failed_copy,document_failed_greyscale,document_failed_other,document_failed_test_mode,document_fraudulent,document_incomplete,document_invalid,document_manipulated,document_not_readable,document_not_uploaded,document_type_not_supported, ordocument_too_large. A machine-readable code specifying the verification state for this document. Max length: 5000. Nullable.front- The front of a document returned by a file upload with apurposevalue ofadditional_verification. Note thatadditional_verificationfiles are not downloadable. Nullable.