Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Controller{ fees: Stripe.Resources.Account.Controller.Fees.t() | nil, is_controller: boolean() | nil, losses: Stripe.Resources.Account.Controller.Losses.t() | nil, requirement_collection: String.t() | nil, stripe_dashboard: Stripe.Resources.Account.Controller.StripeDashboard.t() | nil, type: String.t() | nil }
feesis_controller-trueif the Connect application retrieving the resource controls the account and can therefore exercise platform controls. Otherwise, this field is null.lossesrequirement_collection- A value indicating responsibility for collecting requirements on this account. Only returned when the Connect application retrieving the resource controls the account. Possible values:application,stripe.stripe_dashboardtype- The controller type. Can beapplication, if a Connect application controls the account, oraccount, if the account controls itself. Possible values:account,application.