Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.ExternalAccounts{ data: [Stripe.Resources.ExternalAccount.t()] | nil, has_more: boolean() | nil, object: String.t() | nil, url: String.t() | nil }
data- The list contains all external accounts that have been attached to the Stripe account. These may be bank accounts or cards.has_more- True if this list has another page of items after this one that can be fetched.object- String representing the object's type. Objects of the same type share the same value. Always has the valuelist. Possible values:list.url- The URL where this list can be accessed. Max length: 5000.