Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.FutureRequirements{ alternatives: [Stripe.Resources.Account.FutureRequirements.Alternatives.t()] | nil, current_deadline: integer() | nil, currently_due: [String.t()] | nil, disabled_reason: String.t() | nil, errors: [Stripe.Resources.Account.FutureRequirements.Errors.t()] | nil, eventually_due: [String.t()] | nil, past_due: [String.t()] | nil, pending_verification: [String.t()] | nil }
alternatives- Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the sameoriginal_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providingoriginal_fields_duealso serves as a pathway for attempting to resolve the fields again. Nullable.current_deadline- Date on whichfuture_requirementsbecomes the mainrequirementshash andfuture_requirementsbecomes empty. After the transition,currently_duerequirements may immediately becomepast_due, but the account may also be given a grace period depending on its enablement state prior to transitioning. Format: Unix timestamp. Nullable.currently_due- Fields that need to be resolved to keep the account enabled. If not resolved byfuture_requirements[current_deadline], these fields will transition to the mainrequirementshash. Nullable.disabled_reason- This is typed as an enum for consistency withrequirements.disabled_reason. Possible values:action_required.requested_capabilities,listed,other,platform_paused,rejected.fraud,rejected.incomplete_verification,rejected.listed,rejected.other,rejected.platform_fraud,rejected.platform_other,rejected.platform_terms_of_service,rejected.terms_of_service,requirements.past_due,requirements.pending_verification,under_review. Nullable.errors- Details about validation and verification failures forduerequirements that must be resolved. Nullable.eventually_due- Fields you must collect when all thresholds are reached. As they become required, they appear incurrently_dueas well. Nullable.past_due- Fields that haven't been resolved byrequirements.current_deadline. These fields need to be resolved to enable the capability on the account.future_requirements.past_dueis a subset ofrequirements.past_due. Nullable.pending_verification- Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move toeventually_due,currently_due,past_dueoralternatives. Fields might appear ineventually_due,currently_due,past_dueoralternativesand inpending_verificationif one verification fails but another is still pending. Nullable.