Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Groups{payments_pricing: String.t() | nil}
payments_pricing- The group the account is in to determine their payments pricing, and null if the account is on customized pricing. See the Platform pricing tool documentation for details. Max length: 5000. Nullable.