Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Requirements{ alternatives: [Stripe.Resources.Account.Requirements.Alternatives.t()] | nil, current_deadline: integer() | nil, currently_due: [String.t()] | nil, disabled_reason: String.t() | nil, errors: [Stripe.Resources.Account.Requirements.Errors.t()] | nil, eventually_due: [String.t()] | nil, past_due: [String.t()] | nil, pending_verification: [String.t()] | nil }
alternatives- Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the sameoriginal_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providingoriginal_fields_duealso serves as a pathway for attempting to resolve the fields again. Nullable.current_deadline- Date by which the fields incurrently_duemust be collected to keep the account enabled. These fields may disable the account sooner if the next threshold is reached before they are collected. Format: Unix timestamp. Nullable.currently_due- Fields that need to be resolved to keep the account enabled. If not resolved bycurrent_deadline, these fields will appear inpast_dueas well, and the account is disabled. Nullable.disabled_reason- If the account is disabled, this enum describes why. Learn more about handling verification issues. Possible values:action_required.requested_capabilities,listed,other,platform_paused,rejected.fraud,rejected.incomplete_verification,rejected.listed,rejected.other,rejected.platform_fraud,rejected.platform_other,rejected.platform_terms_of_service,rejected.terms_of_service,requirements.past_due,requirements.pending_verification,under_review. Nullable.errors- Details about validation and verification failures forduerequirements that must be resolved. Nullable.eventually_due- Fields you must collect when all thresholds are reached. As they become required, they appear incurrently_dueas well, andcurrent_deadlinebecomes set. Nullable.past_due- Fields that haven't been resolved bycurrent_deadline. These fields need to be resolved to enable the account. Nullable.pending_verification- Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move toeventually_due,currently_due,past_dueoralternatives. Fields might appear ineventually_due,currently_due,past_dueoralternativesand inpending_verificationif one verification fails but another is still pending. Nullable.