Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Settings.Invoices{ default_account_tax_ids: [String.t() | Stripe.Resources.TaxId.t()] | nil, hosted_payment_method_save: String.t() | nil }
default_account_tax_ids- The list of default Account Tax IDs to automatically include on invoices. Account Tax IDs get added when an invoice is finalized. Nullable.hosted_payment_method_save- Whether to save the payment method after a payment is completed for a one-time invoice or a subscription invoice when the customer already has a default payment method on the hosted invoice page. Possible values:always,never,offer. Nullable.