Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Account.Settings.Payouts{ debit_negative_balances: boolean() | nil, schedule: Stripe.Resources.Account.Settings.Payouts.Schedule.t() | nil, statement_descriptor: String.t() | nil }
debit_negative_balances- A Boolean indicating if Stripe should try to reclaim negative balances from an attached bank account. See Understanding Connect account balances for details. The default value isfalsewhen controller.requirement_collection isapplication, which includes Custom accounts, otherwisetrue.schedulestatement_descriptor- The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard. Max length: 5000. Nullable.