AccountLink
Account Links are the means by which a Connect platform grants a connected account permission to access Stripe-hosted applications, such as Connect Onboarding.
Related guide: Connect Onboarding
Summary
Types
@type t() :: %Stripe.Resources.AccountLink{ created: integer(), expires_at: integer(), object: String.t(), url: String.t() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.expires_at- The timestamp at which this account link will expire. Format: Unix timestamp.object- String representing the object's type. Objects of the same type share the same value. Possible values:account_link.url- The URL for the account link. Max length: 5000.