Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.BankAccount.Requirements{ currently_due: [String.t()] | nil, errors: [Stripe.Resources.BankAccount.Requirements.Errors.t()] | nil, past_due: [String.t()] | nil, pending_verification: [String.t()] | nil }
currently_due- Fields that need to be resolved to keep the external account enabled. If not resolved bycurrent_deadline, these fields will appear inpast_dueas well, and the account is disabled. Nullable.errors- Details about validation and verification failures forduerequirements that must be resolved. Nullable.past_due- Fields that haven't been resolved bycurrent_deadline. These fields need to be resolved to enable the external account. Nullable.pending_verification- Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move toeventually_due,currently_due,past_dueoralternatives. Fields might appear ineventually_due,currently_due,past_dueoralternativesand inpending_verificationif one verification fails but another is still pending. Nullable.