ThresholdsResourceAlert
A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.
Summary
Types
@type t() :: %Stripe.Resources.Billing.Alert{ alert_type: String.t(), id: String.t(), livemode: boolean(), object: String.t(), status: String.t(), title: String.t(), usage_threshold: Stripe.Resources.Billing.Alert.UsageThreshold.t() }
alert_type- Defines the type of the alert. Possible values:usage_threshold.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:billing.alert.status- Status of the alert. This can be active, inactive or archived. Possible values:active,archived,inactive. Nullable.title- Title of the alert. Max length: 5000.usage_threshold- Encapsulates configuration of the alert to monitor usage on a specific Billing Meter. Nullable. Expandable.