CreditBalanceTransaction
A credit balance transaction is a resource representing a transaction (either a credit or a debit) against an existing credit grant.
Summary
Types
@type t() :: %Stripe.Resources.Billing.CreditBalanceTransaction{ created: integer(), credit: Stripe.Resources.Billing.CreditBalanceTransaction.Credit.t(), credit_grant: String.t() | Stripe.Resources.Billing.CreditGrant.t(), debit: Stripe.Resources.Billing.CreditBalanceTransaction.Debit.t(), effective_at: integer(), id: String.t(), livemode: boolean(), object: String.t(), test_clock: String.t() | Stripe.Resources.TestHelpers.TestClock.t(), type: String.t() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.credit- Credit details for this credit balance transaction. Only present if type iscredit. Nullable. Expandable.credit_grant- The credit grant associated with this credit balance transaction. Expandable.debit- Debit details for this credit balance transaction. Only present if type isdebit. Nullable. Expandable.effective_at- The effective time of this credit balance transaction. Format: Unix timestamp.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:billing.credit_balance_transaction.test_clock- ID of the test clock this credit balance transaction belongs to. Nullable. Expandable.type- The type of credit balance transaction (credit or debit). Possible values:credit,debit. Nullable.