Stripe.Resources.Billing.CreditGrant.ApplicabilityConfig.Scope
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Billing.CreditGrant.ApplicabilityConfig.Scope{ price_type: String.t() | nil, prices: [Stripe.Resources.Billing.CreditGrant.ApplicabilityConfig.Scope.Prices.t()] | nil }
price_type- The price type that credit grants can apply to. We currently only support themeteredprice type. This refers to prices that have a Billing Meter attached to them. Cannot be used in combination withprices. Possible values:metered.prices- The prices that credit grants can apply to. We currently only supportmeteredprices. This refers to prices that have a Billing Meter attached to them. Cannot be used in combination withprice_type.