Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Billing.Meter.CustomerMapping{ event_payload_key: String.t() | nil, type: String.t() | nil }
event_payload_key- The key in the meter event payload to use for mapping the event to a customer. Max length: 5000.type- The method for mapping a meter event to a customer. Possible values:by_id.