BillingMeterEvent
Meter events represent actions that customers take in your system. You can use meter events to bill a customer based on their usage. Meter events are associated with billing meters, which define both the contents of the event’s payload and how to aggregate those events.
Summary
Types
@type t() :: %Stripe.Resources.Billing.MeterEvent{ created: integer(), event_name: String.t(), identifier: String.t(), livemode: boolean(), object: String.t(), payload: %{required(String.t()) => String.t()}, timestamp: integer() }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.event_name- The name of the meter event. Corresponds with theevent_namefield on a meter. Max length: 100.identifier- A unique identifier for the event. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:billing.meter_event.payload- The payload of the event. This contains the fields corresponding to a meter'scustomer_mapping.event_payload_key(default isstripe_customer_id) andvalue_settings.event_payload_key(default isvalue). Read more about the payload.timestamp- The timestamp passed in when creating the event. Measured in seconds since the Unix epoch. Format: Unix timestamp.