Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate.Products.AdjustableQuantity
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.BillingPortal.Configuration.Features.SubscriptionUpdate.Products.AdjustableQuantity{ enabled: boolean() | nil, maximum: integer() | nil, minimum: integer() | nil }
enabled- If true, the quantity can be adjusted to any non-negative integer.maximum- The maximum quantity that can be set for the product. Nullable.minimum- The minimum quantity that can be set for the product.