Stripe.Resources.BillingPortal.Session.Flow.SubscriptionUpdateConfirm
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.BillingPortal.Session.Flow.SubscriptionUpdateConfirm{ discounts: [ Stripe.Resources.BillingPortal.Session.Flow.SubscriptionUpdateConfirm.Discounts.t() ] | nil, items: [ Stripe.Resources.BillingPortal.Session.Flow.SubscriptionUpdateConfirm.Items.t() ] | nil, subscription: String.t() | nil }
discounts- The coupon or promotion code to apply to this subscription update. Nullable.items- The subscription item to be updated through this flow. Currently, only up to one may be specified and subscriptions with multiple items are not updatable.subscription- The ID of the subscription to be updated. Max length: 5000.