Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Capability.FutureRequirements{ alternatives: [Stripe.Resources.Capability.FutureRequirements.Alternatives.t()] | nil, current_deadline: integer() | nil, currently_due: [String.t()] | nil, disabled_reason: String.t() | nil, errors: [Stripe.Resources.Capability.FutureRequirements.Errors.t()] | nil, eventually_due: [String.t()] | nil, past_due: [String.t()] | nil, pending_verification: [String.t()] | nil }
alternatives- Fields that are due and can be resolved by providing the corresponding alternative fields instead. Multiple alternatives can reference the sameoriginal_fields_due. When this happens, any of these alternatives can serve as a pathway for attempting to resolve the fields. Additionally, providingoriginal_fields_dueagain also serves as a pathway for attempting to resolve the fields. Nullable.current_deadline- Date on whichfuture_requirementsbecomes the mainrequirementshash andfuture_requirementsbecomes empty. After the transition,currently_duerequirements may immediately becomepast_due, but the account may also be given a grace period depending on the capability's enablement state prior to transitioning. Format: Unix timestamp. Nullable.currently_due- Fields that need to be resolved to keep the capability enabled. If not resolved byfuture_requirements[current_deadline], these fields will transition to the mainrequirementshash.disabled_reason- This is typed as an enum for consistency withrequirements.disabled_reason, but it safe to assumefuture_requirements.disabled_reasonis null because fields infuture_requirementswill never disable the account. Possible values:other,paused.inactivity,pending.onboarding,pending.review,platform_disabled,platform_paused,rejected.inactivity,rejected.other,rejected.unsupported_business,requirements.fields_needed. Nullable.errors- Details about validation and verification failures forduerequirements that must be resolved.eventually_due- Fields you must collect when all thresholds are reached. As they become required, they appear incurrently_dueas well.past_due- Fields that haven't been resolved byrequirements.current_deadline. These fields need to be resolved to enable the capability on the account.future_requirements.past_dueis a subset ofrequirements.past_due.pending_verification- Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move toeventually_due,currently_due,past_dueoralternatives. Fields might appear ineventually_due,currently_due,past_dueoralternativesand inpending_verificationif one verification fails but another is still pending.