Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Capability.Requirements{ alternatives: [Stripe.Resources.Capability.Requirements.Alternatives.t()] | nil, current_deadline: integer() | nil, currently_due: [String.t()] | nil, disabled_reason: String.t() | nil, errors: [Stripe.Resources.Capability.Requirements.Errors.t()] | nil, eventually_due: [String.t()] | nil, past_due: [String.t()] | nil, pending_verification: [String.t()] | nil }
alternatives- Fields that are due and can be resolved by providing the corresponding alternative fields instead. Multiple alternatives can reference the sameoriginal_fields_due. When this happens, any of these alternatives can serve as a pathway for attempting to resolve the fields. Additionally, providingoriginal_fields_dueagain also serves as a pathway for attempting to resolve the fields. Nullable.current_deadline- The date by which all required account information must be both submitted and verified. This includes fields listed incurrently_dueas well as those inpending_verification. If any required information is missing or unverified by this date, the account may be disabled. Note thatcurrent_deadlinemay change if additionalcurrently_duerequirements are requested. Format: Unix timestamp. Nullable.currently_due- Fields that need to be resolved to keep the capability enabled. If not resolved bycurrent_deadline, these fields will appear inpast_dueas well, and the capability is disabled.disabled_reason- Description of why the capability is disabled. Learn more about handling verification issues. Possible values:other,paused.inactivity,pending.onboarding,pending.review,platform_disabled,platform_paused,rejected.inactivity,rejected.other,rejected.unsupported_business,requirements.fields_needed. Nullable.errors- Details about validation and verification failures forduerequirements that must be resolved.eventually_due- Fields you must collect when all thresholds are reached. As they become required, they appear incurrently_dueas well, andcurrent_deadlinebecomes set.past_due- Fields that haven't been resolved bycurrent_deadline. These fields need to be resolved to enable the capability on the account.pending_verification- Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move toeventually_due,currently_due,past_dueoralternatives. Fields might appear ineventually_due,currently_due,past_dueoralternativesand inpending_verificationif one verification fails but another is still pending.