Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.CashBalance.Settings{ reconciliation_mode: String.t() | nil, using_merchant_default: boolean() | nil }
reconciliation_mode- The configuration for how funds that land in the customer cash balance are reconciled. Possible values:automatic,manual.using_merchant_default- A flag to indicate if reconciliation mode returned is the user's default or is specific to this customer cash balance