Stripe.Resources.Charge.PaymentMethodDetails.Alipay
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Alipay{ buyer_id: String.t() | nil, fingerprint: String.t() | nil, transaction_id: String.t() | nil }
buyer_id- Uniquely identifies this particular Alipay account. You can use this attribute to check whether two Alipay accounts are the same. Max length: 5000.fingerprint- Uniquely identifies this particular Alipay account. You can use this attribute to check whether two Alipay accounts are the same. Max length: 5000. Nullable.transaction_id- Transaction ID of this particular Alipay transaction. Max length: 5000. Nullable.