Stripe.Resources.Charge.PaymentMethodDetails.Card.NetworkToken
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Card.NetworkToken{ used: boolean() | nil }
used- Indicates if Stripe used a network token, either user provided or Stripe managed when processing the transaction.