Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet{ amex_express_checkout: map() | nil, apple_pay: map() | nil, dynamic_last4: String.t() | nil, google_pay: map() | nil, link: map() | nil, masterpass: Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet.Masterpass.t() | nil, samsung_pay: map() | nil, type: String.t() | nil, visa_checkout: Stripe.Resources.Charge.PaymentMethodDetails.Card.Wallet.VisaCheckout.t() | nil }
amex_express_checkoutapple_paydynamic_last4- (For tokenized numbers only.) The last four digits of the device account number. Max length: 5000. Nullable.google_paylinkmasterpasssamsung_paytype- The type of the card wallet, one ofamex_express_checkout,apple_pay,google_pay,masterpass,samsung_pay,visa_checkout, orlink. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type. Possible values:amex_express_checkout,apple_pay,google_pay,link,masterpass,samsung_pay,visa_checkout.visa_checkout