Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Charge.PaymentMethodDetails.Link{ country: String.t() | nil }
country- Two-letter ISO code representing the funding source country beneath the Link payment. You could use this attribute to get a sense of international fees. Max length: 5000. Nullable.