Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Charge.TransferData{ amount: integer() | nil, destination: String.t() | Stripe.Resources.Account.t() | nil }
amount- The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account. Nullable.destination- ID of an existing, connected Stripe account to transfer funds to iftransfer_datawas specified in the charge request.