Stripe.Resources.Checkout.Session.AfterExpiration.Recovery
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Checkout.Session.AfterExpiration.Recovery{ allow_promotion_codes: boolean() | nil, enabled: boolean() | nil, expires_at: integer() | nil, url: String.t() | nil }
allow_promotion_codes- Enables user redeemable promotion codes on the recovered Checkout Sessions. Defaults tofalseenabled- Iftrue, a recovery url will be generated to recover this Checkout Session if it expires before a transaction is completed. It will be attached to the Checkout Session object upon expiration.expires_at- The timestamp at which the recovery URL will expire. Format: Unix timestamp. Nullable.url- URL that creates a new Checkout Session when clicked that is a copy of this expired Checkout Session Max length: 5000. Nullable.