Stripe.Resources.Checkout.Session.SavedPaymentMethodOptions
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Checkout.Session.SavedPaymentMethodOptions{ allow_redisplay_filters: [String.t()] | nil, payment_method_remove: String.t() | nil, payment_method_save: String.t() | nil }
allow_redisplay_filters- Uses theallow_redisplayvalue of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout. Nullable.payment_method_remove- Enable customers to choose if they wish to remove their saved payment methods. Disabled by default. Possible values:disabled,enabled. Nullable.payment_method_save- Enable customers to choose if they wish to save their payment method for future use. Disabled by default. Possible values:disabled,enabled. Nullable.