ClimateRemovalsProducts
A Climate product represents a type of carbon removal unit available for reservation. You can retrieve it to see the current price and availability.
Summary
Types
@type t() :: %Stripe.Resources.Climate.Product{ created: integer(), current_prices_per_metric_ton: %{ required(String.t()) => Stripe.Resources.Climate.Product.CurrentPricesPerMetricTon.t() }, delivery_year: integer(), id: String.t(), livemode: boolean(), metric_tons_available: String.t(), name: String.t(), object: String.t(), suppliers: [Stripe.Resources.Climate.Supplier.t()] }
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.current_prices_per_metric_ton- Current prices for a metric ton of carbon removal in a currency's smallest unit. Expandable.delivery_year- The year in which the carbon removal is expected to be delivered. Nullable.id- Unique identifier for the object. For convenience, Climate product IDs are human-readable strings that start withclimsku_. See carbon removal inventory for a list of available carbon removal products. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metric_tons_available- The quantity of metric tons available for reservation. Format: decimal string.name- The Climate product's name. Max length: 5000.object- String representing the object's type. Objects of the same type share the same value. Possible values:climate.product.suppliers- The carbon removal suppliers that fulfill orders for this Climate product. Expandable.