Stripe.Resources.ConfirmationToken.MandateData.CustomerAcceptance.Online
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.ConfirmationToken.MandateData.CustomerAcceptance.Online{ ip_address: String.t() | nil, user_agent: String.t() | nil }
ip_address- The IP address from which the Mandate was accepted by the customer. Max length: 5000. Nullable.user_agent- The user agent of the browser from which the Mandate was accepted by the customer. Max length: 5000. Nullable.