Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.CreditNote.Refunds{ amount_refunded: integer() | nil, payment_record_refund: Stripe.Resources.CreditNote.Refunds.PaymentRecordRefund.t() | nil, refund: String.t() | Stripe.Resources.Refund.t() | nil, type: String.t() | nil }
amount_refunded- Amount of the refund that applies to this credit note, in cents (or local equivalent).payment_record_refund- The PaymentRecord refund details associated with this credit note refund. Nullable.refund- ID of the refund.type- Type of the refund, one ofrefundorpayment_record_refund. Possible values:payment_record_refund,refund. Nullable.