Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Customer.InvoiceSettings{ custom_fields: [Stripe.Resources.Customer.InvoiceSettings.CustomFields.t()] | nil, default_payment_method: String.t() | Stripe.Resources.PaymentMethod.t() | nil, footer: String.t() | nil, rendering_options: Stripe.Resources.Customer.InvoiceSettings.RenderingOptions.t() | nil }
custom_fields- Default custom fields to be displayed on invoices for this customer. Nullable.default_payment_method- ID of a payment method that's attached to the customer, to be used as the customer's default payment method for subscriptions and invoices. Nullable.footer- Default footer to be displayed on invoices for this customer. Max length: 5000. Nullable.rendering_options- Default options for invoice PDF rendering for this customer. Nullable.