Stripe.Resources.Customer.InvoiceSettings.RenderingOptions
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Customer.InvoiceSettings.RenderingOptions{ amount_tax_display: String.t() | nil, template: String.t() | nil }
amount_tax_display- How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. Max length: 5000. Nullable.template- ID of the invoice rendering template to be used for this customer's invoices. If set, the template will be used on all invoices for this customer unless a template is set directly on the invoice. Max length: 5000. Nullable.