Stripe.Resources.Dispute.Evidence.EnhancedEvidence.VisaCompliance
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Dispute.Evidence.EnhancedEvidence.VisaCompliance{ fee_acknowledged: boolean() | nil }
fee_acknowledged- A field acknowledging the fee incurred when countering a Visa compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute. Stripe collects a 500 USD (or local equivalent) amount to cover the network costs associated with resolving compliance disputes. Stripe refunds the 500 USD network fee if you win the dispute.