Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Dispute.PaymentMethodDetails.Card{ brand: String.t() | nil, case_type: String.t() | nil, network_reason_code: String.t() | nil }
brand- Card brand. Can beamex,cartes_bancaires,diners,discover,eftpos_au,jcb,link,mastercard,unionpay,visaorunknown. Max length: 5000.case_type- The type of dispute opened. Different case types may have varying fees and financial impact. Possible values:block,chargeback,compliance,inquiry,resolution.network_reason_code- The card network's specific dispute reason code, which maps to one of Stripe's primary dispute categories to simplify response guidance. The Network code map lists all available dispute reason codes by network. Max length: 5000. Nullable.