Stripe.Resources.FinancialConnections.Account.Balance.Credit
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.FinancialConnections.Account.Balance.Credit{ used: %{required(String.t()) => integer()} | nil }
used- The credit that has been used by the account holder.
Each key is a three-letter ISO currency code, in lowercase.
Each value is a integer amount. A positive amount indicates money owed to the account holder. A negative amount indicates money owed by the account holder. Nullable.