Stripe.Resources.FinancialConnections.Account.OwnershipRefresh
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.FinancialConnections.Account.OwnershipRefresh{ last_attempted_at: integer() | nil, next_refresh_available_at: integer() | nil, status: String.t() | nil }
last_attempted_at- The time at which the last refresh attempt was initiated. Measured in seconds since the Unix epoch. Format: Unix timestamp.next_refresh_available_at- Time at which the next ownership refresh can be initiated. This value will benullwhenstatusispending. Measured in seconds since the Unix epoch. Format: Unix timestamp. Nullable.status- The status of the last refresh attempt. Possible values:failed,pending,succeeded.