CustomerBalanceFundingInstructionsCustomerBalanceFundingInstructions
Each customer has a balance that is
automatically applied to future invoices and payments using the customer_balance payment method.
Customers can fund this balance by initiating a bank transfer to any account in the
financial_addresses field.
Related guide: Customer balance funding instructions
Summary
Types
@type t() :: %Stripe.Resources.FundingInstructions{ bank_transfer: Stripe.Resources.BankTransfer.t(), currency: String.t(), funding_type: String.t(), livemode: boolean(), object: String.t() }
bank_transfer- Expandable.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Max length: 5000.funding_type- Thefunding_typeof the returned instructions Possible values:bank_transfer.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:funding_instructions.