Stripe.Resources.Identity.VerificationReport.Options.Document
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Identity.VerificationReport.Options.Document{ allowed_types: [String.t()] | nil, require_id_number: boolean() | nil, require_live_capture: boolean() | nil, require_matching_selfie: boolean() | nil }
allowed_types- Array of strings of allowed identity document types. If the provided identity document isn’t one of the allowed types, the verification check will fail with a document_type_not_allowed error code.require_id_number- Collect an ID number and perform an ID number check with the document’s extracted name and date of birth.require_live_capture- Disable image uploads, identity document images have to be captured using the device’s camera.require_matching_selfie- Capture a face image and perform a selfie check comparing a photo ID and a picture of your user’s face. Learn more.