Stripe.Resources.Identity.VerificationReport.Selfie
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Identity.VerificationReport.Selfie{ document: String.t() | nil, error: Stripe.Resources.Identity.VerificationReport.Selfie.Error.t() | nil, selfie: String.t() | nil, status: String.t() | nil }
document- ID of the File holding the image of the identity document used in this check. Max length: 5000. Nullable.error- Details on the verification error. Present when status isunverified. Nullable.selfie- ID of the File holding the image of the selfie used in this check. Max length: 5000. Nullable.status- Status of thisselfiecheck. Possible values:unverified,verified.