Stripe.Resources.Identity.VerificationSession.LastError
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Identity.VerificationSession.LastError{ code: String.t() | nil, reason: String.t() | nil }
code- A short machine-readable string giving the reason for the verification or user-session failure. Possible values:abandoned,consent_declined,country_not_supported,device_not_supported,document_expired,document_type_not_supported,document_unverified_other,email_unverified_other,email_verification_declined,id_number_insufficient_document_data,id_number_mismatch,id_number_unverified_other,phone_unverified_other,phone_verification_declined,selfie_document_missing_photo,selfie_face_mismatch,selfie_manipulated,selfie_unverified_other,under_supported_age. Nullable.reason- A message that explains the reason for verification or user-session failure. Max length: 5000. Nullable.