Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Invoice.ConfirmationSecret{ client_secret: String.t() | nil, type: String.t() | nil }
client_secret- The client_secret of the payment that Stripe creates for the invoice after finalization. Max length: 5000.type- The type of client_secret. Currently this is always payment_intent, referencing the default payment_intent that Stripe creates during invoice finalization Max length: 5000.