Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions{ acss_debit: Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.AcssDebit.t() | nil, bancontact: Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.Bancontact.t() | nil, card: Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.Card.t() | nil, customer_balance: Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.CustomerBalance.t() | nil, konbini: map() | nil, payto: Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.Payto.t() | nil, sepa_debit: map() | nil, us_bank_account: Stripe.Resources.Invoice.PaymentSettings.PaymentMethodOptions.UsBankAccount.t() | nil }
acss_debit- If paying byacss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent. Nullable.bancontact- If paying bybancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent. Nullable.card- If paying bycard, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent. Nullable.customer_balance- If paying bycustomer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent. Nullable.konbini- If paying bykonbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent. Nullable.payto- If paying bypayto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent. Nullable.sepa_debit- If paying bysepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent. Nullable.us_bank_account- If paying byus_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent. Nullable.