Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Invoice.Rendering{ amount_tax_display: String.t() | nil, pdf: Stripe.Resources.Invoice.Rendering.Pdf.t() | nil, template: String.t() | nil, template_version: integer() | nil }
amount_tax_display- How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. Max length: 5000. Nullable.pdf- Invoice pdf rendering options Nullable.template- ID of the rendering template that the invoice is formatted by. Max length: 5000. Nullable.template_version- Version of the rendering template that the invoice is using. Nullable.