Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.InvoiceItem.Parent{ subscription_details: Stripe.Resources.InvoiceItem.Parent.SubscriptionDetails.t() | nil, type: String.t() | nil }
subscription_details- Details about the subscription that generated this invoice item Nullable.type- The type of parent that generated this invoice item Possible values:subscription_details.