InvoicesInvoicePayment
Invoice Payments represent payments made against invoices. Invoice Payments can be accessed in two ways:
- By expanding the
paymentsfield on the Invoice resource. - By using the Invoice Payment retrieve and list endpoints.
Invoice Payments include the mapping between payment objects, such as Payment Intent, and Invoices. This resource and its endpoints allows you to easily track if a payment is associated with a specific invoice and monitor the allocation details of the payments.
Summary
Types
@type t() :: %Stripe.Resources.InvoicePayment{ amount_paid: integer(), amount_requested: integer(), created: integer(), currency: String.t(), id: String.t(), invoice: String.t() | Stripe.Resources.Invoice.t(), is_default: boolean(), livemode: boolean(), object: String.t(), payment: Stripe.Resources.InvoicePayment.Payment.t(), status: String.t(), status_transitions: Stripe.Resources.InvoicePayment.StatusTransitions.t() }
amount_paid- Amount that was actually paid for this invoice, in cents (or local equivalent). This field is null until the payment ispaid. This amount can be less than theamount_requestedif the PaymentIntent’samount_receivedis not sufficient to pay all of the invoices that it is attached to. Nullable.amount_requested- Amount intended to be paid toward this invoice, in cents (or local equivalent)created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Max length: 5000.id- Unique identifier for the object. Max length: 5000.invoice- The invoice that was paid. Expandable.is_default- Stripe automatically creates a default InvoicePayment when the invoice is finalized, and keeps it synchronized with the invoice’samount_remaining. The PaymentIntent associated with the default payment can’t be edited or canceled directly.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:invoice_payment.payment- Expandable.status- The status of the payment, one ofopen,paid, orcanceled. Max length: 5000.status_transitions- Expandable.