Stripe.Resources.Issuing.Authorization.Fleet.CardholderPromptData
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Authorization.Fleet.CardholderPromptData{ alphanumeric_id: String.t() | nil, driver_id: String.t() | nil, odometer: integer() | nil, unspecified_id: String.t() | nil, user_id: String.t() | nil, vehicle_number: String.t() | nil }
alphanumeric_id- [Deprecated] An alphanumeric ID, though typical point of sales only support numeric entry. The card program can be configured to prompt for a vehicle ID, driver ID, or generic ID. Max length: 5000. Nullable.driver_id- Driver ID. Max length: 5000. Nullable.odometer- Odometer reading. Nullable.unspecified_id- An alphanumeric ID. This field is used when a vehicle ID, driver ID, or generic ID is entered by the cardholder, but the merchant or card network did not specify the prompt type. Max length: 5000. Nullable.user_id- User ID. Max length: 5000. Nullable.vehicle_number- Vehicle number. Max length: 5000. Nullable.