Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Authorization.NetworkData{ acquiring_institution_id: String.t() | nil, system_trace_audit_number: String.t() | nil, transaction_id: String.t() | nil }
acquiring_institution_id- Identifier assigned to the acquirer by the card network. Sometimes this value is not provided by the network; in this case, the value will benull. Max length: 5000. Nullable.system_trace_audit_number- The System Trace Audit Number (STAN) is a 6-digit identifier assigned by the acquirer. Prefernetwork_data.transaction_idif present, unless you have special requirements. Max length: 5000. Nullable.transaction_id- Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions. Max length: 5000. Nullable.