Stripe.Resources.Issuing.Authorization.PendingRequest
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Authorization.PendingRequest{ amount: integer() | nil, amount_details: Stripe.Resources.Issuing.Authorization.PendingRequest.AmountDetails.t() | nil, currency: String.t() | nil, is_amount_controllable: boolean() | nil, merchant_amount: integer() | nil, merchant_currency: String.t() | nil, network_risk_score: integer() | nil }
amount- The additional amount Stripe will hold if the authorization is approved, in the card's currency and in the smallest currency unit.amount_details- Detailed breakdown of amount components. These amounts are denominated incurrencyand in the smallest currency unit. Nullable.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.is_amount_controllable- If settrue, you may provide amount to control how much to hold for the authorization.merchant_amount- The amount the merchant is requesting to be authorized in themerchant_currency. The amount is in the smallest currency unit.merchant_currency- The local currency the merchant is requesting to authorize. Format: ISO 4217 currency code.network_risk_score- The card network's estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99. Nullable.