Stripe.Resources.Issuing.Card.SpendingControls.SpendingLimits
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Card.SpendingControls.SpendingLimits{ amount: integer() | nil, categories: [String.t()] | nil, interval: String.t() | nil }
amount- Maximum amount allowed to spend per interval. This amount is in the card's currency and in the smallest currency unit.categories- Array of strings containing categories this limit applies to. Omitting this field will apply the limit to all categories. Nullable.interval- Interval (or event) to which the amount applies. Possible values:all_time,daily,monthly,per_authorization,weekly,yearly.