Stripe.Resources.Issuing.Cardholder.Individual.Verification.Document
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Cardholder.Individual.Verification.Document{ back: String.t() | Stripe.Resources.File.t() | nil, front: String.t() | Stripe.Resources.File.t() | nil }
back- The back of a document returned by a file upload with apurposevalue ofidentity_document. Nullable.front- The front of a document returned by a file upload with apurposevalue ofidentity_document. Nullable.