IssuingNetworkToken
An issuing token object is created when an issued card is added to a digital wallet. As a card issuer, you can view and manage these tokens through Stripe.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Token{ card: String.t() | Stripe.Resources.Issuing.Card.t(), created: integer(), device_fingerprint: String.t(), id: String.t(), last4: String.t() | nil, livemode: boolean(), network: String.t(), network_data: Stripe.Resources.Issuing.Token.NetworkData.t() | nil, network_updated_at: integer(), object: String.t(), status: String.t(), wallet_provider: String.t() | nil }
card- Card associated with this token. Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.device_fingerprint- The hashed ID derived from the device ID from the card network associated with the token. Max length: 5000. Nullable.id- Unique identifier for the object. Max length: 5000.last4- The last four digits of the token. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.network- The token service provider / card network associated with the token. Possible values:mastercard,visa.network_data- Expandable.network_updated_at- Time at which the token was last updated by the card network. Measured in seconds since the Unix epoch. Format: Unix timestamp.object- String representing the object's type. Objects of the same type share the same value. Possible values:issuing.token.status- The usage state of the token. Possible values:active,deleted,requested,suspended.wallet_provider- The digital wallet for this token, if one was used. Possible values:apple_pay,google_pay,samsung_pay.