Stripe.Resources.Issuing.Token.NetworkData.Mastercard
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Token.NetworkData.Mastercard{ card_reference_id: String.t() | nil, token_reference_id: String.t() | nil, token_requestor_id: String.t() | nil, token_requestor_name: String.t() | nil }
card_reference_id- A unique reference ID from MasterCard to represent the card account number. Max length: 5000.token_reference_id- The network-unique identifier for the token. Max length: 5000.token_requestor_id- The ID of the entity requesting tokenization, specific to MasterCard. Max length: 5000.token_requestor_name- The name of the entity requesting tokenization, if known. This is directly provided from MasterCard. Max length: 5000.