Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Token.NetworkData.Visa{ card_reference_id: String.t() | nil, token_reference_id: String.t() | nil, token_requestor_id: String.t() | nil, token_risk_score: String.t() | nil }
card_reference_id- A unique reference ID from Visa to represent the card account number. Max length: 5000.token_reference_id- The network-unique identifier for the token. Max length: 5000.token_requestor_id- The ID of the entity requesting tokenization, specific to Visa. Max length: 5000.token_risk_score- Degree of risk associated with the token between01and99, with higher number indicating higher risk. A00value indicates the token was not scored by Visa. Max length: 5000.