Stripe.Resources.Issuing.Token.NetworkData.WalletProvider.CardholderAddress
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Token.NetworkData.WalletProvider.CardholderAddress{ line1: String.t() | nil, postal_code: String.t() | nil }
line1- The street address of the cardholder tokenizing the card. Max length: 5000.postal_code- The postal code of the cardholder tokenizing the card. Max length: 5000.