IssuingTransaction
Any use of an issued card that results in funds entering or leaving
your Stripe account, such as a completed purchase or refund, is represented by an Issuing
Transaction object.
Related guide: Issued card transactions
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Transaction{ amount: integer(), amount_details: Stripe.Resources.Issuing.Transaction.AmountDetails.t(), authorization: String.t() | Stripe.Resources.Issuing.Authorization.t(), balance_transaction: String.t() | Stripe.Resources.BalanceTransaction.t(), card: String.t() | Stripe.Resources.Issuing.Card.t(), cardholder: String.t() | Stripe.Resources.Issuing.Cardholder.t(), created: integer(), currency: String.t(), dispute: String.t() | Stripe.Resources.Issuing.Dispute.t(), id: String.t(), livemode: boolean(), merchant_amount: integer(), merchant_currency: String.t(), merchant_data: Stripe.Resources.Issuing.Transaction.MerchantData.t(), metadata: %{required(String.t()) => String.t()}, network_data: Stripe.Resources.Issuing.Transaction.NetworkData.t(), object: String.t(), purchase_details: Stripe.Resources.Issuing.Transaction.PurchaseDetails.t() | nil, token: String.t() | Stripe.Resources.Issuing.Token.t() | nil, treasury: Stripe.Resources.Issuing.Transaction.Treasury.t() | nil, type: String.t(), wallet: String.t() }
amount- The transaction amount, which will be reflected in your balance. This amount is in your currency and in the smallest currency unit.amount_details- Detailed breakdown of amount components. These amounts are denominated incurrencyand in the smallest currency unit. Nullable. Expandable.authorization- TheAuthorizationobject that led to this transaction. Nullable. Expandable.balance_transaction- ID of the balance transaction associated with this transaction. Nullable. Expandable.card- The card used to make this transaction. Expandable.cardholder- The cardholder to whom this transaction belongs. Nullable. Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.dispute- If you've disputed the transaction, the ID of the dispute. Nullable. Expandable.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.merchant_amount- The amount that the merchant will receive, denominated inmerchant_currencyand in the smallest currency unit. It will be different fromamountif the merchant is taking payment in a different currency.merchant_currency- The currency with which the merchant is taking payment. Format: ISO 4217 currency code.merchant_data- Expandable.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.network_data- Details about the transaction, such as processing dates, set by the card network. Nullable. Expandable.object- String representing the object's type. Objects of the same type share the same value. Possible values:issuing.transaction.purchase_details- Additional purchase information that is optionally provided by the merchant. Nullable. Expandable.token- Token object used for this transaction. If a network token was not used for this transaction, this field will be null. Nullable. Expandable.treasury- Treasury details related to this transaction if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts Nullable. Expandable.type- The nature of the transaction. Possible values:capture,refund.wallet- The digital wallet used for this transaction. One ofapple_pay,google_pay, orsamsung_pay. Possible values:apple_pay,google_pay,samsung_pay. Nullable.