Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Transaction.MerchantData{ category: String.t() | nil, category_code: String.t() | nil, city: String.t() | nil, country: String.t() | nil, name: String.t() | nil, network_id: String.t() | nil, postal_code: String.t() | nil, state: String.t() | nil, tax_id: String.t() | nil, terminal_id: String.t() | nil, url: String.t() | nil }
category- A categorization of the seller's type of business. See our merchant categories guide for a list of possible values. Max length: 5000.category_code- The merchant category code for the seller’s business Max length: 5000.city- City where the seller is located Max length: 5000. Nullable.country- Country where the seller is located Max length: 5000. Nullable.name- Name of the seller Max length: 5000. Nullable.network_id- Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant. Max length: 5000.postal_code- Postal code where the seller is located Max length: 5000. Nullable.state- State where the seller is located Max length: 5000. Nullable.tax_id- The seller's tax identification number. Currently populated for French merchants only. Max length: 5000. Nullable.terminal_id- An ID assigned by the seller to the location of the sale. Max length: 5000. Nullable.url- URL provided by the merchant on a 3DS request Max length: 5000. Nullable.