Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Issuing.Transaction.Treasury{ received_credit: String.t() | nil, received_debit: String.t() | nil }
received_credit- The Treasury ReceivedCredit representing this Issuing transaction if it is a refund Max length: 5000. Nullable.received_debit- The Treasury ReceivedDebit representing this Issuing transaction if it is a capture Max length: 5000. Nullable.