LineItem
A line item.
Summary
Types
@type t() :: %Stripe.Resources.LineItem{ adjustable_quantity: Stripe.Resources.LineItem.AdjustableQuantity.t(), amount_discount: integer(), amount_subtotal: integer(), amount_tax: integer(), amount_total: integer(), currency: String.t(), description: String.t(), discounts: [Stripe.Resources.LineItem.Discounts.t()] | nil, id: String.t(), metadata: %{required(String.t()) => String.t()}, object: String.t(), price: Stripe.Resources.Price.t(), quantity: integer(), taxes: [Stripe.Resources.LineItem.Taxes.t()] | nil }
adjustable_quantity- Nullable. Expandable.amount_discount- Total discount amount applied. If no discounts were applied, defaults to 0.amount_subtotal- Total before any discounts or taxes are applied.amount_tax- Total tax amount applied. If no tax was applied, defaults to 0.amount_total- Total after discounts and taxes.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.description- An arbitrary string attached to the object. Often useful for displaying to users. Defaults to product name. Max length: 5000. Nullable.discounts- The discounts applied to the line item. Expandable.id- Unique identifier for the object. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Nullable.object- String representing the object's type. Objects of the same type share the same value. Possible values:item.price- The price used to generate the line item. Nullable. Expandable.quantity- The quantity of products being purchased. Nullable.taxes- The taxes applied to the line item. Expandable.