LoginLink
Login Links are single-use URLs that takes an Express account to the login page for their Stripe dashboard. A Login Link differs from an Account Link in that it takes the user directly to their Express dashboard for the specified account
Summary
Types
created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.object- String representing the object's type. Objects of the same type share the same value. Possible values:login_link.url- The URL for the login link. Max length: 5000.