PaymentIntentNextActionAlipayHandleRedirect
Summary
Types
@type t() :: %Stripe.Resources.NextActionAlipayHandleRedirect{ native_data: String.t(), native_url: String.t(), return_url: String.t(), url: String.t() }
native_data- The native data to be used with Alipay SDK you must redirect your customer to in order to authenticate the payment in an Android App. Max length: 5000. Nullable.native_url- The native URL you must redirect your customer to in order to authenticate the payment in an iOS App. Max length: 5000. Nullable.return_url- If the customer does not exit their browser while authenticating, they will be redirected to this specified URL after completion. Max length: 5000. Nullable.url- The URL you must redirect your customer to in order to authenticate the payment. Max length: 5000. Nullable.