Stripe.Resources.NextActionDisplayBankTransferInstructions
(tiger_stripe v0.1.10)
PaymentIntentNextActionDisplayBankTransferInstructions
Summary
Types
@type t() :: %Stripe.Resources.NextActionDisplayBankTransferInstructions{ amount_remaining: integer(), currency: String.t(), financial_addresses: [ Stripe.Resources.NextActionDisplayBankTransferInstructions.FinancialAddresses.t() ] | nil, hosted_instructions_url: String.t(), reference: String.t(), type: String.t() }
amount_remaining- The remaining amount that needs to be transferred to complete the payment. Nullable.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code. Nullable.financial_addresses- A list of financial addresses that can be used to fund the customer balance Expandable.hosted_instructions_url- A link to a hosted page that guides your customer through completing the transfer. Max length: 5000. Nullable.reference- A string identifying this payment. Instruct your customer to include this code in the reference or memo field of their bank transfer. Max length: 5000. Nullable.type- Type of bank transfer Possible values:eu_bank_transfer,gb_bank_transfer,jp_bank_transfer,mx_bank_transfer,us_bank_transfer.