Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Card.Wallet
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Card.Wallet{ apple_pay: Stripe.Resources.PaymentAttemptRecord.PaymentMethodDetails.Card.Wallet.ApplePay.t() | nil, dynamic_last4: String.t() | nil, google_pay: map() | nil, type: String.t() | nil }
apple_paydynamic_last4- (For tokenized numbers only.) The last four digits of the device account number. Max length: 5000.google_paytype- The type of the card wallet, one ofapple_payorgoogle_pay. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type. Max length: 5000.