Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentIntent.AmountDetails{ discount_amount: integer() | nil, error: Stripe.Resources.PaymentIntent.AmountDetails.Error.t() | nil, line_items: Stripe.Resources.PaymentIntent.AmountDetails.LineItems.t() | nil, shipping: Stripe.Resources.PaymentIntent.AmountDetails.Shipping.t() | nil, tax: Stripe.Resources.PaymentIntent.AmountDetails.Tax.t() | nil, tip: Stripe.Resources.PaymentIntent.AmountDetails.Tip.t() | nil }
discount_amount- The total discount applied on the transaction represented in the smallest currency unit. An integer greater than 0.
This field is mutually exclusive with the amount_details[line_items][#][discount_amount] field.
errorline_items- A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 200 line items.shippingtaxtip