Stripe.Resources.PaymentIntent.AmountDetails.Shipping
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentIntent.AmountDetails.Shipping{ amount: integer() | nil, from_postal_code: String.t() | nil, to_postal_code: String.t() | nil }
amount- If a physical good is being shipped, the cost of shipping represented in the smallest currency unit. An integer greater than or equal to 0. Nullable.from_postal_code- If a physical good is being shipped, the postal code of where it is being shipped from. At most 10 alphanumeric characters long, hyphens are allowed. Max length: 5000. Nullable.to_postal_code- If a physical good is being shipped, the postal code of where it is being shipped to. At most 10 alphanumeric characters long, hyphens are allowed. Max length: 5000. Nullable.