Stripe.Resources.PaymentIntent.PaymentMethodOptions.CardPresent
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentIntent.PaymentMethodOptions.CardPresent{ capture_method: String.t() | nil, request_extended_authorization: boolean() | nil, request_incremental_authorization_support: boolean() | nil, routing: Stripe.Resources.Routing.t() | nil }
capture_method- Controls when the funds will be captured from the customer's account. Possible values:manual,manual_preferred.request_extended_authorization- Request ability to capture this payment beyond the standard authorization validity window Nullable.request_incremental_authorization_support- Request ability to increment this PaymentIntent if the combination of MCC and card brand is eligible. Check incremental_authorization_supported in the Confirm response to verify support. Nullable.routing