Stripe.Resources.PaymentLink.NameCollection.Business
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentLink.NameCollection.Business{ enabled: boolean() | nil, optional: boolean() | nil }
enabled- Indicates whether business name collection is enabled for the payment link.optional- Whether the customer is required to complete the field before checking out. Defaults tofalse.