Stripe.Resources.PaymentLink.Restrictions.CompletedSessions
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentLink.Restrictions.CompletedSessions{ count: integer() | nil, limit: integer() | nil }
count- The current number of checkout sessions that have been completed on the payment link which count towards thecompleted_sessionsrestriction to be met.limit- The maximum number of checkout sessions that can be completed for thecompleted_sessionsrestriction to be met.