Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentLink.ShippingOptions{ shipping_amount: integer() | nil, shipping_rate: String.t() | Stripe.Resources.ShippingRate.t() | nil }
shipping_amount- A non-negative integer in cents representing how much to charge.shipping_rate- The ID of the Shipping Rate to use for this shipping option.