Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentMethod.RadarOptions{session: String.t() | nil}
session- A Radar Session is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments. Max length: 5000.