Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.PaymentMethod.UsBankAccount{ account_holder_type: String.t() | nil, account_type: String.t() | nil, bank_name: String.t() | nil, financial_connections_account: String.t() | nil, fingerprint: String.t() | nil, last4: String.t() | nil, networks: Stripe.Resources.PaymentMethod.UsBankAccount.Networks.t() | nil, routing_number: String.t() | nil, status_details: Stripe.Resources.PaymentMethod.UsBankAccount.StatusDetails.t() | nil }
account_holder_type- Account holder type: individual or company. Possible values:company,individual. Nullable.account_type- Account type: checkings or savings. Defaults to checking if omitted. Possible values:checking,savings. Nullable.bank_name- The name of the bank. Max length: 5000. Nullable.financial_connections_account- The ID of the Financial Connections Account used to create the payment method. Max length: 5000. Nullable.fingerprint- Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same. Max length: 5000. Nullable.last4- Last four digits of the bank account number. Max length: 5000. Nullable.networks- Contains information about US bank account networks that can be used. Nullable.routing_number- Routing number of the bank account. Max length: 5000. Nullable.status_details- Contains information about the future reusability of this PaymentMethod. Nullable.