Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Person.FutureRequirements{ alternatives: [Stripe.Resources.Person.FutureRequirements.Alternatives.t()] | nil, currently_due: [String.t()] | nil, errors: [Stripe.Resources.Person.FutureRequirements.Errors.t()] | nil, eventually_due: [String.t()] | nil, past_due: [String.t()] | nil, pending_verification: [String.t()] | nil }
alternatives- Fields that are due and can be resolved by providing the corresponding alternative fields instead. Many alternatives can list the sameoriginal_fields_due, and any of these alternatives can serve as a pathway for attempting to resolve the fields again. Re-providingoriginal_fields_duealso serves as a pathway for attempting to resolve the fields again. Nullable.currently_due- Fields that need to be resolved to keep the person's account enabled. If not resolved by the account'sfuture_requirements[current_deadline], these fields will transition to the mainrequirementshash, and may immediately becomepast_due, but the account may also be given a grace period depending on the account's enablement state prior to transition.errors- Details about validation and verification failures forduerequirements that must be resolved.eventually_due- Fields you must collect when all thresholds are reached. As they become required, they appear incurrently_dueas well, and the account'sfuture_requirements[current_deadline]becomes set.past_due- Fields that haven't been resolved by the account'srequirements.current_deadline. These fields need to be resolved to enable the person's account.future_requirements.past_dueis a subset ofrequirements.past_due.pending_verification- Fields that are being reviewed, or might become required depending on the results of a review. If the review fails, these fields can move toeventually_due,currently_due,past_dueoralternatives. Fields might appear ineventually_due,currently_due,past_dueoralternativesand inpending_verificationif one verification fails but another is still pending.