Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Person.Verification{ additional_document: Stripe.Resources.Person.Verification.AdditionalDocument.t() | nil, details: String.t() | nil, details_code: String.t() | nil, document: Stripe.Resources.Person.Verification.Document.t() | nil, status: String.t() | nil }
additional_document- A document showing address, either a passport, local ID card, or utility bill from a well-known utility company. Nullable.details- A user-displayable string describing the verification state for the person. For example, this may say "Provided identity information could not be verified". Max length: 5000. Nullable.details_code- One ofdocument_address_mismatch,document_dob_mismatch,document_duplicate_type,document_id_number_mismatch,document_name_mismatch,document_nationality_mismatch,failed_keyed_identity, orfailed_other. A machine-readable code specifying the verification state for the person. Max length: 5000. Nullable.documentstatus- The state of verification for the person. Possible values areunverified,pending, orverified. Please refer guide to handle verification updates. Max length: 5000.