PaymentIntentNextActionPixDisplayQrCode
Summary
Types
@type t() :: %Stripe.Resources.PixDisplayQrCode{ data: String.t() | nil, expires_at: integer() | nil, hosted_instructions_url: String.t() | nil, image_url_png: String.t() | nil, image_url_svg: String.t() | nil }
data- The raw data string used to generate QR code, it should be used together with QR code library. Max length: 5000.expires_at- The date (unix timestamp) when the PIX expires.hosted_instructions_url- The URL to the hosted pix instructions page, which allows customers to view the pix QR code. Max length: 5000.image_url_png- The image_url_png string used to render png QR code Max length: 5000.image_url_svg- The image_url_svg string used to render svg QR code Max length: 5000.