Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Price.CustomUnitAmount{ maximum: integer() | nil, minimum: integer() | nil, preset: integer() | nil }
maximum- The maximum unit amount the customer can specify for this item. Nullable.minimum- The minimum unit amount the customer can specify for this item. Must be at least the minimum charge amount. Nullable.preset- The starting unit amount which can be updated by the customer. Nullable.