Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Price.Recurring{ interval: String.t() | nil, interval_count: integer() | nil, meter: String.t() | nil, trial_period_days: integer() | nil, usage_type: String.t() | nil }
interval- The frequency at which a subscription is billed. One ofday,week,monthoryear. Possible values:day,month,week,year.interval_count- The number of intervals (specified in theintervalattribute) between subscription billings. For example,interval=monthandinterval_count=3bills every 3 months.meter- The meter tracking the usage of a metered price Max length: 5000. Nullable.trial_period_days- Default number of trial days when subscribing a customer to this price usingtrial_from_plan=true. Nullable.usage_type- Configures how the quantity per period should be determined. Can be eithermeteredorlicensed.licensedautomatically bills thequantityset when adding it to a subscription.meteredaggregates the total usage based on usage records. Defaults tolicensed. Possible values:licensed,metered.