RadarListList
Value lists allow you to group values together which can then be referenced in rules.
Related guide: Default Stripe lists
Summary
Types
@type t() :: %Stripe.Resources.Radar.ValueList{ alias: String.t(), created: integer(), created_by: String.t(), id: String.t(), item_type: String.t(), list_items: Stripe.Resources.Radar.ValueList.ListItems.t(), livemode: boolean(), metadata: %{required(String.t()) => String.t()}, name: String.t(), object: String.t() }
alias- The name of the value list for use in rules. Max length: 5000.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.created_by- The name or email address of the user who created this value list. Max length: 5000.id- Unique identifier for the object. Max length: 5000.item_type- The type of items in the value list. One ofcard_fingerprint,card_bin,email,ip_address,country,string,case_sensitive_string,customer_id,sepa_debit_fingerprint, orus_bank_account_fingerprint. Possible values:card_bin,card_fingerprint,case_sensitive_string,country,customer_id,email,ip_address,sepa_debit_fingerprint,string,us_bank_account_fingerprint.list_items- List of items contained within this value list. Expandable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.name- The name of the value list. Max length: 5000.object- String representing the object's type. Objects of the same type share the same value. Possible values:radar.value_list.