Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Refund.DestinationDetails.Card{ reference: String.t() | nil, reference_status: String.t() | nil, reference_type: String.t() | nil, type: String.t() | nil }
reference- Value of the reference number assigned to the refund. Max length: 5000.reference_status- Status of the reference number on the refund. This can bepending,availableorunavailable. Max length: 5000.reference_type- Type of the reference number assigned to the refund. Max length: 5000.type- The type of refund. This can berefund,reversal, orpending. Possible values:pending,refund,reversal.