Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Reporting.ReportRun.Parameters{ columns: [String.t()] | nil, connected_account: String.t() | nil, currency: String.t() | nil, interval_end: integer() | nil, interval_start: integer() | nil, payout: String.t() | nil, reporting_category: String.t() | nil, timezone: String.t() | nil }
columns- The set of output columns requested for inclusion in the report run.connected_account- Connected account ID by which to filter the report run. Max length: 5000.currency- Currency of objects to be included in the report run. Format: ISO 4217 currency code.interval_end- Ending timestamp of data to be included in the report run. Can be any UTC timestamp between 1 second after the user specifiedinterval_startand 1 second before this report's lastdata_available_endvalue. Format: Unix timestamp.interval_start- Starting timestamp of data to be included in the report run. Can be any UTC timestamp between 1 second after this report'sdata_available_startand 1 second before the user specifiedinterval_endvalue. Format: Unix timestamp.payout- Payout ID by which to filter the report run. Max length: 5000.reporting_category- Category of balance transactions to be included in the report run. Max length: 5000.timezone- Defaults toEtc/UTC. The output timezone for all timestamps in the report. A list of possible time zone values is maintained at the IANA Time Zone Database. Has no effect oninterval_startorinterval_end. Max length: 5000.