RadarReview
Reviews can be used to supplement automated fraud detection with human expertise.
Summary
Types
@type t() :: %Stripe.Resources.Review{ billing_zip: String.t(), charge: String.t() | Stripe.Resources.Charge.t(), closed_reason: String.t(), created: integer(), id: String.t(), ip_address: String.t(), ip_address_location: Stripe.Resources.Review.IpAddressLocation.t(), livemode: boolean(), object: String.t(), open: boolean(), opened_reason: String.t(), payment_intent: String.t() | Stripe.Resources.PaymentIntent.t() | nil, reason: String.t(), session: Stripe.Resources.Review.Session.t() }
billing_zip- The ZIP or postal code of the card used, if applicable. Max length: 5000. Nullable.charge- The charge associated with this review. Nullable. Expandable.closed_reason- The reason the review was closed, or null if it has not yet been closed. One ofapproved,refunded,refunded_as_fraud,disputed,redacted,canceled,payment_never_settled, oracknowledged. Possible values:acknowledged,approved,canceled,disputed,payment_never_settled,redacted,refunded,refunded_as_fraud. Nullable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.id- Unique identifier for the object. Max length: 5000.ip_address- The IP address where the payment originated. Max length: 5000. Nullable.ip_address_location- Information related to the location of the payment. Note that this information is an approximation and attempts to locate the nearest population center - it should not be used to determine a specific address. Nullable. Expandable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:review.open- Iftrue, the review needs action.opened_reason- The reason the review was opened. One ofruleormanual. Possible values:manual,rule.payment_intent- The PaymentIntent ID associated with this review, if one exists. Expandable.reason- The reason the review is currently open or closed. One ofrule,manual,approved,refunded,refunded_as_fraud,disputed,redacted,canceled,payment_never_settled, oracknowledged. Max length: 5000.session- Information related to the browsing session of the user who initiated the payment. Nullable. Expandable.