Stripe.Resources.SetupAttempt.PaymentMethodDetails.Card.Wallet
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SetupAttempt.PaymentMethodDetails.Card.Wallet{ apple_pay: map() | nil, google_pay: map() | nil, type: String.t() | nil }
apple_paygoogle_paytype- The type of the card wallet, one ofapple_pay,google_pay, orlink. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type. Possible values:apple_pay,google_pay,link.