Stripe.Resources.SetupIntent.NextAction.VerifyWithMicrodeposits
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SetupIntent.NextAction.VerifyWithMicrodeposits{ arrival_date: integer() | nil, hosted_verification_url: String.t() | nil, microdeposit_type: String.t() | nil }
arrival_date- The timestamp when the microdeposits are expected to land. Format: Unix timestamp.hosted_verification_url- The URL for the hosted verification page, which allows customers to verify their bank account. Max length: 5000.microdeposit_type- The type of the microdeposit sent to the customer. Used to distinguish between different verification methods. Possible values:amounts,descriptor_code. Nullable.