Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Source.SourceOrder{ amount: integer() | nil, currency: String.t() | nil, email: String.t() | nil, items: [Stripe.Resources.Source.SourceOrder.Items.t()] | nil, shipping: Stripe.Resources.ShippingDetails.t() | nil }
amount- A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount for the order.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.email- The email address of the customer placing the order. Max length: 5000.items- List of items constituting the order. Nullable.shipping