SourceMandateNotification
Source mandate notifications should be created when a notification related to a source mandate must be sent to the payer. They will trigger a webhook or deliver an email to the customer.
Summary
Types
@type t() :: %Stripe.Resources.SourceMandateNotification{ acss_debit: Stripe.Resources.SourceMandateNotification.AcssDebit.t() | nil, amount: integer(), bacs_debit: Stripe.Resources.SourceMandateNotification.BacsDebit.t() | nil, created: integer(), id: String.t(), livemode: boolean(), object: String.t(), reason: String.t(), sepa_debit: Stripe.Resources.SourceMandateNotification.SepaDebit.t() | nil, source: Stripe.Resources.Source.t(), status: String.t(), type: String.t() }
acss_debit- Expandable.amount- A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the amount associated with the mandate notification. The amount is expressed in the currency of the underlying source. Required if the notification type isdebit_initiated. Nullable.bacs_debit- Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:source_mandate_notification.reason- The reason of the mandate notification. Valid reasons aremandate_confirmedordebit_initiated. Max length: 5000.sepa_debit- Expandable.source- Expandable.status- The status of the mandate notification. Valid statuses arependingorsubmitted. Max length: 5000.type- The type of source this mandate notification is attached to. Should be the source type identifier code for the payment method, such asthree_d_secure. Max length: 5000.