Stripe.Resources.SourceTransaction.GbpCreditTransfer
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SourceTransaction.GbpCreditTransfer{ fingerprint: String.t() | nil, funding_method: String.t() | nil, last4: String.t() | nil, reference: String.t() | nil, sender_account_number: String.t() | nil, sender_name: String.t() | nil, sender_sort_code: String.t() | nil }
fingerprint- Bank account fingerprint associated with the Stripe owned bank account receiving the transfer. Max length: 5000.funding_method- The credit transfer rails the sender used to push this transfer. The possible rails are: Faster Payments, BACS, CHAPS, and wire transfers. Currently only Faster Payments is supported. Max length: 5000.last4- Last 4 digits of sender account number associated with the transfer. Max length: 5000.reference- Sender entered arbitrary information about the transfer. Max length: 5000.sender_account_number- Sender account number associated with the transfer. Max length: 5000.sender_name- Sender name associated with the transfer. Max length: 5000.sender_sort_code- Sender sort code associated with the transfer. Max length: 5000.