Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Subscription.CancellationDetails{ comment: String.t() | nil, feedback: String.t() | nil, reason: String.t() | nil }
comment- Additional comments about why the user canceled the subscription, if the subscription was canceled explicitly by the user. Max length: 5000. Nullable.feedback- The customer submitted reason for why they canceled, if the subscription was canceled explicitly by the user. Possible values:customer_service,low_quality,missing_features,other,switched_service,too_complex,too_expensive,unused. Nullable.reason- Why this subscription was canceled. Possible values:cancellation_requested,payment_disputed,payment_failed. Nullable.