Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Subscription.PauseCollection{ behavior: String.t() | nil, resumes_at: integer() | nil }
behavior- The payment collection behavior for this subscription while paused. One ofkeep_as_draft,mark_uncollectible, orvoid. Possible values:keep_as_draft,mark_uncollectible,void.resumes_at- The time after which the subscription will resume collecting payments. Format: Unix timestamp. Nullable.