Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.Card.MandateOptions
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Subscription.PaymentSettings.PaymentMethodOptions.Card.MandateOptions{ amount: integer() | nil, amount_type: String.t() | nil, description: String.t() | nil }
amount- Amount to be charged for future payments. Nullable.amount_type- One offixedormaximum. Iffixed, theamountparam refers to the exact amount to be charged in future payments. Ifmaximum, the amount charged can be up to the value passed for theamountparam. Possible values:fixed,maximum. Nullable.description- A description of the mandate or subscription that is meant to be displayed to the customer. Max length: 200. Nullable.