Stripe.Resources.Subscription.TrialSettings.EndBehavior
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Subscription.TrialSettings.EndBehavior{ missing_payment_method: String.t() | nil }
missing_payment_method- Indicates how the subscription should change when the trial ends if the user did not provide a payment method. Possible values:cancel,create_invoice,pause.