SubscriptionItem
Subscription items allow you to create customer subscriptions with more than one plan, making it easy to represent complex billing relationships.
Summary
Types
@type t() :: %Stripe.Resources.SubscriptionItem{ billing_thresholds: Stripe.Resources.SubscriptionItem.BillingThresholds.t(), created: integer(), current_period_end: integer(), current_period_start: integer(), discounts: [String.t() | Stripe.Resources.Discount.t()], id: String.t(), metadata: %{required(String.t()) => String.t()}, object: String.t(), plan: Stripe.Resources.Plan.t(), price: Stripe.Resources.Price.t(), quantity: integer() | nil, subscription: String.t(), tax_rates: [Stripe.Resources.TaxRate.t()] }
billing_thresholds- Define thresholds at which an invoice will be sent, and the related subscription advanced to a new billing period Nullable. Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch.current_period_end- The end time of this subscription item's current billing period. Format: Unix timestamp.current_period_start- The start time of this subscription item's current billing period. Format: Unix timestamp.discounts- The discounts applied to the subscription item. Subscription item discounts are applied before subscription discounts. Useexpand[]=discountsto expand each discount. Expandable.id- Unique identifier for the object. Max length: 5000.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.object- String representing the object's type. Objects of the same type share the same value. Possible values:subscription_item.plan- Expandable.price- Expandable.quantity- The quantity of the plan to which the customer should be subscribed.subscription- Thesubscriptionthissubscription_itembelongs to. Max length: 5000.tax_rates- The tax rates which apply to thissubscription_item. When set, thedefault_tax_rateson the subscription do not apply to thissubscription_item. Nullable. Expandable.