Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Period.Start
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.SubscriptionSchedule.Phases.AddInvoiceItems.Period.Start{ timestamp: integer() | nil, type: String.t() | nil }
timestamp- A precise Unix timestamp for the start of the invoice item period. Must be less than or equal toperiod.end. Format: Unix timestamp.type- Select how to calculate the start of the invoice item period. Possible values:max_item_period_start,phase_start,timestamp.