Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Tax.Calculation.TaxBreakdown{ amount: integer() | nil, inclusive: boolean() | nil, tax_rate_details: Stripe.Resources.Tax.Calculation.TaxBreakdown.TaxRateDetails.t() | nil, taxability_reason: String.t() | nil, taxable_amount: integer() | nil }
amount- The amount of tax, in the smallest currency unit.inclusive- Specifies whether the tax amount is included in the line item amount.tax_rate_detailstaxability_reason- The reasoning behind this tax, for example, if the product is tax exempt. We might extend the possible values for this field to support new tax rules. Possible values:customer_exempt,not_collecting,not_subject_to_tax,not_supported,portion_product_exempt,portion_reduced_rated,portion_standard_rated,product_exempt,product_exempt_holiday,proportionally_rated,reduced_rated,reverse_charge,standard_rated,taxable_basis_reduced,zero_rated.taxable_amount- The amount on which tax is calculated, in the smallest currency unit.