Stripe.Resources.Tax.Calculation.TaxBreakdown.TaxRateDetails
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Tax.Calculation.TaxBreakdown.TaxRateDetails{ country: String.t() | nil, flat_amount: Stripe.Resources.TaxRateFlatAmount.t() | nil, percentage_decimal: String.t() | nil, rate_type: String.t() | nil, state: String.t() | nil, tax_type: String.t() | nil }
country- Two-letter country code (ISO 3166-1 alpha-2). Max length: 5000. Nullable.flat_amount- The amount of the tax rate when therate_typeisflat_amount. Tax rates withrate_typepercentagecan vary based on the transaction, resulting in this field beingnull. This field exposes the amount and currency of the flat tax rate. Nullable.percentage_decimal- The tax rate percentage as a string. For example, 8.5% is represented as"8.5". Max length: 5000.rate_type- Indicates the type of tax rate applied to the taxable amount. This value can benullwhen no tax applies to the location. This field is only present for TaxRates created by Stripe Tax. Possible values:flat_amount,percentage. Nullable.state- State, county, province, or region (ISO 3166-2). Max length: 5000. Nullable.tax_type- The tax type, such asvatorsales_tax. Possible values:amusement_tax,communications_tax,gst,hst,igst,jct,lease_tax,pst,qst,retail_delivery_fee,rst,sales_tax,service_tax,vat. Nullable.