Stripe.Resources.Tax.Settings.StatusDetails.Pending
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Tax.Settings.StatusDetails.Pending{ missing_fields: [String.t()] | nil }
missing_fields- The list of missing fields that are required to perform calculations. It includes the entryhead_officewhen the status ispending. It is recommended to set the optional values even if they aren't listed as required for calculating taxes. Calculations can fail if missing fields aren't explicitly provided on every call. Nullable.