Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Tax.Transaction.ShippingCost{ amount: integer() | nil, amount_tax: integer() | nil, shipping_rate: String.t() | nil, tax_behavior: String.t() | nil, tax_breakdown: [Stripe.Resources.Tax.Transaction.ShippingCost.TaxBreakdown.t()] | nil, tax_code: String.t() | nil }
amount- The shipping amount in the smallest currency unit. Iftax_behavior=inclusive, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.amount_tax- The amount of tax calculated for shipping, in the smallest currency unit.shipping_rate- The ID of an existing ShippingRate. Max length: 5000.tax_behavior- Specifies whether theamountincludes taxes. Iftax_behavior=inclusive, then the amount includes taxes. Possible values:exclusive,inclusive.tax_breakdown- Detailed account of taxes relevant to shipping cost. (It is not populated for the transaction resource object and will be removed in the next API version.)tax_code- The tax code ID used for shipping. Max length: 5000.