TaxProductResourceTaxCode
Tax codes classify goods and services for tax purposes.
Summary
Types
@type t() :: %Stripe.Resources.TaxCode{ description: String.t(), id: String.t(), name: String.t(), object: String.t() }
description- A detailed description of which types of products the tax code represents. Max length: 5000.id- Unique identifier for the object. Max length: 5000.name- A short name for the tax code. Max length: 5000.object- String representing the object's type. Objects of the same type share the same value. Possible values:tax_code.