Stripe.Resources.Terminal.Configuration.RebootWindow
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Terminal.Configuration.RebootWindow{ end_hour: integer() | nil, start_hour: integer() | nil }
end_hour- Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.start_hour- Integer between 0 to 23 that represents the start hour of the reboot time window.