TerminalLocationLocation
A Location represents a grouping of readers.
Related guide: Fleet management
Summary
Types
@type t() :: %Stripe.Resources.Terminal.Location{ address: Stripe.Resources.Address.t(), address_kana: Stripe.Resources.Terminal.Location.AddressKana.t() | nil, address_kanji: Stripe.Resources.Terminal.Location.AddressKanji.t() | nil, configuration_overrides: String.t() | nil, display_name: String.t(), display_name_kana: String.t() | nil, display_name_kanji: String.t() | nil, id: String.t(), livemode: boolean(), metadata: %{required(String.t()) => String.t()}, object: String.t(), phone: String.t() | nil }
address- Expandable.address_kana- Expandable.address_kanji- Expandable.configuration_overrides- The ID of a configuration that will be used to customize all readers in this location. Max length: 5000.display_name- The display name of the location. Max length: 5000.display_name_kana- The Kana variation of the display name of the location. Max length: 5000.display_name_kanji- The Kanji variation of the display name of the location. Max length: 5000.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.object- String representing the object's type. Objects of the same type share the same value. Possible values:terminal.location.phone- The phone number of the location. Max length: 5000.