Stripe.Resources.Terminal.Reader.Action.CollectInputs.Inputs.CustomText
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Terminal.Reader.Action.CollectInputs.Inputs.CustomText{ description: String.t() | nil, skip_button: String.t() | nil, submit_button: String.t() | nil, title: String.t() | nil }
description- Customize the default description for this input Max length: 5000. Nullable.skip_button- Customize the default label for this input's skip button Max length: 5000. Nullable.submit_button- Customize the default label for this input's submit button Max length: 5000. Nullable.title- Customize the default title for this input Max length: 5000. Nullable.