Stripe.Resources.Terminal.Reader.Action.ProcessSetupIntent
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Terminal.Reader.Action.ProcessSetupIntent{ generated_card: String.t() | nil, process_config: Stripe.Resources.Terminal.Reader.Action.ProcessSetupIntent.ProcessConfig.t() | nil, setup_intent: String.t() | Stripe.Resources.SetupIntent.t() | nil }
generated_card- ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod. Max length: 5000.process_configsetup_intent- Most recent SetupIntent processed by the reader.