Stripe.Resources.Treasury.InboundTransfer.LinkedFlows
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Treasury.InboundTransfer.LinkedFlows{ received_debit: String.t() | nil }
received_debit- If funds for this flow were returned after the flow went to thesucceededstate, this field contains a reference to the ReceivedDebit return. Max length: 5000. Nullable.