Stripe.Resources.Treasury.Transaction.BalanceImpact
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.Treasury.Transaction.BalanceImpact{ cash: integer() | nil, inbound_pending: integer() | nil, outbound_pending: integer() | nil }
cash- The change made to funds the user can spend right now.inbound_pending- The change made to funds that are not spendable yet, but will become available at a later time.outbound_pending- The change made to funds in the account, but not spendable because they are being held for pending outbound flows.