TreasuryTransactionsResourceTransactionEntry
TransactionEntries represent individual units of money movements within a single Transaction.
Summary
Types
@type t() :: %Stripe.Resources.Treasury.TransactionEntry{ balance_impact: Stripe.Resources.Treasury.TransactionEntry.BalanceImpact.t(), created: integer(), currency: String.t(), effective_at: integer(), financial_account: String.t(), flow: String.t(), flow_details: Stripe.Resources.Treasury.TransactionEntry.FlowDetails.t() | nil, flow_type: String.t(), id: String.t(), livemode: boolean(), object: String.t(), transaction: String.t() | Stripe.Resources.Treasury.Transaction.t(), type: String.t() }
balance_impact- Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.effective_at- When the TransactionEntry will impact the FinancialAccount's balance. Format: Unix timestamp.financial_account- The FinancialAccount associated with this object. Max length: 5000.flow- Token of the flow associated with the TransactionEntry. Max length: 5000. Nullable.flow_details- Details of the flow associated with the TransactionEntry. Nullable. Expandable.flow_type- Type of the flow associated with the TransactionEntry. Possible values:credit_reversal,debit_reversal,inbound_transfer,issuing_authorization,other,outbound_payment,outbound_transfer,received_credit,received_debit.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:treasury.transaction_entry.transaction- The Transaction associated with this object. Expandable.type- The specific money movement that generated the TransactionEntry. Possible values:credit_reversal,credit_reversal_posting,debit_reversal,inbound_transfer,inbound_transfer_return,issuing_authorization_hold,issuing_authorization_release,other,outbound_payment,outbound_payment_cancellation,outbound_payment_failure,outbound_payment_posting,outbound_payment_return,outbound_transfer,outbound_transfer_cancellation,outbound_transfer_failure,outbound_transfer_posting,outbound_transfer_return,received_credit,received_debit.