Meter Event
Fix me empty_doc_string.
Summary
Types
@type t() :: %Stripe.Resources.V2.Billing.MeterEvent{ created: String.t(), event_name: String.t(), identifier: String.t(), livemode: boolean(), object: String.t(), payload: %{required(String.t()) => String.t()}, timestamp: String.t() }
created- The creation time of this meter event. Format: date-time.event_name- The name of the meter event. Corresponds with theevent_namefield on a meter.identifier- A unique identifier for the event. If not provided, one will be generated. We recommend using a globally unique identifier for this. We’ll enforce uniqueness within a rolling 24 hour period.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value of the object field. Possible values:v2.billing.meter_event.payload- The payload of the event. This must contain the fields corresponding to a meter’scustomer_mapping.event_payload_key(default isstripe_customer_id) andvalue_settings.event_payload_key(default isvalue). Read more about the payload..timestamp- The time of the event. Must be within the past 35 calendar days or up to 5 minutes in the future. Defaults to current timestamp if not specified. Format: date-time.