Meter Event Session
Summary
Types
@type t() :: %Stripe.Resources.V2.Billing.MeterEventSession{ authentication_token: String.t(), created: String.t(), expires_at: String.t(), id: String.t(), livemode: boolean(), object: String.t() }
authentication_token- The authentication token for this session. Use this token when calling the high-throughput meter event API.created- The creation time of this session. Format: date-time.expires_at- The time at which this session will expire. Format: date-time.id- The unique id of this auth session.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value of the object field. Possible values:v2.billing.meter_event_session.