Stripe.Resources.V2.Core.Account.Configuration.Customer.Billing.Invoice
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Configuration.Customer.Billing.Invoice{ custom_fields: [ Stripe.Resources.V2.Core.Account.Configuration.Customer.Billing.Invoice.CustomFields.t() ] | nil, footer: String.t() | nil, next_sequence: integer() | nil, prefix: String.t() | nil, rendering: Stripe.Resources.V2.Core.Account.Configuration.Customer.Billing.Invoice.Rendering.t() | nil }
custom_fields- The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.footer- Default invoice footer.next_sequence- Sequence number to use on the customer account's next invoice. Defaults to 1.prefix- Prefix used to generate unique invoice numbers. Must be 3-12 uppercase letters or numbers.rendering- Default invoice PDF rendering options.