Stripe.Resources.V2.Core.Account.Configuration.Merchant.Support
(tiger_stripe v0.1.10)
Nested struct within the parent resource.
Summary
Types
@type t() :: %Stripe.Resources.V2.Core.Account.Configuration.Merchant.Support{ address: Stripe.Resources.V2.Core.Account.Configuration.Merchant.Support.Address.t() | nil, email: String.t() | nil, phone: String.t() | nil, url: String.t() | nil }
address- A publicly available mailing address for sending support issues to.email- A publicly available email address for sending support issues to.phone- A publicly available phone number to call with support issues.url- A publicly available website for handling support issues.