AccountExternalAccount API operations.
Summary
Functions
Create an external account
Delete an external account
List all external accounts
Retrieve an external account
Updates the metadata, account holder name, account holder type of a bank account belonging to a connected account and optionally sets it as the default for its currency. Other bank account details are not editable by design.
Functions
@spec create(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create an external account
Create an external account for a given account.
@spec delete(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Delete an external account
Delete a specified external account for a given account.
@spec list(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List all external accounts
List external accounts for an account.
@spec retrieve(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve an external account
Retrieve a specified external account for a given account.
@spec update(Stripe.Client.t(), String.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Updates the metadata, account holder name, account holder type of a bank account belonging to a connected account and optionally sets it as the default for its currency. Other bank account details are not editable by design.
You can only update bank accounts when account.controller.requirement_collection is application, which includes Custom accounts.
You can re-enable a disabled bank account by performing an update call without providing any arguments or changes.