AccountLoginLink API operations.
Summary
Functions
Create a login link
Functions
@spec create(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create a login link
Creates a login link for a connected account to access the Express Dashboard.
You can only create login links for accounts that use the Express Dashboard and are connected to your platform.