Balance
This is an object representing your Stripe balance. You can retrieve it to see the balance currently on your Stripe account.
The top-level available and pending comprise your "payments balance."
Related guide: Balances and settlement time, Understanding Connect account balances
Summary
Functions
Retrieve balance
Functions
@spec retrieve(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve balance
Retrieves the current account balance, based on the authentication that was used to make the request. For a sample request, see Accounting for negative balances.