PortalConfiguration
A portal configuration describes the functionality and behavior you embed in a portal session. Related guide: Configure the customer portal.
Summary
Functions
Create a portal configuration
List portal configurations
Retrieve a portal configuration
Update a portal configuration
Functions
@spec create(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create a portal configuration
Creates a configuration that describes the functionality and behavior of a PortalSession
@spec list(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List portal configurations
Returns a list of configurations that describe the functionality of the customer portal.
@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve a portal configuration
Retrieves a configuration that describes the functionality of the customer portal.
@spec update(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Update a portal configuration
Updates a configuration that describes the functionality of the customer portal.