SessionLineItem API operations.
Summary
Functions
Retrieve a Checkout Session's line items
Functions
@spec list_line_items(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve a Checkout Session's line items
When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.