ClimateRemovalsProducts
A Climate product represents a type of carbon removal unit available for reservation. You can retrieve it to see the current price and availability.
Summary
Functions
@spec list(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List products
Lists all available Climate product objects.
@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve a product
Retrieves the details of a Climate product with the given ID.