CustomerFundingInstructions API operations.
Summary
Functions
Create or retrieve funding instructions for a customer cash balance
Functions
@spec create_funding_instructions(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create or retrieve funding instructions for a customer cash balance
Retrieve funding instructions for a customer cash balance. If funding instructions do not yet exist for the customer, new funding instructions will be created. If funding instructions have already been created for a given customer, the same funding instructions will be retrieved. In other words, we will return the same funding instructions each time.