RadarEarlyFraudWarning
An early fraud warning indicates that the card issuer has notified us that a charge may be fraudulent.
Related guide: Early fraud warnings
Summary
Functions
@spec list(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List all early fraud warnings
Returns a list of early fraud warnings.
@spec retrieve(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Retrieve an early fraud warning
Retrieves the details of an early fraud warning that has previously been created.
Please refer to the early fraud warning object reference for more details.