PaymentFlowsSetupIntentSetupAttempt
A SetupAttempt describes one attempted confirmation of a SetupIntent, whether that confirmation is successful or unsuccessful. You can use SetupAttempts to inspect details of a specific attempt at setting up a payment method using a SetupIntent.
Summary
Functions
List all SetupAttempts
Functions
@spec list(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
List all SetupAttempts
Returns a list of SetupAttempts that associate with a provided SetupIntent.