Stripe.Services.TestHelpers.Issuing.TransactionService
(tiger_stripe v0.1.10)
Transaction API operations.
Summary
Functions
Create a test-mode force capture
Create a test-mode unlinked refund
Refund a test-mode transaction
Functions
@spec create_force_capture(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create a test-mode force capture
Allows the user to capture an arbitrary amount, also known as a forced capture.
@spec create_unlinked_refund(Stripe.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Create a test-mode unlinked refund
Allows the user to refund an arbitrary amount, also known as a unlinked refund.
@spec refund(Stripe.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, Stripe.Error.t()}
Refund a test-mode transaction
Refund a test-mode Transaction.