Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.CreditNoteCreateParams.Refunds{ amount_refunded: integer() | nil, payment_record_refund: map() | nil, refund: String.t() | nil, type: String.t() | nil }
amount_refunded- Amount of the refund that applies to this credit note, in cents (or local equivalent). Defaults to the entire refund amount.payment_record_refund- The PaymentRecord refund details to link to this credit note. Required whentypeispayment_record_refund.refund- ID of an existing refund to link this credit note to. Required whentypeisrefund.type- Type of the refund, one ofrefundorpayment_record_refund. Defaults torefund. Possible values:payment_record_refund,refund.