Parameters for customer session create.
Summary
Types
@type t() :: %StripeElixir.Params.CustomerSessionCreateParams{ components: map(), customer: String.t() | nil, customer_account: String.t() | nil, expand: [String.t()] | nil }
components- Configuration for each component. At least 1 component must be enabled.customer- The ID of an existing customer for which to create the Customer Session. Max length: 5000.customer_account- The ID of an existing Account for which to create the Customer Session. Max length: 5000.expand- Specifies which fields in the response should be expanded.