StripeElixir.Params.Entitlements.FeatureCreateParams
(stripe_elixir v0.1.0)
Parameters for feature create.
Summary
Types
@type t() :: %StripeElixir.Params.Entitlements.FeatureCreateParams{ expand: [String.t()] | nil, lookup_key: String.t(), metadata: map() | nil, name: String.t() }
expand- Specifies which fields in the response should be expanded.lookup_key- A unique key you provide as your own system identifier. This may be up to 80 characters. Max length: 80.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.name- The feature's name, for your own purpose, not meant to be displayable to the customer. Max length: 80.