StripeElixir.Params.Entitlements.FeatureUpdateParams
(stripe_elixir v0.1.0)
Parameters for feature update.
Summary
Types
@type t() :: %StripeElixir.Params.Entitlements.FeatureUpdateParams{ active: boolean() | nil, expand: [String.t()] | nil, metadata: map() | nil, name: String.t() | nil }
active- Inactive features cannot be attached to new products and will not be returned from the features list endpoint.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.name- The feature's name, for your own purpose, not meant to be displayable to the customer. Max length: 80.