Parameters for file list.
Summary
Types
@type t() :: %StripeElixir.Params.FileListParams{ created: map() | nil, ending_before: String.t() | nil, expand: [String.t()] | nil, limit: integer() | nil, purpose: String.t() | nil, starting_after: String.t() | nil }
created- Only return files that were created during the given date interval.ending_before- A cursor for use in pagination.ending_beforeis an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting withobj_bar, your subsequent call can includeending_before=obj_barin order to fetch the previous page of the list. Max length: 5000.expand- Specifies which fields in the response should be expanded.limit- A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.purpose- Filter queries by the file purpose. If you don't provide a purpose, the queries return unfiltered files. Possible values:account_requirement,additional_verification,business_icon,business_logo,customer_signature,dispute_evidence,document_provider_identity_document,finance_report_run,financial_account_statement,identity_document,identity_document_downloadable,issuing_regulatory_reporting,pci_document,platform_terms_of_service,selfie,sigma_scheduled_query,tax_document_user_upload,terminal_android_apk,terminal_reader_splashscreen. Max length: 5000.starting_after- A cursor for use in pagination.starting_afteris an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending withobj_foo, your subsequent call can includestarting_after=obj_fooin order to fetch the next page of the list. Max length: 5000.