StripeElixir.Params.Forwarding.RequestListParams.Created
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Forwarding.RequestListParams.Created{ gt: integer() | nil, gte: integer() | nil, lt: integer() | nil, lte: integer() | nil }
gt- Return results where thecreatedfield is greater than this value.gte- Return results where thecreatedfield is greater than or equal to this value.lt- Return results where thecreatedfield is less than this value.lte- Return results where thecreatedfield is less than or equal to this value.