StripeElixir.Params.PaymentLinkCreateParams.LineItems
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.PaymentLinkCreateParams.LineItems{ adjustable_quantity: map() | nil, price: String.t() | nil, price_data: map() | nil, quantity: integer() | nil }
adjustable_quantity- When set, provides configuration for this item’s quantity to be adjusted by the customer during checkout.price- The ID of the Price or Plan object. One ofpriceorprice_datais required. Max length: 5000.price_data- Data used to generate a new Price object inline. One ofpriceorprice_datais required.quantity- The quantity of the line item being purchased.