StripeElixir.Params.Radar.ValueListItemCreateParams
(stripe_elixir v0.1.0)
Parameters for value list item create.
Summary
Types
@type t() :: %StripeElixir.Params.Radar.ValueListItemCreateParams{ expand: [String.t()] | nil, value: String.t(), value_list: String.t() }
expand- Specifies which fields in the response should be expanded.value- The value of the item (whose type must match the type of the parent value list). Max length: 800.value_list- The identifier of the value list which the created item will be added to. Max length: 5000.