Parameters for setup intent retrieve.
Summary
Types
@type t() :: %StripeElixir.Params.SetupIntentRetrieveParams{ client_secret: String.t() | nil, expand: [String.t()] | nil }
client_secret- The client secret of the SetupIntent. We require this string if you use a publishable key to retrieve the SetupIntent. Max length: 5000.expand- Specifies which fields in the response should be expanded.