Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.SourceCreateParams.Receiver{ refund_attributes_method: String.t() | nil }
refund_attributes_method- The method Stripe should use to request information needed to process a refund or mispayment. Eitheremail(an email is sent directly to the customer) ormanual(asource.refund_attributes_requiredevent is sent to your webhooks endpoint). Refer to each payment method's documentation to learn which refund attributes may be required. Possible values:email,manual,none. Max length: 5000.