StripeElixir.Params.Terminal.ReaderCollectInputsParams.Inputs
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Terminal.ReaderCollectInputsParams.Inputs{ custom_text: map() | nil, required: boolean() | nil, selection: map() | nil, toggles: [map()] | nil, type: String.t() | nil }
custom_text- Customize the text which will be displayed while collecting this inputrequired- Indicate that this input is required, disabling the skip buttonselection- Options for theselectioninputtoggles- List of toggles to be displayed and customization for the togglestype- The type of input to collect Possible values:email,numeric,phone,selection,signature,text.