StripeElixir.Params.TestHelpers.Issuing.AuthorizationFinalizeAmountParams
(stripe_elixir v0.1.0)
Parameters for authorization finalize amount.
Summary
Types
@type t() :: %StripeElixir.Params.TestHelpers.Issuing.AuthorizationFinalizeAmountParams{ expand: [String.t()] | nil, final_amount: integer(), fleet: map() | nil, fuel: map() | nil }
expand- Specifies which fields in the response should be expanded.final_amount- The final authorization amount that will be captured by the merchant. This amount is in the authorization currency and in the smallest currency unit.fleet- Fleet-specific information for authorizations using Fleet cards.fuel- Information about fuel that was purchased with this transaction.