StripeElixir.Params.Treasury.FinancialAccountUpdateParams.Features
(stripe_elixir v0.1.0)
Nested parameters.
Summary
Types
@type t() :: %StripeElixir.Params.Treasury.FinancialAccountUpdateParams.Features{ card_issuing: map() | nil, deposit_insurance: map() | nil, financial_addresses: map() | nil, inbound_transfers: map() | nil, intra_stripe_flows: map() | nil, outbound_payments: map() | nil, outbound_transfers: map() | nil }
card_issuing- Encodes the FinancialAccount's ability to be used with the Issuing product, including attaching cards to and drawing funds from the FinancialAccount.deposit_insurance- Represents whether this FinancialAccount is eligible for deposit insurance. Various factors determine the insurance amount.financial_addresses- Contains Features that add FinancialAddresses to the FinancialAccount.inbound_transfers- Contains settings related to adding funds to a FinancialAccount from another Account with the same owner.intra_stripe_flows- Represents the ability for the FinancialAccount to send money to, or receive money from other FinancialAccounts (for example, via OutboundPayment).outbound_payments- Includes Features related to initiating money movement out of the FinancialAccount to someone else's bucket of money.outbound_transfers- Contains a Feature and settings related to moving money out of the FinancialAccount into another Account with the same owner.