Parameters for webhook endpoint update.
Summary
Types
@type t() :: %StripeElixir.Params.WebhookEndpointUpdateParams{ description: map() | nil, disabled: boolean() | nil, enabled_events: [String.t()] | nil, expand: [String.t()] | nil, metadata: map() | nil, url: String.t() | nil }
description- An optional description of what the webhook is used for.disabled- Disable the webhook endpoint if set to true.enabled_events- The list of events to enable for this endpoint. You may specify['*']to enable all events, except those that require explicit selection.expand- Specifies which fields in the response should be expanded.metadata- Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value tometadata.url- The URL of the webhook endpoint.