ConnectCollectionTransfer
Summary
Types
@type t() :: %StripeElixir.Resources.ConnectCollectionTransfer{ amount: integer(), currency: String.t(), destination: String.t() | map(), id: String.t(), livemode: boolean(), object: String.t() }
amount- Amount transferred, in cents (or local equivalent).currency- Three-letter ISO currency code, in lowercase. Must be a supported currency. Format: ISO 4217 currency code.destination- ID of the account that funds are being collected for. Expandable.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:connect_collection_transfer.