PaymentMethodDomainResourcePaymentMethodDomain
A payment method domain represents a web domain that you have registered with Stripe. Stripe Elements use registered payment method domains to control where certain payment methods are shown.
Related guide: Payment method domains.
Summary
Types
@type t() :: %StripeElixir.Resources.PaymentMethodDomain{ amazon_pay: map(), apple_pay: map(), created: integer(), domain_name: String.t(), enabled: boolean(), google_pay: map(), id: String.t(), klarna: map(), link: map(), livemode: boolean(), object: String.t(), paypal: map() }
amazon_pay- Expandable.apple_pay- Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.domain_name- The domain name that this payment method domain object represents. Max length: 5000.enabled- Whether this payment method domain is enabled. If the domain is not enabled, payment methods that require a payment method domain will not appear in Elements.google_pay- Expandable.id- Unique identifier for the object. Max length: 5000.klarna- Expandable.link- Expandable.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:payment_method_domain.paypal- Expandable.