RadarEarlyFraudWarning
An early fraud warning indicates that the card issuer has notified us that a charge may be fraudulent.
Related guide: Early fraud warnings
Summary
Types
@type t() :: %StripeElixir.Resources.Radar.EarlyFraudWarning{ actionable: boolean(), charge: String.t() | map(), created: integer(), fraud_type: String.t(), id: String.t(), livemode: boolean(), object: String.t(), payment_intent: String.t() | map() | nil }
actionable- An EFW is actionable if it has not received a dispute and has not been fully refunded. You may wish to proactively refund a charge that receives an EFW, in order to avoid receiving a dispute later.charge- ID of the charge this early fraud warning is for, optionally expanded. Expandable.created- Time at which the object was created. Measured in seconds since the Unix epoch. Format: Unix timestamp.fraud_type- The type of fraud labelled by the issuer. One ofcard_never_received,fraudulent_card_application,made_with_counterfeit_card,made_with_lost_card,made_with_stolen_card,misc,unauthorized_use_of_card. Max length: 5000.id- Unique identifier for the object. Max length: 5000.livemode- Has the valuetrueif the object exists in live mode or the valuefalseif the object exists in test mode.object- String representing the object's type. Objects of the same type share the same value. Possible values:radar.early_fraud_warning.payment_intent- ID of the Payment Intent this early fraud warning is for, optionally expanded. Expandable.