ClimateRemovalsOrders
Orders represent your intent to purchase a particular Climate product. When you create an order, the payment is deducted from your merchant balance.
Summary
Functions
@spec cancel(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Cancel an order
Cancels a Climate order. You can cancel an order within 24 hours of creation. Stripe refunds the
reservation amount_subtotal, but not the amount_fees for user-triggered cancellations. Frontier
might cancel reservations if suppliers fail to deliver. If Frontier cancels the reservation, Stripe
provides 90 days advance notice and refunds the amount_total.
@spec create(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Create an order
Creates a Climate order object for a given Climate product. The order will be processed immediately after creation and payment will be deducted your Stripe balance.
@spec list(StripeElixir.Client.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
List orders
Lists all Climate order objects. The orders are returned sorted by creation date, with the most recently created orders appearing first.
@spec retrieve(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Retrieve an order
Retrieves the details of a Climate order object with the given ID.
@spec update(StripeElixir.Client.t(), String.t(), map(), keyword()) :: {:ok, term()} | {:error, StripeElixir.Error.t()}
Update an order
Updates the specified order by setting the values of the parameters passed.